@@ -26,29 +26,31 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "affichage.h"
-#include "utils_file_selection.h"
-#include "gsb_automem.h"
-#include "gsb_data_account.h"
-#include "gsb_file.h"
-#include "navigation.h"
-#include "fenetre_principale.h"
-#include "barre_outils.h"
 #include "accueil.h"
+#include "custom_list.h"
+#include "fenetre_principale.h"
+#include "gsb_automem.h"
+#include "gsb_color.h"
+#include "gsb_data_account.h"
+#include "gsb_dirs.h"
+#include "gsb_file.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_select_icon.h"
 #include "main.h"
-#include "traitement_variables.h"
-#include "utils_str.h"
-#include "utils.h"
+#include "navigation.h"
 #include "parametres.h"
-#include "transaction_list.h"
-#include "utils_font.h"
 #include "structures.h"
-#include "custom_list.h"
+#include "traitement_variables.h"
+#include "transaction_list.h"
+#include "utils.h"
 #include "utils_buttons.h"
+#include "utils_file_selection.h"
+#include "utils_font.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -61,6 +63,8 @@ static gboolean change_grisbi_title_type ( GtkRadioButton *button, GtkWidget *en
 static void change_logo_accueil ( GtkWidget * file_selector );
 static gboolean change_toolbar_display_mode ( GtkRadioButton *button );
 static gboolean modification_logo_accueil ( );
+static gboolean preferences_active_mouse_scrolling_left_pane ( GtkWidget *toggle_button,
+                        gpointer null );
 static gboolean preferences_switch_headings_bar ( GtkWidget *toggle_button,
                         gpointer null );
 static gboolean preferences_view_color_changed ( GtkWidget *color_button,
@@ -80,36 +84,10 @@ static void update_fonte_listes ( gchar *fontname,
 /*START_EXTERN*/
 extern gchar *adresse_commune;
 extern gchar *adresse_secondaire;
-extern GdkColor archive_background_color;
-extern GdkColor calendar_entry_color;
-extern GdkColor couleur_bet_division;
-extern GdkColor couleur_bet_future;
-extern GdkColor couleur_bet_solde;
-extern GdkColor couleur_bet_transfert;
-extern GdkColor couleur_fond[2];
-extern GdkColor couleur_grise;
-extern GdkColor couleur_jour;
-extern GdkColor couleur_selection;
-extern GdkColor default_archive_background_color;
-extern GdkColor default_calendar_entry_color;
-extern GdkColor default_couleur_bet_division;
-extern GdkColor default_couleur_bet_future;
-extern GdkColor default_couleur_bet_solde;
-extern GdkColor default_couleur_bet_transfert;
-extern GdkColor default_couleur_fond[2];
-extern GdkColor default_couleur_grise;
-extern GdkColor default_couleur_jour;
-extern GdkColor default_couleur_selection;
-extern GdkColor default_split_background;
-extern GdkColor default_text_color[2];
 extern GtkWidget *fenetre_preferences;
 extern GtkWidget *hbox_title;
-extern GtkWidget *label_titre_fichier;
 extern GtkWidget *logo_accueil;
-extern GdkColor split_background;
-extern GdkColor text_color[2];
 extern gchar *titre_fichier;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -203,7 +181,7 @@ GtkWidget * onglet_display_fonts ( void )
     hbox = gtk_hbox_new ( FALSE, 10 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
-    check_button = gtk_check_button_new_with_label ( 
+    check_button = gtk_check_button_new_with_label (
                         _("Use a custom font for the transactions: "));
     gtk_box_pack_start ( GTK_BOX ( hbox ), check_button, FALSE, FALSE, 0 );
     gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( check_button ),
@@ -237,7 +215,7 @@ GtkWidget * onglet_display_fonts ( void )
     hbox = gtk_hbox_new ( FALSE, 10 );
     gtk_box_pack_start ( GTK_BOX ( vbox ), hbox, FALSE, FALSE, 10 );
 
-    color_combobox = preferences_view_create_color_combobox ();
+    color_combobox = gsb_color_create_color_combobox ( );
     gtk_box_pack_start ( GTK_BOX (hbox),
 			 color_combobox,
 			 FALSE, FALSE, 0);
@@ -280,7 +258,7 @@ gboolean change_choix_utilise_logo ( GtkWidget *check_button,
                         GtkWidget *hbox )
 {
 
-    etat.utilise_logo = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON 
+    etat.utilise_logo = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON
                             ( check_button ));
     gtk_widget_set_sensitive ( hbox, etat.utilise_logo );
 
@@ -320,8 +298,7 @@ gboolean change_choix_utilise_logo ( GtkWidget *check_button,
         etat.is_pixmaps_dir = 0;
     }
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return ( FALSE );
 }
@@ -397,37 +374,37 @@ GtkWidget *onglet_display_addresses ( void )
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0);
 
-    radiogroup = gtk_radio_button_new_with_label ( NULL, _("Accounts file title") );
+    radiogroup = gtk_radio_button_new_with_label ( NULL, _("Accounting entity") );
     g_object_set_data ( G_OBJECT ( radiogroup ), "display", GINT_TO_POINTER ( GSB_ACCOUNTS_TITLE ) );
     if ( conf.display_grisbi_title == GSB_ACCOUNTS_TITLE )
         gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radiogroup ), TRUE );
-    g_signal_connect ( G_OBJECT ( radiogroup ), 
+    g_signal_connect ( G_OBJECT ( radiogroup ),
                         "toggled",
-                        G_CALLBACK ( change_grisbi_title_type ), 
+                        G_CALLBACK ( change_grisbi_title_type ),
                         entry );
     gtk_box_pack_start ( GTK_BOX( hbox ), radiogroup, FALSE, FALSE, 0 );
 
-    radio = gtk_radio_button_new_with_label_from_widget ( 
+    radio = gtk_radio_button_new_with_label_from_widget (
                         GTK_RADIO_BUTTON ( radiogroup ),
                         _("Account owner name") );
     g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_ACCOUNT_HOLDER ) );
     if ( conf.display_grisbi_title == GSB_ACCOUNT_HOLDER )
             gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
-    g_signal_connect ( G_OBJECT ( radio ), 
+    g_signal_connect ( G_OBJECT ( radio ),
                     "toggled",
-                    G_CALLBACK ( change_grisbi_title_type ), 
+                    G_CALLBACK ( change_grisbi_title_type ),
                     entry );
     gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
 
-    radio = gtk_radio_button_new_with_label_from_widget ( 
+    radio = gtk_radio_button_new_with_label_from_widget (
                         GTK_RADIO_BUTTON ( radiogroup ),
                         _("Filename") );
     g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_ACCOUNTS_FILE ) );
     if ( conf.display_grisbi_title == GSB_ACCOUNTS_FILE )
         gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
-    g_signal_connect ( G_OBJECT ( radio ), 
+    g_signal_connect ( G_OBJECT ( radio ),
                         "toggled",
-                        G_CALLBACK ( change_grisbi_title_type ), 
+                        G_CALLBACK ( change_grisbi_title_type ),
                         entry );
     gtk_box_pack_start ( GTK_BOX( hbox ), radio, FALSE, FALSE, 0 );
 
@@ -435,7 +412,7 @@ GtkWidget *onglet_display_addresses ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
 			 FALSE, FALSE, 0);
 
-    label = gtk_label_new ( _("Accounts file title: ") );
+    label = gtk_label_new ( _("Name of accounting entity: ") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0);
 
@@ -530,7 +507,7 @@ void change_logo_accueil ( GtkWidget * file_selector )
             }
             else
             {
-                if ( g_strcmp0 ( g_path_get_dirname ( chemin_logo ), GRISBI_PIXMAPS_DIR ) == 0 )
+                if ( g_strcmp0 ( g_path_get_dirname ( chemin_logo ), gsb_dirs_get_pixmaps_dir ( ) ) == 0 )
                 {
                     gchar *name_logo;
 
@@ -551,19 +528,19 @@ void change_logo_accueil ( GtkWidget * file_selector )
                 }
 
                 gsb_select_icon_set_logo_pixbuf ( pixbuf );
-                preview = gtk_image_new_from_pixbuf ( 
-                        gdk_pixbuf_scale_simple ( 
+                preview = gtk_image_new_from_pixbuf (
+                        gdk_pixbuf_scale_simple (
                         pixbuf, 48, 48, GDK_INTERP_BILINEAR ) );
-                
+
                 /* Update homepage logo */
                 gtk_widget_destroy ( logo_accueil );
-                
-                logo_accueil =  gtk_image_new_from_pixbuf ( 
+
+                logo_accueil =  gtk_image_new_from_pixbuf (
                                     gsb_select_icon_get_logo_pixbuf ( ) );
                 gtk_box_pack_start ( GTK_BOX ( hbox_title ), logo_accueil, FALSE, FALSE, 0 );
                 gtk_widget_show ( logo_accueil );
                 /* modify the icon of grisbi (set in the panel of gnome or other) */
-                gtk_window_set_default_icon ( 
+                gtk_window_set_default_icon (
                             gsb_select_icon_get_logo_pixbuf ( ) );
             }
 
@@ -571,10 +548,9 @@ void change_logo_accueil ( GtkWidget * file_selector )
         }
         gtk_widget_show ( preview );
         gtk_container_add ( GTK_CONTAINER ( logo_button ), preview );
-        
+
         /* Mark file as modified */
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 }
 /* **************************************************************************************************************************** */
@@ -594,11 +570,11 @@ gboolean modification_logo_accueil ( )
 
     if ( etat.is_pixmaps_dir )
         gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER (
-                        file_selector ), GRISBI_PIXMAPS_DIR );
+                        file_selector ), gsb_dirs_get_pixmaps_dir ( ) );
     else
         gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER (
                         file_selector ), gsb_file_get_last_path () );
-        
+
     gtk_window_set_position ( GTK_WINDOW ( file_selector ), GTK_WIN_POS_CENTER_ON_PARENT );
 
     /* create the preview */
@@ -644,7 +620,7 @@ static gboolean preferences_view_update_preview_logo ( GtkFileChooser *file_choo
   if (!filename)
       return FALSE;
 
-  pixbuf = gdk_pixbuf_new_from_file_at_size ( filename, 
+  pixbuf = gdk_pixbuf_new_from_file_at_size ( filename,
                         LOGO_WIDTH, LOGO_HEIGHT, NULL );
   have_preview = ( pixbuf != NULL );
   g_free (filename);
@@ -679,8 +655,7 @@ gboolean update_homepage_title (GtkEntry *entry, gchar *value,
     gsb_main_set_grisbi_title ( -1 );
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -697,12 +672,17 @@ gboolean update_homepage_title (GtkEntry *entry, gchar *value,
  */
 gboolean change_toolbar_display_mode ( GtkRadioButton *button )
 {
-    if ( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(button)) )
-    {
-	etat.display_toolbar = GPOINTER_TO_INT (g_object_get_data ( G_OBJECT(button), "display" ));
-    }
+    /* Do not execute this callback twice,
+     * as it is triggered for both unselected button and newly selected one.
+     * We keep the call for the newly selected radio button */
+    if ( !gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( button ) ) )
+        return FALSE;
 
-    gsb_gui_update_transaction_toolbar ();
+    /* save the new parameter */
+    conf.display_toolbar = GPOINTER_TO_INT (g_object_get_data ( G_OBJECT(button), "display" ));
+
+    /* update toolbars */
+    gsb_gui_update_all_toolbars ( );
 
     return FALSE;
 }
@@ -717,60 +697,81 @@ gboolean change_toolbar_display_mode ( GtkRadioButton *button )
  */
 GtkWidget *tab_display_toolbar ( void )
 {
-    GtkWidget * vbox_pref, * paddingbox, * radio, * radiogroup;
+    GtkWidget *vbox_pref;
+    GtkWidget *paddingbox;
+    GtkWidget *radio;
+    GtkWidget *radiogroup;
+    GtkWidget *vbox;
+    GtkWidget *button;
 
-    vbox_pref = new_vbox_with_title_and_icon ( _("Toolbars"), "toolbar.png" );
+    vbox_pref = gtk_vbox_new ( FALSE, 10 );
 
-    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE,
-					     _("Display toolbar buttons as") );
+    /* Headings bar */
+    vbox = new_vbox_with_title_and_icon ( _("Headings bar"), "organization.png" );
+    gtk_box_pack_start ( GTK_BOX ( vbox_pref ), vbox, FALSE, FALSE, 0 );
+
+    button = gsb_automem_checkbutton_new ( _("Display headings bar"),
+                        &(conf.show_headings_bar),
+                        G_CALLBACK ( preferences_switch_headings_bar ),
+                        NULL );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 5 );
+
+    /* Navigation pane */
+    vbox = new_vbox_with_title_and_icon ( _("Navigation pane"), "organization.png" );
+    gtk_box_pack_start ( GTK_BOX ( vbox_pref ), vbox, FALSE, FALSE, 0 );
+
+    button = gsb_automem_checkbutton_new (_("Add mouse scrolling support on the navigation pane"),
+                        &conf.active_scrolling_left_pane,
+                        G_CALLBACK ( preferences_active_mouse_scrolling_left_pane ),
+                        NULL );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 5 );
+
+    /* Toolbar */
+    vbox = new_vbox_with_title_and_icon ( _("Toolbars"), "toolbar.png" );
+    gtk_box_pack_start ( GTK_BOX ( vbox_pref ), vbox, FALSE, FALSE, 0 );
+
+    paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Display toolbar buttons as") );
 
     radiogroup = radio = gtk_radio_button_new_with_label ( NULL, _("Text") );
-    g_object_set_data ( G_OBJECT(radio), "display", GINT_TO_POINTER(GSB_BUTTON_TEXT) );
-    gtk_box_pack_start ( GTK_BOX(paddingbox), radio, FALSE, FALSE, 0 );
-    if ( etat.display_toolbar == GSB_BUTTON_TEXT )
-	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (radio), TRUE );
-    g_signal_connect ( G_OBJECT(radio), "toggled",
-		       G_CALLBACK(change_toolbar_display_mode), NULL );
+    g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_BUTTON_TEXT ) );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), radio, FALSE, FALSE, 0 );
+    if ( conf.display_toolbar == GSB_BUTTON_TEXT )
+        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
 
-    radio = gtk_radio_button_new_with_label_from_widget ( GTK_RADIO_BUTTON(radiogroup),
-							  _("Icons") );
-    g_object_set_data ( G_OBJECT(radio), "display", GINT_TO_POINTER(GSB_BUTTON_ICON) );
-    gtk_box_pack_start ( GTK_BOX(paddingbox), radio, FALSE, FALSE, 0 );
-    if ( etat.display_toolbar == GSB_BUTTON_ICON )
-	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (radio), TRUE );
-    g_signal_connect ( G_OBJECT(radio), "toggled",
-		       G_CALLBACK(change_toolbar_display_mode), NULL );
+    g_signal_connect ( G_OBJECT ( radio ),
+                        "toggled",
+                        G_CALLBACK ( change_toolbar_display_mode ),
+                        NULL );
 
-    radio = gtk_radio_button_new_with_label_from_widget ( GTK_RADIO_BUTTON(radiogroup),
-							  _("Both") );
-    g_object_set_data ( G_OBJECT(radio), "display", GINT_TO_POINTER(GSB_BUTTON_BOTH) );
-    gtk_box_pack_start ( GTK_BOX(paddingbox), radio, FALSE, FALSE, 0 );
-    if ( etat.display_toolbar == GSB_BUTTON_BOTH )
-	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (radio), TRUE );
-    g_signal_connect ( G_OBJECT(radio), "toggled",
-		       G_CALLBACK(change_toolbar_display_mode), NULL );
+    radio = gtk_radio_button_new_with_label_from_widget ( GTK_RADIO_BUTTON ( radiogroup ), _("Icons") );
+    g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_BUTTON_ICON ) );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), radio, FALSE, FALSE, 0 );
+    if ( conf.display_toolbar == GSB_BUTTON_ICON )
+        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
+
+    g_signal_connect ( G_OBJECT ( radio ),
+                        "toggled",
+                        G_CALLBACK ( change_toolbar_display_mode ),
+                        NULL );
+
+    radio = gtk_radio_button_new_with_label_from_widget ( GTK_RADIO_BUTTON ( radiogroup ), _("Both") );
+    g_object_set_data ( G_OBJECT ( radio ), "display", GINT_TO_POINTER ( GSB_BUTTON_BOTH ) );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), radio, FALSE, FALSE, 0 );
+    if ( conf.display_toolbar == GSB_BUTTON_BOTH )
+        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( radio ), TRUE );
+
+    g_signal_connect ( G_OBJECT ( radio ),
+                        "toggled",
+                        G_CALLBACK ( change_toolbar_display_mode ),
+                        NULL );
 
     gtk_widget_show_all ( vbox_pref );
 
     if ( !gsb_data_account_get_accounts_amount () )
-	gtk_widget_set_sensitive ( vbox_pref, FALSE );
-
-    /** TODO: really add option to hide toolbar?  This could save
-     * space, but if so, we should add all equivalents to menus.  */
-/*     gtk_box_pack_start ( GTK_BOX ( vbox_pref ),  */
-/* 			 gsb_automem_checkbutton_new ( _("Display toolbar"), */
-/* 						   &(etat.show_toolbar), */
-/* 						   NULL ), */
-/* 			 FALSE, FALSE, 0 ); */
-
-    gtk_box_pack_start ( GTK_BOX ( vbox_pref ),
-			 gsb_automem_checkbutton_new ( _("Display headings bar"),
-						       &(etat.show_headings_bar),
-						       G_CALLBACK (preferences_switch_headings_bar), NULL ),
-			 FALSE, FALSE, 0 );
+        gtk_widget_set_sensitive ( vbox_pref, FALSE );
 
+    /* return */
     return ( vbox_pref );
-
 }
 
 
@@ -791,77 +792,30 @@ gboolean preferences_switch_headings_bar ( GtkWidget *toggle_button,
 }
 
 
-
 /**
- * create a list of customable colors
+ * called when switch the active mouse scrolling option
+ * to set unset the scrolling
  *
- * \param
+ * \param toggle button
+ * \param null
  *
- * \return a GtkComboBox
+ * \return FALSE
  * */
-static GtkWidget *preferences_view_create_color_combobox (void)
+gboolean preferences_active_mouse_scrolling_left_pane ( GtkWidget *toggle_button,
+                        gpointer null )
 {
-    GtkWidget *combobox;
-    GtkListStore *store;
-    gint i;
-    GtkCellRenderer *renderer;
+    if ( conf.active_scrolling_left_pane )
+        g_signal_handlers_unblock_by_func ( gsb_gui_navigation_get_tree_view ( ),
+                        G_CALLBACK ( gsb_gui_navigation_check_scroll ),
+                        NULL );
+    else
+        g_signal_handlers_block_by_func ( gsb_gui_navigation_get_tree_view ( ),
+                        G_CALLBACK ( gsb_gui_navigation_check_scroll ),
+                        NULL );
 
-    struct config_color {
-    gchar *name;
-    GdkColor *color;
-    GdkColor *default_color;
-
-    } config_colors[] = {
-    { N_("Transaction list background 1"), &couleur_fond[0], &default_couleur_fond[0]},
-    { N_("Transaction list background 2"), &couleur_fond[1], &default_couleur_fond[1]},
-    { N_("Color for the operation that gives the balance today"), &couleur_jour, &default_couleur_jour},
-    { N_("Color of transaction's text"), &text_color[0], &default_text_color[0]},
-    { N_("Text of unfinished split transaction"), &text_color[1], &default_text_color[1]},
-    { N_("Children of split transaction"), &split_background, &default_split_background},
-    { N_("Selection color"), &couleur_selection, &default_couleur_selection},
-    { N_("Background of non selectable scheduled transactions"), &couleur_grise, &default_couleur_grise},
-    { N_("Archive color"), &archive_background_color, &default_archive_background_color},
-    { N_("Background of invalid date entry"), &calendar_entry_color, &default_calendar_entry_color },
-    { N_("Background of bet division"), &couleur_bet_division, &default_couleur_bet_division },
-    { N_("Background of bet futur"), &couleur_bet_future, &default_couleur_bet_future },
-    { N_("Background of bet solde"), &couleur_bet_solde, &default_couleur_bet_solde },
-    { N_("Background of bet transfer"), &couleur_bet_transfert, &default_couleur_bet_transfert },
-    { NULL, 0, 0},
-    };
-
-    /* the store contains the name of the color we can modify and
-     * a pointer to the corresponding variable */
-    store = gtk_list_store_new ( 3,
-                        G_TYPE_STRING,
-                        G_TYPE_POINTER,
-                        G_TYPE_POINTER );
-    /* fill the store */
-    for ( i = 0 ; config_colors[i].name != NULL ; i++ )
-    {
-    GtkTreeIter iter;
-
-    gtk_list_store_append ( GTK_LIST_STORE (store),
-                        &iter );
-    gtk_list_store_set ( GTK_LIST_STORE (store),
-                        &iter,
-                        0, _(config_colors[i].name),
-                        1, config_colors[i].color,
-                        2, config_colors[i].default_color,
-                        -1);
-    }
-
-    /* create the combobox */
-    combobox = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
-
-    renderer = gtk_cell_renderer_text_new ();
-    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combobox), renderer, TRUE);
-    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combobox), renderer,
-                        "text", 0,
-                        NULL);
-    return combobox;
+    return FALSE;
 }
 
-
 /**
  * called when the color combobox changed,
  * update the GtkColorButton with the color of the combobox
@@ -995,7 +949,7 @@ gboolean change_grisbi_title_type ( GtkRadioButton *button, GtkWidget *entry )
 {
     if ( gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( button ) ) )
     {
-        conf.display_grisbi_title = GPOINTER_TO_INT ( g_object_get_data 
+        conf.display_grisbi_title = GPOINTER_TO_INT ( g_object_get_data
                         ( G_OBJECT ( button ), "display" ) );
     }
 
@@ -1025,6 +979,7 @@ gboolean change_grisbi_title_type ( GtkRadioButton *button, GtkWidget *entry )
     return FALSE;
 }
 
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
