@@ -1,6 +1,8 @@
 #ifndef _AFFICHAGE_LISTE_H
 #define _AFFICHAGE_LISTE_H (1)
 
+#include <gtk/gtk.h>
+
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
 
@@ -8,6 +10,7 @@
 /* START_DECLARATION */
 gboolean display_mode_check_line ( gint line_in_transaction,
                         gint visibles_lines );
+GtkWidget *onglet_affichage_liste ( void );
 GtkWidget *onglet_affichage_operations ( void );
 GtkWidget *onglet_diverse_form_and_lists ( void );
 GtkWidget *onglet_form_completion ( void );
