@@ -24,6 +24,7 @@
 #endif
 
 #include "include.h"
+#include <math.h>
 
 /*START_INCLUDE*/
 #include "bet_data_finance.h"
@@ -41,11 +42,8 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gint no_devise_totaux_categ;
 /*END_EXTERN*/
 
-gdouble bet_taux_step[] = { 0, 0.1, 0.01, 0.001, 0.0001 };
-
 /**
  * retourne l'échéance hors frais
  *
@@ -59,12 +57,14 @@ gdouble bet_data_finance_get_echeance ( gdouble capital,
     gdouble coeff;
     gdouble number;
 
-    coeff = pow ( ( 1 + taux_periodique ), nbre_echeances );
-
-    if ( taux_periodique == 0 )
+    if ( taux_periodique < GSB_EPSILON )
         number = capital / nbre_echeances;
     else
+    {
+        coeff = pow ( ( 1 + taux_periodique ), nbre_echeances );
         number = ( capital * taux_periodique * coeff ) / ( coeff - 1 );
+    }
+
     number = bet_data_finance_troncate_number ( number, 2 );
 
     return number;
@@ -84,6 +84,9 @@ gdouble bet_data_finance_get_taux_periodique ( gdouble taux, gint type_taux )
 {
     gdouble taux_periodique;
 
+    if ( taux < GSB_EPSILON )
+        return 0.;
+
     if ( type_taux )
         taux_periodique = ( taux / 100 ) / 12;
     else
@@ -199,7 +202,7 @@ GDate *bet_data_finance_get_date_last_installment_paid ( GDate *date_depart )
 
     if ( g_date_get_day ( date_jour ) > jour )
         g_date_add_months  ( date_jour, 1 );
-    
+
     g_date_set_day ( date_jour, jour );
 
     return date_jour;
@@ -258,12 +261,9 @@ gdouble bet_data_finance_get_total_cost ( struct_echeance *s_echeance )
  * */
 void bet_data_finance_structure_amortissement_free ( struct_amortissement *s_amortissement )
 {
-    if ( s_amortissement -> str_date )
-        g_free ( s_amortissement -> str_date );
-    if ( s_amortissement -> str_echeance )
-        g_free ( s_amortissement -> str_echeance );
-    if ( s_amortissement -> str_frais )
-        g_free ( s_amortissement -> str_frais );
+    g_free ( s_amortissement -> str_date );
+    g_free ( s_amortissement -> str_echeance );
+    g_free ( s_amortissement -> str_frais );
 
     g_free ( s_amortissement );
 }
@@ -298,7 +298,7 @@ struct_amortissement *bet_data_finance_structure_amortissement_init ( void )
 void bet_data_finance_data_simulator_init ( void )
 {
     etat.bet_capital = 1000.0;
-    etat.bet_currency = no_devise_totaux_categ;
+    etat.bet_currency = etat.no_devise_totaux_categ;
     etat.bet_taux_annuel = 4.0;
     etat.bet_index_duree = 0;
     etat.bet_frais = 0;
@@ -307,13 +307,15 @@ void bet_data_finance_data_simulator_init ( void )
 
 
 /**
- *
+ * FIXME: nbre_digits is never used... this needs to be checked...
  *
  *
  *
  * */
 gdouble bet_data_finance_get_bet_taux_step ( gint nbre_digits )
 {
+    const gdouble bet_taux_step[] = { 0, 0.1, 0.01, 0.001, 0.0001 };
+
     return bet_taux_step[BET_TAUX_DIGITS];
 }
 
