@@ -24,6 +24,9 @@
 #endif
 
 #include "include.h"
+#include <gdk/gdkkeysyms.h>
+#include <glib/gprintf.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "bet_finance_ui.h"
@@ -32,9 +35,11 @@
 #include "export_csv.h"
 #include "fenetre_principale.h"
 #include "gsb_automem.h"
+#include "gsb_color.h"
 #include "gsb_combo_box.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
+#include "gsb_dirs.h"
 #include "gsb_file.h"
 #include "gsb_form_widget.h"
 #include "gsb_real.h"
@@ -46,6 +51,7 @@
 #include "utils.h"
 #include "utils_dates.h"
 #include "utils_file_selection.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -60,7 +66,6 @@ static gboolean bet_finance_capital_entry_key_press_event ( GtkWidget *widget,
                         GdkEventKey *ev,
                         GtkWidget *page );
 static GtkWidget *bet_finance_create_amortization_page ( void );
-static GtkWidget *bet_finance_create_amortization_toolbar ( GtkWidget *parent, GtkWidget *tree_view );
 static GtkWidget *bet_finance_create_amortization_tree_view ( GtkWidget *container, gint origin );
 static GtkWidget *bet_finance_create_data_tree_view ( GtkWidget *container );
 static GtkWidget *bet_finance_create_duration_widget ( GtkWidget *parent );
@@ -83,26 +88,29 @@ static void bet_finance_fill_amortization_ligne ( GtkTreeModel *model,
 static void bet_finance_fill_data_ligne ( GtkTreeModel *model,
                         struct_echeance *s_echeance,
                         const gchar *unit );
-static gboolean bet_finance_list_set_background_color ( GtkWidget *tree_view, gint color_column );
 static void bet_finance_spin_button_fees_changed ( GtkSpinButton *spinbutton, GtkWidget *page );
 static void bet_finance_spin_button_taux_changed ( GtkSpinButton *spinbutton, GtkWidget *page );
 static void bet_finance_switch_amortization_initial_date ( GtkWidget *button, GtkWidget *tree_view );
 static void bet_finance_ui_export_tab ( GtkWidget *menu_item, GtkTreeView *tree_view );
 static void bet_finance_ui_struct_amortization_free ( struct_amortissement *s_amortissement );
 static void bet_finance_type_taux_changed ( GtkWidget *togglebutton, GdkEventButton *event, GtkWidget *widget );
+static void bet_finance_update_account_toolbar ( void );
+static void bet_finance_update_amortization_toolbar ( void );
+static void bet_finance_update_simulator_toolbar ( void );
 /*END_STATIC*/
 
 /*START_EXTERN*/
 extern GtkWidget *account_page;
-extern GdkColor calendar_entry_color;
-extern GdkColor couleur_fond[2];
-extern GdkColor couleur_selection;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 /* notebook pour la simulation de crédits */
 static GtkWidget *finance_notebook;
 
+/* toolbars */
+static GtkWidget *account_toolbar;
+static GtkWidget *amortization_toolbar;
+static GtkWidget *simulator_toolbar;
+
 enum bet_finance_data_columns
 {
     BET_FINANCE_DURATION_COLUMN,
@@ -163,7 +171,7 @@ GtkWidget *bet_finance_create_page ( void )
     /* create the array page */
     page = bet_finance_create_amortization_page ( );
     gtk_notebook_append_page ( GTK_NOTEBOOK ( finance_notebook ), page, NULL );
-    
+
     return finance_notebook;
 }
 
@@ -200,7 +208,6 @@ GtkWidget *bet_finance_create_simulator_page ( void )
     GtkWidget *label;
     GtkWidget *spin_button = NULL;
     GtkWidget *tree_view;
-    GtkWidget *toolbar;
     gchar *str_capital;
 
     devel_debug (NULL);
@@ -210,7 +217,7 @@ GtkWidget *bet_finance_create_simulator_page ( void )
     /* titre de la page */
     align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
     gtk_box_pack_start ( GTK_BOX ( page ), align, FALSE, FALSE, 5);
- 
+
     label_title = gtk_label_new ( _("Credits simulator") );
     gtk_container_add ( GTK_CONTAINER ( align ), label_title );
 
@@ -227,7 +234,7 @@ GtkWidget *bet_finance_create_simulator_page ( void )
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 5 );
 
-    str_capital = gsb_real_get_string_with_currency ( gsb_real_double_to_real (
+    str_capital = utils_real_get_string_with_currency ( gsb_real_double_to_real (
                         etat.bet_capital ),
                         etat.bet_currency,
                         FALSE );
@@ -299,13 +306,15 @@ GtkWidget *bet_finance_create_simulator_page ( void )
     g_object_set_data ( G_OBJECT ( tree_view ), "label_title", label_title );
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( tree_view, GTK_STATE_SELECTED, &couleur_selection );
-    gtk_widget_modify_base ( tree_view, GTK_STATE_ACTIVE, &couleur_selection );
+    utils_set_tree_view_selection_and_text_color ( tree_view );
 
     /* on y ajoute la barre d'outils */
-    toolbar = bet_finance_create_simulator_toolbar ( page, tree_view, TRUE, FALSE );
-    gtk_box_pack_start ( GTK_BOX ( page ), toolbar, FALSE, FALSE, 0 );
-    gtk_box_reorder_child ( GTK_BOX ( page ), toolbar, 0 );
+    simulator_toolbar = gtk_handle_box_new ( );
+    g_object_set_data ( G_OBJECT ( simulator_toolbar ), "tree_view", tree_view );
+    g_object_set_data ( G_OBJECT ( simulator_toolbar ), "page", page );
+    gtk_widget_show ( simulator_toolbar );
+    gtk_box_pack_start ( GTK_BOX ( page ), simulator_toolbar, FALSE, FALSE, 0 );
+    gtk_box_reorder_child ( GTK_BOX ( page ), simulator_toolbar, 0 );
 
     gtk_widget_show_all ( page );
 
@@ -331,7 +340,7 @@ GtkWidget *bet_finance_create_duration_widget ( GtkWidget *parent )
     combobox = gsb_combo_box_new_with_index ( text_duration,
                         G_CALLBACK ( bet_finance_duration_button_changed ),
                         parent );
-    
+
     g_signal_handlers_block_by_func ( G_OBJECT ( combobox ),
                         G_CALLBACK ( bet_finance_duration_button_changed ),
                         parent );
@@ -383,7 +392,7 @@ GtkWidget *bet_finance_create_saisie_widget ( GtkWidget *parent )
                         "value-changed",
                         G_CALLBACK ( bet_finance_spin_button_fees_changed ),
                         parent );
-    
+
     tmp_str = g_strconcat (_("%"), _(" of borrowed capital"), NULL );
     label = gtk_label_new ( tmp_str );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
@@ -761,23 +770,15 @@ void bet_finance_calculer_clicked ( GtkButton *button, GtkWidget *widget )
         }
     }
 
-    bet_finance_list_set_background_color ( tree_view, BET_FINANCE_BACKGROUND_COLOR );
+    utils_set_tree_view_background_color ( tree_view, BET_FINANCE_BACKGROUND_COLOR );
     path = gtk_tree_path_new_first ( );
     gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( tree_view ), path, NULL, TRUE, 0.0, 0.0 );
     gtk_tree_selection_select_path ( gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) ), path );
-    
-    bouton = g_object_get_data ( G_OBJECT ( widget ), "amortization_button" );
-    gtk_widget_set_sensitive ( bouton, TRUE );
-    bouton = g_object_get_data ( G_OBJECT ( widget ), "print_button" );
-    gtk_widget_set_sensitive ( bouton, TRUE );
-    bouton = g_object_get_data ( G_OBJECT ( widget ), "export_button" );
-    gtk_widget_set_sensitive ( bouton, TRUE );
 
     gtk_tree_path_free ( path );
     g_free ( s_echeance );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 }
 
 
@@ -809,7 +810,7 @@ gdouble bet_finance_get_number_from_string ( GtkWidget *parent, const gchar *nam
         {
             number = utils_str_strtod ( entry, NULL );
 
-            tmp_str = gsb_real_get_string_with_currency (
+            tmp_str = utils_real_get_string_with_currency (
                                 gsb_real_double_to_real ( number ),
                                 etat.bet_currency,
                                 FALSE );
@@ -840,31 +841,34 @@ void bet_finance_fill_data_ligne ( GtkTreeModel *model,
     gchar *str_echeance;
     gchar *str_totale;
     gchar *str_total_cost;
+    gchar *str_format;
     gchar buffer[256];
     gint nbre_char;
 
     str_duree = g_strconcat ( utils_str_itoa ( s_echeance -> duree ), " ", unit, " ", NULL );
 
-    str_capital = gsb_real_get_string_with_currency (
+    str_capital = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_echeance -> capital ),
                         s_echeance -> devise, TRUE );
 
-    nbre_char = g_sprintf ( buffer, "%.2f", s_echeance -> taux );
+    str_format = g_strconcat ("%.", utils_str_itoa ( BET_TAUX_DIGITS ), "f", NULL );
+    nbre_char = g_sprintf ( buffer, str_format, s_echeance -> taux );
     str_taux =  g_strndup ( buffer, nbre_char + 1 );
+    g_free ( str_format );
 
-    str_frais = gsb_real_get_string_with_currency (
+    str_frais = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_echeance -> frais ),
                         s_echeance -> devise, TRUE );
 
-    str_echeance = gsb_real_get_string_with_currency (
+    str_echeance = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_echeance -> echeance ),
                         s_echeance -> devise, TRUE );
 
-    str_totale = gsb_real_get_string_with_currency (
+    str_totale = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_echeance -> total_echeance ),
                         s_echeance -> devise, TRUE );
 
-    str_total_cost = gsb_real_get_string_with_currency (
+    str_total_cost = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_echeance -> total_cost ),
                         s_echeance -> devise, TRUE );
 
@@ -897,43 +901,6 @@ void bet_finance_fill_data_ligne ( GtkTreeModel *model,
 }
 
 
-/**
- * set the background colors of the list
- *
- * \param tree_view
- *
- * \return FALSE
- * */
-gboolean bet_finance_list_set_background_color ( GtkWidget *tree_view, gint color_column )
-{
-    GtkTreeModel *model;
-    GtkTreeIter iter;
-
-    if ( !tree_view )
-        return FALSE;
-
-    model = gtk_tree_view_get_model ( GTK_TREE_VIEW ( tree_view ));
-
-    if ( gtk_tree_model_get_iter_first ( GTK_TREE_MODEL ( model ), &iter ) )
-    {
-        gint current_color = 0;
-
-        do
-        {
-            gtk_tree_store_set ( GTK_TREE_STORE ( model ),
-                        &iter,
-                        color_column, &couleur_fond[current_color],
-                        -1 );
-
-            current_color = !current_color;
-        }
-        while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &iter ) );
-    }
-
-    return FALSE;
-}
-
-
 /**
  *
  *
@@ -1013,7 +980,7 @@ void bet_finance_data_list_context_menu ( GtkWidget *tree_view, gint page_num )
 
     origin = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( tree_view ), "origin" ) );
 
-    tmp_str = g_build_filename ( GRISBI_PIXMAPS_DIR, "ac_liability_16.png", NULL);
+    tmp_str = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), "ac_liability_16.png", NULL);
     image = gtk_image_new_from_file ( tmp_str );
     gtk_image_set_pixel_size ( GTK_IMAGE ( image ), GTK_ICON_SIZE_MENU );
     g_free ( tmp_str );
@@ -1036,7 +1003,7 @@ void bet_finance_data_list_context_menu ( GtkWidget *tree_view, gint page_num )
                         G_CALLBACK ( bet_finance_switch_simulator_page ),
                         NULL );
         }
-        
+
     }
     else
     {
@@ -1103,7 +1070,6 @@ GtkWidget *bet_finance_create_amortization_page ( void )
     GtkWidget *label_title;
     GtkWidget *label;
     GtkWidget *tree_view;
-    GtkWidget *toolbar;
 
     devel_debug (NULL);
 
@@ -1112,7 +1078,7 @@ GtkWidget *bet_finance_create_amortization_page ( void )
     /* titre de la page */
     align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
     gtk_box_pack_start ( GTK_BOX ( page ), align, FALSE, FALSE, 5);
- 
+
     label_title = gtk_label_new ( _("Amortization Table") );
     gtk_container_add ( GTK_CONTAINER ( align ), label_title );
 
@@ -1140,7 +1106,7 @@ GtkWidget *bet_finance_create_amortization_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 5 );
 
     label = gtk_label_new ( NULL );
-    g_object_set_data ( G_OBJECT ( page ), "taux", label );
+    g_object_set_data ( G_OBJECT ( page ), "bet_finance_taux", label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("%") );
@@ -1165,13 +1131,16 @@ GtkWidget *bet_finance_create_amortization_page ( void )
     g_object_set_data ( G_OBJECT ( tree_view ), "label_title", label_title );
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( tree_view, GTK_STATE_SELECTED, &couleur_selection );
-    gtk_widget_modify_base ( tree_view, GTK_STATE_ACTIVE, &couleur_selection );
+    utils_set_tree_view_selection_and_text_color ( tree_view );
 
     /* on y ajoute la barre d'outils */
-    toolbar = bet_finance_create_simulator_toolbar ( page, tree_view, FALSE, TRUE );
-    gtk_box_pack_start ( GTK_BOX ( page ), toolbar, FALSE, FALSE, 0 );
-    gtk_box_reorder_child ( GTK_BOX ( page ), toolbar, 0 );
+    amortization_toolbar = gtk_handle_box_new ( );
+    g_object_set_data ( G_OBJECT ( amortization_toolbar ), "tree_view", tree_view );
+    g_object_set_data ( G_OBJECT ( amortization_toolbar ), "page", page );
+    gtk_widget_show ( amortization_toolbar );
+
+    gtk_box_pack_start ( GTK_BOX ( page ), amortization_toolbar, FALSE, FALSE, 0 );
+    gtk_box_reorder_child ( GTK_BOX ( page ), amortization_toolbar, 0 );
 
     gtk_widget_show_all ( page );
 
@@ -1306,7 +1275,7 @@ GtkWidget *bet_finance_create_amortization_tree_view ( GtkWidget *container, gin
     g_free ( title );
 
     /* Fees*/
-    title = g_strdup ( _("Insurance") );
+    title = g_strdup ( _("Fees") );
     cell = gtk_cell_renderer_text_new ( );
     g_object_set ( G_OBJECT ( cell ), "xalign", 0.5, NULL );
 
@@ -1417,7 +1386,7 @@ void bet_finance_fill_amortization_array ( GtkWidget *menu_item,
     page = gtk_notebook_get_nth_page ( GTK_NOTEBOOK ( finance_notebook ), 1 );
     label = g_object_get_data ( G_OBJECT ( page ), "capital" );
     gtk_label_set_label ( GTK_LABEL ( label ), str_capital );
-    label = g_object_get_data ( G_OBJECT ( page ), "taux" );
+    label = g_object_get_data ( G_OBJECT ( page ), "bet_finance_taux" );
     gtk_label_set_label ( GTK_LABEL ( label ), str_taux );
     label = g_object_get_data ( G_OBJECT ( page ), "duree" );
     gtk_label_set_label ( GTK_LABEL ( label ), str_duree );
@@ -1444,7 +1413,7 @@ void bet_finance_fill_amortization_array ( GtkWidget *menu_item,
                         s_amortissement -> interets,
                         s_amortissement -> frais );
             g_free ( s_amortissement -> str_echeance );
-            s_amortissement -> str_echeance = gsb_real_get_string_with_currency (
+            s_amortissement -> str_echeance = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> echeance ),
                         s_amortissement ->  devise, TRUE );
             s_amortissement -> principal = s_amortissement -> capital_du;
@@ -1459,11 +1428,11 @@ void bet_finance_fill_amortization_array ( GtkWidget *menu_item,
         s_amortissement -> capital_du -= s_amortissement -> principal;
     }
 
-    bet_finance_list_set_background_color ( tree_view, BET_AMORTIZATION_BACKGROUND_COLOR );
+    utils_set_tree_view_background_color ( tree_view, BET_AMORTIZATION_BACKGROUND_COLOR );
     path = gtk_tree_path_new_first ( );
     gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( tree_view ), path, NULL, TRUE, 0.0, 0.0 );
     gtk_tree_selection_select_path ( gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) ), path );
-    
+
     gtk_tree_path_free ( path );
     bet_data_finance_structure_amortissement_free ( s_amortissement );
 }
@@ -1483,15 +1452,15 @@ void bet_finance_fill_amortization_ligne ( GtkTreeModel *model,
     gchar *str_interets = NULL;
     gchar *str_principal = NULL;
 
-    str_capital_du = gsb_real_get_string_with_currency (
+    str_capital_du = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> capital_du ),
                         s_amortissement -> devise, TRUE );
 
-    str_interets = gsb_real_get_string_with_currency (
+    str_interets = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> interets ),
                         s_amortissement ->  devise, TRUE );
 
-    str_principal = gsb_real_get_string_with_currency (
+    str_principal = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> principal ),
                         s_amortissement ->  devise, TRUE );
 
@@ -1542,7 +1511,6 @@ GtkWidget *bet_finance_create_account_page ( void )
     GtkWidget *label_title;
     GtkWidget *label;
     GtkWidget *tree_view;
-    GtkWidget *toolbar;
 
     devel_debug (NULL);
 
@@ -1551,7 +1519,7 @@ GtkWidget *bet_finance_create_account_page ( void )
     /* titre de la page */
     align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
     gtk_box_pack_start ( GTK_BOX ( page ), align, FALSE, FALSE, 5);
- 
+
     label_title = gtk_label_new ( _("Amortization Table") );
     g_object_set_data ( G_OBJECT ( account_page ), "bet_finance_amortization_title", label_title );
     gtk_container_add ( GTK_CONTAINER ( align ), label_title );
@@ -1605,13 +1573,16 @@ GtkWidget *bet_finance_create_account_page ( void )
     g_object_set_data ( G_OBJECT ( tree_view ), "label_title", label_title );
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( tree_view, GTK_STATE_SELECTED, &couleur_selection );
-    gtk_widget_modify_base ( tree_view, GTK_STATE_ACTIVE, &couleur_selection );
+    utils_set_tree_view_selection_and_text_color ( tree_view );
 
     /* on y ajoute la barre d'outils */
-    toolbar = bet_finance_create_simulator_toolbar ( page, tree_view, FALSE, FALSE );
-    gtk_box_pack_start ( GTK_BOX ( page ), toolbar, FALSE, FALSE, 0 );
-    gtk_box_reorder_child ( GTK_BOX ( page ), toolbar, 0 );
+    account_toolbar = gtk_handle_box_new ( );
+    g_object_set_data ( G_OBJECT ( account_toolbar ), "tree_view", tree_view );
+    g_object_set_data ( G_OBJECT ( account_toolbar ), "page", page );
+    gtk_widget_show ( account_toolbar );
+
+    gtk_box_pack_start ( GTK_BOX ( page ), account_toolbar, FALSE, FALSE, 0 );
+    gtk_box_reorder_child ( GTK_BOX ( page ), account_toolbar, 0 );
 
     gtk_widget_show_all ( page );
 
@@ -1644,7 +1615,7 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
     struct_amortissement *s_amortissement;
     gboolean amortization_initial_date;
 
-    devel_debug ( NULL );
+/*     devel_debug ( NULL );  */
     if ( gsb_gui_navigation_get_current_account ( ) != account_number )
         return;
 
@@ -1676,7 +1647,7 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
     /* set capital */
     s_amortissement -> capital_du = gsb_data_account_get_bet_finance_capital ( account_number );
     label = g_object_get_data ( G_OBJECT ( account_page ), "bet_finance_capital" );
-    tmp_str = gsb_real_get_string_with_currency (
+    tmp_str = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> capital_du ),
                         s_amortissement -> devise, TRUE );
     gtk_label_set_label ( GTK_LABEL ( label ), tmp_str );
@@ -1687,7 +1658,7 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
     taux = gsb_data_account_get_bet_finance_taux_annuel ( account_number );
     type_taux = gsb_data_account_get_bet_finance_type_taux ( account_number );
     taux_periodique = bet_data_finance_get_taux_periodique ( taux, type_taux );
-    tmp_str = utils_str_dtostr ( taux, 2, FALSE );
+    tmp_str = utils_str_dtostr ( taux, BET_TAUX_DIGITS, FALSE );
     gtk_label_set_label ( GTK_LABEL ( label ), tmp_str );
     g_free ( tmp_str );
 
@@ -1705,7 +1676,7 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
 
     /* set frais */
     s_amortissement -> frais = gsb_data_account_get_bet_finance_frais ( account_number );
-    s_amortissement -> str_frais = gsb_real_get_string_with_currency (
+    s_amortissement -> str_frais = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> frais ),
                         s_amortissement -> devise, TRUE );
 
@@ -1717,7 +1688,7 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
     s_amortissement -> echeance = bet_data_finance_get_echeance ( s_amortissement -> capital_du,
                         taux_periodique, nbre_echeances );
     s_amortissement -> echeance += s_amortissement -> frais;
-    s_amortissement -> str_echeance = gsb_real_get_string_with_currency (
+    s_amortissement -> str_echeance = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> echeance ),
                         s_amortissement -> devise, TRUE );
 
@@ -1733,7 +1704,7 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
                         s_amortissement -> interets,
                         s_amortissement -> frais );
             g_free ( s_amortissement -> str_echeance );
-            s_amortissement -> str_echeance = gsb_real_get_string_with_currency (
+            s_amortissement -> str_echeance = utils_real_get_string_with_currency (
                         gsb_real_double_to_real ( s_amortissement -> echeance ),
                         s_amortissement ->  devise, TRUE );
             s_amortissement -> principal = s_amortissement -> capital_du;
@@ -1755,11 +1726,11 @@ void bet_finance_ui_update_amortization_tab ( gint account_number )
     g_date_free ( date );
     g_date_free ( last_paid_date );
 
-    bet_finance_list_set_background_color ( tree_view, BET_AMORTIZATION_BACKGROUND_COLOR );
+    utils_set_tree_view_background_color ( tree_view, BET_AMORTIZATION_BACKGROUND_COLOR );
     path = gtk_tree_path_new_first ( );
     gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( tree_view ), path, NULL, TRUE, 0.0, 0.0 );
     gtk_tree_selection_select_path ( gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) ), path );
-    
+
     gtk_tree_path_free ( path );
 }
 
@@ -1794,22 +1765,17 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
                         gboolean simulator,
                         gboolean amortization )
 {
-    GtkWidget *handlebox;
     GtkWidget *hbox;
     GtkWidget *button;
     GtkTreeSelection *selection;
 
-    /* HandleBox */
-    handlebox = gtk_handle_box_new ( );
-
     /* Hbox */
     hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_container_add ( GTK_CONTAINER ( handlebox ), hbox );
 
     if ( simulator )
     {
     /* création du bouton calculer */
-        button = gsb_automem_stock_button_new ( etat.display_toolbar,
+        button = gsb_automem_stock_button_new ( conf.display_toolbar,
                         GTK_STOCK_EXECUTE,
                         _("Calculate"),
                         NULL,
@@ -1824,7 +1790,7 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
 
         /* création du bouton afficher le tableau d'amortissement */
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
-        button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
+        button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
                         _("Amortization"),
                         "ac_liability_16.png",
                         NULL,
@@ -1834,14 +1800,12 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
                         "clicked",
                         G_CALLBACK ( bet_finance_fill_amortization_array ),
                         selection );
-        gtk_widget_set_sensitive ( button, FALSE );
-        g_object_set_data ( G_OBJECT ( parent ), "amortization_button", button );
         gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
     }
     else if ( amortization )
     {
         /* création du bouton afficher le simulateur de crédits */
-        button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
+        button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
                         _("Credits"),
                         "ac_liability_16.png",
                         NULL,
@@ -1858,8 +1822,8 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
         gboolean amortization_initial_date = FALSE;
 
         /* création du bouton afficher le simulateur de crédits */
-        button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
-                        _("Amortization"),
+        button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
+                        _("Start date"),
                         "ac_liability_16.png",
                         NULL,
                         NULL );
@@ -1876,7 +1840,7 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
     }
 
     /* création du bouton print */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
                         GTK_STOCK_PRINT,
                         _("Print"),
                         NULL,
@@ -1886,13 +1850,10 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
                         "clicked",
                         G_CALLBACK ( print_tree_view_list ),
                         tree_view );
-    if ( simulator )
-        gtk_widget_set_sensitive ( button, FALSE );
-    g_object_set_data ( G_OBJECT ( parent ), "print_button", button );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
 
     /* Export button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
 					   GTK_STOCK_SAVE,
 					   _("Export"),
 					   NULL,
@@ -1902,14 +1863,11 @@ GtkWidget *bet_finance_create_simulator_toolbar ( GtkWidget *parent,
                         "clicked",
                         G_CALLBACK ( bet_finance_ui_export_tab ),
                         tree_view );
-    if ( simulator )
-        gtk_widget_set_sensitive ( button, FALSE );
-    g_object_set_data ( G_OBJECT ( parent ), "export_button", button );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
 
-    gtk_widget_show_all ( handlebox );
+    gtk_widget_show_all ( hbox );
 
-    return ( handlebox );
+    return ( hbox );
 
 }
 
@@ -1927,7 +1885,7 @@ void bet_finance_ui_export_tab ( GtkWidget *menu_item, GtkTreeView *tree_view )
     gchar *filename;
 
     dialog = gtk_file_chooser_dialog_new ( _("Export the array"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
@@ -1986,7 +1944,18 @@ void bet_finance_switch_amortization_initial_date ( GtkWidget *widget, GtkWidget
         tmp_button = widget;
     else
         tmp_button = g_object_get_data ( G_OBJECT ( tree_view ), "amortization_initial_date_button" );
-    
+
+        if ( conf.display_toolbar != GSB_BUTTON_ICON )
+        {
+            GtkWidget *label;
+
+            label = g_object_get_data ( G_OBJECT ( tmp_button ), "label" );
+            if ( amortization_initial_date )
+                gtk_label_set_text_with_mnemonic ( GTK_LABEL ( label ), _("At today") );
+            else
+                gtk_label_set_text_with_mnemonic ( GTK_LABEL ( label ), _("Start date") );
+        }
+
     if ( amortization_initial_date )
             gtk_widget_set_tooltip_text ( GTK_WIDGET ( tmp_button ), _("Show amortization schedule to date") );
     else
@@ -2105,7 +2074,7 @@ gboolean bet_finance_capital_entry_changed ( GtkWidget *entry, GtkWidget *page
     {
 	    /* the entry is not valid, make it red */
 		gtk_widget_modify_base ( entry, GTK_STATE_NORMAL,
-                        &calendar_entry_color );
+                        gsb_color_get_couleur ( "entry_error_color" ) );
     }
 
     return FALSE;
@@ -2142,7 +2111,7 @@ gboolean bet_finance_capital_entry_key_press_event ( GtkWidget *widget,
             break;
 
         case GDK_Escape :
-            str_capital = gsb_real_get_string_with_currency ( gsb_real_double_to_real (
+            str_capital = utils_real_get_string_with_currency ( gsb_real_double_to_real (
                                     etat.bet_capital ),
                                     etat.bet_currency,
                                     FALSE );
@@ -2176,6 +2145,11 @@ gboolean bet_finance_capital_entry_key_press_event ( GtkWidget *widget,
 }
 
 
+/**
+ *
+ *
+ *
+ */
 GtkWidget *bet_finance_get_capital_entry ( void )
 {
     GtkWidget *page;
@@ -2188,6 +2162,100 @@ GtkWidget *bet_finance_get_capital_entry ( void )
 }
 
 
+/**
+ *
+ *
+ *
+ */
+void bet_finance_update_account_toolbar ( void )
+{
+    GtkWidget *page;
+    GtkWidget *tree_view;
+    GList *list = NULL;
+
+    page = g_object_get_data ( G_OBJECT ( account_toolbar ), "page" );
+    tree_view = g_object_get_data ( G_OBJECT ( account_toolbar ), "tree_view" );
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( account_toolbar ) );
+
+    if ( list )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( account_toolbar ),
+                               GTK_WIDGET ( list -> data ) );
+        g_list_free ( list );
+    }
+    gtk_container_add ( GTK_CONTAINER ( account_toolbar ),
+                        bet_finance_create_simulator_toolbar ( page, tree_view, FALSE, FALSE ) );
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void bet_finance_update_amortization_toolbar ( void )
+{
+    GtkWidget *page;
+    GtkWidget *tree_view;
+    GList *list = NULL;
+
+    page = g_object_get_data ( G_OBJECT ( amortization_toolbar ), "page" );
+    tree_view = g_object_get_data ( G_OBJECT ( amortization_toolbar ), "tree_view" );
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( amortization_toolbar ) );
+
+    if ( list )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( amortization_toolbar ),
+                               GTK_WIDGET ( list -> data ) );
+        g_list_free ( list );
+    }
+    gtk_container_add ( GTK_CONTAINER ( amortization_toolbar ),
+                        bet_finance_create_simulator_toolbar ( page, tree_view, FALSE, TRUE ) );
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void bet_finance_update_simulator_toolbar ( void )
+{
+    GtkWidget *page;
+    GtkWidget *tree_view;
+    GList *list = NULL;
+
+    page = g_object_get_data ( G_OBJECT ( simulator_toolbar ), "page" );
+    tree_view = g_object_get_data ( G_OBJECT ( simulator_toolbar ), "tree_view" );
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( simulator_toolbar ) );
+
+    if ( list )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( simulator_toolbar ),
+                               GTK_WIDGET ( list -> data ) );
+        g_list_free ( list );
+    }
+    gtk_container_add ( GTK_CONTAINER ( simulator_toolbar ),
+                        bet_finance_create_simulator_toolbar ( page, tree_view, TRUE, FALSE ) );
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void bet_finance_update_all_finance_toolbars ( void )
+{
+    bet_finance_update_account_toolbar ( );
+    bet_finance_update_simulator_toolbar ( );
+    bet_finance_update_amortization_toolbar ( );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
