@@ -26,24 +26,35 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "bet_hist.h"
 #include "bet_config.h"
 #include "bet_data.h"
+#include "bet_graph.h"
 #include "bet_tab.h"
+#include "dialog.h"
+#include "export_csv.h"
 #include "fenetre_principale.h"
+#include "gsb_automem.h"
+#include "gsb_color.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_transaction.h"
+#include "gsb_file.h"
 #include "gsb_fyear.h"
 #include "gsb_real.h"
 #include "mouse.h"
 #include "navigation.h"
+#include "print_tree_view_list.h"
 #include "structures.h"
 #include "traitement_variables.h"
+#include "utils.h"
 #include "utils_dates.h"
+#include "utils_file_selection.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -59,6 +70,8 @@ static gboolean bet_historical_amount_differ_average ( GtkTreeModel *model,
 static gboolean bet_historical_button_press ( GtkWidget *tree_view,
                         GdkEventButton *ev );
 static void bet_historical_context_menu ( GtkWidget *tree_view );
+static GtkWidget *bet_historical_create_toolbar ( GtkWidget *parent,
+                        GtkWidget *tree_view );
 static void bet_historical_div_cell_edited (GtkCellRendererText *cell,
                         const gchar *path_string,
                         const gchar *new_text,
@@ -70,12 +83,13 @@ static void bet_historical_div_cell_editing_started (GtkCellRenderer *cell,
 static gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *renderer,
                         gchar *path_string,
                         GtkTreeModel *model );
+static void bet_historical_export_tab ( GtkWidget *menu_item,
+                        GtkTreeView *tree_view );
 static gboolean bet_historical_fyear_create_combobox_store ( void );
 static void bet_historical_fyear_hide_present_futures_fyears ( void );
 static gsb_real bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *parent );
 static GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container );
 static gboolean bet_historical_get_full_div ( GtkTreeModel *model, GtkTreeIter *parent );
-static GDate *bet_historical_get_start_date_current_fyear ( void );
 static gint bet_historical_get_type_transaction ( const GDate *date,
                         GDate *start_current_fyear,
                         GDate *date_max );
@@ -83,6 +97,8 @@ static gboolean bet_historical_initializes_account_settings ( gint account_numbe
 static void bet_historical_populate_div_model ( gpointer key,
                         gpointer value,
                         gpointer user_data );
+static void bet_historical_print_tab ( GtkWidget *menu_item,
+                        GtkTreeView *tree_view );
 static void bet_historical_row_collapse_all ( GtkTreeView *tree_view,
                         GtkTreeIter *iter,
                         GtkTreeModel *model );
@@ -101,15 +117,17 @@ static gboolean bet_historical_set_full_sub_div ( GtkTreeModel *model, GtkTreeIt
 
 /*START_EXTERN*/
 extern GtkWidget *account_page;
-extern GdkColor couleur_fond[2];
-extern GdkColor couleur_selection;
-extern GtkWidget *notebook_general;
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 /* blocage des signaux pour le tree_view pour les comptes de type GSB_TYPE_CASH */
 static gboolean hist_block_signal = FALSE;
 
+/* toolbar */
+static GtkWidget *bet_historical_toolbar;
+
+/* liste qui contient les transactions concernées */
+static GHashTable *list_trans_hist = NULL;
+
 /**
  * this is a tree model filter with 3 columns :
  * the name, the number and a boolean to show it or not
@@ -122,7 +140,7 @@ GtkTreeModel *bet_fyear_model = NULL;
  * */
 GtkTreeModel *bet_fyear_model_filter = NULL;
 
- 
+
 /**
  * Create the historical page
  *
@@ -135,7 +153,7 @@ GtkWidget *bet_historical_create_page ( void )
     GtkWidget *page;
     GtkWidget *hbox;
     GtkWidget *align;
-    GtkWidget *label;
+    GtkWidget *label_title;
     GtkWidget *button_1, *button_2;
     GtkWidget *tree_view;
     gpointer pointeur;
@@ -147,10 +165,10 @@ GtkWidget *bet_historical_create_page ( void )
     /* titre de la page */
     align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
     gtk_box_pack_start ( GTK_BOX ( page ), align, FALSE, FALSE, 5) ;
- 
-    label = gtk_label_new ( "bet_hist_title" );
-    gtk_container_add ( GTK_CONTAINER ( align ), label );
-    g_object_set_data ( G_OBJECT ( account_page ), "bet_hist_title", label);
+
+    label_title = gtk_label_new ( "bet_hist_title" );
+    gtk_container_add ( GTK_CONTAINER ( align ), label_title );
+    g_object_set_data ( G_OBJECT ( account_page ), "bet_hist_title", label_title);
 
     /* Choix des données sources */
     align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
@@ -211,10 +229,19 @@ GtkWidget *bet_historical_create_page ( void )
     /* création de la liste des données */
     tree_view = bet_historical_get_data_tree_view ( page );
     g_object_set_data ( G_OBJECT ( account_page ), "bet_historical_treeview", tree_view );
+    g_object_set_data ( G_OBJECT ( tree_view ), "label_title", label_title );
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( tree_view, GTK_STATE_SELECTED, &couleur_selection );
-    gtk_widget_modify_base ( tree_view, GTK_STATE_ACTIVE, &couleur_selection );
+    utils_set_tree_view_selection_and_text_color ( tree_view );
+
+    /* on y ajoute la barre d'outils */
+    bet_historical_toolbar = gtk_handle_box_new ( );
+    g_object_set_data ( G_OBJECT ( bet_historical_toolbar ), "tree_view", tree_view );
+    g_object_set_data ( G_OBJECT ( bet_historical_toolbar ), "page", page );
+    gtk_widget_show ( bet_historical_toolbar );
+
+    gtk_box_pack_start ( GTK_BOX ( page ), bet_historical_toolbar, FALSE, FALSE, 0 );
+    gtk_box_reorder_child ( GTK_BOX ( page ), bet_historical_toolbar, 0 );
 
     gtk_widget_show_all ( page );
 
@@ -268,7 +295,7 @@ gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *renderer,
                         account_number, div, sub_div); */
             bet_data_hist_add_div ( account_number, div_number, sub_div_nb );
             bet_data_set_div_amount ( account_number, div_number, sub_div_nb,
-                        gsb_real_safe_real_from_string ( str_amount ) );
+                        utils_real_get_from_string ( str_amount ) );
             gtk_tree_store_set ( GTK_TREE_STORE ( model ), &iter,
                         SPP_HISTORICAL_SELECT_COLUMN, 1,
                         SPP_HISTORICAL_RETAINED_COLUMN, str_average,
@@ -310,13 +337,10 @@ gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *renderer,
                 if ( bet_historical_get_full_div ( model, &parent ) )
                 {
                     amount = bet_historical_get_children_amount ( model, &parent );
-                    if ( str_amount )
-                        g_free ( str_amount );
-                    str_amount = gsb_real_safe_real_to_string ( amount,
-                                gsb_data_account_get_currency_floating_point ( account_number ) );
-                    if ( str_average )
-                        g_free ( str_average );
-                    str_average = gsb_real_get_string_with_currency ( amount,
+                    g_free ( str_amount );
+                    str_amount = utils_real_get_string ( amount );
+                    g_free ( str_average );
+                    str_average = utils_real_get_string_with_currency ( amount,
                                 gsb_data_account_get_currency ( account_number ), TRUE );
                     gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                                 &parent,
@@ -326,7 +350,7 @@ gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *renderer,
                                 -1);
                     if ( bet_historical_amount_differ_average ( model, &parent) )
                         bet_data_set_div_amount ( account_number, div_number, 0, amount );
-                        
+
                     bet_historical_row_collapse_all ( NULL, &parent, model );
                 }
                 else
@@ -345,8 +369,7 @@ gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *renderer,
         bet_data_update_bet_module ( account_number, GSB_HISTORICAL_PAGE );
     }
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -363,7 +386,7 @@ void bet_historical_div_cell_editing_started (GtkCellRenderer *cell,
                         const gchar *path_string,
                         GtkWidget *tree_view )
 {
-    if ( GTK_IS_ENTRY ( editable ) ) 
+    if ( GTK_IS_ENTRY ( editable ) )
         gtk_editable_delete_text ( GTK_EDITABLE ( editable ), 0, -1 );
 }
 
@@ -416,11 +439,10 @@ void bet_historical_div_cell_edited (GtkCellRendererText *cell,
             bet_historical_row_collapse_all ( GTK_TREE_VIEW ( tree_view ), &iter, model );
         }
 
-        number = gsb_real_get_from_string ( new_text );
+        number = utils_real_get_from_string ( new_text );
         currency_number = gsb_data_account_get_currency ( account_number );
-        tmp_str = gsb_real_get_string_with_currency ( number, currency_number, TRUE );
-        str_amount = gsb_real_safe_real_to_string ( number,
-                                gsb_data_currency_get_floating_point ( currency_number ) );
+        tmp_str = utils_real_get_string_with_currency ( number, currency_number, TRUE );
+        str_amount = utils_real_get_string ( number );
 
         if ( bet_data_search_div_hist ( account_number, div_number, sub_div_nb ) == FALSE )
             bet_data_hist_add_div ( account_number, div_number, sub_div_nb );
@@ -445,9 +467,8 @@ void bet_historical_div_cell_edited (GtkCellRendererText *cell,
         {
             number = bet_historical_get_children_amount ( model, &parent );
             bet_data_set_div_amount ( account_number, div_number, 0, number );
-            str_amount = gsb_real_safe_real_to_string ( number,
-                                gsb_data_currency_get_floating_point ( currency_number ) );
-            tmp_str = gsb_real_get_string_with_currency ( number, currency_number, TRUE );
+            str_amount = utils_real_get_string ( number );
+            tmp_str = utils_real_get_string_with_currency ( number, currency_number, TRUE );
             gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                         &parent,
                         SPP_HISTORICAL_SELECT_COLUMN, TRUE,
@@ -461,8 +482,7 @@ void bet_historical_div_cell_edited (GtkCellRendererText *cell,
 
         gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ESTIMATE );
 
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 }
 
@@ -491,8 +511,9 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     tree_model = gtk_tree_store_new ( SPP_HISTORICAL_NUM_COLUMNS,
                         G_TYPE_BOOLEAN,     /* SPP_HISTORICAL_SELECT_COLUMN     */
                         G_TYPE_STRING,      /* SPP_HISTORICAL_DESC_COLUMN       */
-                        G_TYPE_STRING,      /* SPP_HISTORICAL_CURRENT_COLUMN     */
+                        G_TYPE_STRING,      /* SPP_HISTORICAL_CURRENT_COLUMN    */
                         G_TYPE_STRING,      /* SPP_HISTORICAL_BALANCE_COLUMN    */
+                        G_TYPE_STRING,      /* SPP_HISTORICAL_BALANCE_AMOUNT    */
                         G_TYPE_STRING,      /* SPP_HISTORICAL_AVERAGE_COLUMN    */
                         G_TYPE_STRING,      /* SPP_HISTORICAL_AVERAGE_AMOUNT    */
                         G_TYPE_STRING,      /* SPP_HISTORICAL_RETAINED_COLUMN   */
@@ -538,6 +559,8 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     gtk_tree_view_column_set_alignment ( column, 0.5 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( tree_view ), column );
     gtk_tree_view_column_set_resizable ( column, TRUE );
+    g_object_set_data ( G_OBJECT ( column ), "num_col_model",
+                        GINT_TO_POINTER ( SPP_HISTORICAL_SELECT_COLUMN ) );
 
     /* name of the div sous-div column*/
     title = g_strdup ( _("Category") );
@@ -553,6 +576,8 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
                         GTK_TREE_VIEW_COLUMN ( column ) );
     gtk_tree_view_column_set_expand ( GTK_TREE_VIEW_COLUMN ( column ), TRUE );
     gtk_tree_view_column_set_resizable ( column, TRUE );
+    g_object_set_data ( G_OBJECT ( column ), "num_col_model",
+                        GINT_TO_POINTER ( SPP_HISTORICAL_DESC_COLUMN ) );
 
     /* amount column */
     cell = gtk_cell_renderer_text_new ( );
@@ -569,6 +594,8 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     gtk_tree_view_column_set_clickable ( GTK_TREE_VIEW_COLUMN ( column ), FALSE );
     gtk_tree_view_column_set_expand ( GTK_TREE_VIEW_COLUMN ( column ), TRUE );
     gtk_tree_view_column_set_resizable ( column, TRUE );
+    g_object_set_data ( G_OBJECT ( column ), "num_col_model",
+                        GINT_TO_POINTER ( SPP_HISTORICAL_BALANCE_COLUMN ) );
 
     /* average column */
     cell = gtk_cell_renderer_text_new ( );
@@ -585,6 +612,8 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     gtk_tree_view_column_set_clickable ( GTK_TREE_VIEW_COLUMN ( column ), FALSE );
     gtk_tree_view_column_set_expand ( GTK_TREE_VIEW_COLUMN ( column ), TRUE );
     gtk_tree_view_column_set_resizable ( column, TRUE );
+    g_object_set_data ( G_OBJECT ( column ), "num_col_model",
+                        GINT_TO_POINTER ( SPP_HISTORICAL_AVERAGE_COLUMN ) );
 
     /* current fyear column */
     cell = gtk_cell_renderer_text_new ( );
@@ -601,6 +630,8 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     gtk_tree_view_column_set_clickable ( GTK_TREE_VIEW_COLUMN ( column ), FALSE );
     gtk_tree_view_column_set_expand ( GTK_TREE_VIEW_COLUMN ( column ), TRUE );
     gtk_tree_view_column_set_resizable ( column, TRUE );
+    g_object_set_data ( G_OBJECT ( column ), "num_col_model",
+                        GINT_TO_POINTER ( SPP_HISTORICAL_CURRENT_COLUMN ) );
 
     /* amount retained column */
     cell = gtk_cell_renderer_text_new ( );
@@ -619,6 +650,8 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     gtk_tree_view_column_set_clickable ( GTK_TREE_VIEW_COLUMN ( column ), FALSE );
     gtk_tree_view_column_set_expand ( GTK_TREE_VIEW_COLUMN ( column ), TRUE );
     gtk_tree_view_column_set_resizable ( column, TRUE );
+    g_object_set_data ( G_OBJECT ( column ), "num_col_model",
+                        GINT_TO_POINTER ( SPP_HISTORICAL_RETAINED_COLUMN ) );
 
     g_signal_connect ( cell,
                         "editing-started",
@@ -666,7 +699,8 @@ void bet_historical_populate_data ( gint account_number )
     GDate *date_max;
     GDate *start_current_fyear;
     GSList* tmp_list;
-    GHashTable  *list_div;
+    GHashTable *list_div;
+    TransactionCurrentFyear *tcf = NULL;
 
     devel_debug_int ( account_number );
     tree_view = g_object_get_data (G_OBJECT ( account_page ), "bet_historical_treeview" );
@@ -698,13 +732,21 @@ void bet_historical_populate_data ( gint account_number )
 
     /* calculate the current_fyear */
     start_current_fyear = bet_historical_get_start_date_current_fyear ( );
-/*     printf ("start_current_fyear = %s\n", gsb_format_gdate ( start_current_fyear ));  */
 
     list_div = g_hash_table_new_full ( g_str_hash,
                         g_str_equal,
                         (GDestroyNotify) g_free,
                         (GDestroyNotify) struct_free_bet_historical );
 
+    /* on initialise ici la liste des transactions pour les graphiques mensuels */
+    if ( list_trans_hist )
+        g_hash_table_remove_all ( list_trans_hist );
+
+    list_trans_hist = g_hash_table_new_full ( g_str_hash,
+                                    g_str_equal,
+                                    (GDestroyNotify) g_free,
+                                    (GDestroyNotify) struct_free_bet_transaction_current_fyear );
+
     /* search transactions of the account  */
     tmp_list = gsb_data_transaction_get_complete_transactions_list ( );
     while ( tmp_list )
@@ -738,11 +780,16 @@ void bet_historical_populate_data ( gint account_number )
         /* on détermine le type de transaction pour l'affichage */
         type_de_transaction = bet_historical_get_type_transaction ( date, start_current_fyear, date_max );
 
-        bet_data_populate_div ( transaction_number, TRUE, list_div, type_de_transaction );
+        tcf = struct_initialise_transaction_current_fyear ();
+        tcf->transaction_number = transaction_number;
+        tcf->date = gsb_date_copy ( date );
+        tcf->type_de_transaction = type_de_transaction;
+
+        g_hash_table_insert ( list_trans_hist, utils_str_itoa ( transaction_number ), tcf );
+        bet_data_populate_div ( transaction_number, TRUE, list_div, type_de_transaction, tcf );
     }
 
     bet_historical_affiche_div ( list_div, tree_view );
-    /* bet_data_synchronise_hist_div_list ( list_div ); */
 
     g_hash_table_remove_all ( list_div );
     g_date_free ( date_jour );
@@ -751,6 +798,7 @@ void bet_historical_populate_data ( gint account_number )
     g_date_free ( start_current_fyear );
 
     bet_historical_set_background_color ( tree_view );
+    bet_array_list_select_path ( tree_view, NULL );
 }
 
 
@@ -792,6 +840,7 @@ void bet_historical_populate_div_model ( gpointer key,
     gpointer sub_key, sub_value;
     gchar *div_name = NULL;
     gchar *str_balance;
+    gchar *str_balance_amount;
     gchar *str_average;
     gchar *str_amount;
     gchar *str_retained = NULL;
@@ -812,20 +861,20 @@ void bet_historical_populate_div_model ( gpointer key,
     div_name = bet_data_get_div_name ( div_number, 0, NULL );
     account_nb = sh -> account_nb;
     kind = gsb_data_account_get_kind ( account_nb );
-    if ( kind == GSB_TYPE_CASH )
+    if ( kind == GSB_TYPE_CASH && etat.bet_deb_cash_account_option == 0 )
         edited = FALSE;
 
     currency_number = gsb_data_account_get_currency ( account_nb );
 
     model = gtk_tree_view_get_model ( tree_view );
 
-    str_balance = gsb_real_get_string_with_currency ( sbr -> current_balance, currency_number, TRUE );
+    str_balance_amount = utils_real_get_string ( sbr->current_balance );
+    str_balance = utils_real_get_string_with_currency ( sbr -> current_balance, currency_number, TRUE );
     average = gsb_real_div ( sbr -> current_balance, period );
-    str_amount = gsb_real_safe_real_to_string ( average,
-                        gsb_data_currency_get_floating_point ( currency_number ) );
-    str_average = gsb_real_get_string_with_currency ( average, currency_number, TRUE );
+    str_amount = utils_real_get_string ( average );
+    str_average = utils_real_get_string_with_currency ( average, currency_number, TRUE );
 
-    str_current_fyear = gsb_real_get_string_with_currency ( sbr -> current_fyear, currency_number, TRUE );
+    str_current_fyear = utils_real_get_string_with_currency ( sbr -> current_fyear, currency_number, TRUE );
 
     gtk_tree_store_append ( GTK_TREE_STORE ( model ), &parent, NULL);
     gtk_tree_store_set ( GTK_TREE_STORE ( model ),
@@ -833,6 +882,7 @@ void bet_historical_populate_div_model ( gpointer key,
                         SPP_HISTORICAL_DESC_COLUMN, div_name,
                         SPP_HISTORICAL_CURRENT_COLUMN, str_current_fyear,
                         SPP_HISTORICAL_BALANCE_COLUMN, str_balance,
+                        SPP_HISTORICAL_BALANCE_AMOUNT, str_balance_amount,
                         SPP_HISTORICAL_AVERAGE_COLUMN, str_average,
                         SPP_HISTORICAL_AVERAGE_AMOUNT, str_amount,
                         SPP_HISTORICAL_RETAINED_AMOUNT, str_amount,
@@ -842,18 +892,16 @@ void bet_historical_populate_div_model ( gpointer key,
                         SPP_HISTORICAL_EDITED_COLUMN, edited,
                         -1);
 
-    if ( bet_data_search_div_hist ( account_nb, div_number, 0 ) 
+    if ( bet_data_search_div_hist ( account_nb, div_number, 0 )
      &&
      ( bet_data_get_div_edited ( account_nb, div_number, 0 )
       ||
       g_hash_table_size ( sh -> list_sub_div ) < 1 ) )
     {
         retained = bet_data_hist_get_div_amount ( account_nb, div_number, 0 );
-        if ( str_amount )
-            g_free ( str_amount );
-        str_amount = gsb_real_safe_real_to_string ( retained,
-                        gsb_data_currency_get_floating_point ( currency_number ) );
-        str_retained = gsb_real_get_string_with_currency ( retained, currency_number, TRUE );
+        g_free ( str_amount );
+        str_amount = utils_real_get_string ( retained );
+        str_retained = utils_real_get_string_with_currency ( retained, currency_number, TRUE );
         gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                         &parent,
                         SPP_HISTORICAL_SELECT_COLUMN, TRUE,
@@ -864,6 +912,8 @@ void bet_historical_populate_div_model ( gpointer key,
     }
 /* printf ("division = %d div_name = %s\n", div_number, div_name);  */
     g_free ( div_name );
+        g_free ( str_balance );
+        g_free ( str_balance_amount );
     g_free ( str_average );
     g_free ( str_amount );
     g_free ( str_current_fyear );
@@ -872,7 +922,7 @@ void bet_historical_populate_div_model ( gpointer key,
         return;
 
     g_hash_table_iter_init ( &iter, sh -> list_sub_div );
-    while ( g_hash_table_iter_next ( &iter, &sub_key, &sub_value ) ) 
+    while ( g_hash_table_iter_next ( &iter, &sub_key, &sub_value ) )
     {
         SH *sub_sh = ( SH* ) sub_value;
         SBR *sub_sbr = sub_sh -> sbr;
@@ -886,24 +936,23 @@ void bet_historical_populate_div_model ( gpointer key,
 /*         printf ("division = %d sub_div = %d div_name = %s\n", div_number, sub_sh -> div, div_name);  */
         if ( div_name && g_utf8_strrchr ( div_name, -1, ':' ) )
         {
-	        tab_str = g_strsplit ( div_name, ":", 2 );
+            tab_str = g_strsplit ( div_name, ":", 2 );
             if ( g_strv_length ( tab_str ) > 1 )
             {
                 g_free ( div_name );
                 div_name = g_strdup ( g_strstrip ( tab_str[1] ) );
             }
-            if ( tab_str )
-                g_strfreev ( tab_str );
+            g_strfreev ( tab_str );
         }
 
-        str_balance = gsb_real_get_string_with_currency ( sub_sbr -> current_balance, 
+        str_balance_amount = utils_real_get_string ( sub_sbr->current_balance );
+        str_balance = utils_real_get_string_with_currency ( sub_sbr -> current_balance,
                         currency_number, TRUE );
         average = gsb_real_div ( sub_sbr -> current_balance, period );
-        str_amount = gsb_real_safe_real_to_string ( average,
-                        gsb_data_currency_get_floating_point ( currency_number ) );
-        str_average = gsb_real_get_string_with_currency ( average,
+        str_amount = utils_real_get_string ( average );
+        str_average = utils_real_get_string_with_currency ( average,
                         currency_number, TRUE );
-        str_current_fyear = gsb_real_get_string_with_currency ( sub_sbr -> current_fyear,
+        str_current_fyear = utils_real_get_string_with_currency ( sub_sbr -> current_fyear,
                         currency_number, TRUE );
 
         gtk_tree_store_append ( GTK_TREE_STORE ( model ), &fils, &parent );
@@ -912,6 +961,7 @@ void bet_historical_populate_div_model ( gpointer key,
                         SPP_HISTORICAL_DESC_COLUMN, div_name,
                         SPP_HISTORICAL_CURRENT_COLUMN, str_current_fyear,
                         SPP_HISTORICAL_BALANCE_COLUMN, str_balance,
+                        SPP_HISTORICAL_BALANCE_AMOUNT, str_balance_amount,
                         SPP_HISTORICAL_AVERAGE_COLUMN, str_average,
                         SPP_HISTORICAL_AVERAGE_AMOUNT, str_amount,
                         SPP_HISTORICAL_RETAINED_AMOUNT, str_amount,
@@ -929,11 +979,9 @@ void bet_historical_populate_div_model ( gpointer key,
             {
                 /* printf ("account_nb = %d div_number = %d sub_sh -> div = %d\n", account_nb, div_number, sub_sh -> div ); */
                 retained = bet_data_hist_get_div_amount ( account_nb, div_number, sub_sh -> div );
-                if ( str_amount )
-                    g_free ( str_amount );
-                str_amount = gsb_real_safe_real_to_string ( retained,
-                        gsb_data_currency_get_floating_point ( currency_number ) );
-                str_retained = gsb_real_get_string_with_currency ( retained, currency_number, TRUE );
+                g_free ( str_amount );
+                str_amount = utils_real_get_string ( retained );
+                str_retained = utils_real_get_string_with_currency ( retained, currency_number, TRUE );
 
                 edited = FALSE;
                 gtk_tree_store_set ( GTK_TREE_STORE ( model ),
@@ -962,6 +1010,7 @@ void bet_historical_populate_div_model ( gpointer key,
         }
         g_free ( div_name );
         g_free ( str_balance );
+        g_free ( str_balance_amount );
         g_free ( str_average );
         g_free ( str_amount );
         g_free ( str_current_fyear );
@@ -970,9 +1019,8 @@ void bet_historical_populate_div_model ( gpointer key,
     if ( sub_div_visible && bet_historical_get_full_div ( model, &parent ) )
     {
         amount = bet_historical_get_children_amount ( model, &parent );
-        str_amount = gsb_real_safe_real_to_string ( amount,
-                    gsb_data_currency_get_floating_point ( currency_number ) );
-        str_retained = gsb_real_get_string_with_currency ( amount, currency_number, TRUE );
+        str_amount = utils_real_get_string ( amount );
+        str_retained = utils_real_get_string_with_currency ( amount, currency_number, TRUE );
 
         gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                     &parent,
@@ -1205,11 +1253,11 @@ gboolean bet_historical_set_full_sub_div ( GtkTreeModel *model, GtkTreeIter *par
                         SPP_HISTORICAL_EDITED_COLUMN, &edited,
                         -1 );
 
-            retained = gsb_real_safe_real_from_string ( str_amount );
+            retained = utils_real_get_from_string ( str_amount );
             bet_data_hist_add_div ( account_nb, div_number, sub_div_nb );
             bet_data_set_div_amount ( account_nb, div_number, sub_div_nb,
-                        gsb_real_safe_real_from_string ( str_amount ) );
-            str_retained = gsb_real_get_string_with_currency ( retained,
+                        utils_real_get_from_string ( str_amount ) );
+            str_retained = utils_real_get_string_with_currency ( retained,
                         gsb_data_account_get_currency ( account_nb ), TRUE );
             gtk_tree_store_set ( GTK_TREE_STORE ( model ), &fils_iter,
                         SPP_HISTORICAL_SELECT_COLUMN, TRUE,
@@ -1297,7 +1345,7 @@ gsb_real bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *
                         SPP_HISTORICAL_RETAINED_AMOUNT, &str_amount,
                         -1 );
             amount = gsb_real_add ( amount,
-                                gsb_real_safe_real_from_string ( str_amount ) );
+                                utils_real_get_from_string ( str_amount ) );
         }
         while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &fils_iter ) );
     }
@@ -1350,7 +1398,7 @@ void bet_historical_row_expanded_event ( GtkTreeView *tree_view,
 
 
 /**
- * Cette fonction compare le montant de la colonne montant retenu avec le montant 
+ * Cette fonction compare le montant de la colonne montant retenu avec le montant
  * de la colonne moyenne
  *
  * \ return O si egal -1 ou 1 si différent
@@ -1360,14 +1408,14 @@ gboolean bet_historical_amount_differ_average ( GtkTreeModel *model,
 {
     gchar *str_average;
     gchar *str_amount;
-    
+
     gtk_tree_model_get ( GTK_TREE_MODEL ( model ), iter,
                         SPP_HISTORICAL_AVERAGE_AMOUNT, &str_average,
                         SPP_HISTORICAL_RETAINED_AMOUNT, &str_amount,
                         -1 );
 
-    return gsb_real_cmp ( gsb_real_safe_real_from_string ( str_average ),
-                        gsb_real_safe_real_from_string ( str_amount ) );
+    return gsb_real_cmp ( utils_real_get_from_string ( str_average ),
+                        utils_real_get_from_string ( str_amount ) );
 }
 
 
@@ -1511,10 +1559,9 @@ void bet_historical_add_last_amount ( GtkWidget *menu_item,
                         gsb_data_account_get_bet_hist_data ( account_number ) );
 
     currency_number = gsb_data_account_get_currency ( account_number );
-    str_amount = gsb_real_safe_real_to_string ( amount, 
-                    gsb_data_currency_get_floating_point ( currency_number ) );
+    str_amount = utils_real_get_string ( amount );
 
-    tmp_str = gsb_real_get_string_with_currency ( amount, currency_number, TRUE );
+    tmp_str = utils_real_get_string_with_currency ( amount, currency_number, TRUE );
     /* printf ("div = %d sub_div_nb = %d tmp_str = %s\n", div_number, sub_div_nb, tmp_str); */
     if ( bet_data_search_div_hist ( account_number, div_number, sub_div_nb ) == FALSE )
         bet_data_hist_add_div ( account_number, div_number, sub_div_nb );
@@ -1538,8 +1585,7 @@ void bet_historical_add_last_amount ( GtkWidget *menu_item,
 
     gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ESTIMATE );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 }
 
 
@@ -1653,7 +1699,8 @@ gboolean bet_historical_set_background_color ( GtkWidget *tree_view )
         {
             gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                         &iter,
-                        SPP_HISTORICAL_BACKGROUND_COLOR, &couleur_fond[current_color],
+                        SPP_HISTORICAL_BACKGROUND_COLOR,
+                        gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
                         -1 );
             current_color = !current_color;
 
@@ -1666,7 +1713,8 @@ gboolean bet_historical_set_background_color ( GtkWidget *tree_view )
                 {
                     gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                         &fils_iter,
-                        SPP_HISTORICAL_BACKGROUND_COLOR, &couleur_fond[current_color],
+                        SPP_HISTORICAL_BACKGROUND_COLOR,
+                        gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
                         -1 );
                     current_color = !current_color;
                 }
@@ -1739,14 +1787,29 @@ void bet_historical_g_signal_unblock_tree_view ( void )
  * */
 void bet_historical_set_page_title ( gint account_number )
 {
-    GtkWidget * widget;
+    GtkWidget *widget;
     gchar *title;
+    gchar *hist_srce_name;
+    gint result;
 
-    title = g_strdup_printf (
-                    _("Please select the data source for the account: \"%s\""),
+    hist_srce_name = bet_historical_get_hist_source_name ( account_number );
+    result = gsb_data_account_get_bet_hist_fyear ( account_number );
+    if ( result == 0 )
+        title = g_strdup_printf (
+                    _("Amounts by %s on 12 months rolling for the account: '%s'"),
+                    hist_srce_name,
                     gsb_data_account_get_name ( account_number ) );
+    else
+        title = g_strdup_printf (
+                    _("Amounts by %s in %s for the account: «%s»"),
+                    hist_srce_name,
+                    gsb_data_fyear_get_name ( result ),
+                    gsb_data_account_get_name ( account_number ) );
+
     widget = GTK_WIDGET ( g_object_get_data ( G_OBJECT ( account_page ), "bet_hist_title") );
     gtk_label_set_label ( GTK_LABEL ( widget ), title );
+
+    g_free ( hist_srce_name );
     g_free ( title );
 }
 
@@ -1783,10 +1846,16 @@ GDate *bet_historical_get_start_date_current_fyear ( void )
 
 
 /**
+ * discrimine les opérations appartenant à l'exercice en cours
+ *
+ * \param date                  date de l'opération est > date_min de recherche
+ * \param start_current_fyear   date de début de l'exercice en cours
+ * \param date_max              date max de recherche des données passées
+ *
  * \return 0    opération <= à date_max et < start_current_fyear (n'appartient pas à l'exercice en cours)
- * \return 1    opération > à date_max et > start_current_fyear (appartient à l'exercice en cours)
- * \return 2    opération <= à date_max et > start_current_fyear (appartient à l'exercice en cours)
- * \return -1   toutes les autres opérations 
+ * \return 1    opération > start_current_fyear (appartient à l'exercice en cours)
+ * \return 2    opération <= à date_max et > start_current_fyear (appartient à l'exercice en cours) *
+ * \return -1   toutes les autres opérations ( aucune à priori )
  * */
 gint bet_historical_get_type_transaction ( const GDate *date,
                         GDate *start_current_fyear,
@@ -1848,9 +1917,225 @@ void bet_historical_fyear_hide_present_futures_fyears ( void )
         tmp_list = tmp_list -> next;
     }
 
+    g_date_free ( date );
 }
 
 
+/**
+ *
+ *
+ *
+ *
+ * */
+GtkWidget *bet_historical_create_toolbar ( GtkWidget *parent,
+                        GtkWidget *tree_view )
+{
+    GtkWidget *hbox;
+    GtkWidget *button;
+
+    /* Hbox */
+    hbox = gtk_hbox_new ( FALSE, 0 );
+
+    /* print button */
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                        GTK_STOCK_PRINT,
+                        _("Print"),
+                        NULL,
+                        NULL );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Print the array") );
+    g_signal_connect ( G_OBJECT ( button ),
+                        "clicked",
+                        G_CALLBACK ( bet_historical_print_tab ),
+                        tree_view );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+
+    /* Export button */
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+					   GTK_STOCK_SAVE,
+					   _("Export"),
+					   NULL,
+					   NULL );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Export the array") );
+    g_signal_connect ( G_OBJECT ( button ),
+                        "clicked",
+                        G_CALLBACK ( bet_historical_export_tab ),
+                        tree_view );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+
+#ifdef HAVE_GOFFICE
+    /* sectors button */
+    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
+                        _("Data graph"),
+                        "graph-sectors.png",
+                        NULL,
+                        NULL );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Display the pie graph") );
+    g_signal_connect ( G_OBJECT ( button ),
+                        "clicked",
+                        G_CALLBACK ( bet_graph_sectors_graph_new ),
+                        tree_view );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+
+    /* monthly button */
+    button = bet_graph_button_menu_new ( conf.display_toolbar,
+                        "historical_graph",
+                        G_CALLBACK ( bet_graph_montly_graph_new ),
+                        tree_view );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+#endif /* HAVE_GOFFICE */
+
+    gtk_widget_show_all ( hbox );
+
+    return ( hbox );
+
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void bet_historical_update_toolbar ( void )
+{
+    GtkWidget *page;
+    GtkWidget *tree_view;
+    GList *list = NULL;
+
+    page = g_object_get_data ( G_OBJECT ( bet_historical_toolbar ), "page" );
+    tree_view = g_object_get_data ( G_OBJECT ( bet_historical_toolbar ), "tree_view" );
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( bet_historical_toolbar ) );
+
+    if ( list )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( bet_historical_toolbar ),
+                               GTK_WIDGET ( list -> data ) );
+        g_list_free ( list );
+    }
+    gtk_container_add ( GTK_CONTAINER ( bet_historical_toolbar ),
+                        bet_historical_create_toolbar ( page, tree_view ) );
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void bet_historical_export_tab ( GtkWidget *menu_item,
+                        GtkTreeView *tree_view )
+{
+    GtkWidget *dialog;
+    gint resultat;
+    gchar *filename;
+
+    dialog = gtk_file_chooser_dialog_new ( _("Export the historical data"),
+					   GTK_WINDOW ( run.window ),
+					   GTK_FILE_CHOOSER_ACTION_SAVE,
+					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+					   NULL);
+
+    gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ), "division.csv");
+    gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( dialog ), gsb_file_get_last_path () );
+    gtk_file_chooser_set_do_overwrite_confirmation ( GTK_FILE_CHOOSER ( dialog ), TRUE);
+    gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
+
+    resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
+
+    switch ( resultat )
+    {
+	case GTK_RESPONSE_OK :
+	    filename = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ) );
+	    gsb_file_update_last_path ( file_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE ) );
+	    gtk_widget_destroy ( GTK_WIDGET ( dialog ) );
+
+	    /* vérification que c'est possible est faite par la boite de dialogue */
+	    if ( !gsb_csv_export_tree_view_list ( filename, tree_view ) )
+	    {
+            dialogue_error ( _("Cannot save file.") );
+            return;
+	    }
+
+	    break;
+
+	default :
+	    gtk_widget_destroy ( GTK_WIDGET ( dialog ));
+	    return;
+    }
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+void bet_historical_print_tab ( GtkWidget *menu_item,
+                        GtkTreeView *tree_view )
+{
+    GtkTreeSelection *selection;
+
+    selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
+
+    if ( !gtk_tree_selection_get_selected ( GTK_TREE_SELECTION ( selection ), NULL, NULL ) )
+    {
+        GtkTreePath *path;
+
+        path = gtk_tree_path_new_first ( );
+        gtk_tree_selection_select_path ( selection, path );
+        gtk_tree_path_free ( path );
+    }
+
+    print_tree_view_list ( menu_item, tree_view );
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gchar *bet_historical_get_hist_source_name ( gint account_number )
+{
+    gint result ;
+
+    if ( account_number == -1 )
+        return g_strdup ( _("Categories") );
+
+    result = gsb_data_account_get_bet_hist_data ( account_number );
+    if ( result )
+        return g_strdup ( _("Budgetary lines") );
+    else
+        return g_strdup ( _("Categories") );
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return TRUE
+ * */
+GHashTable *bet_historical_get_list_trans_current_fyear ( void )
+{
+    return list_trans_hist;
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return TRUE
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
