@@ -26,10 +26,12 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "categories_onglet.h"
 #include "dialog.h"
+#include "fenetre_principale.h"
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
 #include "gsb_data_category.h"
@@ -38,6 +40,7 @@
 #include "gsb_file_others.h"
 #include "gsb_transactions_list.h"
 #include "main.h"
+#include "meta_categories.h"
 #include "metatree.h"
 #include "mouse.h"
 #include "structures.h"
@@ -51,27 +54,26 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static void appui_sur_ajout_category ( GtkTreeModel * model, GtkButton *button );
-static gboolean categ_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePath * path,
-			       GtkSelectionData * selection_data );
+static void appui_sur_ajout_category ( GtkTreeModel *model,
+                        GtkButton *button );
+static gboolean categ_drag_data_get ( GtkTreeDragSource *drag_source,
+                        GtkTreePath *path,
+                        GtkSelectionData *selection_data );
 static gboolean category_list_button_press ( GtkWidget *tree_view,
                         GdkEventButton *ev,
                         gpointer null );
 static void category_list_popup_context_menu ( void );
-static void category_list_toggle_edit_category ( GtkCheckMenuItem *menu_item, gpointer data );
 static GtkWidget *creation_barre_outils_categ ( void );
-static gboolean edit_category ( GtkTreeView * view );
-static gboolean exporter_categ ( GtkButton * widget, gpointer data );
-static void importer_categ ( void );
-static gboolean popup_category_view_mode_menu ( GtkWidget * button );
-static void selectionne_sub_category ( GtkTreeModel * model );
+static gboolean edit_category ( GtkTreeView *tree_view );
+static gboolean popup_category_view_mode_menu ( GtkWidget *button );
+static void selectionne_sub_category ( GtkTreeModel *model );
 /*END_STATIC*/
 
 
-/* Category tree model & view */
-GtkTreeStore *categ_tree_model = NULL;
-GtkWidget *arbre_categ = NULL;
-gint no_devise_totaux_categ;
+/* Category toolbar, tree model & tree view */
+static GtkWidget *category_toolbar = NULL;
+static GtkTreeStore *categ_tree_model = NULL;
+static GtkWidget *arbre_categ = NULL;
 
 /* variable for the management of the cancelled edition */
 static gboolean sortie_edit_category = FALSE;
@@ -79,19 +81,36 @@ static gboolean sortie_edit_category = FALSE;
 /* structure pour la sauvegarde de la position */
 struct metatree_hold_position *category_hold_position;
 
+
 /*START_EXTERN*/
-extern MetatreeInterface * category_interface;
-extern GdkColor couleur_selection;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
+/**
+ * réinitialisation des variables globales
+ *
+ * \param
+ *
+ * \return
+ * */
+void categories_init_variables_list ( void )
+{
+    categ_tree_model = NULL;
+
+    category_toolbar = NULL;
+    arbre_categ = NULL;
+    etat.no_devise_totaux_categ = 1;
+
+    sortie_edit_category = FALSE;
+}
+
+
 /**
  * Create and return contents of the "Category" notebook page.
  *
  * \return A newly allocated hbox.
  */
-GtkWidget *onglet_categories ( void )
+GtkWidget *categories_create_list ( void )
 {
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
@@ -101,34 +120,18 @@ GtkWidget *onglet_categories ( void )
     static GtkTargetEntry row_targets[] = {
 	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
     };
+    MetatreeInterface *category_interface;
+
+    category_interface = category_get_metatree_interface ( );
 
     /* We create the gtktreeview and model early so that they can be referenced. */
     arbre_categ = gtk_tree_view_new();
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( arbre_categ, GTK_STATE_SELECTED, &couleur_selection );
-
-    categ_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
-
-    /* We create the main vbox */
-    vbox = gtk_vbox_new ( FALSE, 5 );
-    gtk_widget_show ( vbox );
-
-    /* on y ajoute la barre d'outils */
-    gtk_box_pack_start ( GTK_BOX ( vbox ), creation_barre_outils_categ(),
-			 FALSE, FALSE, 0 );
-
-    /* création de l'arbre principal */
-
-    scroll_window = gtk_scrolled_window_new ( NULL, NULL );
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scroll_window ),
-				     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scroll_window),
-					  GTK_SHADOW_IN );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), scroll_window, TRUE, TRUE, 0 );
-    gtk_widget_show ( scroll_window );
+    utils_set_tree_view_selection_and_text_color ( arbre_categ );
 
     /* Create model */
+    categ_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
     gtk_tree_sortable_set_sort_column_id ( GTK_TREE_SORTABLE(categ_tree_model),
 					   META_TREE_TEXT_COLUMN, GTK_SORT_ASCENDING );
     gtk_tree_sortable_set_sort_func ( GTK_TREE_SORTABLE(categ_tree_model),
@@ -137,6 +140,24 @@ GtkWidget *onglet_categories ( void )
     g_object_set_data ( G_OBJECT (categ_tree_model), "metatree-interface",
 			category_interface );
 
+    /* We create the main vbox */
+    vbox = gtk_vbox_new ( FALSE, 5 );
+    gtk_widget_show ( vbox );
+
+    /* on y ajoute la barre d'outils */
+    category_toolbar = gtk_handle_box_new ();
+    gtk_widget_show ( category_toolbar );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), category_toolbar, FALSE, FALSE, 0 );
+
+    /* création de l'arbre principal */
+    scroll_window = gtk_scrolled_window_new ( NULL, NULL );
+    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scroll_window ),
+				     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
+    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scroll_window),
+					  GTK_SHADOW_IN );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), scroll_window, TRUE, TRUE, 0 );
+    gtk_widget_show ( scroll_window );
+
     /* Create container + TreeView */
     gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (arbre_categ), TRUE);
     gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(arbre_categ),
@@ -157,6 +178,7 @@ GtkWidget *onglet_categories ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Category"), cell,
 						       "text", META_TREE_TEXT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( arbre_categ ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -166,6 +188,7 @@ GtkWidget *onglet_categories ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Account"), cell,
 						       "text", META_TREE_ACCOUNT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( arbre_categ ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -176,6 +199,7 @@ GtkWidget *onglet_categories ( void )
 						       "text", META_TREE_BALANCE_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
 						       "xalign", META_TREE_XALIGN_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_column_set_alignment ( column, 1.0 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( arbre_categ ),
@@ -185,6 +209,11 @@ GtkWidget *onglet_categories ( void )
     gtk_widget_show ( arbre_categ );
 
     /* Connect to signals */
+    g_signal_connect ( G_OBJECT ( arbre_categ ),
+                        "row-collapsed",
+                        G_CALLBACK ( division_column_collapsed ),
+                        NULL );
+
     g_signal_connect ( G_OBJECT ( arbre_categ ),
                         "row-expanded",
                         G_CALLBACK ( division_column_expanded ),
@@ -233,10 +262,11 @@ GtkWidget *onglet_categories ( void )
 /**
  * Fill category tree with data.
  */
-void remplit_arbre_categ ( void )
+void categories_fill_list ( void )
 {
     GSList *category_list;
     GtkTreeIter iter_categ, iter_sous_categ;
+    MetatreeInterface *category_interface;
 
     devel_debug (NULL);
 
@@ -253,10 +283,12 @@ void remplit_arbre_categ ( void )
 
     /** Then, populate tree with categories. */
     category_list = gsb_data_category_get_categories_list ();
-    
+
     /* add first the empty category */
     category_list = g_slist_prepend ( category_list, gsb_data_category_get_empty_category ());
 
+    category_interface = category_get_metatree_interface ( );
+
     while ( category_list )
     {
 	gint category_number;
@@ -316,12 +348,25 @@ void remplit_arbre_categ ( void )
             gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( arbre_categ ), ancestor );
             gtk_tree_path_free (ancestor );
         }
+        /* on colorise les lignes du tree_view */
+        utils_set_tree_view_background_color ( arbre_categ, META_TREE_BACKGROUND_COLOR );
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( arbre_categ ) );
         gtk_tree_selection_select_path ( selection, category_hold_position -> path );
         gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( arbre_categ ),
                         category_hold_position -> path,
                         NULL, TRUE, 0.5, 0.5 );
     }
+    else
+    {
+        gchar *title;
+
+        /* on colorise les lignes du tree_view */
+        utils_set_tree_view_background_color ( arbre_categ, META_TREE_BACKGROUND_COLOR );
+	    title = g_strdup(_("Categories"));
+        gsb_gui_headings_update_title ( title );
+        g_free ( title );
+        gsb_gui_headings_update_suffix ( "" );
+    }
 }
 
 
@@ -335,8 +380,9 @@ void remplit_arbre_categ ( void )
  *
  * \return FALSE, to allow future processing by the callback chain.
  */
-gboolean categ_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePath * path,
-			       GtkSelectionData * selection_data )
+gboolean categ_drag_data_get ( GtkTreeDragSource *drag_source,
+                        GtkTreePath *path,
+                        GtkSelectionData *selection_data )
 {
     if ( path )
     {
@@ -353,14 +399,14 @@ gboolean categ_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePath * pa
  *
  *
  */
-gboolean exporter_categ ( GtkButton * widget, gpointer data )
+void categories_exporter_list ( void )
 {
     GtkWidget *dialog;
     gint resultat;
     gchar *nom_categ;
 
     dialog = gtk_file_chooser_dialog_new ( _("Export categories"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
@@ -375,8 +421,8 @@ gboolean exporter_categ ( GtkButton * widget, gpointer data )
 
     if ( resultat != GTK_RESPONSE_OK )
     {
-	gtk_widget_destroy ( dialog );
-	return FALSE;
+        gtk_widget_destroy ( dialog );
+        return;
     }
 
     nom_categ = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
@@ -384,8 +430,6 @@ gboolean exporter_categ ( GtkButton * widget, gpointer data )
     gtk_widget_destroy ( GTK_WIDGET ( dialog ));
 
     gsb_file_others_save_category ( nom_categ );
-
-    return FALSE;
 }
 
 
@@ -394,7 +438,7 @@ gboolean exporter_categ ( GtkButton * widget, gpointer data )
  *
  *
  */
-void importer_categ ( void )
+void categories_importer_list ( void )
 {
     GtkWidget *dialog;
     gint resultat;
@@ -403,7 +447,7 @@ void importer_categ ( void )
     GtkFileFilter * filter;
 
     dialog = gtk_file_chooser_dialog_new ( _("Import categories"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_OPEN,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
@@ -482,7 +526,6 @@ void importer_categ ( void )
 }
 
 
-
 /**
  * Create a button bar allowing to act on the categories list.  Some
  * of these buttons are "linked" to the selection status of the
@@ -493,96 +536,111 @@ void importer_categ ( void )
  */
 GtkWidget *creation_barre_outils_categ ( void )
 {
-    GtkWidget * handlebox, * hbox2, * button;
-
-    /* HandleBox */
-    handlebox = gtk_handle_box_new ();
-
-    /* Hbox2 */
-    hbox2 = gtk_hbox_new ( FALSE, 0 );
-    gtk_container_add ( GTK_CONTAINER(handlebox), hbox2 );
+    GtkWidget *hbox, *button;
+    /* hbox */
+    hbox = gtk_hbox_new ( FALSE, 0 );
 
     /* New category button */
-    button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
-					       _("New\ncategory"),
-					       "new-categ.png",
-					       G_CALLBACK ( appui_sur_ajout_category ),
-					       categ_tree_model );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Create a new category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT (button), "type", GINT_TO_POINTER (1) );
+    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
+                                                _("New\ncategory"),
+                                                "new-categ.png",
+                                                G_CALLBACK ( appui_sur_ajout_category ),
+                                                categ_tree_model );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Create a new category"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (1) );
 
     /* New sub category button */
-    button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
-					       _("New sub\ncategory"),
-					       "new-sub-categ.png",
-					       G_CALLBACK (appui_sur_ajout_category),
-					       categ_tree_model );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "selection" );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "sub-division" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Create a new sub-category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT (button), "type", GINT_TO_POINTER (2) );
+    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
+                                                _("New sub\ncategory"),
+                                                "new-sub-categ.png",
+                                                G_CALLBACK (appui_sur_ajout_category),
+                                                categ_tree_model );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "selection" );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "sub-division" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Create a new sub-category"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (2) );
 
     /* Import button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_OPEN,
-					   _("Import"),
-					   G_CALLBACK (importer_categ),
-					   NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Import a Grisbi category file (.cgsb)"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                            GTK_STOCK_OPEN,
+                                            _("Import"),
+                                            G_CALLBACK ( categories_importer_list ),
+                                            NULL );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Import a Grisbi category file (.cgsb)"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* Export button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_SAVE,
-					   _("Export"),
-					   G_CALLBACK(exporter_categ),
-					   NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Export a Grisbi category file (.cgsb)"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                            GTK_STOCK_SAVE,
+                                            _("Export"),
+                                            G_CALLBACK ( categories_exporter_list ),
+                                            NULL );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Export a Grisbi category file (.cgsb)"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* Delete button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_DELETE, _("Delete"),
-					   G_CALLBACK (supprimer_division), arbre_categ );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Delete selected category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                            GTK_STOCK_DELETE, _("Delete"),
+                                            G_CALLBACK ( supprimer_division ), arbre_categ );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Delete selected category"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* Properties button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_PROPERTIES, _("Properties"),
-					   G_CALLBACK (edit_category), arbre_categ );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(categ_tree_model), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Edit selected category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                            GTK_STOCK_EDIT, _("Edit"),
+                                            G_CALLBACK ( edit_category ), arbre_categ );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Edit selected category"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* View button */
-    button = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
-						GTK_STOCK_SELECT_COLOR,
-						_("View"),
-						G_CALLBACK (popup_category_view_mode_menu),
-						NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Change view mode"));
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_menu_new ( conf.display_toolbar,
+                                                 GTK_STOCK_SELECT_COLOR,
+                                                 _("View"),
+                                                 G_CALLBACK ( popup_category_view_mode_menu ),
+                                                 NULL );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                                  _("Change view mode"));
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    gtk_widget_show_all ( handlebox );
+    gtk_widget_show_all ( hbox );
 
-    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL(categ_tree_model),
-					    FALSE, "selection" );
+    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL ( categ_tree_model ),
+                                            FALSE, "selection" );
 
-    return ( handlebox );
+    return ( hbox );
 }
 
 
+/**
+ *
+ *
+ *
+ */
+void categories_update_toolbar_list ( void )
+{
+    GList * list = NULL;
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( category_toolbar ) );
+
+    if ( list )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( category_toolbar ),
+                               GTK_WIDGET ( list -> data ) );
+        g_list_free ( list );
+    }
+    gtk_container_add ( GTK_CONTAINER ( category_toolbar ), creation_barre_outils_categ () );
+}
+
 
 /**
  * Popup a menu that allow changing the view mode of the category
@@ -592,7 +650,7 @@ GtkWidget *creation_barre_outils_categ ( void )
  *
  * \return		FALSE
  */
-gboolean popup_category_view_mode_menu ( GtkWidget * button )
+gboolean popup_category_view_mode_menu ( GtkWidget *button )
 {
     GtkWidget *menu, *menu_item;
 
@@ -631,7 +689,7 @@ gboolean popup_category_view_mode_menu ( GtkWidget * button )
  *
  *
  */
-gboolean edit_category ( GtkTreeView * view )
+gboolean edit_category ( GtkTreeView *tree_view )
 {
     GtkWidget * dialog, *paddingbox, *table, *label, *entry, *hbox, *radiogroup;
     gint category_number = -1, sub_category_number = -1;
@@ -640,11 +698,12 @@ gboolean edit_category ( GtkTreeView * view )
     GtkTreeIter iter;
     gchar * title;
     GtkTreeIter *div_iter;
+    MetatreeInterface *category_interface;
 
     /* fill category_number and sub_category_number */
 
-    selection = gtk_tree_view_get_selection ( view );
-    if ( selection && gtk_tree_selection_get_selected(selection, &model, &iter))
+    selection = gtk_tree_view_get_selection ( tree_view );
+    if ( selection && gtk_tree_selection_get_selected ( selection, &model, &iter ) )
     {
 	gtk_tree_model_get ( model, &iter,
 			     META_TREE_NO_DIV_COLUMN, &category_number,
@@ -665,7 +724,7 @@ gboolean edit_category ( GtkTreeView * view )
 										       _("No category defined") ));
 
     dialog = gtk_dialog_new_with_buttons ( title,
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_DIALOG_MODAL,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
 					   GTK_STOCK_APPLY, GTK_RESPONSE_OK,
@@ -754,14 +813,14 @@ gboolean edit_category ( GtkTreeView * view )
 	    if ( sub_category_number > 0 )
 	    {
 		message = g_strdup_printf ( _("You tried to rename current sub-category to '%s' "
-					      "but this sub-category already exists.  Please "
+					      "but this sub-category already exists. Please "
 					      "choose another name."),
 					    gtk_entry_get_text ( GTK_ENTRY ( entry ) ) );
 	    }
 	    else
 	    {
 		message = g_strdup_printf ( _("You tried to rename current category to '%s' "
-					      "but this category already exists.  Please "
+					      "but this category already exists. Please "
 					      "choose another name."),
 					    gtk_entry_get_text ( GTK_ENTRY ( entry ) ) );
 	    }
@@ -787,6 +846,8 @@ gboolean edit_category ( GtkTreeView * view )
 
     gtk_widget_destroy ( dialog );
 
+    category_interface = category_get_metatree_interface ( );
+
     if ( sub_category_number > 0 )
     {
 	div_iter = get_iter_from_div ( model, category_number, sub_category_number );
@@ -807,9 +868,7 @@ gboolean edit_category ( GtkTreeView * view )
     /* update the transactions list */
     transaction_list_update_element (ELEMENT_CATEGORY);
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
-
+    gsb_file_set_modified ( TRUE );
 
     return TRUE;
 }
@@ -820,7 +879,8 @@ gboolean edit_category ( GtkTreeView * view )
  *
  * \param the model for the division
  */
-void appui_sur_ajout_category ( GtkTreeModel * model, GtkButton *button )
+void appui_sur_ajout_category ( GtkTreeModel *model,
+                        GtkButton *button )
 {
     gint type;
 
@@ -845,7 +905,7 @@ void appui_sur_ajout_category ( GtkTreeModel * model, GtkButton *button )
  *
  * \param the model for the division
  */
-void selectionne_sub_category ( GtkTreeModel * model )
+void selectionne_sub_category ( GtkTreeModel *model )
 {
     GtkTreeSelection * selection;
     GtkTreeIter parent;
@@ -872,7 +932,7 @@ void selectionne_sub_category ( GtkTreeModel * model )
         return;
 
     name =  my_strdup (_("New sub-category"));
-    sub_category_number = gsb_data_category_get_sub_category_number_by_name ( 
+    sub_category_number = gsb_data_category_get_sub_category_number_by_name (
                         category_number, name, FALSE );
     j = gtk_tree_model_iter_n_children ( model, &parent );
     for (i = 0; i < j; i++ )
@@ -902,7 +962,7 @@ void selectionne_sub_category ( GtkTreeModel * model )
  *
  * \return une copie de category_hold_position -> path
  */
-GtkTreePath *category_hold_position_get_path ( void )
+GtkTreePath *categories_hold_position_get_path ( void )
 {
     return gtk_tree_path_copy ( category_hold_position -> path );
 }
@@ -912,7 +972,7 @@ GtkTreePath *category_hold_position_get_path ( void )
  *
  * \param path
  */
-gboolean category_hold_position_set_path ( GtkTreePath *path )
+gboolean categories_hold_position_set_path ( GtkTreePath *path )
 {
     category_hold_position -> path = gtk_tree_path_copy ( path );
 
@@ -925,7 +985,7 @@ gboolean category_hold_position_set_path ( GtkTreePath *path )
  *
  * \param expand
  */
-gboolean category_hold_position_set_expand ( gboolean expand )
+gboolean categories_hold_position_set_expand ( gboolean expand )
 {
     category_hold_position -> expand = expand;
 
@@ -1020,13 +1080,28 @@ void category_list_popup_context_menu ( void )
 
     type_division = metatree_get_row_type_from_tree_view ( arbre_categ );
 
-    if ( type_division == META_TREE_TRANSACTION
-     ||
-     type_division == META_TREE_INVALID )
+    if ( type_division == META_TREE_INVALID )
         return;
 
     menu = gtk_menu_new ();
 
+    if ( type_division == META_TREE_TRANSACTION )
+    {
+        title = g_strdup ( _("Transfers the identical transactions in another sub-category") );
+
+        menu_item = gtk_image_menu_item_new_with_label ( title );
+        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
+                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
+                        GTK_ICON_SIZE_MENU ) );
+        g_signal_connect_swapped ( G_OBJECT ( menu_item ),
+                        "activate",
+                        G_CALLBACK ( metatree_transfer_identical_transactions ),
+                        arbre_categ );
+        gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+
+        g_free ( title );
+    }
+
     if ( type_division == META_TREE_DIV || type_division == META_TREE_SUB_DIV )
     {
 
@@ -1038,7 +1113,7 @@ void category_list_popup_context_menu ( void )
 
         menu_item = gtk_image_menu_item_new_with_label ( title );
         gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                            gtk_image_new_from_stock ( GTK_STOCK_PROPERTIES,
+                            gtk_image_new_from_stock ( GTK_STOCK_EDIT,
                             GTK_ICON_SIZE_MENU ) );
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                             "activate",
@@ -1081,6 +1156,87 @@ void category_list_popup_context_menu ( void )
 }
 
 
+/**
+ *
+ *
+ *
+ */
+GtkWidget *category_list_get_toolbar ( void )
+{
+    return category_toolbar;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+GtkTreeStore *categories_get_tree_store ( void )
+{
+    return categ_tree_model;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+GtkWidget *categories_get_tree_view ( void )
+{
+    return arbre_categ;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void categories_new_category ( void )
+{
+    metatree_new_division ( GTK_TREE_MODEL ( categ_tree_model ) );
+
+    sortie_edit_category = FALSE;
+    edit_category ( GTK_TREE_VIEW ( arbre_categ ) );
+    if ( sortie_edit_category )
+    {
+        supprimer_division ( GTK_TREE_VIEW ( arbre_categ ) );
+        sortie_edit_category = FALSE;
+    }
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void categories_delete_category ( void )
+{
+    supprimer_division ( GTK_TREE_VIEW ( arbre_categ ) );
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void categories_edit_category ( void )
+{
+    edit_category ( GTK_TREE_VIEW ( arbre_categ ) );
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
