@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C)    2005-2006 Benjamin Drieu (bdrieu@april.org)           */
-/*          2008-2009 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          2008-2011 Pierre Biava (grisbi@pierre.biava.name)                 */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -26,12 +26,14 @@
 #endif
 
 #include "include.h"
+#include <string.h>
 
 /*START_INCLUDE*/
 #include "csv_parse.h"
 #include "utils_dates.h"
 #include "gsb_data_currency.h"
 #include "gsb_real.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "gsb_data_transaction.h"
 #include "import.h"
@@ -41,7 +43,7 @@
 /*END_EXTERN*/
 
 /*START_STATIC*/
-static gchar * sanitize_field ( gchar * begin, gchar * end  );
+static gchar *sanitize_field ( gchar *begin, gchar *end  );
 /*END_STATIC*/
 
 
@@ -50,115 +52,121 @@ static gchar * sanitize_field ( gchar * begin, gchar * end  );
  *
  *
  */
-GSList * csv_parse_line ( gchar ** contents, gchar * separator )
+GSList * csv_parse_line ( gchar **contents, gchar *separator )
 {
-    gchar * tmp = (* contents), * begin = tmp;
-    gint is_unquoted = FALSE, len = strlen ( separator );
-    GSList * list = NULL;
+    gchar *tmp;
+    gchar *begin;
+    gint is_unquoted = FALSE;
+    gint len;
+    GSList *list = NULL;
+
+    len = strlen ( separator );
+    tmp = (*contents);
+    begin = tmp;
 
     if ( *tmp == '\n' )
     {
-	*contents = tmp+1;
-	return GINT_TO_POINTER(-1);
+        *contents = tmp + 1;
+        return GINT_TO_POINTER ( -1 );
     }
-    
+
     if ( *tmp == '!' || *tmp == '#' || *tmp == ';' )
     {
-	*contents = strchr ( tmp, '\n' ) + 1;
-	return GINT_TO_POINTER(-1);
+        *contents = strchr ( tmp, '\n' ) + 1;
+        return GINT_TO_POINTER(-1);
     }
 
     while ( *tmp )
     {
-	switch ( *tmp )
-	{
-	    case '\n':
-		list = g_slist_append ( list, sanitize_field ( begin, tmp ) );
-		*contents = tmp+1;
-		return list;
+        switch ( *tmp )
+        {
+            case '\n':
+            list = g_slist_append ( list, sanitize_field ( begin, tmp ) );
+            *contents = tmp+1;
+            return list;
 
-	    case '"':
-		if ( ! is_unquoted )
-		{
-		    tmp++;
-		    while ( *tmp )
-		    {
-			/* This is lame escaping but we need to
-			 * support it. */
-			if ( *tmp == '\\' && *(tmp+1) == '"' )
-			{
-			    tmp += 2;
-			}
+            case '"':
+            if ( ! is_unquoted )
+            {
+                tmp++;
+                while ( *tmp )
+                {
+                /* This is lame escaping but we need to
+                 * support it. */
+                if ( *tmp == '\\' && *(tmp+1) == '"' )
+                {
+                    tmp += 2;
+                }
 
-			/* End of quoted string. */
-			if ( *tmp == '"' && *(tmp+1) != '"' )
-			{
-			    break;
-			}
-			
-			tmp++;
-		    }
-		}
+                /* End of quoted string. */
+                if ( *tmp == '"' && *(tmp+1) != '"' )
+                {
+                    break;
+                }
 
-	    default:
-		is_unquoted = TRUE;
-		if ( !strncmp ( tmp, separator, len ) )
-		{
-		    list = g_slist_append ( list, sanitize_field ( begin, tmp ) );
-		    begin = tmp + len;
-		    is_unquoted = FALSE;
-		}
-		break;
-	}
+                tmp++;
+                }
+            }
 
-	tmp++;
+            default:
+            is_unquoted = TRUE;
+            if ( !strncmp ( tmp, separator, len ) )
+            {
+                list = g_slist_append ( list, sanitize_field ( begin, tmp ) );
+                begin = tmp + len;
+                is_unquoted = FALSE;
+            }
+            break;
+        }
+
+        tmp++;
     }
 
     return NULL;
 }
 
 
-
 /**
  * TODO
  *
  */
-gchar * sanitize_field ( gchar * begin, gchar * end  )
+gchar *sanitize_field ( gchar *begin, gchar *end  )
 {
-    gchar * field, * iter;
+    gchar *field;
+    gchar *iter;
 
     g_return_val_if_fail ( begin <= end, NULL );
 
     if ( end <= begin )
-	return "";
+        return "";
 
     iter = field = g_malloc0 ( end - begin + 1 );
 
     /* Strip out intial white spaces. */
     while ( *begin == ' ' )
-	begin++;
+        begin++;
 
     if ( *begin == '"' )
     {
-	begin++;
-	while ( *end != '"' && end >= begin )
-	    end--;
+        begin++;
+        while ( *end != '"' && end >= begin )
+            end--;
     }
 
     while ( begin < end )
     {
-	if ( *begin == '"' && *(begin+1) == '"' )
-	    begin++;
+        if ( *begin == '"' && *(begin+1) == '"' )
+            begin++;
 
-	if ( *begin == '\\' && *(begin+1) == '"' )
-	    begin++;
-	
-	*iter++ = *begin++;
+        if ( *begin == '\\' && *(begin+1) == '"' )
+            begin++;
+
+        *iter++ = *begin++;
     }
 
     /* Strip out remaining white spaces. */
-    while ( *(iter-1) == ' ' || *(iter-1) == '\n' )
-	iter--;
+    while ( *(iter-1) == ' ' || *(iter-1) == '\r' || *(iter-1) == '\n' )
+        iter--;
 
     *iter = '\0';
 
@@ -166,10 +174,6 @@ gchar * sanitize_field ( gchar * begin, gchar * end  )
 }
 
 
-
-
-
-
 /**
  *
  *
@@ -193,13 +197,13 @@ gboolean csv_import_validate_date ( gchar * string )
     g_return_val_if_fail ( string, FALSE );
 
     date = gsb_parse_date_string ( string );
-    if ( date && g_date_valid ( date ) && 
+    if ( date && g_date_valid ( date ) &&
 	 ! csv_import_validate_number ( string ) )
     {
         g_date_free ( date );
         return TRUE;
     }
-    
+
     if ( date )
         g_date_free ( date );
     return FALSE;
@@ -254,7 +258,6 @@ gboolean csv_import_validate_amount ( gchar * string )
 }
 
 
-
 /**
  *
  *
@@ -280,7 +283,7 @@ gboolean csv_import_parse_date ( struct struct_ope_importation * ope, gchar * st
 {
     g_return_val_if_fail ( string, FALSE );
 
-    if ( ope -> date ) 
+    if ( ope -> date )
         g_date_free ( ope-> date );
     ope -> date = gsb_parse_date_string ( string );
 
@@ -422,11 +425,12 @@ gboolean csv_import_parse_sub_budget ( struct struct_ope_importation * ope, gcha
  */
 gboolean csv_import_parse_balance ( struct struct_ope_importation * ope, gchar * string )
 {
-    g_return_val_if_fail ( string, FALSE );
+    if ( !string )
+        return FALSE;
 
     if ( strlen ( string ) > 0 )
     {
-        ope -> montant = gsb_real_get_from_string ( string );
+        ope -> montant = utils_real_get_from_string ( string );
         return TRUE;
     }
 
@@ -439,35 +443,38 @@ gboolean csv_import_parse_balance ( struct struct_ope_importation * ope, gchar *
  */
 gboolean csv_import_parse_credit ( struct struct_ope_importation * ope, gchar * string )
 {
-    g_return_val_if_fail ( string, FALSE );
+    if ( !string )
+        return FALSE;
+
     if ( strlen ( string ) > 0 )
     {
-	ope -> montant = gsb_real_add ( ope -> montant,
-					gsb_real_get_from_string (string));
+        ope -> montant = gsb_real_add ( ope -> montant,
+                        utils_real_get_from_string (string));
     }
+
     return TRUE;
 }
 
 
-
 /**
  *
  *
  */
 gboolean csv_import_parse_debit ( struct struct_ope_importation * ope, gchar * string )
 {
-    g_return_val_if_fail ( string, FALSE );
+    if ( !string )
+        return FALSE;
 
     if ( strlen ( string ) > 0 )
     {
-	ope -> montant = gsb_real_sub ( ope -> montant,
-					gsb_real_get_from_string (string));
+        ope -> montant = gsb_real_sub ( ope -> montant,
+                        utils_real_get_from_string ( string ) );
     }
+
     return TRUE;
 }
 
 
-
 /**
  *
  *
