@@ -86,7 +86,9 @@ extern GdkColor text_color[2];
 /*END_EXTERN*/
 
 
-static GObjectClass *parent_class = NULL;  /* GObject stuff - nothing to worry about */
+G_DEFINE_TYPE_EXTENDED (
+    CustomList, custom_list, G_TYPE_OBJECT, 0,
+    G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, custom_list_tree_model_init));
 
 
 /**
@@ -143,52 +145,6 @@ CustomList *custom_list_new (void)
 }
 
 
-/**
- * we register our new type and its interfaces with the type system.
- * extern is necessary for mk_include to set that function in custom_list.h
- *
- * \param
- *
- * \return	Gtype
- * */
-extern GType custom_list_get_type (void)
-{
-    static GType custom_list_type = 0;
-
-    /* Some boilerplate type registration stuff */
-    if (custom_list_type == 0)
-    {
-	static const GTypeInfo custom_list_info =
-	{
-	    sizeof (CustomListClass),
-	    NULL,                                         /* base_init */
-	    NULL,                                         /* base_finalize */
-	    (GClassInitFunc) custom_list_class_init,
-	    NULL,                                         /* class finalize */
-	    NULL,                                         /* class_data */
-	    sizeof (CustomList),
-	    0,                                           /* n_preallocs */
-	    (GInstanceInitFunc) custom_list_init
-	};
-	static const GInterfaceInfo tree_model_info =
-	{
-	    (GInterfaceInitFunc) custom_list_tree_model_init,
-	    NULL,
-	    NULL
-	};
-
-	/* First register the new derived type with the GObject type system */
-	custom_list_type = g_type_register_static (G_TYPE_OBJECT, "CustomList",
-						   &custom_list_info, (GTypeFlags)0);
-
-	/* Now register our GtkTreeModel interface with the type system */
-	g_type_add_interface_static (custom_list_type, GTK_TYPE_TREE_MODEL, &tree_model_info);
-    }
-
-    return custom_list_type;
-}
-
-
 /**
  * Init callback for the type system
  * called once when our new class is created
@@ -199,12 +155,9 @@ extern GType custom_list_get_type (void)
  * */
 static void custom_list_class_init (CustomListClass *klass)
 {
-    GObjectClass *object_class;
+    GObjectClass *gobject_class = G_OBJECT_CLASS ( klass );
 
-    parent_class = (GObjectClass*) g_type_class_peek_parent (klass);
-    object_class = (GObjectClass*) klass;
-
-    object_class->finalize = custom_list_finalize;
+    gobject_class->finalize = custom_list_finalize;
 }
 
 
@@ -294,10 +247,48 @@ static void custom_list_init (CustomList *custom_list)
  * */
 void custom_list_finalize (GObject *object)
 {
-    transaction_model_initialize ();
+    CustomList *custom_list;
+    gint i;
+
+    custom_list = CUSTOM_LIST ( object );
+
+    /* free all records and free all memory used by the list */
+    for (i=0 ; i<custom_list -> num_rows ; i++)
+    {
+	CustomRecord *record;
+	gint j;
+
+	record = custom_list -> rows[i];
+	for (j=0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++)
+	    if (record -> visible_col[j])
+		g_free (record -> visible_col[j]);
+
+	if (record -> number_of_children)
+	{
+	    gint k;
+	    for (k=0 ; k<record -> number_of_children ; k++)
+	    {
+		CustomRecord *child_record;
+
+		child_record = record -> children_rows[k];
+
+		for (j=0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++)
+		    if (child_record -> visible_col[j])
+			g_free (child_record -> visible_col[j]);
+		g_free (child_record);
+	    }
+	    g_free (record -> children_rows);
+
+	    for (k=0 ; k<TRANSACTION_LIST_ROWS_NB ; k++)
+		record -> transaction_records[k] -> number_of_children = 0;
+	}
+	g_free (record);
+    }
+    g_free (custom_list -> rows);
+    g_free (custom_list -> visibles_rows);
 
     /* must chain up - finalize parent */
-    (* parent_class->finalize) (object);
+    G_OBJECT_CLASS(custom_list_parent_class)->finalize (object);
 }
 
 
@@ -324,7 +315,7 @@ static GtkTreeModelFlags custom_list_get_flags (GtkTreeModel *tree_model)
 /**
  * tells the rest of the world how many data
  * columns we export via the tree model interface
- * 
+ *
  * reached by gtk_tree_model_get_n_columns
  *
  * \param 	tree_model
@@ -441,14 +432,11 @@ static GtkTreePath *custom_list_get_path (GtkTreeModel *tree_model,
 {
     GtkTreePath  *path;
     CustomRecord *record;
-    CustomList   *custom_list;
 
     g_return_val_if_fail (CUSTOM_IS_LIST(tree_model), NULL);
     g_return_val_if_fail (iter != NULL,               NULL);
     g_return_val_if_fail (iter->user_data != NULL,    NULL);
 
-    custom_list = CUSTOM_LIST(tree_model);
-
     record = (CustomRecord*) iter->user_data;
 
     path = gtk_tree_path_new();
@@ -480,7 +468,6 @@ static void custom_list_get_value (GtkTreeModel *tree_model,
 				   GValue       *value)
 {
     CustomRecord  *record;
-    CustomList    *custom_list;
 
     g_return_if_fail (CUSTOM_IS_LIST (tree_model));
     g_return_if_fail (iter != NULL);
@@ -488,8 +475,6 @@ static void custom_list_get_value (GtkTreeModel *tree_model,
 
     g_value_init (value, CUSTOM_LIST(tree_model)->column_types[column]);
 
-    custom_list = CUSTOM_LIST(tree_model);
-
     record = (CustomRecord*) iter->user_data;
     g_return_if_fail ( record != NULL );
 
@@ -793,7 +778,7 @@ static gboolean custom_list_iter_has_child (GtkTreeModel *tree_model,
 
 /**
  * Returns the number of children the row
- * specified by 'iter' has. 
+ * specified by 'iter' has.
  * A special case i when 'iter' is NULL, in which case we need
  * to return the number of top-level nodes, ie. the number of rows in our list.
  *
