@@ -26,14 +26,16 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "dialog.h"
 #include "parametres.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
+static void dialogue_special ( GtkMessageType param, gchar *text );
 static void dialogue_conditional ( gchar *text, gchar *var );
 static GtkDialog *dialogue_conditional_new ( gchar *text,
                         gchar *var,
@@ -45,7 +47,6 @@ static gboolean dialogue_update_var ( GtkWidget *checkbox, gint message );
 
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -59,9 +60,9 @@ struct conditional_message messages[] =
 
     { "encryption-is-irreversible", N_("Encryption is irreversible."),
       N_("Grisbi encrypts files in a very secure way that does not allow recovery without "
-      "original password.  It means that if you forget your password, you will loose all "
-      "your data.  Use with caution.\n\nI repeat: if you ever forget your password, there "
-      "is no coming back, we cannot help you."), 
+      "original password. It means that if you forget your password, you will loose all "
+      "your data. Use with caution.\n\nI repeat: if you ever forget your password, there "
+      "is no coming back, we cannot help you."),
       FALSE, FALSE, },
 
     { "account-file-readable",  N_("Account file is world readable."),
@@ -74,11 +75,11 @@ struct conditional_message messages[] =
       "(maybe Grisbi crashed?).\nGrisbi can't save the file unless you activate the "
       "\"Force saving locked files\" option in setup."),
       FALSE, FALSE, },
-     
-    { "minimum-balance-alert", N_("Account under desired balance."),
-      N_("Grisbi detected that an account is under a desired balance: %s"), 
+
+    { "minimum-balance-alert", N_("Account under desired balance"),
+      N_("Grisbi detected that an account is under a desired balance: %s"),
       FALSE, FALSE, },
-    
+
     { "no-budgetary-line", N_("No budgetary line was entered"),
       N_("This transaction has no budgetary line entered.  You should use them to "
       "easily produce budgets and make reports on them."),
@@ -96,31 +97,25 @@ struct conditional_message messages[] =
     { "reconcile-transaction", N_("Confirmation of manual (un)reconciliation"),
       N_("You are trying to reconcile or unreconcile a transaction manually, "
 	  "which is not a recommended action.\n"
-      "Are you really sure you know what you are doing?"), 
+      "Are you really sure you know what you are doing?"),
       FALSE, FALSE, },
 
     { "reconcile-start-end-dates", N_("Reconcile start and end dates."),
       N_("In previous versions, Grisbi did not save start date, end date and balance for "
-      "reconciliation.  This is now done, so Grisbi will try to guess values from your "
-      "accounts.  Thought this can not harm data coherence, false values can be guessed. "
-      "Please check in the Preferences window for more information."), 
+      "reconciliation. This is now done, so Grisbi will try to guess values from your "
+      "accounts. Thought this can not harm data coherence, false values can be guessed. "
+      "Please check in the Preferences window for more information."),
       FALSE, FALSE, },
 
-    { "development-version", N_("You are running Grisbi version %s"), 
+    { "development-version", N_("You are running Grisbi version %s"),
       N_("Warning, please be aware that the version you run is a DEVELOPMENT version. "
-      "Never use your original file grisbi: you could make it unusable.\n"
+      "Never use your original file Grisbi: you could make it unusable.\n"
       "Make a copy now."),
       FALSE, FALSE },
 
-    { "gtk_obsolete", N_("You are running Grisbi with GTK version %s"), 
-      N_("Warning, please be aware that the version you run is a DEVELOPMENT version. "
-     "In any case do not work with this version on your original accounting files. "
-     "(File format may change and render files incompatible with previous versions)."),
-      FALSE, FALSE },
-
 /*
     { "", N_(),
-      N_(), 
+      N_(),
       FALSE, FALSE, },
 */
     { NULL },
@@ -156,7 +151,7 @@ void dialogue ( gchar *texte_dialogue )
  *
  * \param text Text to display in window
  */
-G_MODULE_EXPORT void dialogue_error ( gchar *text )
+void dialogue_error ( gchar *text )
 {
     dialogue_special ( GTK_MESSAGE_ERROR, text );
 }
@@ -168,7 +163,7 @@ G_MODULE_EXPORT void dialogue_error ( gchar *text )
  * \param text Text to display in window
  * \param hint Text to display in window as hint (bold, larger)
  */
-G_MODULE_EXPORT void dialogue_error_hint ( const gchar *text, gchar *hint )
+void dialogue_error_hint ( const gchar *text, gchar *hint )
 {
     dialogue_special ( GTK_MESSAGE_ERROR, make_hint (hint, text) );
 }
@@ -179,7 +174,7 @@ G_MODULE_EXPORT void dialogue_error_hint ( const gchar *text, gchar *hint )
  *
  * \param text Text to display in window
  */
-G_MODULE_EXPORT void dialogue_warning ( gchar *text )
+void dialogue_warning ( gchar *text )
 {
     dialogue_special ( GTK_MESSAGE_WARNING, text );
 }
@@ -199,7 +194,7 @@ void dialogue_warning_hint ( gchar *text, gchar *hint )
 
 /**
  * Display a dialog window with arbitrary icon.
- * WARNING you may need to escape text with g_markup_escape_text() 
+ * WARNING you may need to escape text with g_markup_escape_text()
  * or g_markup_printf_escaped():
  *
  * \param param Type of Window to display
@@ -209,7 +204,7 @@ void dialogue_special ( GtkMessageType param, gchar *text )
 {
     GtkWidget *dialog;
 
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window), 
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
                         GTK_DIALOG_DESTROY_WITH_PARENT,
                         param, GTK_BUTTONS_CLOSE,
                         "%s", text );
@@ -223,9 +218,9 @@ void dialogue_special ( GtkMessageType param, gchar *text )
 
 /**
  * Display a dialog window with arbitrary icon.
- * WARNING you may need to escape text with g_markup_escape_text() 
+ * WARNING you may need to escape text with g_markup_escape_text()
  * or g_markup_printf_escaped():
- * 
+ *
  * \param param Type of Window to display
  * \param text Text to display in window
  */
@@ -235,13 +230,22 @@ GtkWidget *dialogue_special_no_run ( GtkMessageType param,
 {
     GtkWidget *dialog;
 
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window), 
-                        GTK_DIALOG_DESTROY_WITH_PARENT,
+    if ( GTK_IS_WINDOW ( run.window ) )
+    {
+        dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
+                        GTK_DIALOG_DESTROY_WITH_PARENT || GTK_DIALOG_MODAL,
                         param, buttons,
                         "%s", text );
-    gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG(dialog)->label ), text );
+    }
+    else
+    {
+        dialog = gtk_message_dialog_new ( NULL,
+                        0,
+                        param, buttons,
+                        "%s", text );
+    }
 
-    gtk_window_set_modal ( GTK_WINDOW ( dialog ), TRUE );
+    gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG(dialog)->label ), text );
 
     return dialog;
 }
@@ -287,7 +291,7 @@ gboolean dialogue_update_var ( GtkWidget *checkbox, gint message )
 /**
  * Create a dialog with an informal text and a checkbox that allow
  * this message not to be displayed again thanks to preferences.
- * WARNING you may need to escape text with g_markup_escape_text() 
+ * WARNING you may need to escape text with g_markup_escape_text()
  * or g_markup_printf_escaped():
  *
  * \param text  Text to be displayed
@@ -320,7 +324,7 @@ GtkDialog *dialogue_conditional_new ( gchar *text,
         }
     }
 
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window),
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
                         GTK_DIALOG_DESTROY_WITH_PARENT,
                         type, buttons,
                         "%s", text );
@@ -330,7 +334,7 @@ GtkDialog *dialogue_conditional_new ( gchar *text,
     vbox = GTK_DIALOG(dialog) -> vbox;
 
     checkbox = gtk_check_button_new_with_label ( _("Do not show this message again") );
-    g_signal_connect ( G_OBJECT ( checkbox ), "toggled", 
+    g_signal_connect ( G_OBJECT ( checkbox ), "toggled",
                         G_CALLBACK ( dialogue_update_var ), GINT_TO_POINTER ( i ) );
     gtk_box_pack_start ( GTK_BOX ( vbox ), checkbox, TRUE, TRUE, 6 );
     gtk_widget_show_all ( checkbox );
@@ -420,7 +424,7 @@ gboolean question_yes_no_hint ( gchar *hint,
 /**
  * Pop up a warning dialog window with a question and wait for user to
  * press 'YES' or 'NO'.
-  * WARNING you may need to escape text with g_markup_escape_text() 
+  * WARNING you may need to escape text with g_markup_escape_text()
  * or g_markup_printf_escaped():
  *
  * \param texte  Text to be displayed
@@ -433,7 +437,7 @@ gboolean question_yes_no ( gchar *text, gint default_answer )
     GtkWidget *dialog;
     gint response;
 
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window),
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
                         GTK_DIALOG_DESTROY_WITH_PARENT,
                         GTK_MESSAGE_QUESTION,
                         GTK_BUTTONS_YES_NO,
@@ -518,7 +522,7 @@ gboolean question_conditional_yes_no_with_struct ( struct conditional_message *m
         return message -> default_answer;
 
     text = make_hint ( _(message -> hint), message -> message );
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window),
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
                         GTK_DIALOG_DESTROY_WITH_PARENT,
                         GTK_MESSAGE_WARNING,
                         GTK_BUTTONS_YES_NO,
@@ -530,7 +534,7 @@ gboolean question_conditional_yes_no_with_struct ( struct conditional_message *m
 
     checkbox = gtk_check_button_new_with_label ( _("Do not show this message again") );
     g_signal_connect ( G_OBJECT ( checkbox ),
-                        "toggled", 
+                        "toggled",
                         G_CALLBACK ( dialogue_update_struct_message ),
                         message );
     gtk_box_pack_start ( GTK_BOX ( vbox ), checkbox, TRUE, TRUE, 6 );
@@ -601,12 +605,12 @@ gchar *make_hint ( const gchar *hint, const gchar *text )
 /**
  * use pango layout to produce a string that will contain a text.
  *
- * \param text Text 
+ * \param text Text
  *
- * \return a pango formated string It returns a newly allocated string which must 
+ * \return a pango formated string It returns a newly allocated string which must
  *         be freed when no more used.
  */
-gchar *make_red ( gchar *text )
+gchar *make_red ( const gchar *text )
 {
     gchar *tmpstr;
 
@@ -620,17 +624,18 @@ gchar *make_red ( gchar *text )
  * use pango layout to produce a string that will contain a text.
  *
  * \param attribut  exemple foreground=\"red\", size=\"x-large\"
- * \param text      Text 
+ * \param text      Text
  *
- * \return a pango formated string It returns a newly allocated string which must 
+ * \return a pango formated string It returns a newly allocated string which must
  *         be freed when no more used.
  */
-gchar *make_pango_attribut ( gchar *attribut, gchar *text )
+gchar *make_pango_attribut ( gchar *attribut, const gchar *text )
 {
-    gchar *tmpstr;
+    gchar *tmpstr, *span_format;
 
-    tmpstr = g_markup_printf_escaped (
-                        g_strconcat ( "<span ", attribut, ">%s</span>", NULL ), text );
+    span_format = g_strconcat ( "<span ", attribut, ">%s</span>", NULL );
+    tmpstr = g_markup_printf_escaped ( span_format , text );
+    g_free ( span_format );
 
     return tmpstr;
 }
@@ -639,12 +644,12 @@ gchar *make_pango_attribut ( gchar *attribut, gchar *text )
 /**
  * use pango layout to produce a string that will contain a text.
  *
- * \param text Text 
+ * \param text Text
  *
- * \return a pango formated string It returns a newly allocated string which must 
+ * \return a pango formated string It returns a newly allocated string which must
  *         be freed when no more used.
  */
-gchar *make_blue ( gchar *text )
+gchar *make_blue ( const gchar *text )
 {
     gchar *tmpstr;
 
@@ -662,7 +667,7 @@ gchar *make_blue ( gchar *text )
 void dialogue_error_brain_damage ()
 {
     dialogue_error_hint ( _("Hi, you are in the middle of nowhere, between two lines of code."
-                        " Grisbi is expected to crash very soon. Have a nice day."), 
+                        " Grisbi is expected to crash very soon. Have a nice day."),
                         _("Serious brain damage expected.") );
 }
 
@@ -732,9 +737,9 @@ const gchar *dialogue_hint_with_entry ( gchar *text, gchar *hint, gchar *entry_d
 
     format_text = make_hint ( hint, text );
 
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window), 
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
                         GTK_DIALOG_DESTROY_WITH_PARENT,
-                        GTK_MESSAGE_INFO, 
+                        GTK_MESSAGE_INFO,
                         GTK_BUTTONS_CLOSE,
                         "%s", format_text );
     gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG(dialog)->label ), format_text );
