@@ -28,24 +28,24 @@
 #endif
 
 #include "include.h"
-
+#include <stdlib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "erreur.h"
 #include "dialog.h"
+#include "gsb_dirs.h"
+#include "gsb_file.h"
 #include "gsb_file_save.h"
 #include "gsb_file_util.h"
-#include "gsb_file_config.h"
-#include "gsb_plugins.h"
 #include "gsb_real.h"
 #include "gsb_status.h"
 #include "import.h"
 #include "main.h"
-#include "structures.h"
-#include "traitement_variables.h"
 #include "utils.h"
-#include "utils_files.h"
 #include "utils_str.h"
+#include "menu.h"
 /*END_INCLUDE*/
 
 #ifdef HAVE_BACKTRACE
@@ -60,20 +60,18 @@ static GtkWidget * print_backtrace ( void );
 
 /*START_EXTERN*/
 extern gchar *nom_fichier_comptes;
-extern GtkUIManager * ui_manager;
 /*END_EXTERN*/
 
 static gint debugging_grisbi;
 
 /* path and name of the file containing the log when debug mode is active
  * this values should not be freed when begin a new file to continue the log */
-gchar *debug_filename = NULL;
-FILE *debug_file = NULL;
+static FILE *debug_file = NULL;
 
 /*************************************************************************************************************/
 void traitement_sigsegv ( gint signal_nb )
 {
-    gchar *gsb_file_default_dir;
+    const gchar *gsb_file_default_dir;
     gchar *errmsg = g_strdup ( "" );
 	gchar *old_errmsg;
     gchar *tmpstr;
@@ -87,32 +85,32 @@ void traitement_sigsegv ( gint signal_nb )
     /* soit on était en train de sauver un fichier, et là on peut rien faire */
     /* sinon on essaie de sauver le fichier sous le nom entouré de # */
 
-    if ( etat.en_train_de_charger || 
-	 etat.en_train_de_sauvegarder || 
-	 etat.modification_fichier == 0 )
+    if ( run.is_loading ||
+	 run.is_saving ||
+	 !gsb_file_get_modified ( ) )
     {
 
-	if ( etat.en_train_de_charger )
+	if ( run.is_loading )
 	{
 	    old_errmsg = errmsg;
 	    errmsg = g_strconcat ( errmsg, _("File is corrupted."), NULL );
 	    g_free ( old_errmsg );
 	}
 
-	if ( etat.en_train_de_sauvegarder )
+	if ( run.is_saving )
 	{
 	    old_errmsg = errmsg;
 	    errmsg = g_strconcat ( errmsg, _("Error occured saving file."), NULL );
 	    g_free ( old_errmsg );
 	}
     }
-    else 
+    else
     {
 	/* c'est un bug pendant le fonctionnement de Grisbi s'il n'y a
 	   pas de nom de fichier, on le crée, sinon on rajoute #
 	   autour */
 
-        gsb_file_default_dir = (gchar *) my_get_gsb_file_default_dir();
+        gsb_file_default_dir = gsb_dirs_get_default_dir ();
 
 	if ( nom_fichier_comptes )
 	    /* set # around the filename */
@@ -132,7 +130,7 @@ void traitement_sigsegv ( gint signal_nb )
 	gsb_status_clear();
 
     old_errmsg = errmsg;
-	errmsg = g_strconcat ( errmsg, 
+	errmsg = g_strconcat ( errmsg,
 			       g_strdup_printf ( _("Grisbi made a backup file at '%s'."),
 						 nom_fichier_comptes ),
 			       NULL );
@@ -140,7 +138,7 @@ void traitement_sigsegv ( gint signal_nb )
     }
 
     old_errmsg = errmsg;
-    errmsg = g_strconcat ( errmsg, 
+    errmsg = g_strconcat ( errmsg,
 			   "\n\n",
 			   _("Please report this problem to <tt>http://www.grisbi.org/bugtracking/</tt>.  "),
 			   NULL );
@@ -196,7 +194,7 @@ void initialize_debugging ( void )
 	debug_variable=utils_str_atoi (getenv ("DEBUG_GRISBI"));
 
 	/* on verifie que la variable est cohérente */
-	if (debug_variable > 0 && debug_variable <= MAX_DEBUG_LEVEL) 
+	if (debug_variable > 0 && debug_variable <= MAX_DEBUG_LEVEL)
 	{
 	    /* on renseigne le texte du level de debug */
 	    debugging_grisbi = debug_variable;
@@ -212,7 +210,7 @@ void initialize_debugging ( void )
 	    /* on affiche un message de debug pour indiquer que le debug est actif */
 	    tmpstr1 = g_strdup_printf(_("GRISBI %s Debug"),VERSION);
 	    tmpstr2 = g_strdup_printf(_("Debug enabled, level is '%s'"),debug_level);
-	    debug_message_string ( tmpstr1 , 
+	    debug_message_string ( tmpstr1 ,
 				   __FILE__, __LINE__, __PRETTY_FUNCTION__,
 				   tmpstr2,
 				   DEBUG_LEVEL_INFO, TRUE);
@@ -223,7 +221,7 @@ void initialize_debugging ( void )
 	{
 	    /* on affiche un message de debug pour indiquer que le debug est actif */
 	    gchar* tmpstr = g_strdup_printf(_("GRISBI %s Debug"),VERSION);
-	    debug_message_string (tmpstr , 
+	    debug_message_string (tmpstr ,
 				  __FILE__, __LINE__, __PRETTY_FUNCTION__,
 				  _("Wrong debug level, please check DEBUG_GRISBI environnement variable"),
 				  DEBUG_LEVEL_INFO, TRUE);
@@ -255,14 +253,14 @@ gchar *get_debug_time ( void )
 
     /* on renvoit le temps */
     return str_debug_time;
-}	
+}
 
 
 
 /**
  * show a debug message in the terminal
  * only if debug mode is on
- * not called directly so need to force the extern 
+ * not called directly so need to force the extern
  * the param to chow is a string
  *
  * \param
@@ -275,7 +273,7 @@ gchar *get_debug_time ( void )
  *
  * \return
  * */
-G_MODULE_EXPORT extern void debug_message_string ( gchar *prefixe,
+void debug_message_string ( gchar *prefixe,
                         gchar *file,
                         gint line,
                         const char *function,
@@ -312,7 +310,7 @@ G_MODULE_EXPORT extern void debug_message_string ( gchar *prefixe,
 /**
  * show a debug message in the terminal
  * only if debug mode is on
- * not called directly so need to force the extern 
+ * not called directly so need to force the extern
  * the param to chow is a number
  *
  * \param
@@ -325,7 +323,7 @@ G_MODULE_EXPORT extern void debug_message_string ( gchar *prefixe,
  *
  * \return
  * */
-extern void debug_message_int ( gchar *prefixe,
+void debug_message_int ( gchar *prefixe,
                         gchar *file,
                         gint line,
                         const char *function,
@@ -358,7 +356,7 @@ extern void debug_message_int ( gchar *prefixe,
 /**
  * show a debug message in the terminal
  * only if debug mode is on
- * not called directly so need to force the extern 
+ * not called directly so need to force the extern
  * the param to chow is a number
  *
  * \param
@@ -371,7 +369,7 @@ extern void debug_message_int ( gchar *prefixe,
  *
  * \return
  * */
-extern void debug_message_real ( gchar *prefixe,
+void debug_message_real ( gchar *prefixe,
                         gchar *file,
                         gint line,
                         const char *function,
@@ -414,17 +412,17 @@ GtkWidget * print_backtrace ( void )
     size_t i;
     gchar **backtrace_strings, *text = g_strdup("");
     GtkWidget * label;
-		
+
     backtrace_size = backtrace (backtrace_content, 15);
     backtrace_strings = backtrace_symbols (backtrace_content, backtrace_size);
-		
+
     g_print ("%s : %d elements in stack.\n", get_debug_time(), backtrace_size);
-		
-    for (i = 0; i < backtrace_size; i++) 
+
+    for (i = 0; i < backtrace_size; i++)
     {
 	g_print ("\t%s\n", backtrace_strings[i]);
 	gchar* old_text = text;
-	text = g_strconcat ( text, g_strconcat ( "\t", backtrace_strings[i], "\n", NULL ), 
+	text = g_strconcat ( text, g_strconcat ( "\t", backtrace_strings[i], "\n", NULL ),
 			     NULL );
 	g_free ( old_text );
     }
@@ -449,6 +447,7 @@ GtkWidget * print_backtrace ( void )
 gboolean gsb_debug_start_log ( void )
 {
     gchar *tmp_str;
+    gchar *debug_filename;
 
     devel_debug ( NULL );
 
@@ -462,7 +461,7 @@ gboolean gsb_debug_start_log ( void )
         complete_filename = g_strconcat ( base_filename, "-log.txt", NULL);
         basename = g_path_get_basename ( complete_filename );
 
-        debug_filename = g_strconcat ( my_get_gsb_file_default_dir (), "/", basename, NULL);
+        debug_filename = g_build_filename ( gsb_dirs_get_default_dir (), basename, NULL);
 
         g_free ( basename);
         g_free ( complete_filename );
@@ -470,7 +469,7 @@ gboolean gsb_debug_start_log ( void )
     }
     else
     {
-        debug_filename = g_strconcat ( my_get_gsb_file_default_dir (), "/", "No_name-log.txt", NULL);
+        debug_filename = g_build_filename ( gsb_dirs_get_default_dir (), "No_name-log.txt", NULL);
     }
 
 
@@ -483,10 +482,13 @@ gboolean gsb_debug_start_log ( void )
 
     debug_file = g_fopen ( debug_filename, "w" );
 
+    g_free ( debug_filename );
+
     if ( debug_file )
     {
         GtkWidget *widget;
         gchar *tmp_str_2;
+        GtkUIManager *ui_manager = gsb_menu_get_ui_manager ( );
 
         widget = gtk_ui_manager_get_widget ( ui_manager, "/menubar/FileMenu/DebugMode" );
         etat.debug_mode = TRUE;
@@ -495,7 +497,7 @@ gboolean gsb_debug_start_log ( void )
         if ( widget && GTK_IS_WIDGET ( widget ) )
             gtk_widget_set_sensitive ( widget, FALSE );
 
-        /* début du mode débogage */
+        /* début du mode de débogage */
         tmp_str = g_strdup_printf(_("%s, %2f : Debug - %s:%d:%s\n\n"),
                         get_debug_time ( ),
                         (double ) clock ( )/ CLOCKS_PER_SEC,
@@ -554,12 +556,22 @@ gboolean gsb_debug_start_log ( void )
 }
 
 
+/**
+ *
+ * */
+void gsb_debug_finish_log ( void )
+{
+    if ( debug_file )
+        fclose (debug_file);
+}
+
+
 /**
  *
  *
  *
  */
-extern void debug_print_log_string ( gchar *prefixe,
+void debug_print_log_string ( gchar *prefixe,
                         gchar *file,
                         gint line,
                         const char *function,
