@@ -26,7 +26,7 @@
 #endif
 
 #include "include.h"
-
+#include <string.h>
 
 /*START_INCLUDE*/
 #include "etats_calculs.h"
@@ -47,7 +47,6 @@
 #include "gsb_real.h"
 #include "gsb_status.h"
 #include "utils_str.h"
-#include "print_config.h"
 #include "structures.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -80,12 +79,13 @@ static gint dernier_no_rappr;     /* quand on a choisi le plus grand, contient l
 struct struct_etat_affichage * etat_affichage_output;
 
 
-
+/* Uh, what?! See etats_affiche.c as well... */
 static gint ancien_tiers_etat;
+extern gint ancien_tiers_etat;
+
 
 /*START_EXTERN*/
 extern gint ancien_compte_etat;
-extern gint ancien_tiers_etat;
 extern gint ancienne_categ_etat;
 extern gint ancienne_categ_speciale_etat;
 extern gint ancienne_ib_etat;
@@ -101,8 +101,6 @@ extern gint devise_ib_etat;
 extern gint devise_tiers_etat;
 extern gint exo_en_cours_etat;
 extern struct struct_etat_affichage gtktable_affichage;
-extern struct struct_etat_affichage gtktable_affichage;
-extern struct struct_etat_affichage latex_affichage;
 extern gint ligne_debut_partie;
 extern gsb_real montant_categ_etat;
 extern gsb_real montant_compte_etat;
@@ -129,8 +127,6 @@ extern const gchar *nom_ib_en_cours;
 extern const gchar *nom_ss_categ_en_cours;
 extern const gchar *nom_ss_ib_en_cours;
 extern const gchar *nom_tiers_en_cours;
-extern GtkWidget *notebook_general;
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -504,7 +500,7 @@ GSList *recupere_opes_etat ( gint report_number )
 			    gint ope_dans_second_test;
 			    gint ope_dans_test;
 			    gint amount_comparison_number;
-			    
+
 			    amount_comparison_number = GPOINTER_TO_INT (comparison_list -> data);
 
 			    montant = gsb_data_transaction_get_adjusted_amount ( transaction_number_tmp, -1);
@@ -927,7 +923,7 @@ const gchar *recupere_texte_test_etat ( gint transaction_number,
 
 	case 1:
 	    /* info du tiers */
-	    
+
 	    texte = gsb_data_payee_get_description ( gsb_data_transaction_get_party_number (transaction_number));
 	    break;
 
@@ -1465,7 +1461,7 @@ classement_suivant:
 	    {
 		gint category_number_1;
 		gint category_number_2;
-		
+
 		category_number_1 = gsb_data_transaction_get_category_number (transaction_number_1);
 		category_number_2 = gsb_data_transaction_get_category_number (transaction_number_2);
 
@@ -2643,31 +2639,6 @@ void denote_struct_sous_jaccentes ( gint origine )
 
 
 
-/*****************************************************************************************************/
-/* Fonction d'impression de l'état */
-/*****************************************************************************************************/
-/*void impression_etat ( gint report_number )
-{
-
-    if ( ! print_config() )
-       return;
-
-    affichage_etat ( report_number, &latex_affichage, NULL );
-}*/
-
-
-/*void impression_etat_courant ( )
-{
-    if ( gtk_notebook_get_current_page ( GTK_NOTEBOOK ( notebook_general)) != NAVIGATION_REPORT )
-       gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook_general),
-                               NAVIGATION_REPORT );
-
-    impression_etat (gsb_gui_navigation_get_current_report ());
-}*/
-
-
-
-
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
