@@ -8,14 +8,6 @@
 #define TEXT_LARGE	(1<<3)
 #define TEXT_SMALL	(1<<4)
 
-enum report_tree_columns {
-    REPORT_TREE_TEXT_COLUMN,
-    REPORT_TREE_PAGE_COLUMN,
-    REPORT_TREE_BOLD_COLUMN,
-    REPORT_TREE_ITALIC_COLUMN,
-    REPORT_TREE_NUM_COLUMNS,
-};
-
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
 
