@@ -23,6 +23,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "etats_html.h"
@@ -43,7 +44,7 @@
 
 /*START_STATIC*/
 static void html_attach_hsep ( int x, int x2, int y, int y2);
-static void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y, int y2, 
+static void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y, int y2,
 			  enum alignement align, gint transaction_number );
 static void html_attach_vsep ( int x, int x2, int y, int y2);
 static gint html_finish ();
@@ -93,10 +94,10 @@ struct struct_etat_affichage html_affichage = {
  * \param transaction_number the number of a transaction to link to (not used as html
  *            backend is not interactive)
  */
-void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y, int y2, 
+void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y, int y2,
 			  enum alignement align, gint transaction_number )
 {
-    int pad, realsize, realcolumns;
+    int pad, realsize;
     gint current_report_number;
 
     current_report_number = gsb_gui_navigation_get_current_report ();
@@ -135,10 +136,6 @@ void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y,
 		realsize ++;
 	}
     }
-    if ( gsb_data_report_get_show_report_transactions (current_report_number))
-	realcolumns = (float)((nb_colonnes / 2) + 1);
-    else 
-	realcolumns = nb_colonnes;
 
     switch ( align )
     {
@@ -219,7 +216,7 @@ void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y,
  * \param y2 bottom position of the separator
  */
 void html_attach_vsep ( int x, int x2, int y, int y2)
-{ 
+{
   int pad;
 
   if ( y >= html_lastline )
@@ -260,10 +257,10 @@ void html_attach_hsep ( int x, int x2, int y, int y2)
       fprintf ( html_out, "      </tr>\n\n");
     }
 
-  fprintf ( html_out, 
+  fprintf ( html_out,
 	    "      <tr>\n"
 	    "        <td colspan=\"%d\">\n"
-	    "          <hr/>\n" 
+	    "          <hr/>\n"
 	    "        </td>\n",
 	    nb_colonnes );
 
@@ -297,7 +294,7 @@ gint html_initialise ( GSList * opes_selectionnees, gchar * filename )
       return FALSE;
     }
 
-    fprintf (html_out, 
+    fprintf (html_out,
 	     "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n"
 	     "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"\n"
 	     "  \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n\n"
@@ -310,7 +307,7 @@ gint html_initialise ( GSList * opes_selectionnees, gchar * filename )
 	return FALSE;
 
     html_safe (etats_titre(gsb_gui_navigation_get_current_report ()));
-    fprintf (html_out, 
+    fprintf (html_out,
 	     "</title>\n"
 	     "  </head>\n\n"
 	     "  <body>\n"
@@ -328,7 +325,7 @@ gint html_initialise ( GSList * opes_selectionnees, gchar * filename )
  */
 gint html_finish ()
 {
-    fprintf (html_out, 
+    fprintf (html_out,
 	     "      </tr>\n\n"
 	     "    </table>\n"
 	     "  </body>\n"
@@ -340,14 +337,14 @@ gint html_finish ()
 
 
 
-/** 
+/**
  * Print a html safe string into the html_out file descriptor.  All
  * chars that cannot be printed via html are converted to their html
  * equivalent
  *
  * \param text Text to print.
  */
-void html_safe ( gchar * text ) 
+void html_safe ( gchar * text )
 {
     gboolean start = 1;
 
