@@ -26,6 +26,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "fenetre_principale.h"
@@ -35,24 +36,26 @@
 #include "bet_finance_ui.h"
 #include "bet_hist.h"
 #include "bet_tab.h"
-#include "navigation.h"
-#include "gsb_transactions_list.h"
+#include "categories_onglet.h"
 #include "etats_onglet.h"
-#include "gsb_data_account.h"
 #include "gsb_account_property.h"
+#include "gsb_data_account.h"
 #include "gsb_form.h"
 #include "gsb_scheduler_list.h"
-#include "main.h"
-#include "categories_onglet.h"
+#include "gsb_transactions_list.h"
 #include "imputation_budgetaire.h"
-#include "tiers_onglet.h"
+#include "main.h"
+#include "menu.h"
+#include "navigation.h"
 #include "structures.h"
+#include "tiers_onglet.h"
+#include "traitement_variables.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static GtkWidget *create_main_notebook (void );
-static gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook );
+static GtkWidget *gsb_gui_create_general_notebook (void );
+static gboolean gsb_gui_fill_general_notebook ( GtkWidget *notebook );
 static void gsb_gui_headings_private_update_label_markup ( GtkLabel *label,
                         const gchar *text,
                         gboolean escape_text );
@@ -64,15 +67,12 @@ static gboolean on_simpleclick_event_run ( GtkWidget * button, GdkEvent * button
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gint mini_paned_width;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
-/* adr du notebook de base */
-GtkWidget *notebook_general = NULL;
-GtkWidget *main_hpaned = NULL;
-GtkWidget *main_vbox = NULL;
+/* données des widgets généraux */
+static GtkWidget *vbox_general = NULL;
+static GtkWidget *notebook_general = NULL;
 
 /** Notebook of the account pane. */
 GtkWidget *account_page = NULL;
@@ -91,14 +91,15 @@ static GtkWidget * headings_suffix = NULL;
  *
  * \return A newly-allocated vbox holding all elements.
  */
-GtkWidget * create_main_widget ( void )
+GtkWidget *gsb_gui_create_general_widgets ( void )
 {
+    GtkWidget *hpaned_general;
     GtkWidget * hbox, * arrow_eb, * arrow_left, * arrow_right;
     GtkStyle * style;
 
     /* All stuff will be put in a huge vbox, with an hbox containing
      * quick summary. */
-    main_vbox = gtk_vbox_new ( FALSE, 0 );
+    vbox_general = gtk_vbox_new ( FALSE, 0 );
 
     headings_eb = gtk_event_box_new ();
     style = gtk_widget_get_style ( headings_eb );
@@ -110,8 +111,8 @@ GtkWidget * create_main_widget ( void )
     arrow_eb = gtk_event_box_new ();
     gtk_widget_modify_bg ( arrow_eb, 0, &(style -> bg[GTK_STATE_ACTIVE]) );
     gtk_container_add ( GTK_CONTAINER ( arrow_eb ), arrow_left );
-    g_signal_connect ( G_OBJECT ( arrow_eb ), "button-press-event", 
-		       G_CALLBACK ( on_simpleclick_event_run ), 
+    g_signal_connect ( G_OBJECT ( arrow_eb ), "button-press-event",
+		       G_CALLBACK ( on_simpleclick_event_run ),
 		       gsb_gui_navigation_select_prev );
     gtk_box_pack_start ( GTK_BOX ( hbox ), arrow_eb, FALSE, FALSE, 0 );
 
@@ -119,8 +120,8 @@ GtkWidget * create_main_widget ( void )
     arrow_eb = gtk_event_box_new ();
     gtk_widget_modify_bg ( arrow_eb, 0, &(style -> bg[GTK_STATE_ACTIVE]) );
     gtk_container_add ( GTK_CONTAINER ( arrow_eb ), arrow_right );
-    g_signal_connect ( G_OBJECT ( arrow_eb ), "button-press-event", 
-		       G_CALLBACK ( on_simpleclick_event_run ), 
+    g_signal_connect ( G_OBJECT ( arrow_eb ), "button-press-event",
+		       G_CALLBACK ( on_simpleclick_event_run ),
 		       gsb_gui_navigation_select_next );
     gtk_box_pack_start ( GTK_BOX(hbox), arrow_eb, FALSE, FALSE, 3 );
 
@@ -137,51 +138,52 @@ GtkWidget * create_main_widget ( void )
     gtk_widget_modify_bg ( headings_eb, 0, &(style -> bg[GTK_STATE_ACTIVE]) );
     gtk_container_set_border_width ( GTK_CONTAINER ( hbox ), 6 );
 
-    gtk_box_pack_start ( GTK_BOX(main_vbox), headings_eb, FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX( vbox_general ), headings_eb, FALSE, FALSE, 0 );
     gsb_gui_update_show_headings ();
 
     /* Then create and fill the main hpaned. */
-    main_hpaned = gtk_hpaned_new ();
-    g_signal_connect ( G_OBJECT ( main_hpaned ),
+    hpaned_general = gtk_hpaned_new ();
+    g_signal_connect ( G_OBJECT ( hpaned_general ),
 		       "size_allocate",
 		       G_CALLBACK ( gsb_gui_hpaned_size_allocate ),
 		       NULL );
-    gtk_box_pack_start ( GTK_BOX(main_vbox), main_hpaned, TRUE, TRUE, 0 );
-    gtk_paned_add1 ( GTK_PANED( main_hpaned ), create_navigation_pane ( ) );
-    gtk_paned_add2 ( GTK_PANED( main_hpaned ), create_main_notebook ( ) );
-    gtk_container_set_border_width ( GTK_CONTAINER ( main_hpaned ), 6 );
-    if ( conf.largeur_colonne_comptes_operation )
+    gtk_box_pack_start ( GTK_BOX ( vbox_general ), hpaned_general, TRUE, TRUE, 0 );
+    gtk_paned_add1 ( GTK_PANED ( hpaned_general ), gsb_gui_navigation_create_navigation_pane ( ) );
+    gtk_paned_add2 ( GTK_PANED ( hpaned_general ), gsb_gui_create_general_notebook ( ) );
+    gtk_container_set_border_width ( GTK_CONTAINER ( hpaned_general ), 6 );
+    if ( conf.panel_width == -1 )
     {
-	gtk_paned_set_position ( GTK_PANED ( main_hpaned ),
-                        conf.largeur_colonne_comptes_operation );
+        gint width, height;
+
+        gtk_window_get_size ( GTK_WINDOW ( run.window ), &width, &height );
+        gtk_paned_set_position ( GTK_PANED ( hpaned_general ), (gint) width / 4 );
     }
     else
     {
-	gint width, height;
-
-	gtk_window_get_size ( GTK_WINDOW ( window ), &width, &height );
-    if ( height < mini_paned_width )
-        height = mini_paned_width;
-	gtk_paned_set_position ( GTK_PANED ( main_hpaned ), (gint) width / 4 );
+        if ( conf.panel_width )
+            gtk_paned_set_position ( GTK_PANED ( hpaned_general ), conf.panel_width );
+        else
+            gtk_paned_set_position ( GTK_PANED ( hpaned_general ), 1 );
     }
-    gtk_widget_show ( main_hpaned );
 
-    gtk_widget_show ( main_vbox );
+    gtk_widget_show ( hpaned_general );
 
-    return main_vbox;
+    gtk_widget_show ( vbox_general );
+
+    return vbox_general;
 }
 
 
 
 /**
- * Create the main notebook : 
+ * Create the main notebook :
  * a notebook wich contains the pages : main page, accounts, scheduler... and
  * the form on the bottom, the form will be showed only for accounts page and
  * scheduler page
  *
  * \return the notebook
  */
-GtkWidget *create_main_notebook (void )
+GtkWidget *gsb_gui_create_general_notebook (void )
 {
     GtkWidget * vbox, * form;
 
@@ -205,7 +207,7 @@ GtkWidget *create_main_notebook (void )
     gtk_widget_hide ( form );
 
     /* fill the notebook */
-    gsb_gui_fill_main_notebook ( notebook_general );
+    gsb_gui_fill_general_notebook ( notebook_general );
 
     gtk_widget_show ( vbox );
 
@@ -213,6 +215,16 @@ GtkWidget *create_main_notebook (void )
 }
 
 
+/**
+ *
+ *
+ */
+GtkWidget *gsb_gui_get_general_notebook (void )
+{
+    return notebook_general;
+}
+
+
 /**
  * fill the notebook given in param
  *
@@ -220,7 +232,7 @@ GtkWidget *create_main_notebook (void )
  *
  * \return FALSE
  * */
-gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
+gboolean gsb_gui_fill_general_notebook ( GtkWidget *notebook )
 {
     /* append the main page */
     gtk_notebook_append_page ( GTK_NOTEBOOK ( notebook ),
@@ -236,7 +248,7 @@ gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
     gtk_notebook_append_page ( GTK_NOTEBOOK ( notebook ),
                         account_page,
                         gtk_label_new ( _("Accounts") ) );
-   
+
     gtk_notebook_append_page ( GTK_NOTEBOOK ( account_page ),
                         creation_fenetre_operations (),
                         gtk_label_new ( _("Transactions") ) );
@@ -259,9 +271,9 @@ gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
                         gsb_account_property_create_page (),
                         gtk_label_new ( _("Properties") ) );
 
-    g_signal_connect ( G_OBJECT (account_page),
-                        "switch_page",
-                        G_CALLBACK (gsb_gui_on_account_switch_page),
+    g_signal_connect ( G_OBJECT ( account_page ),
+                        "switch-page",
+                        G_CALLBACK ( gsb_gui_on_account_switch_page ),
                         NULL );
 
     /* append the scheduled transactions page */
@@ -271,7 +283,7 @@ gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
 
     /* append the payee page */
     gtk_notebook_append_page ( GTK_NOTEBOOK ( notebook ),
-                        onglet_tiers (),
+                        payees_create_list ( ),
                         gtk_label_new ( _("Payee") ) );
 
     /* append the financial page */
@@ -281,12 +293,12 @@ gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
 
     /* append the categories page */
     gtk_notebook_append_page ( GTK_NOTEBOOK ( notebook ),
-                        onglet_categories (),
+                        categories_create_list ( ),
                         gtk_label_new ( _("Categories") ) );
 
     /* append the budget page */
     gtk_notebook_append_page ( GTK_NOTEBOOK ( notebook ),
-                        onglet_imputations(),
+                        budgetary_lines_create_list ( ),
                         gtk_label_new ( _("Budgetary lines") ) );
 
     /* append the reports page */
@@ -294,6 +306,9 @@ gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
                         creation_onglet_etats (),
                         gtk_label_new ( _("Reports") ) );
 
+    /* update toolbars */
+    gsb_gui_update_all_toolbars ( );
+
     return FALSE;
 }
 
@@ -310,17 +325,24 @@ gboolean gsb_gui_fill_main_notebook ( GtkWidget *notebook )
  * \return		FALSE
  */
 gboolean gsb_gui_on_account_switch_page ( GtkNotebook *notebook,
-                        GtkNotebookPage *page,
+                        gpointer page,
                         guint page_number,
                         gpointer null )
 {
     gint account_number;
 
-    /* devel_debug_int (page_number); */
+    if ( page_number != GSB_TRANSACTIONS_PAGE )
+    {
+        gsb_menu_set_menus_view_account_sensitive ( FALSE );
+        gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/NewTransaction", FALSE );
+    }
+
     switch ( page_number )
     {
     case GSB_TRANSACTIONS_PAGE:
         gsb_form_set_expander_visible ( TRUE, TRUE );
+        gsb_menu_set_menus_view_account_sensitive ( TRUE );
+        gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/NewTransaction", TRUE );
         break;
     case GSB_ESTIMATE_PAGE:
         gsb_form_set_expander_visible (FALSE, FALSE );
@@ -350,10 +372,10 @@ gboolean gsb_gui_on_account_switch_page ( GtkNotebook *notebook,
 
 /**
  * Set the account notebook page.
- * 
+ *
  * \param page		Page to set.
  */
-void gsb_gui_on_account_change_page ( GsbaccountNotebookPages page )
+void gsb_gui_on_account_change_page ( GsbAccountNotebookPages page )
 {
     gtk_notebook_set_current_page ( GTK_NOTEBOOK ( account_page ), page );
 }
@@ -411,9 +433,9 @@ void gsb_gui_headings_update_suffix ( gchar * suffix )
  *
  * return		FALSE
  */
-gboolean gsb_gui_update_show_headings ()
+gboolean gsb_gui_update_show_headings ( void )
 {
-    if ( etat.show_headings_bar )
+    if ( conf.show_headings_bar )
     {
 	gtk_widget_show_all ( headings_eb );
     }
@@ -441,7 +463,7 @@ void gsb_gui_sensitive_headings ( gboolean sensitive )
 
 /**
  * Set the main notebook page.
- * 
+ *
  * \param page		Page to set.
  */
 void gsb_gui_notebook_change_page ( GsbGeneralNotebookPages page )
@@ -467,21 +489,66 @@ gboolean on_simpleclick_event_run ( GtkWidget * button, GdkEvent * button_event,
 }
 
 
+/**
+ *
+ *
+ *
+ */
 gboolean gsb_gui_hpaned_size_allocate ( GtkWidget *hpaned,
                         GtkAllocation *allocation,
                         gpointer null )
 {
-    gint paned_width;
-
-    paned_width = gtk_paned_get_position ( GTK_PANED ( hpaned ) );
-    
-    if ( paned_width  < mini_paned_width )
-        gtk_paned_set_position ( GTK_PANED ( hpaned ), mini_paned_width );
+    conf.panel_width = gtk_paned_get_position ( GTK_PANED ( hpaned ) );
 
     return FALSE;
 }
 
 
+/**
+ * initialise notebook_general et vbox_general
+ *
+ *
+ */
+void gsb_gui_init_general_vbox ( void )
+{
+    if ( vbox_general )
+    {
+        gtk_widget_destroy ( vbox_general );
+        vbox_general = NULL;
+    }
+}
+
+
+/**
+ * initialise notebook_general et vbox_general
+ *
+ *
+ */
+void gsb_gui_init_general_notebook ( void )
+{
+        notebook_general = NULL;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void gsb_gui_update_all_toolbars ( void )
+{
+    gsb_gui_update_transaction_toolbar ( );
+    gsb_gui_update_scheduler_toolbar ( );
+    payees_update_toolbar_list ( );
+    categories_update_toolbar_list ( );
+    budgetary_lines_update_toolbar_list ( );
+    gsb_gui_update_reports_toolbar ( );
+    bet_array_update_toolbar ( );
+    bet_historical_update_toolbar ( );
+    bet_finance_update_all_finance_toolbars ( );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
