@@ -25,10 +25,13 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_account.h"
+#include "categories_onglet.h"
 #include "dialog.h"
+#include "fenetre_principale.h"
 #include "gsb_account_property.h"
 #include "gsb_category.h"
 #include "gsb_data_account.h"
@@ -38,35 +41,26 @@
 #include "gsb_data_transaction.h"
 #include "gsb_file.h"
 #include "gsb_form_scheduler.h"
-#include "navigation.h"
-#include "fenetre_principale.h"
-#include "menu.h"
 #include "gsb_real.h"
 #include "gsb_scheduler_list.h"
-#include "main.h"
-#include "traitement_variables.h"
-#include "tiers_onglet.h"
-#include "categories_onglet.h"
-#include "imputation_budgetaire.h"
-#include "transaction_list.h"
 #include "gsb_transactions_list.h"
+#include "imputation_budgetaire.h"
+#include "main.h"
+#include "menu.h"
+#include "navigation.h"
 #include "structures.h"
+#include "tiers_onglet.h"
+#include "traitement_variables.h"
+#include "transaction_list.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 /*END_STATIC*/
 
 
-
-
-
 /*START_EXTERN*/
 extern GtkWidget *account_page;
-extern gint mise_a_jour_fin_comptes_passifs;
-extern gint mise_a_jour_liste_comptes_accueil;
-extern gint mise_a_jour_liste_echeances_manuelles_accueil;
-extern gint mise_a_jour_soldes_minimaux;
-extern GtkWidget *notebook_general;
 /*END_EXTERN*/
 
 
@@ -75,9 +69,9 @@ extern GtkWidget *notebook_general;
  * called to create a new account
  * called by the account assistant, should not be used directly
  * !! here is just to add an account, for new complete file see gsb_file_new
- * 
+ *
  * \param none
- * 
+ *
  * \return FALSE if problem, TRUE if ok
  */
 
@@ -89,8 +83,9 @@ gboolean gsb_account_new ( kind_account account_type,
                gchar *name_icon )
 {
     gint account_number;
+    GtkWidget *notebook_general;
 
-    /*     create the new account */ 
+    /*     create the new account */
     account_number = gsb_data_account_new (account_type);
     if ( account_number == -1 )
     {
@@ -103,34 +98,42 @@ gboolean gsb_account_new ( kind_account account_type,
 
     /* set the icon_name */
     if ( name_icon )
+    {
+        GdkPixbuf *pixbuf;
+
         gsb_data_account_set_name_icon ( account_number, name_icon );
+        pixbuf = gdk_pixbuf_new_from_file_at_size ( name_icon , 32, 32, NULL );
+        if ( pixbuf )
+            gsb_data_account_set_account_icon_pixbuf ( account_number, pixbuf );
+    }
 
     gsb_data_account_set_currency ( account_number, currency_number);
     gsb_data_account_set_bank (account_number, bank_number);
     gsb_data_account_set_init_balance (account_number, init_amount);
-    gsb_data_account_set_mini_balance_wanted ( account_number, 
-					       gsb_real_new ( 0, 
+    gsb_data_account_set_mini_balance_wanted ( account_number,
+					       gsb_real_new ( 0,
 							      gsb_data_currency_get_floating_point (currency_number) ) );
-    gsb_data_account_set_mini_balance_authorized (account_number, 
-						  gsb_real_new ( 0, 
+    gsb_data_account_set_mini_balance_authorized (account_number,
+						  gsb_real_new ( 0,
 								 gsb_data_currency_get_floating_point (currency_number) ) );
     gsb_data_account_set_name (account_number, name);
 
-    /* update the combofix for categ */ 
+    /* update the combofix for categ */
     gsb_category_update_combofix ( FALSE );
 
     /* update the name of accounts in form */
     gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (SCHEDULED_FORM_ACCOUNT),
 				    FALSE );
 
-    /* update the main page */ 
-    mise_a_jour_liste_comptes_accueil = 1;
+    /* update the main page */
+    run.mise_a_jour_liste_comptes_accueil = TRUE;
 
-    /* update the accounts lists */ 
-    gsb_menu_update_accounts_in_menus (); 
+    /* update the accounts lists */
+    gsb_menu_update_accounts_in_menus ();
 
-    /* do the next part only if the widgets are created 
+    /* do the next part only if the widgets are created
      * (can come here at the end of the new file assistant...) */
+    notebook_general = gsb_gui_get_general_notebook ( );
     if (notebook_general)
     {
         /* Add an entry in navigation pane. */
@@ -143,17 +146,19 @@ gboolean gsb_account_new ( kind_account account_type,
         gsb_account_property_fill_page ();
     }
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return TRUE;
 }
 
 
 
-/** that function delete the current account selected in the account properties
- * \param none
- * \return FALSE FALSE
+/**
+ * that function delete the current account selected
+ *
+ * \param   none
+ *
+ * \return  FALSE
  * */
 gboolean gsb_account_delete ( void )
 {
@@ -163,9 +168,10 @@ gboolean gsb_account_delete ( void )
 	gchar* tmpstr;
 
     deleted_account = gsb_gui_navigation_get_current_account ();
+    devel_debug_int (deleted_account);
 
     tmpstr = g_strdup_printf (_("Delete account \"%s\"?"),
-				     gsb_data_account_get_name ( deleted_account ) ) ;
+                        gsb_data_account_get_name ( deleted_account ) ) ;
 
     if ( !question_yes_no_hint ( tmpstr,
 				        _("This will irreversibly remove this account and all operations "
@@ -181,7 +187,7 @@ gboolean gsb_account_delete ( void )
     /* if the last account, close the file */
     if ( gsb_data_account_get_accounts_amount () == 1 )
     {
-        modification_fichier ( FALSE );
+        gsb_file_set_modified ( FALSE );
         gsb_file_close ();
         return FALSE;
     }
@@ -193,14 +199,12 @@ gboolean gsb_account_delete ( void )
         gint scheduled_number;
 
         scheduled_number = gsb_data_scheduled_get_scheduled_number ( list_tmp -> data );
+        list_tmp = list_tmp -> next;
 
         if ( gsb_data_scheduled_get_account_number (scheduled_number) == deleted_account )
             gsb_data_scheduled_remove_scheduled (scheduled_number);
-
-        list_tmp = list_tmp -> next;
     }
 
-
     /* remove all the transactions of that account */
     list_tmp = gsb_data_transaction_get_complete_transactions_list ();
     while (list_tmp)
@@ -225,6 +229,7 @@ gboolean gsb_account_delete ( void )
                 gsb_data_transaction_set_contra_transaction_number ( contra_transaction_number, -1);
 
             /* now can remove the transaction */
+            transaction_list_remove_transaction ( transaction_number );
             gsb_data_transaction_remove_transaction_without_check ( transaction_number );
         }
     }
@@ -246,51 +251,44 @@ gboolean gsb_account_delete ( void )
     /* delete the account */
     gsb_data_account_delete ( deleted_account );
 
-    /* check gsb_gui_navigation_get_current_account () and gsb_gui_navigation_get_current_account ()_onglet and put them
-     * on the first account if they are on the deleted account */
-
+    /* check gsb_gui_navigation_get_current_account () and gsb_gui_navigation_get_current_account ()_onglet
+     * and put them on the first account if they are on the deleted account */
     if ( gsb_gui_navigation_get_current_account () == deleted_account )
     {
-	/* update the transaction list */
+        GtkWidget *notebook_general;
+        gint first_account;
 
-	page_number = gtk_notebook_get_current_page (GTK_NOTEBOOK(notebook_general));
+        /* sélection du premier compte de la liste */
+        notebook_general = gsb_gui_get_general_notebook ();
+        page_number = gtk_notebook_get_current_page ( GTK_NOTEBOOK ( notebook_general ) );
+        first_account = gsb_data_account_first_no_closed_account ();
 
-	navigation_change_account ( GINT_TO_POINTER ( gsb_data_account_first_number () ));
-
-	gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook_general ), page_number );
+        gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook_general ), page_number );
+        gsb_gui_navigation_set_selection ( 1, first_account, NULL );
+        navigation_change_account ( first_account );
     }
 
-    /* update the buttons lists */
-    gsb_menu_update_accounts_in_menus();
-
-    /* Replace trees contents. */
-    remplit_arbre_categ ();
-    remplit_arbre_imputation ();
-    payee_fill_tree ();
-
-    /* update the categories in lists */
-    transaction_list_update_element (ELEMENT_CATEGORY);
-
-    /* update the name of accounts in form */
-    gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (SCHEDULED_FORM_ACCOUNT),
-				    FALSE );
-
-    gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
-    mise_a_jour_liste_echeances_manuelles_accueil = 1;
-    mise_a_jour_liste_comptes_accueil = 1;
-    mise_a_jour_soldes_minimaux = 1;
-    mise_a_jour_fin_comptes_passifs = 1;
-
     /* Update navigation pane. */
     gsb_gui_navigation_remove_account ( deleted_account );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    /* update the buttons lists */
+    gsb_menu_update_accounts_in_menus();
+
+    /* update the name of accounts in form */
+    gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (SCHEDULED_FORM_ACCOUNT), FALSE );
+
+    run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+    run.mise_a_jour_liste_comptes_accueil = TRUE;
+    run.mise_a_jour_soldes_minimaux = TRUE;
+    run.mise_a_jour_fin_comptes_passifs = TRUE;
+
+    gsb_file_set_modified ( TRUE );
+
+    /* return */
     return FALSE;
 }
 
 
-
 /**
  * create a combobox containing the list of the accounts
  *
@@ -299,8 +297,8 @@ gboolean gsb_account_delete ( void )
  * \param include_closed If set to TRUE, include the closed accounts
  *
  * \return a new GtkCombobox containing the list of the accounts
- */
-GtkWidget *gsb_account_create_combo_list ( GCallback func, 
+ * */
+GtkWidget *gsb_account_create_combo_list ( GCallback func,
 					   gpointer data,
 					   gboolean include_closed )
 {
@@ -375,34 +373,46 @@ gboolean gsb_account_update_combo_list ( GtkWidget *combo_box,
     GSList *list_tmp;
     GtkListStore *store;
 
-    if (!combo_box)
-	return FALSE;
+    if ( !combo_box )
+        return FALSE;
 
-    store = GTK_LIST_STORE (gtk_combo_box_get_model ( GTK_COMBO_BOX (combo_box)));;
-    gtk_list_store_clear (store);
+    g_signal_handlers_block_by_func ( G_OBJECT ( combo_box ),
+                        G_CALLBACK ( gsb_form_scheduler_change_account ),
+                        NULL );
+
+    store = GTK_LIST_STORE ( gtk_combo_box_get_model ( GTK_COMBO_BOX ( combo_box) ) );
+    gtk_list_store_clear ( store );
 
     list_tmp = gsb_data_account_get_list_accounts ();
 
     while ( list_tmp )
     {
-	gint account_number;
-	GtkTreeIter iter;
+        gint account_number;
+        GtkTreeIter iter;
 
-	account_number = gsb_data_account_get_no_account ( list_tmp -> data );
+        account_number = gsb_data_account_get_no_account ( list_tmp -> data );
 
-	if ( account_number >= 0 && ( !gsb_data_account_get_closed_account (account_number)
-				      || include_closed ) )
-	{
-	    gtk_list_store_append ( GTK_LIST_STORE (store),
-				    &iter );
-	    gtk_list_store_set ( store,
-				 &iter,
-				 0, gsb_data_account_get_name (account_number),
-				 1, account_number,
-				 -1 );
-	}
-	list_tmp = list_tmp -> next;
+        if ( account_number >= 0
+         &&
+         ( !gsb_data_account_get_closed_account ( account_number )
+           ||
+           include_closed
+         ) )
+        {
+            gtk_list_store_append ( GTK_LIST_STORE ( store ), &iter );
+            gtk_list_store_set ( store,
+                        &iter,
+                        0, gsb_data_account_get_name ( account_number ),
+                        1, account_number,
+                        -1 );
+        }
+        list_tmp = list_tmp -> next;
     }
+
+    g_signal_handlers_unblock_by_func ( G_OBJECT ( combo_box ),
+                        G_CALLBACK ( gsb_form_scheduler_change_account ),
+                        NULL );
+
     return FALSE;
 }
 
@@ -477,7 +487,7 @@ gboolean gsb_account_set_combo_account_number ( GtkWidget *combo_box,
 	}
     }
     while (gtk_tree_model_iter_next (model, &iter));
-    
+
     return FALSE;
 }
 
@@ -494,8 +504,8 @@ gboolean gsb_account_set_combo_account_number ( GtkWidget *combo_box,
  * \param include_closed If set to TRUE, include the closed accounts
  *
  * \return A newly created menu
- */
-GtkWidget *gsb_account_create_menu_list ( GtkSignalFunc func, 
+ * */
+GtkWidget *gsb_account_create_menu_list ( GCallback func,
 					  gboolean activate_currrent,
 					  gboolean include_closed )
 {
@@ -523,11 +533,11 @@ GtkWidget *gsb_account_create_menu_list ( GtkSignalFunc func,
 		g_signal_connect ( G_OBJECT ( item ), "activate", G_CALLBACK(func), NULL );
 	    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), item );
 
-	    if ( !activate_currrent && 
+	    if ( !activate_currrent &&
 		 gsb_gui_navigation_get_current_account () == i)
 	    {
 		gtk_widget_set_sensitive ( item, FALSE );
-	    }      
+	    }
 
 	    gtk_widget_show ( item );
 	}
@@ -541,6 +551,13 @@ GtkWidget *gsb_account_create_menu_list ( GtkSignalFunc func,
 
 
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
