@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_archive_config.h"
@@ -42,6 +43,7 @@
 #include "gsb_data_archive_store.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_transaction.h"
+#include "gsb_file.h"
 #include "utils_dates.h"
 #include "navigation.h"
 #include "gsb_real.h"
@@ -51,6 +53,7 @@
 #include "dialog.h"
 #include "transaction_list.h"
 #include "structures.h"
+#include "gsb_dirs.h"
 /*END_INCLUDE*/
 
 /** Columns for payment methods tree */
@@ -81,7 +84,6 @@ static gboolean gsb_archive_config_select ( GtkTreeSelection *selection,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 /**
@@ -174,8 +176,8 @@ GtkWidget *gsb_archive_config_create ( void )
     modification_paddingbox = new_paddingbox_with_title (vbox_pref, FALSE,
 						    _("Archive modification"));
     gtk_widget_set_sensitive ( modification_paddingbox, FALSE );
-    g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (archive_treeview)), 
-		      "changed", 
+    g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (archive_treeview)),
+		      "changed",
 		      G_CALLBACK (gsb_archive_config_select),
 		      modification_paddingbox);
 
@@ -209,8 +211,8 @@ GtkWidget *gsb_archive_config_create ( void )
 		       "clicked",
 		       G_CALLBACK (gsb_archive_config_delete_archive),
 		       archive_treeview );
-    tmpstr = g_build_filename ( GRISBI_PIXMAPS_DIR, "import.png", NULL );
-    gtk_button_set_image ( GTK_BUTTON(button), 
+    tmpstr = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), "import.png", NULL );
+    gtk_button_set_image ( GTK_BUTTON(button),
 			   gtk_image_new_from_file ( tmpstr ) );
     g_free ( tmpstr );
     gtk_table_attach ( GTK_TABLE ( table ),
@@ -226,8 +228,8 @@ GtkWidget *gsb_archive_config_create ( void )
 		       "clicked",
 		       G_CALLBACK (gsb_archive_config_destroy_archive),
 		       archive_treeview );
-    tmpstr = g_build_filename ( GRISBI_PIXMAPS_DIR, "import.png", NULL );
-    gtk_button_set_image ( GTK_BUTTON(button), 
+    tmpstr = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), "import.png", NULL );
+    gtk_button_set_image ( GTK_BUTTON(button),
 			   gtk_image_new_from_file ( tmpstr ) );
     g_free ( tmpstr );
 
@@ -339,7 +341,7 @@ static void gsb_archive_config_fill_list ( GtkListStore *store )
 
 
 /**
- * Callback used when an archive is selected 
+ * Callback used when an archive is selected
  *
  * \param selection the tree selection
  * \param paddingbox the modification paddingbox
@@ -363,7 +365,7 @@ static gboolean gsb_archive_config_select ( GtkTreeSelection *selection,
 				   TRUE );
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (archive_treeview));
-	gtk_tree_model_get (model, &iter, 
+	gtk_tree_model_get (model, &iter,
 			    ARCHIVES_NUMBER, &archive_number,
 			    -1 );
 
@@ -410,12 +412,12 @@ static gboolean gsb_archive_config_name_changed ( GtkWidget *entry,
 	gint archive_number;
 
 	model = gtk_tree_view_get_model ( GTK_TREE_VIEW (tree_view));
-	gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter, 
+	gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter,
 			     ARCHIVES_NUMBER, &archive_number,
 			     -1 );
 
 	/* update the tree view */
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 			    ARCHIVES_NAME_COLUMN, gsb_data_archive_get_name (archive_number),
 			    -1 );
     }
@@ -451,7 +453,7 @@ static gboolean gsb_archive_config_delete_archive ( GtkWidget *button,
     gint archive_number;
 
     model = gtk_tree_view_get_model ( GTK_TREE_VIEW (tree_view));
-    gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter, 
+    gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter,
                         ARCHIVES_NUMBER, &archive_number,
                         -1 );
 
@@ -463,7 +465,7 @@ static gboolean gsb_archive_config_delete_archive ( GtkWidget *button,
                           "If you continue, all the transactions linked to that archive "
                           "will loose the link and will begin again not archived.\n"
                           "All the information about that archive will be destroyed.\n\n"
-                          "Do you want to continue ?"),
+                          "Do you want to continue?"),
                         gsb_data_archive_get_name (archive_number) );
     if (!question_yes_no_hint (_("Deleting an archive"), tmpstr , GTK_RESPONSE_CANCEL ))
     {
@@ -481,8 +483,7 @@ static gboolean gsb_archive_config_delete_archive ( GtkWidget *button,
 
     /* remove from the list */
     gtk_list_store_remove ( GTK_LIST_STORE (model), &iter );
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
     return FALSE;
 }
@@ -516,7 +517,7 @@ static gboolean gsb_archive_config_destroy_archive ( GtkWidget *button,
 	gchar* tmpstr;
 
 	model = gtk_tree_view_get_model ( GTK_TREE_VIEW (tree_view));
-	gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter, 
+	gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter,
 			     ARCHIVES_NUMBER, &archive_number,
 			     -1 );
 
@@ -571,7 +572,7 @@ static gboolean gsb_archive_config_destroy_archive ( GtkWidget *button,
 	while (tmp_list)
 	{
 	    gint transaction_number;
-	    
+
 	    transaction_number = gsb_data_transaction_get_transaction_number (tmp_list -> data);
 	    if (gsb_data_transaction_get_archive_number (transaction_number) == archive_number)
 	    {
@@ -600,9 +601,8 @@ static gboolean gsb_archive_config_destroy_archive ( GtkWidget *button,
 	    gsb_account_property_fill_page ();
 	    transaction_list_set_balances ();
 	}
-	
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+
+        gsb_file_set_modified ( TRUE );
     }
     return FALSE;
 }
