@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_assistant_archive_export.h"
@@ -89,7 +90,6 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -377,7 +377,7 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 	case ARCHIVE_EXPORT_ASSISTANT_NAME:
 	    /* if we come here, an archive must have been selected,
 	     * so needn't to check */
-	    tmpstr = g_markup_printf_escaped ( 
+	    tmpstr = g_markup_printf_escaped (
                         _("<span size=\"x-large\">Exporting the archive: %s</span>"),
                         gsb_data_archive_get_name (archive_number));
 	    gtk_label_set_markup ( GTK_LABEL ( archive_export_label ), tmpstr);
@@ -436,11 +436,11 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 	    /* now success = TRUE or FALSE, show the good final page of assistant */
 	    if (success)
 		gtk_label_set_text ( GTK_LABEL (archive_export_label_success),
-				     _("Success !\nThe export of the archive finished successfully.\n\nYou can now close the assistant."));
+				     _("Success!\nThe export of the archive finished successfully.\n\nYou can now close the assistant."));
 	    else
 	    {
 		gtk_label_set_text ( GTK_LABEL (archive_export_label_success),
-				     _("Error !\nAn error occured while saving the archive.\n\nPlease press the Previous button to correct the problem,\nor the close button to cancel the action."));
+				     _("Error!\nAn error occured while saving the archive.\n\nPlease press the Previous button to correct the problem,\nor the close button to cancel the action."));
 		gsb_assistant_sensitive_button_prev ( assistant, TRUE );
 	    }
     }
