@@ -34,16 +34,17 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_automem.h"
-#include "utils_editables.h"
-#include "traitement_variables.h"
-#include "utils_str.h"
-#include "utils_buttons.h"
-#include "utils.h"
+#include "gsb_file.h"
 #include "structures.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "utils_buttons.h"
+#include "utils_editables.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -53,10 +54,10 @@ static gboolean gsb_automem_entry_changed (GtkWidget *entry,
 					   gpointer null );
 static gboolean gsb_automem_spin_button_changed ( GtkWidget *spin,
 						  gpointer null);
-static GtkWidget *gsb_automem_spin_button_new_full ( gint *value, 
-					      gdouble lower, gdouble upper, 
-					      gdouble step_increment, gdouble page_increment, 
-					      gdouble page_size, 
+static GtkWidget *gsb_automem_spin_button_new_full ( gint *value,
+					      gdouble lower, gdouble upper,
+					      gdouble step_increment, gdouble page_increment,
+					      gdouble page_size,
 					      gdouble climb_rate,
 					      GCallback hook, gpointer data );
 static gboolean gsb_automem_textview_changed ( GtkTextBuffer *buffer,
@@ -105,7 +106,7 @@ GtkWidget *gsb_automem_entry_new ( gchar **value,
 
 
 
-/** 
+/**
  * set the value in an gsb_automem_entry
  *
  * \param entry the gsb_automem_enty
@@ -120,11 +121,11 @@ void gsb_automem_entry_set_value ( GtkWidget *entry,
     !* Block everything *!
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed-hook"));
 
     !* Fill in value *!
@@ -139,11 +140,11 @@ void gsb_automem_entry_set_value ( GtkWidget *entry,
     !* Unblock everything *!
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed-hook"));
 }
 */
@@ -170,8 +171,7 @@ static gboolean gsb_automem_entry_changed (GtkWidget *entry,
         if ( *data )
 	    g_free ( *data );
 	*data = my_strdup (gtk_entry_get_text ( GTK_ENTRY (entry) ));
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     return FALSE;
@@ -219,7 +219,7 @@ GtkWidget *gsb_automem_textview_new ( gchar **value,
 }
 
 
-/** 
+/**
  * set the value in an gsb_automem_textview
  *
  * \param entry the gsb_automem_enty
@@ -227,7 +227,7 @@ GtkWidget *gsb_automem_textview_new ( gchar **value,
  *
  * \return
  */
-/* TODO dOm : this function seems not to be used. Is it possible to remove it 
+/* TODO dOm : this function seems not to be used. Is it possible to remove it
 void gsb_automem_textview_set_value ( GtkWidget *text_view,
 				      gchar **value )
 {
@@ -244,7 +244,7 @@ void gsb_automem_textview_set_value ( GtkWidget *text_view,
 				 (gulong) g_object_get_data ( G_OBJECT(buffer), "changed" ));
     if ( g_object_get_data (G_OBJECT(buffer), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(buffer),
-				 (gulong) g_object_get_data ( G_OBJECT(buffer), 
+				 (gulong) g_object_get_data ( G_OBJECT(buffer),
 							      "changed-hook" ));
     !* Fill in value *!
     if (value && *value)
@@ -260,7 +260,7 @@ void gsb_automem_textview_set_value ( GtkWidget *text_view,
 				   (gulong) g_object_get_data ( G_OBJECT(buffer), "changed" ));
     if ( g_object_get_data (G_OBJECT(buffer), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(buffer),
-				   (gulong) g_object_get_data ( G_OBJECT(buffer), 
+				   (gulong) g_object_get_data ( G_OBJECT(buffer),
 								"changed-hook" ));
 }
 */
@@ -290,8 +290,7 @@ static gboolean gsb_automem_textview_changed ( GtkTextBuffer *buffer,
     if (data)
     {
 	*data = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     return FALSE;
@@ -326,12 +325,12 @@ GtkWidget *gsb_automem_checkbutton_new ( const gchar *label,
     g_object_set_data ( G_OBJECT (checkbutton),
 			"pointer", value);
 
-    g_object_set_data ( G_OBJECT (checkbutton), "changed", 
+    g_object_set_data ( G_OBJECT (checkbutton), "changed",
 			(gpointer) g_signal_connect (checkbutton, "toggled",
 						     G_CALLBACK (gsb_automem_checkbutton_changed), NULL));
 
     if ( hook )
-	g_object_set_data ( G_OBJECT ( checkbutton ), "changed-hook", 
+	g_object_set_data ( G_OBJECT ( checkbutton ), "changed-hook",
 			    (gpointer) g_signal_connect (checkbutton, "toggled",
 							 G_CALLBACK (hook), data ));
     return checkbutton;
@@ -342,7 +341,7 @@ GtkWidget *gsb_automem_checkbutton_new ( const gchar *label,
 /**
  * Update the widget's appearance accordingly.  If update is set, update
  * property as well.
- * 
+ *
  * \param checkbutton The checkbutton to update
  * \param value A pointer to a boolean which contains the new value to
  * 	fill in checkbutton's properties.  This boolean will be modified by
@@ -353,8 +352,8 @@ GtkWidget *gsb_automem_checkbutton_new ( const gchar *label,
 {
     // Block everything
     if (g_object_get_data (G_OBJECT(checkbutton), "changed") > 0)
-	g_signal_handler_block ( checkbutton, 
-				 (gulong) g_object_get_data (G_OBJECT(checkbutton), 
+	g_signal_handler_block ( checkbutton,
+				 (gulong) g_object_get_data (G_OBJECT(checkbutton),
 							     "changed" ));
     if (g_object_get_data (G_OBJECT(checkbutton), "changed-hook") > 0)
 	g_signal_handler_block ( checkbutton,
@@ -369,7 +368,7 @@ GtkWidget *gsb_automem_checkbutton_new ( const gchar *label,
 
     // Unblock everything
     if (g_object_get_data (G_OBJECT(checkbutton), "changed") > 0)
-	g_signal_handler_unblock ( checkbutton, 
+	g_signal_handler_unblock ( checkbutton,
 				   (gulong) g_object_get_data (G_OBJECT(checkbutton),
 							       "changed" ));
     if (g_object_get_data (G_OBJECT(checkbutton), "changed-hook") > 0)
@@ -384,7 +383,7 @@ GtkWidget *gsb_automem_checkbutton_new ( const gchar *label,
 /**
  * Set a boolean integer to the value of a checkbutton.  Normally called
  * via a GTK "toggled" signal handler.
- * 
+ *
  * \param checkbutton a pointer to a checkbutton widget.
  * \param null not used
  */
@@ -397,8 +396,7 @@ static gboolean gsb_automem_checkbutton_changed ( GtkWidget *checkbutton,
     if (value)
     {
 	*value = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(checkbutton));
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     return FALSE;
@@ -434,7 +432,7 @@ GtkWidget *gsb_automem_radiobutton_new_with_title ( GtkWidget *parent,
     gtk_box_pack_start (GTK_BOX(paddingbox),
 			gsb_automem_radiobutton_new ( choice1, choice2,
 						      value,
-						      hook, data ), 
+						      hook, data ),
 			FALSE, FALSE, 0 );
     return paddingbox;
 }
@@ -466,7 +464,7 @@ GtkWidget *gsb_automem_radiobutton_new ( const gchar *choice1,
 
     button1 = gtk_radio_button_new_with_mnemonic ( NULL, choice1 );
     gtk_box_pack_start (GTK_BOX(vbox), button1, FALSE, FALSE, 0 );
-    button2 = gtk_radio_button_new_with_mnemonic ( gtk_radio_button_get_group (GTK_RADIO_BUTTON(button1)), 
+    button2 = gtk_radio_button_new_with_mnemonic ( gtk_radio_button_get_group (GTK_RADIO_BUTTON(button1)),
 						   choice2 );
     gtk_box_pack_start (GTK_BOX(vbox), button2, FALSE, FALSE, 0 );
 
@@ -609,7 +607,7 @@ GtkWidget *gsb_automem_radiobutton3_new ( const gchar *choice1,
         if ( button3 )
             g_signal_connect ( G_OBJECT ( button3 ), "button-release-event", G_CALLBACK ( callback ), data );
     }
- 
+
     return box;
 }
 
@@ -625,10 +623,10 @@ GtkWidget *gsb_automem_radiobutton3_new ( const gchar *choice1,
  * \param value a pointer to an integer wich will change with the value of the spin button
  * \param hook An optional hook to run at each change
  * \param data optional data to send to hook
- * 
+ *
  * \return a GtkSpinButton
  * */
-GtkWidget *gsb_automem_spin_button_new ( gint *value, 
+GtkWidget *gsb_automem_spin_button_new ( gint *value,
 					 GCallback hook,
 					 gpointer data )
 {
@@ -666,10 +664,10 @@ GtkWidget *gsb_automem_spin_button_new ( gint *value,
  * \param hook An optional hook to run at each change
  * \param data optional data to send to hook
  */
-GtkWidget *gsb_automem_spin_button_new_full ( gint *value, 
-					      gdouble lower, gdouble upper, 
-					      gdouble step_increment, gdouble page_increment, 
-					      gdouble page_size, 
+GtkWidget *gsb_automem_spin_button_new_full ( gint *value,
+					      gdouble lower, gdouble upper,
+					      gdouble step_increment, gdouble page_increment,
+					      gdouble page_size,
 					      gdouble climb_rate,
 					      GCallback hook, gpointer data )
 {
@@ -680,7 +678,7 @@ GtkWidget *gsb_automem_spin_button_new_full ( gint *value,
     if ( value )  /* Sanity check */
 	initial = *value;
 
-    adjustment = GTK_ADJUSTMENT( gtk_adjustment_new ( initial, lower, upper, 
+    adjustment = GTK_ADJUSTMENT( gtk_adjustment_new ( initial, lower, upper,
 						      step_increment, page_increment,
 						      page_size ));
 
@@ -691,13 +689,13 @@ GtkWidget *gsb_automem_spin_button_new_full ( gint *value,
 
     g_object_set_data ( G_OBJECT (spin), "changed",
 			(gpointer) g_signal_connect ( G_OBJECT (spin),
-						      "value-changed", 
-						      G_CALLBACK (gsb_automem_spin_button_changed), 
+						      "value-changed",
+						      G_CALLBACK (gsb_automem_spin_button_changed),
 						      NULL ));
     if ( hook )
 	g_object_set_data ( G_OBJECT (spin), "changed-hook",
-			    (gpointer) g_signal_connect ( G_OBJECT (spin), 
-							  "value-changed", 
+			    (gpointer) g_signal_connect ( G_OBJECT (spin),
+							  "value-changed",
 							  G_CALLBACK (hook),
 							  data ));
     return spin;
@@ -714,7 +712,7 @@ GtkWidget *gsb_automem_spin_button_new_full ( gint *value,
  * \return
  *
  */
-/* TODO dOm : this function seems not to be used. Is it possible to remove it 
+/* TODO dOm : this function seems not to be used. Is it possible to remove it
 void gsb_automem_spin_button_set_value ( GtkWidget *spin,
 					 gint *value )
 {
@@ -730,7 +728,7 @@ void gsb_automem_spin_button_set_value ( GtkWidget *spin,
     !* Block everything *!
     if ( g_object_get_data (G_OBJECT (spin), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(adjustment),
-				 (gulong) g_object_get_data ( G_OBJECT (spin), 
+				 (gulong) g_object_get_data ( G_OBJECT (spin),
 							      "changed"));
     if ( g_object_get_data (G_OBJECT (spin), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(adjustment),
@@ -748,7 +746,7 @@ void gsb_automem_spin_button_set_value ( GtkWidget *spin,
     !* Unblock everything *!
     if ( g_object_get_data (G_OBJECT (spin), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(adjustment),
-				   (gulong) g_object_get_data ( G_OBJECT (spin), 
+				   (gulong) g_object_get_data ( G_OBJECT (spin),
 								"changed"));
     if ( g_object_get_data (G_OBJECT (spin), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(adjustment),
@@ -761,7 +759,7 @@ void gsb_automem_spin_button_set_value ( GtkWidget *spin,
 /**
  * Set an int to the value of a spin button.  Normally called via
  * a GTK "changed" signal handler.
- * 
+ *
  * \param spin a pointer to a spinbutton widget.
  * \param null unused
  */
@@ -775,8 +773,7 @@ static gboolean gsb_automem_spin_button_changed ( GtkWidget *spin,
     if ( data )
     {
 	*data = gtk_spin_button_get_value_as_int ( GTK_SPIN_BUTTON(spin));
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     return (FALSE);
@@ -789,15 +786,22 @@ static gboolean gsb_automem_spin_button_changed ( GtkWidget *spin,
  *
  */
 GtkWidget *gsb_automem_stock_button_new ( GsbButtonStyle style,
-					  const gchar * stock_id, const gchar * name, 
-					  GCallback callback, gpointer data )
+                        const gchar *stock_id,
+                        const gchar *name,
+                        GCallback callback,
+                        gpointer data )
 {
-    GtkWidget *button, *vbox;
+    GtkWidget *vbox;
+    GtkWidget *button;
+    GtkWidget *label;
 
     vbox = new_stock_image_label ( style, stock_id, name );
 
+    label = g_object_get_data ( G_OBJECT ( vbox ), "label" );
+
     button = gtk_button_new ();
     gtk_button_set_relief ( GTK_BUTTON(button), GTK_RELIEF_NONE );
+    g_object_set_data ( G_OBJECT ( button ), "label", label );
 
     gtk_container_add ( GTK_CONTAINER(button), vbox );
     gtk_widget_show_all ( button );
@@ -806,12 +810,12 @@ GtkWidget *gsb_automem_stock_button_new ( GsbButtonStyle style,
     {
 	if ( data >= 0 )
 	{
-	    g_signal_connect_swapped ( G_OBJECT(button), "clicked", 
+	    g_signal_connect_swapped ( G_OBJECT(button), "clicked",
 				       G_CALLBACK(callback), data );
 	}
 	else
 	{
-	    g_signal_connect ( G_OBJECT(button), "clicked", 
+	    g_signal_connect ( G_OBJECT(button), "clicked",
 			       G_CALLBACK(callback), data );
 	}
     }
@@ -819,13 +823,12 @@ GtkWidget *gsb_automem_stock_button_new ( GsbButtonStyle style,
 }
 
 
-
 /**
  *TODO : document
  *
  */
 GtkWidget *gsb_automem_stock_button_menu_new ( GsbButtonStyle style,
-					       const gchar * stock_id, const gchar * name, 
+					       const gchar * stock_id, const gchar * name,
 					       GCallback callback, gpointer data )
 {
     GtkWidget * button, * vbox, * hbox, * arrow;
@@ -846,7 +849,7 @@ GtkWidget *gsb_automem_stock_button_menu_new ( GsbButtonStyle style,
 
     if ( callback )
     {
-	g_signal_connect ( G_OBJECT(button), "button-press-event", 
+	g_signal_connect ( G_OBJECT(button), "button-press-event",
 			   G_CALLBACK(callback), data );
     }
 
@@ -859,15 +862,22 @@ GtkWidget *gsb_automem_stock_button_menu_new ( GsbButtonStyle style,
  *
  */
 GtkWidget *gsb_automem_imagefile_button_new ( GsbButtonStyle style,
-					      const gchar * name, const gchar * filename,
-					      GCallback callback, gpointer data )
+                        const gchar *name,
+                        const gchar *filename,
+                        GCallback callback,
+                        gpointer data )
 {
-    GtkWidget * button, *vbox;
+    GtkWidget *vbox;
+    GtkWidget *button;
+    GtkWidget *label;
 
     vbox = new_image_label ( style, filename, name );
 
+    label = g_object_get_data ( G_OBJECT ( vbox ), "label" );
+
     button = gtk_button_new ();
     gtk_button_set_relief ( GTK_BUTTON(button), GTK_RELIEF_NONE );
+    g_object_set_data ( G_OBJECT ( button ), "label", label );
 
     gtk_container_add ( GTK_CONTAINER(button), vbox );
     gtk_widget_show_all ( button );
@@ -876,12 +886,12 @@ GtkWidget *gsb_automem_imagefile_button_new ( GsbButtonStyle style,
     {
 	if ( data >= 0 )
 	{
-	    g_signal_connect_swapped ( G_OBJECT(button), "clicked", 
+	    g_signal_connect_swapped ( G_OBJECT(button), "clicked",
 				       G_CALLBACK(callback), data );
 	}
 	else
 	{
-	    g_signal_connect ( G_OBJECT(button), "clicked", 
+	    g_signal_connect ( G_OBJECT(button), "clicked",
 			       G_CALLBACK(callback), data );
 	}
     }
