@@ -32,14 +32,16 @@
 #endif
 
 #include "include.h"
-
 #include <ctype.h>
 #include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_calendar_entry.h"
-#include "utils_dates.h"
+#include "gsb_color.h"
 #include "gsb_form_widget.h"
+#include "structures.h"
+#include "utils_dates.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -67,8 +69,6 @@ static void gsb_calendar_entry_step_date ( GtkWidget *entry,
 
 
 /*START_EXTERN*/
-extern GdkColor calendar_entry_color;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 #define ENTRY_NORMAL 0
@@ -185,15 +185,15 @@ gboolean gsb_calendar_entry_set_color ( GtkWidget *entry,
 
     if (normal_color)
     {
-	gtk_widget_modify_base ( entry, 
+	gtk_widget_modify_base ( entry,
 				 GTK_STATE_NORMAL,
 				 NULL );
     }
     else
     {
-	gtk_widget_modify_base ( entry, 
+	gtk_widget_modify_base ( entry,
 				 GTK_STATE_NORMAL,
-				 &calendar_entry_color );
+				 gsb_color_get_couleur ( "entry_error_color" ) );
     }
 
     return FALSE;
@@ -386,7 +386,7 @@ gboolean gsb_calendar_entry_focus_out ( GtkWidget *entry,
     gint valid;
 
     valid = gsb_date_check_and_complete_entry (entry, GPOINTER_TO_INT (set_today));
-    gsb_calendar_entry_set_color ( entry, valid ) ;    
+    gsb_calendar_entry_set_color ( entry, valid ) ;
 
     return FALSE;
 }
@@ -454,7 +454,7 @@ GtkWidget *gsb_calendar_entry_popup ( GtkWidget *entry )
     popup = gtk_window_new ( GTK_WINDOW_TOPLEVEL );
     gtk_window_set_modal ( GTK_WINDOW ( popup ), TRUE );
     gtk_window_set_transient_for ( GTK_WINDOW ( popup ),
-                        GTK_WINDOW ( window ) );
+                        GTK_WINDOW ( run.window ) );
     gtk_window_set_decorated ( GTK_WINDOW ( popup ), FALSE );
     g_signal_connect_swapped ( G_OBJECT ( popup ),
 				"destroy",
@@ -478,8 +478,8 @@ GtkWidget *gsb_calendar_entry_popup ( GtkWidget *entry )
 
     /* set the calendar */
     pCalendar = gtk_calendar_new();
-    gtk_calendar_select_month ( GTK_CALENDAR ( pCalendar ), 
-				g_date_get_month ( date ) - 1, 
+    gtk_calendar_select_month ( GTK_CALENDAR ( pCalendar ),
+				g_date_get_month ( date ) - 1,
 				g_date_get_year ( date ) );
     gtk_calendar_select_day ( GTK_CALENDAR ( pCalendar ), g_date_get_day ( date ) );
 
