@@ -32,22 +32,26 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_currency.h"
 #include "dialog.h"
 #include "gsb_autofunc.h"
+#include "gsb_color.h"
+#include "gsb_currency_config.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_currency_link.h"
+#include "gsb_data_form.h"
 #include "gsb_data_transaction.h"
+#include "gsb_dirs.h"
 #include "gsb_form_widget.h"
 #include "gsb_real.h"
-#include "utils.h"
 #include "structures.h"
+#include "utils.h"
 #include "utils_files.h"
-#include "gsb_data_form.h"
-#include "gsb_currency_config.h"
+#include "utils_real.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -103,16 +107,10 @@ static gsb_real current_exchange_fees;
 
 
 /*START_EXTERN*/
-extern GdkColor calendar_entry_color;
 extern GtkWidget *combo_devise_totaux_categ;
 extern GtkWidget *combo_devise_totaux_ib;
 extern GtkWidget *combo_devise_totaux_tiers;
 extern GtkWidget *detail_devise_compte;
-extern gint mise_a_jour_liste_comptes_accueil;
-extern gint mise_a_jour_liste_echeances_auto_accueil;
-extern gint mise_a_jour_liste_echeances_manuelles_accueil;
-extern gsb_real null_real;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -151,7 +149,7 @@ GtkWidget *gsb_currency_make_combobox ( gboolean set_name )
     if ( !combobox_currency_store )
         gsb_currency_create_combobox_store ();
 
-    combo_box = gtk_combo_box_new_with_model (GTK_TREE_MODEL 
+    combo_box = gtk_combo_box_new_with_model (GTK_TREE_MODEL
                         (combobox_currency_store));
 
     /* Flag renderer */
@@ -274,41 +272,41 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
      * try to find why. */
     if ( detail_devise_compte && G_IS_OBJECT ( detail_devise_compte ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (detail_devise_compte), "changed-hook" );
         if ( handler_id > 0 )
         {
             g_signal_handler_block ( (gpointer *) detail_devise_compte,
                             handler_id );
-            old_currency_number = gtk_combo_box_get_active (GTK_COMBO_BOX 
+            old_currency_number = gtk_combo_box_get_active (GTK_COMBO_BOX
                             (detail_devise_compte));
         }
     }
     if ( combo_devise_totaux_tiers && G_IS_OBJECT ( combo_devise_totaux_tiers ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_tiers), "changed-hook" );
         if ( handler_id > 0 )
             g_signal_handler_block ( (gpointer *) combo_devise_totaux_tiers,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_tiers), "changed-hook" ) );
     }
     if ( combo_devise_totaux_categ  && G_IS_OBJECT ( combo_devise_totaux_categ ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_categ), "changed-hook" );
         if ( handler_id > 0 )
             g_signal_handler_block ( (gpointer *) combo_devise_totaux_categ,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_categ), "changed-hook" ) );
     }
     if ( combo_devise_totaux_ib  && G_IS_OBJECT ( combo_devise_totaux_ib ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_ib), "changed-hook" );
         if ( handler_id > 0 )
             g_signal_handler_block ( (gpointer *) combo_devise_totaux_ib,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_ib), "changed-hook" ) );
     }
 
@@ -323,8 +321,8 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
         gint currency_number;
 
         currency_number = gsb_data_currency_get_no_currency (list_tmp -> data);
-        string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
-                    "flags", C_DIRECTORY_SEPARATOR,
+        string = g_strconcat( gsb_dirs_get_pixmaps_dir ( ), G_DIR_SEPARATOR_S,
+                    "flags", G_DIR_SEPARATOR_S,
                     gsb_data_currency_get_code_iso4217 (currency_number),
                     ".png", NULL );
         pixbuf = gdk_pixbuf_new_from_file ( string, NULL );
@@ -347,58 +345,58 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
         list_tmp = list_tmp -> next;
     }
 
-    mise_a_jour_liste_comptes_accueil = 1;
-    mise_a_jour_liste_echeances_manuelles_accueil = 1;
-    mise_a_jour_liste_echeances_auto_accueil = 1;
+    run.mise_a_jour_liste_comptes_accueil = TRUE;
+    run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+    run.mise_a_jour_liste_echeances_auto_accueil = TRUE;
 
     if ( detail_devise_compte && G_IS_OBJECT ( detail_devise_compte ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (detail_devise_compte), "changed-hook" );
         {
-            gtk_combo_box_set_active ( GTK_COMBO_BOX (detail_devise_compte), 
+            gtk_combo_box_set_active ( GTK_COMBO_BOX (detail_devise_compte),
                             old_currency_number );
             g_signal_handler_unblock ( detail_devise_compte,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (detail_devise_compte), "changed-hook" ) );
         }
     }
     if ( combo_devise_totaux_tiers && G_IS_OBJECT ( combo_devise_totaux_tiers ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_tiers), "changed-hook" );
         if ( handler_id > 0 )
         {
-            gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_tiers), 
+            gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_tiers),
                             old_currency_number );
             g_signal_handler_unblock ( (gpointer *) combo_devise_totaux_tiers,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_tiers), "changed-hook" ) );
         }
     }
     if ( combo_devise_totaux_categ  && G_IS_OBJECT ( combo_devise_totaux_categ ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_categ), "changed-hook" );
         if ( handler_id > 0 )
         {
-            gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_categ), 
+            gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_categ),
                             old_currency_number );
             g_signal_handler_unblock ( (gpointer *) combo_devise_totaux_categ,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_categ), "changed-hook" ) );
         }
     }
     if ( combo_devise_totaux_ib  && G_IS_OBJECT ( combo_devise_totaux_ib ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT 
+        handler_id = (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_ib), "changed-hook" );
         if ( handler_id > 0 )
         {
-            gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_ib), 
+            gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_ib),
                             old_currency_number );
             g_signal_handler_unblock ( (gpointer *) combo_devise_totaux_ib,
-                            (gulong) g_object_get_data ( G_OBJECT 
+                            (gulong) g_object_get_data ( G_OBJECT
                             (combo_devise_totaux_ib), "changed-hook" ) );
         }
     }
@@ -523,7 +521,7 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     }
 
     dialog = gtk_dialog_new_with_buttons ( _("Enter exchange rate"),
-                        GTK_WINDOW ( window ),
+                        GTK_WINDOW ( run.window ),
                         GTK_DIALOG_MODAL,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_OK, GTK_RESPONSE_OK,
@@ -698,14 +696,14 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     /* if the rate or fees exist already, fill them here */
     if ( exchange_rate.mantissa )
     {
-        tmpstr = gsb_real_get_string ( exchange_rate );
+        tmpstr = utils_real_get_string ( exchange_rate );
         gtk_entry_set_text ( GTK_ENTRY ( entry ), tmpstr );
         g_free ( tmpstr );
     }
 
     if ( exchange_fees.mantissa )
     {
-        tmpstr = gsb_real_get_string (gsb_real_abs (exchange_fees));
+        tmpstr = utils_real_get_string (gsb_real_abs (exchange_fees));
         gtk_entry_set_text ( GTK_ENTRY ( fees_entry ), tmpstr );
         g_free ( tmpstr );
     }
@@ -721,14 +719,14 @@ dialog_return:
         gint new_link_number;
         gint new_link_currency;
 
-        current_exchange = gsb_real_get_from_string (
+        current_exchange = utils_real_get_from_string (
                         gtk_entry_get_text ( GTK_ENTRY ( entry ) ) );
 
         if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( fees_entry ) ) ) > 0
          ||
          strcmp ( gtk_entry_get_text ( GTK_ENTRY ( fees_entry ) ), "0" ) != 0 )
         {
-            current_exchange_fees = gsb_real_get_from_string (
+            current_exchange_fees = utils_real_get_from_string (
                         gtk_entry_get_text ( GTK_ENTRY ( fees_entry ) ) );
         }
         else
@@ -857,7 +855,7 @@ gboolean gsb_currency_create_combobox_store ( void )
     /* the currency list store, contains 4 columns :
      * CURRENCY_COL_CODE : the code of the currency
      * CURRENCY_COL_NAME : the name(code) of the currency
-     * CURRENCY_COL_NUMBER : the number of the currency 
+     * CURRENCY_COL_NUMBER : the number of the currency
      * CURRENCY_COL_FLAG :  */
 
     combobox_currency_store = gtk_list_store_new ( CURRENCY_NUM_COL,
@@ -956,7 +954,7 @@ void gsb_currency_init_exchanges ( void )
 
 /*
  * Handler that change the entries and calculate the exchange_rate
- * 
+ *
  *
  * \param entry_1 the entry wich receive the signal
  * \param entry_2 the other entry
@@ -997,7 +995,7 @@ gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
     {
         /* the entry is not valid, make it red */
         gtk_widget_modify_base ( entry_1, GTK_STATE_NORMAL,
-                        &calendar_entry_color );
+                        gsb_color_get_couleur ( "entry_error_color" ) );
         return FALSE;
     }
     valide = gsb_form_widget_get_valide_amout_entry (
@@ -1011,7 +1009,7 @@ gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
     {
         /* the entry is not valid, make it red */
         gtk_widget_modify_base ( entry_2, GTK_STATE_NORMAL,
-                        &calendar_entry_color );
+                        gsb_color_get_couleur ( "entry_error_color" ) );
         return FALSE;
     }
 
@@ -1025,10 +1023,10 @@ gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
 		else
         {
             gtk_widget_set_sensitive ( GTK_WIDGET ( entry ), FALSE );
-            amount_1 = gsb_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY ( entry_1 ) ) );
-            amount_2 = gsb_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY ( entry_2 ) ) );
+            amount_1 = utils_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY ( entry_1 ) ) );
+            amount_2 = utils_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY ( entry_2 ) ) );
             taux = gsb_real_div ( amount_2, amount_1 );
-            gtk_entry_set_text ( GTK_ENTRY ( entry ), gsb_real_get_string ( taux ) );
+            gtk_entry_set_text ( GTK_ENTRY ( entry ), utils_real_get_string ( taux ) );
         }
     }
     return FALSE;
@@ -1053,8 +1051,8 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
     combobox_store = gtk_list_store_new ( 3, G_TYPE_INT, GDK_TYPE_PIXBUF,
 						G_TYPE_STRING);
 
-    string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
-                        "flags", C_DIRECTORY_SEPARATOR,
+    string = g_strconcat( gsb_dirs_get_pixmaps_dir ( ), G_DIR_SEPARATOR_S,
+                        "flags", G_DIR_SEPARATOR_S,
                         gsb_data_currency_get_code_iso4217 (
                         transaction_currency_number ),
                         ".png", NULL );
@@ -1068,8 +1066,8 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
                     2, gsb_data_currency_get_name ( transaction_currency_number ),
                     -1 );
 
-    string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
-                        "flags", C_DIRECTORY_SEPARATOR,
+    string = g_strconcat( gsb_dirs_get_pixmaps_dir ( ), G_DIR_SEPARATOR_S,
+                        "flags", G_DIR_SEPARATOR_S,
                         gsb_data_currency_get_code_iso4217 (
                         account_currency_number ),
                         ".png", NULL );
@@ -1083,7 +1081,7 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
                     2, gsb_data_currency_get_name ( account_currency_number ),
                     -1 );
 
-    combo_box = gtk_combo_box_new_with_model (GTK_TREE_MODEL 
+    combo_box = gtk_combo_box_new_with_model (GTK_TREE_MODEL
                         (combobox_store));
 
     /* Flag renderer */
