@@ -30,6 +30,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_currency_config.h"
@@ -42,6 +43,8 @@
 #include "gsb_data_currency.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
+#include "gsb_file.h"
+#include "gsb_locale.h"
 #include "main.h"
 #include "traitement_variables.h"
 #include "utils.h"
@@ -52,6 +55,7 @@
 #include "structures.h"
 #include "utils_files.h"
 #include "erreur.h"
+#include "gsb_dirs.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -76,11 +80,6 @@ static gboolean gsb_currency_config_update_list ( GtkWidget * checkbox,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *main_vbox;
-extern gint no_devise_totaux_categ;
-extern gint no_devise_totaux_ib;
-extern gint no_devise_totaux_tiers;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 GtkWidget *combo_devise_totaux_tiers;
@@ -192,6 +191,7 @@ struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Europe"), N_("Austrian Schilling"), N_("Austria"), "ATS", NULL, FALSE, "ATS.png", 2, 1 },
     { N_("Europe"), N_("Belgian Franc"), N_("Belgium"), "BEF", NULL, FALSE, "BEF.png", 2, 1 },
     { N_("Europe"), N_("Bulgarian Lev"), N_("Bulgaria"), "BGL", NULL, FALSE, "BGN.png", 2, 1 },
+    { N_("Europe"), N_("Croatian kuna"), N_("Croatia"), "HRK", "kn", TRUE, "HRK.png", 2, 1 },
     { N_("Europe"), N_("Czech Koruna"), N_("Czech Republic"), "CZK", NULL, TRUE, "CZK.png", 2, 1 },
     { N_("Europe"), N_("Danish Krone"), N_("Denmark"), "DKK", NULL, TRUE, "DKK.png", 2, 1 },
     { N_("Europe"), N_("Deutsche Mark"), N_("Germany"), "DEM", NULL, FALSE, "DEM.png", 2, 1 },
@@ -207,13 +207,13 @@ struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Europe"), N_("Italian Lira"), N_("Holy See"), "ITL", "₤", FALSE, "VAT.png", 2, 1 },
     { N_("Europe"), N_("Italian Lira"), N_("Italy"), "ITL", "₤", FALSE, "ITL.png", 2, 1 },
     { N_("Europe"), N_("Italian Lira"), N_("San Marino"), "ITL", "₤", FALSE, "SAN.png", 2, 1 },
-    { N_("Europe"), N_("Latvian Lat"), N_("Latvia"), "LVL", NULL, TRUE, "LVL.png", 2, 1 },
+    { N_("Europe"), N_("Latvian Lats"), N_("Latvia"), "LVL", NULL, TRUE, "LVL.png", 2, 1 },
     { N_("Europe"), N_("Lithuanian Litas"), N_("Lietuva"), "LTL", NULL, TRUE, "LTL.png", 2, 1 },
     { N_("Europe"), N_("Luxembourg Franc"), N_("Luxembourg"), "LUF", "₣", FALSE, "LUF.png", 2, 1 },
     { N_("Europe"), N_("Netherlands Guilder"), N_("Netherlands"), "NLG", "ƒ", FALSE, "NLG.png", 2, 1 },
     { N_("Europe"), N_("New Yugoslavian Dinar"), N_("Serbia and Montenegro"), "YUD", NULL, FALSE, "YUV.png", 2, 1 },
     { N_("Europe"), N_("Norwegian Krone"), N_("Norway"), "NOK", NULL, TRUE, "NOK.png", 2, 1 },
-    { N_("Europe"), N_("Polish Zloty"), N_("Poland"), "PLZ", NULL, TRUE, "PLN.png", 2, 1 },
+    { N_("Europe"), N_("Polish Zloty"), N_("Poland"), "PLN", NULL, TRUE, "PLN.png", 2, 1 },
     { N_("Europe"), N_("Portuguese Escudo"), N_("Portugal"), "PTE", NULL, FALSE, "PTE.png", 2, 1 },
     { N_("Europe"), N_("Pound Sterling"), N_("United Kingdom"), "GBP", "£", TRUE, "GBP.png", 2, 1 },
     { N_("Europe"), N_("Romanian Leu"), N_("Romania"), "ROL", NULL, TRUE, "ROL.png", 2, 1 },
@@ -562,8 +562,8 @@ void gsb_currency_append_currency_to_list ( GtkListStore *model,
     GtkTreeIter iter;
     gchar *string;
 
-    string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
-			  "flags", C_DIRECTORY_SEPARATOR,
+    string = g_strconcat( gsb_dirs_get_pixmaps_dir ( ), G_DIR_SEPARATOR_S,
+			  "flags", G_DIR_SEPARATOR_S,
 			  gsb_data_currency_get_code_iso4217 (currency_number),
 			  ".png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( string,
@@ -746,8 +746,7 @@ gboolean gsb_currency_config_entry_changed ( GtkWidget *entry,
 			 CURRENCY_FLOATING_COLUMN,  gsb_data_currency_get_floating_point (currency_number),
 			 -1);
     gsb_currency_update_combobox_currency_list ();
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -813,7 +812,7 @@ gboolean gsb_currency_config_select_currency ( GtkTreeSelection *selection,
  */
 GtkWidget *gsb_currency_config_create_totals_page ( void )
 {
-    GtkWidget *table, *label, *check_button;
+    GtkWidget *table, *label;
 
     table = gtk_table_new ( 4, 2, FALSE );
     gtk_table_set_col_spacings ( GTK_TABLE ( table ), 5 );
@@ -824,8 +823,8 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label,
                         0, 1, 0, 1, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
-    combo_devise_totaux_tiers = gsb_currency_config_new_combobox ( &no_devise_totaux_tiers,
-                        payee_fill_tree );
+    combo_devise_totaux_tiers = gsb_currency_config_new_combobox ( &etat.no_devise_totaux_tiers,
+                        payees_fill_list );
     gtk_table_attach ( GTK_TABLE ( table ), combo_devise_totaux_tiers,
                         1, 2, 0, 1, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
@@ -834,8 +833,8 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label,
                         0, 1, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
-    combo_devise_totaux_categ = gsb_currency_config_new_combobox ( &no_devise_totaux_categ,
-                        remplit_arbre_categ );
+    combo_devise_totaux_categ = gsb_currency_config_new_combobox ( &etat.no_devise_totaux_categ,
+                        categories_fill_list );
     gtk_table_attach ( GTK_TABLE ( table ), combo_devise_totaux_categ,
                         1, 2, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
@@ -844,19 +843,11 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label,
                         0, 1, 2, 3, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
-    combo_devise_totaux_ib = gsb_currency_config_new_combobox ( &no_devise_totaux_ib,
-                        remplit_arbre_imputation );
+    combo_devise_totaux_ib = gsb_currency_config_new_combobox ( &etat.no_devise_totaux_ib,
+                        budgetary_lines_fill_list );
     gtk_table_attach ( GTK_TABLE ( table ), combo_devise_totaux_ib,
                         1, 2, 2, 3, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
-    check_button = gsb_automem_checkbutton_new (
-                        _("Add transactions archived in the totals"),
-                        &(etat.add_archive_in_total_balance),
-                        G_CALLBACK ( gsb_config_metatree_sort_transactions_changed ),
-                        NULL);
-    gtk_table_attach ( GTK_TABLE ( table ), check_button,
-                        0, 1, 3, 4, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
-
     return ( table );
 }
 
@@ -885,7 +876,7 @@ GtkWidget * gsb_currency_config_new_combobox ( gint * value, GCallback hook )
     g_object_set_data ( G_OBJECT ( combo_box ), "pointer", value);
 
     if ( hook )
-    g_object_set_data ( G_OBJECT (combo_box), "changed-hook", 
+    g_object_set_data ( G_OBJECT (combo_box), "changed-hook",
                         (gpointer) g_signal_connect_after (G_OBJECT(combo_box), "changed",
                         G_CALLBACK (hook), value ));
 
@@ -912,8 +903,7 @@ gboolean gsb_currency_config_set_int_from_combobox ( GtkWidget *combobox, gint *
     }
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return (FALSE);
 }
@@ -943,7 +933,7 @@ gboolean gsb_currency_config_add_currency ( GtkWidget *button,
     GtkTreeModel *model;
 
     dialog = gtk_dialog_new_with_buttons ( _("Add a currency"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_DIALOG_MODAL,
 					   GTK_STOCK_CLOSE, 1,
 					   NULL );
@@ -1046,20 +1036,10 @@ dialog_return:
     {
         /* check if the currency exists si la devise existe on ne fait rien */
 
-        if ( gsb_data_currency_get_number_by_name ( currency_name ) )
+        if ( ! gsb_data_currency_get_number_by_name ( currency_name ) &&
+             ! gsb_data_currency_get_number_by_code_iso4217 ( currency_isocode ) )
         {
-            currency_number = gsb_data_currency_get_number_by_name 
-                        ( currency_name );
-        }
-        else if ( gsb_data_currency_get_number_by_code_iso4217 
-                        ( currency_isocode ) )
-        {
-            currency_number = gsb_data_currency_get_number_by_code_iso4217 
-                        ( currency_isocode );
-        }
-        else
-        {
-            currency_number = gsb_currency_config_create_currency ( currency_name, 
+            currency_number = gsb_currency_config_create_currency ( currency_name,
                         currency_code, currency_isocode, floating_point );
 
             /* update the currencies list in account properties */
@@ -1070,8 +1050,7 @@ dialog_return:
                 gsb_currency_append_currency_to_list ( GTK_LIST_STORE ( currency_tree_model ),
                                    currency_number );
                 gtk_widget_destroy ( GTK_WIDGET ( dialog ));
-                if ( etat.modification_fichier == 0 )
-                    modification_fichier ( TRUE );
+                gsb_file_set_modified ( TRUE );
                 return TRUE;
             }
         }
@@ -1248,7 +1227,7 @@ void gsb_currency_config_fill_popup_list ( GtkTreeView * tree_view,
 	    GdkPixbuf * pixbuf;
 	    gchar *string;
 
-	    string = g_build_filename ( GRISBI_PIXMAPS_DIR,
+	    string = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ),
 					"flags",
 					currency -> flag_filename,
 					NULL );
@@ -1297,7 +1276,7 @@ gboolean gsb_currency_config_update_list ( GtkWidget * checkbox,
 
     model = gtk_tree_view_get_model ( tree_view );
     gtk_list_store_clear ( GTK_LIST_STORE (model) );
-    gsb_currency_config_fill_popup_list ( tree_view, 
+    gsb_currency_config_fill_popup_list ( tree_view,
                         gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbox)) );
 
     /* re-select the default currency
@@ -1376,7 +1355,7 @@ gboolean gsb_currency_config_select_currency_popup ( GtkTreeSelection *selection
 gboolean gsb_currency_config_select_default ( GtkTreeModel * tree_model, GtkTreePath * path,
                         GtkTreeIter * iter, GtkTreeView * tree_view )
 {
-    struct lconv * conv = localeconv();
+    struct lconv *locale = gsb_locale_get_locale ( );
     gchar * code, * symbol, * country;
     gboolean good = FALSE, main_currency;
 
@@ -1385,9 +1364,9 @@ gboolean gsb_currency_config_select_default ( GtkTreeModel * tree_model, GtkTree
 			 COUNTRY_NAME_COLUMN, &country,
 			 CURRENCY_MAIN_CURRENCY_COLUMN, &main_currency,
 			 -1 );
-    if ( conv && conv -> int_curr_symbol && strlen ( conv -> int_curr_symbol ) )
+    if ( locale && locale -> int_curr_symbol && strlen ( locale -> int_curr_symbol ) )
     {
-	symbol = g_strdup ( conv -> int_curr_symbol );
+	symbol = g_strdup ( locale -> int_curr_symbol );
 	g_strstrip ( symbol );
 	/* When matching, weed out currencies that are not "main"
 	 * currency, that is for example, do not match USD on Panama
@@ -1411,7 +1390,7 @@ gboolean gsb_currency_config_select_default ( GtkTreeModel * tree_model, GtkTree
     if ( good )
     {
         gchar* tmpstr = g_strdup_printf ( "found '%s'",
-					conv -> int_curr_symbol );
+					locale -> int_curr_symbol );
 	devel_debug ( tmpstr );
 	g_free ( tmpstr );
 	gtk_tree_selection_select_path ( gtk_tree_view_get_selection ( tree_view ), path );
