@@ -31,6 +31,8 @@
 #endif
 
 #include "include.h"
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_currency_link_config.h"
@@ -39,11 +41,13 @@
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_currency_link.h"
-#include "navigation.h"
+#include "gsb_file.h"
 #include "gsb_real.h"
+#include "navigation.h"
+#include "structures.h"
 #include "traitement_variables.h"
 #include "utils.h"
-#include "structures.h"
+#include "utils_real.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -82,7 +86,7 @@ enum link_list_column {
 /**
  * create the currency_link page for the config
  *
- * \param 
+ * \param
  *
  * \return a newly created box
  * */
@@ -97,7 +101,7 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
     GtkWidget *combobox;
     gint width_entry = 170;
 
-    vbox_pref = new_vbox_with_title_and_icon ( _("Links between currencies"), "currencies.png" ); 
+    vbox_pref = new_vbox_with_title_and_icon ( _("Links between currencies"), "currencies.png" );
     paddingbox = new_paddingbox_with_title (vbox_pref, TRUE, _("Known links"));
 
     hbox = gtk_hbox_new ( FALSE, 5 );
@@ -113,9 +117,9 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
     tree_model = gtk_tree_view_get_model ( tree_view );
     gtk_container_add ( GTK_CONTAINER ( scrolled_window ), GTK_WIDGET(tree_view) );
     gtk_box_pack_start ( GTK_BOX ( hbox ), scrolled_window, TRUE, TRUE, 0);
-    g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW ( tree_view ) ), 
+    g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW ( tree_view ) ),
 		       "changed",
-		       G_CALLBACK ( gsb_currency_link_config_select_currency ), 
+		       G_CALLBACK ( gsb_currency_link_config_select_currency ),
 		       NULL );
     /* check the keys on the list */
     g_signal_connect ( G_OBJECT ( tree_view ),
@@ -295,7 +299,6 @@ GtkWidget *gsb_currency_link_config_create_list ( void )
 								gtk_cell_renderer_pixbuf_new (),
 								"stock-id", i,
 								NULL );
-        ;
 	}
 	else
 	{
@@ -313,7 +316,7 @@ GtkWidget *gsb_currency_link_config_create_list ( void )
     }
 
     /* Sort columns accordingly */
-    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model), 
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model),
 					  LINK_CURRENCY1_COLUMN, GTK_SORT_ASCENDING);
 
     return treeview;
@@ -354,7 +357,7 @@ void gsb_currency_link_config_fill_list ( GtkTreeModel *model )
  * \param link_number
  * \param iter a pointer to an iter to fill it with the position of the new link, or NULL
  *
- * \return 
+ * \return
  * */
 void gsb_currency_link_config_append_line ( GtkTreeModel *model,
 					    gint link_number,
@@ -378,7 +381,7 @@ void gsb_currency_link_config_append_line ( GtkTreeModel *model,
     else
 	invalid = NULL;
 
-    tmpstr = gsb_real_get_string (gsb_data_currency_link_get_change_rate (link_number));
+    tmpstr = utils_real_get_string (gsb_data_currency_link_get_change_rate (link_number));
     gtk_list_store_append ( GTK_LIST_STORE ( model ), iter_ptr );
     gtk_list_store_set ( GTK_LIST_STORE ( model ),
 			 iter_ptr,
@@ -455,7 +458,7 @@ gboolean gsb_currency_link_config_select_currency ( GtkTreeSelection *tree_selec
     g_signal_handlers_unblock_by_func ( G_OBJECT (combobox_1),
 					G_CALLBACK (gsb_currency_link_config_modify_link),
 					tree_view );
-    
+
     g_signal_handlers_block_by_func ( G_OBJECT (combobox_2),
 				      G_CALLBACK (gsb_currency_link_config_modify_link),
 				      tree_view );
@@ -468,7 +471,7 @@ gboolean gsb_currency_link_config_select_currency ( GtkTreeSelection *tree_selec
     g_signal_handlers_block_by_func ( G_OBJECT (exchange_entry),
 				      G_CALLBACK (gsb_currency_link_config_modify_link),
 				      tree_view );
-    tmpstr = gsb_real_get_string (gsb_data_currency_link_get_change_rate (link_number));
+    tmpstr = utils_real_get_string (gsb_data_currency_link_get_change_rate (link_number));
     gtk_entry_set_text ( GTK_ENTRY (exchange_entry), tmpstr);
     g_free ( tmpstr );
     g_signal_handlers_unblock_by_func ( G_OBJECT (exchange_entry),
@@ -544,7 +547,7 @@ gboolean gsb_currency_link_config_modify_link ( GtkWidget *tree_view )
     exchange_entry = g_object_get_data ( G_OBJECT (model),
 					 "exchange_entry" );
 
-    number = gsb_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY (exchange_entry) ) );
+    number = utils_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY (exchange_entry) ) );
     if ( number.exponent > 8 )
         gtk_entry_set_max_length (GTK_ENTRY (exchange_entry),
                         strlen( gtk_entry_get_text ( GTK_ENTRY ( exchange_entry ) ) - 1) );
@@ -563,7 +566,7 @@ gboolean gsb_currency_link_config_modify_link ( GtkWidget *tree_view )
     else
 	invalid = NULL;
 
-    tmpstr = gsb_real_get_string ( gsb_data_currency_link_get_change_rate ( link_number ) );
+    tmpstr = utils_real_get_string ( gsb_data_currency_link_get_change_rate ( link_number ) );
     gtk_list_store_set ( GTK_LIST_STORE (model),
 			 &iter,
 			 LINK_CURRENCY1_COLUMN, gsb_data_currency_get_name (gsb_data_currency_link_get_first_currency(link_number)),
@@ -587,8 +590,7 @@ gboolean gsb_currency_link_config_modify_link ( GtkWidget *tree_view )
     else
 	gtk_widget_hide (label);
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     gsb_gui_navigation_update_home_page ( );
 
     return FALSE;
@@ -626,8 +628,7 @@ gboolean gsb_currency_link_config_add_link ( GtkWidget *tree_view )
 					   &iter );
     gtk_tree_selection_select_iter ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)),
 				     &iter );
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -671,8 +672,7 @@ gboolean gsb_currency_link_config_remove_link ( GtkWidget *tree_view )
     if ( GTK_WIDGET_VISIBLE ( label ) )
         gtk_widget_hide (label);
 
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
     return FALSE;
 }
