@@ -1,9 +1,11 @@
 #ifndef _GSB_ACCOUNT_H
 #define _GSB_ACCOUNT_H (1)
 
+#include <gtk/gtk.h>
 
 /* START_INCLUDE_H */
 #include "gsb_real.h"
+#include "structures.h"
 /* END_INCLUDE_H */
 
 
@@ -13,6 +15,7 @@
 
 enum _kind_account
 {
+    GSB_TYPE_BALANCE     = -1,
     GSB_TYPE_BANK        = 0,
     GSB_TYPE_CASH        = 1,
     GSB_TYPE_LIABILITIES = 2,
@@ -32,18 +35,23 @@ void gsb_data_account_colorize_current_balance ( gint account_number );
 gint gsb_data_account_compare_position ( gint account_number_1,
                         gint account_number_2 );
 gboolean gsb_data_account_delete ( gint account_number );
+gboolean gsb_data_account_exists ( gint account_number );
 gint gsb_data_account_first_number ( void );
+gint gsb_data_account_first_no_closed_account ( void );
 gint gsb_data_account_get_account_by_id ( const gchar *account_id );
 GtkWidget *gsb_data_account_get_account_icon_image ( gint account_number );
 GdkPixbuf *gsb_data_account_get_account_icon_pixbuf ( gint account_number );
 GdkPixbuf *gsb_data_account_get_account_standard_pixbuf ( kind_account account_kind );
 gint gsb_data_account_get_accounts_amount ( void );
+gsb_real gsb_data_account_get_balance_at_date ( gint account_number,
+                        GDate *date );
 gint gsb_data_account_get_bank ( gint account_number );
 gchar *gsb_data_account_get_bank_account_iban (gint account_number);
 gchar *gsb_data_account_get_bank_account_key ( gint account_number );
 gchar *gsb_data_account_get_bank_account_number ( gint account_number );
 gchar *gsb_data_account_get_bank_branch_code ( gint account_number );
 gboolean gsb_data_account_get_bet_auto_inc_month ( gint account_number );
+gint gsb_data_account_get_bet_credit_card ( gint account_number );
 gdouble gsb_data_account_get_bet_finance_capital ( gint account_number );
 gdouble gsb_data_account_get_bet_finance_frais ( gint account_number );
 gdouble gsb_data_account_get_bet_finance_taux_annuel ( gint account_number );
@@ -53,6 +61,7 @@ gint gsb_data_account_get_bet_hist_fyear ( gint account_number );
 gint gsb_data_account_get_bet_maj ( gint account_number );
 gint gsb_data_account_get_bet_months ( gint account_number );
 gint gsb_data_account_get_bet_select_label ( gint account_number, gint origine );
+bet_type_onglets gsb_data_account_get_bet_show_onglets ( gint account_number );
 gint gsb_data_account_get_bet_spin_range ( gint account_number );
 GDate *gsb_data_account_get_bet_start_date ( gint account_number );
 gint gsb_data_account_get_bet_use_budget ( gint account_number );
@@ -113,6 +122,8 @@ gboolean gsb_data_account_set_bank_branch_code ( gint account_number,
                         const gchar *bank_branch_code );
 gboolean gsb_data_account_set_bet_auto_inc_month ( gint account_number,
                         gboolean auto_inc_month );
+gboolean gsb_data_account_set_bet_credit_card ( gint account_number,
+                        gint value );
 gboolean gsb_data_account_set_bet_finance_capital ( gint account_number, gdouble capital );
 gboolean gsb_data_account_set_bet_finance_frais ( gint account_number, gdouble frais );
 gboolean gsb_data_account_set_bet_finance_taux_annuel ( gint account_number, gdouble taux_annuel );
@@ -124,6 +135,8 @@ gboolean gsb_data_account_set_bet_months ( gint account_number, gint months );
 gboolean gsb_data_account_set_bet_select_label ( gint account_number,
                         gint origine,
                         gint type );
+gboolean gsb_data_account_set_bet_show_onglets ( gint account_number );
+gboolean gsb_data_account_set_bet_show_onglets_all_accounts ( void );
 gboolean gsb_data_account_set_bet_spin_range ( gint account_number, gint spin_range );
 gboolean gsb_data_account_set_bet_start_date ( gint account_number, const GDate *date );
 gboolean gsb_data_account_set_bet_use_budget ( gint account_number, gint value );
