@@ -10,6 +10,7 @@
 
 /* START_DECLARATION */
 void gsb_data_payee_add_transaction_to_payee ( gint transaction_number );
+void gsb_data_payee_free_name_and_report_list ( GSList *liste );
 gsb_real gsb_data_payee_get_balance ( gint no_payee );
 const gchar *gsb_data_payee_get_description ( gint no_payee );
 gpointer gsb_data_payee_get_empty_payee ( void );
@@ -23,6 +24,7 @@ gint gsb_data_payee_get_number_by_name ( const gchar *name,
 GSList *gsb_data_payee_get_payees_list ( void );
 const gchar *gsb_data_payee_get_search_string ( gint no_payee );
 gpointer gsb_data_payee_get_structure ( gint no_payee );
+gint gsb_data_payee_get_unused_payees ( void );
 gboolean gsb_data_payee_init_variables ( void );
 gint gsb_data_payee_new ( const gchar *name );
 gboolean gsb_data_payee_remove ( gint no_payee );
@@ -36,5 +38,7 @@ gint gsb_data_payee_set_new_number ( gint no_payee,
 				     gint new_no_payee );
 gboolean gsb_data_payee_set_search_string ( gint no_payee, const gchar *search_string );
 void gsb_data_payee_update_counters ( void );
+gboolean gsb_data_payee_compare_payees_by_name ( gpointer payee_ptr_a,
+                                                 gpointer payee_ptr_b);
 /* END_DECLARATION */
 #endif
