@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 #include <errno.h>
 
 /*START_INCLUDE*/
@@ -46,16 +47,18 @@
 #include "gsb_data_currency_link.h"
 #include "gsb_data_payee.h"
 #include "gsb_data_payment.h"
-#include "utils_dates.h"
+#include "gsb_file.h"
 #include "gsb_real.h"
-#include "utils_str.h"
+#include "gsb_transactions_list.h"
 #include "structures.h"
+#include "utils_dates.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
 
 /**
- * \struct 
+ * \struct
  * Describe a transaction
  */
 typedef struct
@@ -70,7 +73,7 @@ typedef struct
     gint marked_transaction;            /**<  OPERATION_NORMALE=nothing, OPERATION_POINTEE=P, OPERATION_TELERAPPROCHEE=T, OPERATION_RAPPROCHEE=R */
     gint archive_number;                /**< if it's an archived transaction, contains the number of the archive */
     gshort automatic_transaction;       /**< 0=manual, 1=automatic (scheduled transaction) */
-    gint reconcile_number;              /**< the number of reconcile, carreful : can be filled without marked_transaction=OPERATION_RAPPROCHEE sometimes,
+    gint reconcile_number;              /**< the number of reconciliation, carreful : can be filled without marked_transaction=OPERATION_RAPPROCHEE sometimes,
                                              it happen if the user did ctrl R to un-R the transaction, we keep reconcile_number because most of them
                                              will re-R after the change, and that value will help the user to find wich statement it belong.
                                              o always check marked_transaction before checking reconcile_number here */
@@ -112,7 +115,6 @@ static gboolean gsb_data_transaction_save_transaction_pointer ( gpointer transac
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -136,9 +138,9 @@ static gint current_transaction_buffer;
 
 /**
  * set the transactions global variables to NULL, usually when we init all the global variables
- * 
+ *
  * \param
- * 
+ *
  * \return FALSE
  * */
 gboolean gsb_data_transaction_init_variables ( void )
@@ -148,7 +150,7 @@ gboolean gsb_data_transaction_init_variables ( void )
 }
 
 
-/** 
+/**
  * return a pointer to the g_slist of transactions structure
  * it's not a copy, so we must not free or change it
  * if we want to change something, use gsb_data_transaction_copy_transactions_list instead
@@ -163,7 +165,7 @@ GSList *gsb_data_transaction_get_transactions_list ( void )
     return transactions_list;
 }
 
-/** 
+/**
  * return a pointer to the complete g_slist of transactions structure
  * it's not a copy, so we must not free or change it
  * if we want to change something, use gsb_data_transaction_copy_transactions_list instead
@@ -181,7 +183,7 @@ GSList *gsb_data_transaction_get_complete_transactions_list ( void )
 /**
  * just append the archived transaction given in param
  * into the non archived transactions list
- * called when want to load archived transactions into grisbi
+ * called when want to load archived transactions into Grisbi
  *
  * \param transaction_number the transaction to append
  *
@@ -194,19 +196,18 @@ gboolean gsb_data_transaction_add_archived_to_list ( gint transaction_number )
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
     if ( !transaction )
-	return FALSE;
+	    return FALSE;
+    transactions_list = g_slist_append ( transactions_list, transaction );
 
-    transactions_list = g_slist_append ( transactions_list,
-					 transaction );
     return TRUE;
 }
 
 
 /**
  * transitionnal fonction, give back the pointer to the transaction,
- * normally deleted when the transfer from old transactions is finished 
+ * normally deleted when the transfer from old transactions is finished
  * set also in the transactions list, check if it's fast enough with only the transactions number ?
- * 
+ *
  * \param transaction_number
  *
  * \return a pointer to the structure of the transation
@@ -222,9 +223,9 @@ gpointer gsb_data_transaction_get_pointer_of_transaction ( gint transaction_numb
 
 /**
  * find the last number of transaction
- * 
+ *
  * \param none
- * 
+ *
  * \return the number
  * */
 gint gsb_data_transaction_get_last_number (void)
@@ -253,7 +254,7 @@ gint gsb_data_transaction_get_last_number (void)
  * all the white lines have a number < 0, and it always exists at least
  * one line, which number -1 which is the general white line (without mother)
  * so we never return 0 to avoid -1 for a number of white split
- * 
+ *
  * \param none
  *
  * \return the number
@@ -275,7 +276,7 @@ gint gsb_data_transaction_get_last_white_number (void)
 
 	transactions_list_tmp = transactions_list_tmp -> next;
     }
-    
+
     /* if the general white line has not been appened already, we
      * return -1 to keep that number for the general white line
      * (the number will be decreased after to numbered the new line) */
@@ -310,9 +311,9 @@ gint gsb_data_transaction_get_transaction_number ( gpointer transaction_pointer
 
 /**
  * save the pointer in a buffer to increase the speed later
- * 
+ *
  * \param transaction the pointer to the transaction
- * 
+ *
  * \return TRUE or FALSE if pb
  * */
 gboolean gsb_data_transaction_save_transaction_pointer ( gpointer transaction )
@@ -331,11 +332,11 @@ gboolean gsb_data_transaction_save_transaction_pointer ( gpointer transaction )
 
 
 /**
- * return the transaction which the number is in the parameter. 
+ * return the transaction which the number is in the parameter.
  * the new transaction is stored in the buffer
- * 
+ *
  * \param transaction_number
- * 
+ *
  * \return a pointer to the transaction, NULL if not found
  * */
 struct_transaction *gsb_data_transaction_get_transaction_by_no ( gint transaction_number )
@@ -402,7 +403,7 @@ const gchar *gsb_data_transaction_get_transaction_id ( gint transaction_number )
 }
 
 
-/** set the transaction_id 
+/** set the transaction_id
  * \param transaction_number
  * \param no_account
  * \param transaction_id a gchar with the new transaction_id
@@ -431,9 +432,9 @@ gboolean gsb_data_transaction_set_transaction_id ( gint transaction_number,
 
 /**
  * get the account_number
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the account of the transaction or -1 if problem
  * */
 gint gsb_data_transaction_get_account_number ( gint transaction_number )
@@ -455,7 +456,7 @@ gint gsb_data_transaction_get_account_number ( gint transaction_number )
  *
  * \param transaction_number
  * \param no_account
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_account_number ( gint transaction_number,
@@ -468,7 +469,7 @@ gboolean gsb_data_transaction_set_account_number ( gint transaction_number,
     if ( !transaction )
 	return FALSE;
 
-    gsb_data_account_set_balances_are_dirty ( transaction -> account_number );    
+    gsb_data_account_set_balances_are_dirty ( transaction -> account_number );
     transaction -> account_number = no_account;
     gsb_data_account_set_balances_are_dirty ( no_account );
 
@@ -496,10 +497,10 @@ gboolean gsb_data_transaction_set_account_number ( gint transaction_number,
 
 
 /**
- * get the GDate of the transaction 
- * 
+ * get the GDate of the transaction
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the GDate of the transaction
  * */
 const GDate *gsb_data_transaction_get_date ( gint transaction_number )
@@ -518,10 +519,10 @@ const GDate *gsb_data_transaction_get_date ( gint transaction_number )
 /**
  * set the GDate of the transaction
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param no_account
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_date ( gint transaction_number,
@@ -535,7 +536,7 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
 	return FALSE;
 
     if (transaction -> date)
-	g_date_free (transaction -> date);
+        g_date_free (transaction -> date);
 
     transaction -> date = gsb_date_copy (date);
 
@@ -553,10 +554,26 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
 	    transaction = tmp_list -> data;
 
 	    if (transaction -> date)
-		g_date_free (transaction -> date);
+            g_date_free (transaction -> date);
 
 	    transaction -> date = gsb_date_copy (date);
 
+        /* si l'opération fille est un transfert on regarde si la contre opération est rapprochée
+         * si elle ne l'est pas on peut mettre à jour la date */
+        if ( transaction->transaction_number_transfer > 0 )
+        {
+            gint contra_marked_transaction = 0;
+
+            contra_marked_transaction = gsb_data_transaction_get_marked_transaction (
+                        transaction->transaction_number_transfer );
+
+            if ( contra_marked_transaction != OPERATION_RAPPROCHEE )
+            {
+                gsb_data_transaction_set_date ( transaction->transaction_number_transfer, transaction -> date );
+                gsb_transactions_list_update_transaction ( transaction->transaction_number_transfer );
+            }
+        }
+
 	    tmp_list = tmp_list -> next;
 	}
 	g_slist_free (save_tmp_list);
@@ -567,7 +584,7 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
 
 
 
-/** get the value GDate of the transaction 
+/** get the value GDate of the transaction
  * \param transaction_number the number of the transaction
  * \return the GDate of the transaction
  * */
@@ -584,13 +601,13 @@ const GDate *gsb_data_transaction_get_value_date ( gint transaction_number )
 }
 
 
-/** 
+/**
  * set the value GDate of the transaction
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param date the value date
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_value_date ( gint transaction_number,
@@ -630,7 +647,7 @@ gboolean gsb_data_transaction_set_value_date ( gint transaction_number,
 	}
 	g_slist_free (save_tmp_list);
     }
-    
+
     return TRUE;
 }
 
@@ -661,9 +678,9 @@ const GDate *gsb_data_transaction_get_value_date_or_date ( gint transaction_numb
 /**
  * get the amount of the transaction without any currency change
  * (so just get the given amout)
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the amount of the transaction
  * */
 gsb_real gsb_data_transaction_get_amount ( gint transaction_number )
@@ -680,10 +697,10 @@ gsb_real gsb_data_transaction_get_amount ( gint transaction_number )
 
 
 /** set the amount of the transaction
- * 
+ *
  * \param transaction_number
  * \param amount
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_amount ( gint transaction_number,
@@ -698,7 +715,7 @@ gboolean gsb_data_transaction_set_amount ( gint transaction_number,
 
     transaction -> transaction_amount = amount;
     gsb_data_account_set_balances_are_dirty ( transaction -> account_number );
-    
+
     return TRUE;
 }
 
@@ -712,10 +729,10 @@ gboolean gsb_data_transaction_set_amount ( gint transaction_number,
  * !! we should never use -1 for the return_exponent because the numbers become to deep and
  * 	the functions gsb_real_add and others can return an overflow
  * 	try to pass a return_exponent by gsb_data_currency_get_floating_point before
- * 
+ *
  * \param transaction_number the number of the transaction
  * \param return_exponent the exponent we want to have for the returned number, or -1 for the exponent of the returned currency
- * 
+ *
  * \return the amount of the transaction
  * */
 gsb_real gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
@@ -738,12 +755,12 @@ gsb_real gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
 
 /**
  * get the amount of the transaction, modified to be ok with the currency
- * given in param 
- * 
+ * given in param
+ *
  * \param transaction_number 		the number of the transaction
  * \param return_currency_number 	the currency we want to adjust the transaction's amount
  * \param return_exponent 		the exponent we want to have for the returned number, or -1 for the exponent of the returned currency
- * 
+ *
  * \return the amount of the transaction
  * */
 gsb_real gsb_data_transaction_get_adjusted_amount_for_currency ( gint transaction_number,
@@ -823,7 +840,7 @@ gsb_real gsb_data_transaction_get_adjusted_amount_for_currency ( gint transactio
             amount = gsb_real_sub ( amount, current_exchange_fees );
         else
             amount = gsb_real_sub ( amount, transaction -> exchange_fees );
-            
+
     }
 
     return gsb_real_adjust_exponent  ( amount, return_exponent );
@@ -832,7 +849,7 @@ gsb_real gsb_data_transaction_get_adjusted_amount_for_currency ( gint transactio
 
 
 
-/** get the currency_number 
+/** get the currency_number
  * \param transaction_number the number of the transaction
  * \return the currency number of the transaction
  * */
@@ -852,10 +869,10 @@ gint gsb_data_transaction_get_currency_number ( gint transaction_number )
 /**
  * set the currency_number
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param no_currency
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_currency_number ( gint transaction_number,
@@ -869,7 +886,7 @@ gboolean gsb_data_transaction_set_currency_number ( gint transaction_number,
 	return FALSE;
 
     transaction -> currency_number = no_currency;
-    
+
     /* if the transaction is a split, change all the children */
     if (transaction -> split_of_transaction)
     {
@@ -895,12 +912,12 @@ gboolean gsb_data_transaction_set_currency_number ( gint transaction_number,
 
 
 /**
- * get the change_between_account_and_transaction 
+ * get the change_between_account_and_transaction
  * if the value is 1, we have : 1 account_currency = (exchange_rate * amount) transaction_currency
  * else we have : 1 transaction_currency = (exchange_rate * amount) account_currency
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the currency number of the transaction
  * */
 gint gsb_data_transaction_get_change_between ( gint transaction_number )
@@ -921,10 +938,10 @@ gint gsb_data_transaction_get_change_between ( gint transaction_number )
  * if the value is 1, we have : 1 account_currency = (exchange_rate * amount) transaction_currency
  * else we have : 1 transaction_currency = (exchange_rate * amount) account_currency
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param value
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_change_between ( gint transaction_number,
@@ -938,7 +955,7 @@ gboolean gsb_data_transaction_set_change_between ( gint transaction_number,
 	return FALSE;
 
     transaction -> change_between_account_and_transaction = value;
-    
+
     /* if the transaction is a split, change all the children */
     if (transaction -> split_of_transaction)
     {
@@ -965,9 +982,9 @@ gboolean gsb_data_transaction_set_change_between ( gint transaction_number,
 
 /**
  * get the exchange_rate of the transaction
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the exchange_rate of the transaction
  * */
 gsb_real gsb_data_transaction_get_exchange_rate ( gint transaction_number )
@@ -986,10 +1003,10 @@ gsb_real gsb_data_transaction_get_exchange_rate ( gint transaction_number )
 /**
  * set the exchange_rate of the transaction
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param rate
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
@@ -1003,7 +1020,7 @@ gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
 	return FALSE;
 
     transaction -> exchange_rate = rate;
-    
+
     /* if the transaction is a split, change all the children */
     if (transaction -> split_of_transaction)
     {
@@ -1026,11 +1043,11 @@ gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
 
 
 
-/** 
+/**
  * get the exchange_fees of the transaction
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the exchange_fees of the transaction
  * */
 gsb_real gsb_data_transaction_get_exchange_fees ( gint transaction_number )
@@ -1049,10 +1066,10 @@ gsb_real gsb_data_transaction_get_exchange_fees ( gint transaction_number )
 /**
  * set the exchange_fees of the transaction
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param rate
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_exchange_fees ( gint transaction_number,
@@ -1066,7 +1083,7 @@ gboolean gsb_data_transaction_set_exchange_fees ( gint transaction_number,
 	return FALSE;
 
     transaction -> exchange_fees = rate;
-    
+
     /* if the transaction is a split, change all the children */
     if (transaction -> split_of_transaction)
     {
@@ -1090,11 +1107,11 @@ gboolean gsb_data_transaction_set_exchange_fees ( gint transaction_number,
 
 
 
-/** 
- * get the party_number 
- * 
+/**
+ * get the party_number
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the currency number of the transaction
  * */
 gint gsb_data_transaction_get_party_number ( gint transaction_number )
@@ -1113,10 +1130,10 @@ gint gsb_data_transaction_get_party_number ( gint transaction_number )
 /**
  * set the party_number
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param value
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_party_number ( gint transaction_number,
@@ -1154,11 +1171,11 @@ gboolean gsb_data_transaction_set_party_number ( gint transaction_number,
 
 
 
-/** 
- * get the category_number 
- * 
+/**
+ * get the category_number
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the category number of the transaction, -1 for error
  * */
 gint gsb_data_transaction_get_category_number ( gint transaction_number )
@@ -1195,7 +1212,7 @@ gboolean gsb_data_transaction_set_category_number ( gint transaction_number,
 }
 
 
-/** get the sub_category_number 
+/** get the sub_category_number
  * \param transaction_number the number of the transaction
  * \return the sub_category number of the transaction
  * */
@@ -1215,10 +1232,10 @@ gint gsb_data_transaction_get_sub_category_number ( gint transaction_number )
 
 /**
  * set the sub_category_number
- * 
+ *
  * \param transaction_number
  * \param value
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_sub_category_number ( gint transaction_number,
@@ -1239,9 +1256,9 @@ gboolean gsb_data_transaction_set_sub_category_number ( gint transaction_number,
 
 /**
  * check if the transaction is a split (mother)
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return TRUE if the transaction is a split of transaction
  * */
 gint gsb_data_transaction_get_split_of_transaction ( gint transaction_number )
@@ -1257,12 +1274,12 @@ gint gsb_data_transaction_get_split_of_transaction ( gint transaction_number )
 }
 
 
-/** 
+/**
  * set the transaction as split or not
  *
  * \param transaction_number
  * \param is_split
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_split_of_transaction ( gint transaction_number,
@@ -1283,9 +1300,9 @@ gboolean gsb_data_transaction_set_split_of_transaction ( gint transaction_number
 
 /**
  * get the notes
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the notes of the transaction
  * */
 const gchar *gsb_data_transaction_get_notes ( gint transaction_number )
@@ -1327,7 +1344,7 @@ gboolean gsb_data_transaction_set_notes ( gint transaction_number,
 	transaction -> notes = my_strdup (notes);
     else
 	transaction -> notes = NULL;
-    
+
     return TRUE;
 }
 
@@ -1336,7 +1353,7 @@ gboolean gsb_data_transaction_set_notes ( gint transaction_number,
 /**
  * get the method_of_payment_number
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the method_of_payment_number
  * */
 gint gsb_data_transaction_get_method_of_payment_number ( gint transaction_number )
@@ -1355,10 +1372,10 @@ gint gsb_data_transaction_get_method_of_payment_number ( gint transaction_number
 /**
  * set the method_of_payment_number
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
- * \param 
- * 
+ * \param
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_method_of_payment_number ( gint transaction_number,
@@ -1395,7 +1412,7 @@ gboolean gsb_data_transaction_set_method_of_payment_number ( gint transaction_nu
 }
 
 
-/** 
+/**
  * get the method_of_payment_content
  *
  * \param transaction_number the number of the transaction
@@ -1414,7 +1431,7 @@ const gchar *gsb_data_transaction_get_method_of_payment_content ( gint transacti
 }
 
 
-/** 
+/**
  * set the method_of_payment_content
  * dupplicate the parameter before storing it in the transaction
  *
@@ -1442,7 +1459,7 @@ gboolean gsb_data_transaction_set_method_of_payment_content ( gint transaction_n
 	transaction -> method_of_payment_content = my_strdup (method_of_payment_content);
     else
 	transaction -> method_of_payment_content = NULL;
-    
+
     return TRUE;
 }
 
@@ -1450,9 +1467,9 @@ gboolean gsb_data_transaction_set_method_of_payment_content ( gint transaction_n
 
 /**
  * get the marked_transaction
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the marked_transaction : OPERATION_NORMALE, OPERATION_POINTEE, OPERATION_TELERAPPROCHEE, OPERATION_RAPPROCHEE
  * */
 gint gsb_data_transaction_get_marked_transaction ( gint transaction_number )
@@ -1471,10 +1488,10 @@ gint gsb_data_transaction_get_marked_transaction ( gint transaction_number )
 /**
  * set the marked_transaction
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param marked_transaction : OPERATION_NORMALE, OPERATION_POINTEE, OPERATION_TELERAPPROCHEE, OPERATION_RAPPROCHEE
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_marked_transaction ( gint transaction_number,
@@ -1514,9 +1531,9 @@ gboolean gsb_data_transaction_set_marked_transaction ( gint transaction_number,
 
 /**
  * get the number of the archive
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the archive number, 0 if not archived and -1 if transaction not found
  * */
 gint gsb_data_transaction_get_archive_number ( gint transaction_number )
@@ -1533,12 +1550,12 @@ gint gsb_data_transaction_get_archive_number ( gint transaction_number )
 
 
 /**
- * set the number of the archive if it's an archived transaction 
+ * set the number of the archive if it's an archived transaction
  * add or remove the transaction from the list of transactions without archive according to the value
- * 
+ *
  * \param transaction_number
  * \param archive_number or 0 if not an archive
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_archive_number ( gint transaction_number,
@@ -1628,10 +1645,10 @@ gint gsb_data_transaction_get_reconcile_number ( gint transaction_number )
 /**
  * set the reconcile_number
  * if the transaction has some children, they change too
- * 
+ *
  * \param transaction_number
  * \param  reconcile_number
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_reconcile_number ( gint transaction_number,
@@ -1687,10 +1704,10 @@ gint gsb_data_transaction_get_financial_year_number ( gint transaction_number )
 
 /**
  * set the financial_year_number
- * 
+ *
  * \param transaction_number
  * \param  financial_year_number
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_financial_year_number ( gint transaction_number,
@@ -1819,7 +1836,7 @@ gboolean gsb_data_transaction_set_voucher ( gint transaction_number,
     if ( !transaction )
 	return FALSE;
 
-    
+
     if ( transaction -> voucher )
         g_free ( transaction -> voucher );
 
@@ -1829,13 +1846,13 @@ gboolean gsb_data_transaction_set_voucher ( gint transaction_number,
 	transaction -> voucher = my_strdup (voucher);
     else
 	transaction -> voucher = g_strdup("");
-    
+
     return TRUE;
 }
 
 
 
-/** 
+/**
  * get the bank_references
  *
  * \param transaction_number the number of the transaction
@@ -1858,10 +1875,10 @@ const gchar *gsb_data_transaction_get_bank_references ( gint transaction_number
 /**
  * set the bank_references
  * it's a copy of the parameter which will be stored in the transaction
- * 
+ *
  * \param transaction_number
  * \param bank_references. This string may be NULL. If not NULL, the string is duplicated.
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_bank_references ( gint transaction_number,
@@ -1883,16 +1900,16 @@ gboolean gsb_data_transaction_set_bank_references ( gint transaction_number,
 	transaction -> bank_references = my_strdup (bank_references);
     else
 	transaction -> bank_references = NULL;
-    
+
     return TRUE;
 }
 
 
 /**
  * get the  transaction_number_transfer
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the transaction_number_transfer number of the transaction
  * */
 gint gsb_data_transaction_get_contra_transaction_number ( gint transaction_number )
@@ -1909,10 +1926,10 @@ gint gsb_data_transaction_get_contra_transaction_number ( gint transaction_numbe
 
 /**
  * set the transaction_number_transfer
- * 
+ *
  * \param transaction_number
  * \param transaction_number_transfer
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_contra_transaction_number ( gint transaction_number,
@@ -1933,11 +1950,11 @@ gboolean gsb_data_transaction_set_contra_transaction_number ( gint transaction_n
 
 /**
  * get the account number of the contra transaction
- * it's not saved into grisbi, this function avoid just to get the contra-transaction
+ * it's not saved into Grisbi, this function avoid just to get the contra-transaction
  * and find its account
  *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the account number of the contra-transaction
  * */
 gint gsb_data_transaction_get_contra_transaction_account ( gint transaction_number )
@@ -1960,11 +1977,11 @@ gint gsb_data_transaction_get_contra_transaction_account ( gint transaction_numb
 
 
 
-/** 
+/**
  * get the  mother_transaction_number
- * 
+ *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the mother_transaction_number of the transaction or 0 if the transaction doen't exist
  * */
 gint gsb_data_transaction_get_mother_transaction_number ( gint transaction_number )
@@ -1982,10 +1999,10 @@ gint gsb_data_transaction_get_mother_transaction_number ( gint transaction_numbe
 
 /**
  * set the mother_transaction_number
- * 
+ *
  * \param transaction_number
  * \param mother_transaction_number
- * 
+ *
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_mother_transaction_number ( gint transaction_number,
@@ -2010,10 +2027,10 @@ gboolean gsb_data_transaction_set_mother_transaction_number ( gint transaction_n
  * set the transaction number given in param (if no number, give the last number + 1)
  * set the number of the account, the number of the transaction and the currency number
  * which is by default the currency of the account
- * 
+ *
  * \param no_account the number of the account where the transaction should be made
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the number of the new transaction
  * */
 gint gsb_data_transaction_new_transaction_with_number ( gint no_account,
@@ -2053,9 +2070,9 @@ gint gsb_data_transaction_new_transaction_with_number ( gint no_account,
 /**
  * create a new transaction with gsb_data_transaction_new_transaction_with_number
  * but set automatickly the last number
- * 
+ *
  * \param no_account the number of the account where the transaction should be made
- * 
+ *
  * \return the number of the new transaction
  * */
 gint gsb_data_transaction_new_transaction ( gint no_account )
@@ -2065,7 +2082,7 @@ gint gsb_data_transaction_new_transaction ( gint no_account )
 }
 
 
-/** 
+/**
  * create a new white line
  * if there is a mother transaction, it's a split and we increment in the negatives values
  * the number of that line
@@ -2074,7 +2091,7 @@ gint gsb_data_transaction_new_transaction ( gint no_account )
  * if it's a child split, the account is set as for its mother,
  * if it's the last white line, the account is set to -1
  * that transaction is appended to the white transactions list
- * 
+ *
  * \param mother_transaction_number the number of the mother's transaction if it's a split child ; 0 if not
  *
  * \return the number of the white line
@@ -2122,11 +2139,11 @@ gint gsb_data_transaction_new_white_line ( gint mother_transaction_number)
  * all the char are dupplicated,
  * 	transaction_id is set to NULL,
  * 	marked, reconcile number and archive number are set to 0
- * 
+ *
  * \param source_transaction_number the transaction we want to copy
  * \param target_transaction_number the trnasaction we want to fill with the content of the first one
  * \param reset transaction_id, marked, reconcile number and archive number
- * 
+ *
  * \return TRUE if ok, FALSE else
  * */
 gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
@@ -2145,6 +2162,7 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
 	 !target_transaction )
 	return FALSE;
 
+    /* on sauvegarde le numéro de compte initial */
     target_transaction_account_number = target_transaction -> account_number;
 
     memcpy ( target_transaction,
@@ -2157,7 +2175,6 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
         target_transaction -> reconcile_number = 0;
         target_transaction -> marked_transaction = 0;
         target_transaction -> transaction_id = NULL;
-        target_transaction -> archive_number = 0;
     }
 
     /* make the archive_number */
@@ -2217,7 +2234,7 @@ static void gsb_data_transaction_free ( struct_transaction *transaction)
  * free the transaction
  * if there is a contra-transaction, remove it too
  * if there is some children, remove them and their contra-transaction if they exist
- * 
+ *
  * \param transaction_number
  *
  * \return TRUE if ok
@@ -2304,15 +2321,14 @@ gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
     gsb_data_budget_remove_transaction_from_budget (transaction_number);
 
     /* now can remove safely the transaction */
-    transactions_list = g_slist_remove ( transactions_list,
-					 transaction );
-    complete_transactions_list = g_slist_remove ( complete_transactions_list,
-						  transaction );
-
-    gsb_data_transaction_free (transaction);
+    transactions_list = g_slist_remove ( transactions_list, transaction );
+    complete_transactions_list = g_slist_remove ( complete_transactions_list, transaction );
 
     /* force the update module budget */
     gsb_data_account_set_bet_maj ( transaction -> account_number, BET_MAJ_ALL );
+    gsb_file_set_modified ( TRUE );
+
+    gsb_data_transaction_free (transaction);
 
     return TRUE;
 }
@@ -2322,7 +2338,7 @@ gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
  * just do it and only for that transaction, check nothing
  * usefull when we need to delete a lot of transactions in one time
  * 	(example to delete an archive)
- * 
+ *
  * \param transaction_number
  *
  * \return TRUE if ok
@@ -2446,61 +2462,6 @@ GSList *gsb_data_transaction_get_children ( gint transaction_number,
 }
 
 
-/**
- * find a transaction by the method of payment content in a given account
- *
- * \param string
- * \param account_number
- *
- * \return the number of the transaction or 0 if not found
- * */
-gint gsb_data_transaction_find_by_payment_content ( const gchar *string,
-                        gint account_number )
-{
-    GSList *tmp_list;
-    gint64 number_1;
-    gchar *endptr;
-
-    if (!string)
-        return 0;
-
-    errno = 0;
-    number_1 = g_ascii_strtoll ( string, &endptr, 10);
-    if ( errno == ERANGE )
-        return 0;
-
-    if ( endptr )
-        return 0;
-
-    tmp_list = transactions_list;
-    while (tmp_list)
-    {
-        struct_transaction *transaction;
-
-        transaction = tmp_list -> data;
-
-        if ( transaction -> method_of_payment_content
-         &&
-         transaction -> account_number == account_number )
-        {
-            gint64 number_2;
-
-            errno = 0;
-            number_2 = g_ascii_strtoll ( transaction -> method_of_payment_content, &endptr, 10);
-            if ( errno == ERANGE )
-                return 0;
-            if ( endptr )
-                return 0;
-
-            if ( number_1 == number_2 )
-                return transaction -> transaction_number;
-        }
-        tmp_list = tmp_list -> next;
-    }
-    return 0;
-}
-
-
 /**
  * find a transaction by its id
  *
@@ -2516,8 +2477,8 @@ gint gsb_data_transaction_find_by_id ( gchar *id, gint account_number )
         return 0;
 
     tmp_list = g_slist_copy ( transactions_list );
-    
-    tmp_list = g_slist_sort (tmp_list, 
+
+    tmp_list = g_slist_sort (tmp_list,
                         (GCompareFunc) classement_sliste_transactions_par_date_decroissante );
 
     while (tmp_list)
@@ -2530,8 +2491,7 @@ gint gsb_data_transaction_find_by_id ( gchar *id, gint account_number )
          &&
          !strcmp ( id, transaction -> transaction_id )
          &&
-         account_number == gsb_data_transaction_get_account_number (
-         transaction -> transaction_number ) )
+         account_number ==  transaction -> account_number )
             return transaction -> transaction_number;
 
         tmp_list = tmp_list -> next;
@@ -2622,7 +2582,7 @@ gint gsb_data_transaction_check_content_payment ( gint payment_number,
 }
 
 
-/** 
+/**
  * return a copy of the g_slist of transactions structure
  * sorted by date
  *  * THIS IS THE LIST WITHOUT THE ARCHIVED TRANSACTIONS
@@ -2631,7 +2591,7 @@ gint gsb_data_transaction_check_content_payment ( gint payment_number,
  *
  * \return the slist of transactions structures
  * */
-GSList *gsb_data_transaction_get_transactions_list_by_date ( void )
+GSList *gsb_data_transaction_get_metatree_transactions_list ( void )
 {
     GSList *list_tmp;
 
@@ -2640,12 +2600,19 @@ GSList *gsb_data_transaction_get_transactions_list_by_date ( void )
     else
         list_tmp = g_slist_copy ( transactions_list );
 
-    if ( etat.metatree_sort_transactions == 1 )
+    switch ( etat.metatree_sort_transactions )
+    {
+        case 1 :
         list_tmp = g_slist_sort (list_tmp,
                         (GCompareFunc) classement_sliste_transactions_par_date );
-    else
+        break;
+        case 2 :
         list_tmp = g_slist_sort (list_tmp,
                         (GCompareFunc) classement_sliste_transactions_par_date_decroissante );
+        break;
+        default :
+        break;
+    }
 
     return list_tmp;
 }
@@ -2655,7 +2622,7 @@ GSList *gsb_data_transaction_get_transactions_list_by_date ( void )
  * get the id of the transaction
  *
  * \param transaction_number the number of the transaction
- * 
+ *
  * \return the id of the transaction
  * */
 const gchar *gsb_data_transaction_get_id ( gint transaction_number )
@@ -2686,8 +2653,8 @@ gsb_real gsb_data_transaction_get_last_transaction_with_div_sub_div (
     GSList *tmp_list;
 
     tmp_list = g_slist_copy ( transactions_list );
-    
-    tmp_list = g_slist_sort (tmp_list, 
+
+    tmp_list = g_slist_sort (tmp_list,
                         (GCompareFunc) classement_sliste_transactions_par_date_decroissante );
 
     while ( tmp_list )
@@ -2701,7 +2668,7 @@ gsb_real gsb_data_transaction_get_last_transaction_with_div_sub_div (
          && transaction -> category_number == div_number
          && transaction -> sub_category_number == sub_div_nb )
             return transaction -> transaction_amount;
-        else if ( type_div == 1 
+        else if ( type_div == 1
          && transaction -> account_number == account_number
          && transaction -> budgetary_number == div_number
          && transaction -> sub_budgetary_number == sub_div_nb )
@@ -2738,6 +2705,75 @@ gint gsb_data_transaction_get_currency_floating_point ( gint transaction_number
 }
 
 
+/**
+ * remove the transaction from the transaction's list
+ * not in complete_transaction_list
+ *
+ * \param transaction_number
+ *
+ * \return TRUE if ok
+ * */
+gboolean gsb_data_transaction_remove_transaction_in_transaction_list ( gint transaction_number )
+{
+    struct_transaction *transaction;
+
+    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number );
+
+    if ( !transaction )
+        return FALSE;
+
+    /* delete the transaction from the lists */
+    transactions_list = g_slist_remove ( transactions_list, transaction );
+
+    return TRUE;
+}
+
+
+/**
+ * renvoie la liste des opérations concernées par un fichier importé.
+ *
+ * \param account_number
+ * \param first_date_import     date de début de recherche
+ *
+ * \return
+ * */
+GSList *gsb_import_get_transactions_list_for_import ( gint account_number,
+                        GDate *first_date_import )
+{
+    GSList *tmp_list;
+    GSList *ope_list = NULL;
+
+    tmp_list = g_slist_copy ( transactions_list );
+    tmp_list = g_slist_sort ( tmp_list, (GCompareFunc) classement_sliste_transactions_par_date_decroissante );
+
+    while ( tmp_list )
+    {
+        struct_transaction *transaction;
+        GDate *ope_date;
+
+        transaction = tmp_list->data;
+
+        if ( transaction->value_date && g_date_valid ( transaction->value_date ) )
+            ope_date = transaction->value_date;
+        else
+            ope_date = transaction->date;
+
+        if ( transaction->account_number == account_number
+         &&
+         g_date_compare ( ope_date, first_date_import ) >= 0 )
+        {
+            ope_list = g_slist_append ( ope_list,  GINT_TO_POINTER ( transaction->transaction_number ) );
+        }
+
+        tmp_list = tmp_list->next;
+    }
+
+    g_slist_free ( tmp_list );
+
+    return ope_list;
+}
+
+
 /**
  *
  *
