@@ -24,8 +24,6 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
                         gint target_transaction_number,
                         gboolean reset_mark );
 gint gsb_data_transaction_find_by_id ( gchar *id, gint account_number );
-gint gsb_data_transaction_find_by_payment_content ( const gchar *string,
-                        gint account_number );
 gint gsb_data_transaction_get_account_number ( gint transaction_number );
 gsb_real gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
                         gint return_exponent );
@@ -58,6 +56,7 @@ gsb_real gsb_data_transaction_get_last_transaction_with_div_sub_div (
                         gint sub_div_nb,
                         gint type_div );
 gint gsb_data_transaction_get_marked_transaction ( gint transaction_number );
+GSList *gsb_data_transaction_get_metatree_transactions_list ( void );
 const gchar *gsb_data_transaction_get_method_of_payment_content ( gint transaction_number );
 gint gsb_data_transaction_get_method_of_payment_number ( gint transaction_number );
 gint gsb_data_transaction_get_mother_transaction_number ( gint transaction_number );
@@ -71,7 +70,8 @@ gint gsb_data_transaction_get_sub_category_number ( gint transaction_number );
 const gchar *gsb_data_transaction_get_transaction_id ( gint transaction_number );
 gint gsb_data_transaction_get_transaction_number ( gpointer transaction_pointer );
 GSList *gsb_data_transaction_get_transactions_list ( void );
-GSList *gsb_data_transaction_get_transactions_list_by_date ( void );
+GSList *gsb_import_get_transactions_list_for_import ( gint account_number,
+                        GDate *first_date_import );
 const GDate *gsb_data_transaction_get_value_date ( gint transaction_number );
 const GDate *gsb_data_transaction_get_value_date_or_date ( gint transaction_number );
 const gchar *gsb_data_transaction_get_voucher ( gint transaction_number );
@@ -82,6 +82,7 @@ gint gsb_data_transaction_new_transaction_with_number ( gint no_account,
                         gint transaction_number );
 gint gsb_data_transaction_new_white_line ( gint mother_transaction_number);
 gboolean gsb_data_transaction_remove_transaction ( gint transaction_number );
+gboolean gsb_data_transaction_remove_transaction_in_transaction_list ( gint transaction_number );
 gboolean gsb_data_transaction_remove_transaction_without_check ( gint transaction_number );
 gboolean gsb_data_transaction_set_account_number ( gint transaction_number,
                         gint no_account );
