@@ -26,8 +26,11 @@
 #endif
 
 #include "include.h"
-
 #include <time.h>
+#include <limits.h>
+#include <stdlib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
 
 #ifdef _WIN32
 #	if defined(_MSC_VER) || defined(_MINGW)
@@ -39,33 +42,33 @@
 
 /*START_INCLUDE*/
 #include "gsb_file.h"
-#include "menu.h"
-#include "utils.h"
-#include "fenetre_principale.h"
+#include "accueil.h"
+#include "affichage_liste.h"
 #include "dialog.h"
-#include "utils_file_selection.h"
+#include "fenetre_principale.h"
 #include "gsb_account_property.h"
 #include "gsb_assistant_account.h"
 #include "gsb_assistant_file.h"
 #include "gsb_data_account.h"
 #include "gsb_data_archive_store.h"
-#include "gsb_file_config.h"
+#include "gsb_dirs.h"
 #include "gsb_file_load.h"
 #include "gsb_file_save.h"
 #include "gsb_file_util.h"
-#include "navigation.h"
-#include "accueil.h"
 #include "gsb_real.h"
 #include "gsb_status.h"
 #include "gsb_transactions_list.h"
-#include "traitement_variables.h"
 #include "main.h"
-#include "utils_str.h"
+#include "menu.h"
+#include "navigation.h"
 #include "parametres.h"
-#include "affichage_liste.h"
-#include "transaction_list.h"
-#include "utils_files.h"
 #include "structures.h"
+#include "traitement_variables.h"
+#include "transaction_list.h"
+#include "utils.h"
+#include "utils_file_selection.h"
+#include "utils_files.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -91,18 +94,11 @@ gint id_timeout = 0;
 
 /*START_EXTERN*/
 extern gchar *copy_old_filename;
-extern GtkWidget *main_hpaned;
-extern GtkWidget *main_vbox;
-extern GtkWidget * navigation_tree_view;
-extern gsize nb_derniers_fichiers_ouverts;
-extern gint nb_max_derniers_fichiers_ouverts;
 extern gchar *nom_fichier_comptes;
-extern GtkWidget *notebook_general;
 extern gchar **tab_noms_derniers_fichiers_ouverts;
 extern GtkWidget *table_etat;
 extern gchar *titre_fichier;
 extern GtkWidget *tree_view_vbox;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -149,14 +145,16 @@ gboolean gsb_file_new_finish ( void )
         return FALSE;
     }
 
+    /* the the name in the last opened files */
+    gsb_file_append_name_to_opened_list ( nom_fichier_comptes );
+
     /* init the gui */
     gsb_file_new_gui ();
 
     mise_a_jour_accueil ( TRUE );
     gsb_gui_navigation_set_selection ( GSB_HOME_PAGE, -1, NULL );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -166,19 +164,20 @@ gboolean gsb_file_new_finish ( void )
  */
 void gsb_file_new_gui ( void )
 {
-    GtkWidget *window_vbox_principale;
-    GtkWidget * tree_view_widget;
+    GtkWidget *main_vbox;
+    GtkWidget *tree_view_widget;
+    GtkWidget *notebook_general;
 
     /* dégrise les menus nécessaire */
-    menus_sensitifs ( TRUE );
+    gsb_menu_set_menus_with_file_sensitive ( TRUE );
 
     /*     récupère l'organisation des colonnes  */
     recuperation_noms_colonnes_et_tips ();
 
     /* Create main widget. */
-    gsb_status_message ( _("Creating main window"));
-    window_vbox_principale = g_object_get_data ( G_OBJECT ( window ), "window_vbox_principale" );
-    gtk_box_pack_start ( GTK_BOX ( window_vbox_principale), create_main_widget(), TRUE, TRUE, 0 );
+    gsb_status_message ( _("Creating main window") );
+    main_vbox = g_object_get_data ( G_OBJECT ( run.window ), "main_vbox" );
+    gtk_box_pack_start ( GTK_BOX ( main_vbox ), gsb_gui_create_general_widgets ( ), TRUE, TRUE, 0 );
 
     /* create the model */
     if (!transaction_list_create ())
@@ -197,11 +196,12 @@ void gsb_file_new_gui ( void )
                 0 );
     gtk_widget_show ( tree_view_widget );
 
-    navigation_change_account ( GINT_TO_POINTER ( gsb_gui_navigation_get_current_account () ) );
+    navigation_change_account ( gsb_gui_navigation_get_current_account () );
 
     /* Display accounts in menus */
     gsb_menu_update_accounts_in_menus ();
 
+    notebook_general = gsb_gui_get_general_notebook ( );
     gtk_notebook_set_current_page ( GTK_NOTEBOOK( notebook_general ), GSB_HOME_PAGE );
 
     gtk_widget_show ( notebook_general );
@@ -222,7 +222,7 @@ gboolean gsb_file_open_menu ( void )
     GtkFileFilter * filter;
 
     selection_fichier = gtk_file_chooser_dialog_new ( _("Open an accounts file"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_OPEN,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
@@ -319,7 +319,7 @@ const gchar *gsb_file_get_backup_path ( void )
 void gsb_file_set_backup_path ( const gchar *path )
 {
     if ( path == NULL || strlen ( path ) == 0 )
-        backup_path = my_strdup ( C_PATH_DATA_FILES );
+        backup_path = my_strdup ( gsb_dirs_get_user_data_dir () );
     else
         backup_path = my_strdup ( path );
 
@@ -376,7 +376,7 @@ gboolean gsb_file_open_file ( gchar *filename )
     gsb_status_message ( _("Loading accounts") );
 
     /* try to load the file */
-    /* FIXME:BUG under Windows: for unknwon reason yet filename is cleared 
+    /* FIXME:BUG under Windows: for unknwon reason yet filename is cleared
      * when returning from gsb_file_load_open_file!
      * making application crashes! */
 
@@ -387,7 +387,7 @@ gboolean gsb_file_open_file ( gchar *filename )
         if ( conf.sauvegarde_demarrage )
         {
             gsb_file_save_backup ();
-            etat.modification_fichier = FALSE;
+            gsb_file_set_modified ( FALSE );
         }
     }
     else
@@ -398,7 +398,7 @@ gboolean gsb_file_open_file ( gchar *filename )
         if ( conf.sauvegarde_demarrage || conf.make_backup || conf.make_backup_every_minutes )
         {
             gchar *tmpstr = g_strdup_printf ( _("Error loading file '%s'"), filename);
-            gchar *tmpstr2 = g_strdup_printf ( 
+            gchar *tmpstr2 = g_strdup_printf (
                                 _("Grisbi was unable to load file. You should find the last "
                                   "backups in '%s', they are saved with date and time into "
                                   "their name so you should find easily the last backup "
@@ -418,7 +418,7 @@ gboolean gsb_file_open_file ( gchar *filename )
             gchar *tmpstr2;
 
             if (gsb_file_get_backup_path ())
-            tmpstr2 = g_strdup_printf ( 
+            tmpstr2 = g_strdup_printf (
                             _("Grisbi was unable to load file and the backups seem not to "
                               "be activated... This is a bad thing.\nYour backup path is '%s', "
                               "try to find if earlier you had some backups in there ?\n"
@@ -465,7 +465,7 @@ gboolean gsb_file_open_file ( gchar *filename )
 	account_number = gsb_data_account_get_no_account ( list_tmp -> data );
 
 	/* set the minimum balances to be shown or not */
-	value = gsb_real_cmp ( gsb_data_account_get_current_balance (account_number), 
+	value = gsb_real_cmp ( gsb_data_account_get_current_balance (account_number),
                           gsb_data_account_get_mini_balance_authorized (account_number) ) == -1;
     gsb_data_account_set_mini_balance_authorized_message ( account_number, value);
     value = gsb_real_cmp ( gsb_data_account_get_current_balance (account_number),
@@ -482,7 +482,7 @@ gboolean gsb_file_open_file ( gchar *filename )
 
     /* for now, the flag for modification of the file is ok, but the menu couldn't be set
      * as sensitive/unsensitive so do it now */
-    modification_fichier (etat.modification_fichier != 0);
+    gsb_file_set_modified ( gsb_file_get_modified ( ) );
 
     gsb_status_message ( _("Done") );
     gsb_status_stop_wait ( TRUE );
@@ -491,7 +491,7 @@ gboolean gsb_file_open_file ( gchar *filename )
     gsb_gui_navigation_set_selection ( GSB_HOME_PAGE, -1, NULL );
 
     /* set the focus to the selection tree at left */
-    gtk_widget_grab_focus (navigation_tree_view);
+    gtk_widget_grab_focus ( gsb_gui_navigation_get_tree_view ( ) );
 
     return TRUE;
 }
@@ -535,7 +535,7 @@ gboolean gsb_file_save_file ( gint origine )
 
     etat_force = 0;
 
-    if ( ( !etat.modification_fichier && origine != -2 ) ||
+    if ( ( !gsb_file_get_modified ( ) && origine != -2 ) ||
 	 !gsb_data_account_get_accounts_amount () )
     {
 	notice_debug ( "nothing done in gsb_file_save_file" );
@@ -603,7 +603,7 @@ gboolean gsb_file_save_file ( gint origine )
 
 	/* update variables */
 	etat.fichier_deja_ouvert = 0;
-    modification_fichier ( FALSE );
+        gsb_file_set_modified ( FALSE );
 	gsb_main_set_grisbi_title ( gsb_gui_navigation_get_current_account ( ) );
 	gsb_file_append_name_to_opened_list ( nom_fichier_comptes );
     }
@@ -631,7 +631,7 @@ gboolean gsb_file_save_backup ( void )
 
     if (!gsb_file_get_backup_path ()
 	||
-	!etat.modification_fichier )
+	!gsb_file_get_modified ( ) )
 	return FALSE;
 
     gsb_status_message ( _("Saving backup") );
@@ -646,8 +646,8 @@ gboolean gsb_file_save_backup ( void )
         {
             g_free ( name );
             name = g_strdup ( tab_str[0] );
-            g_strfreev ( tab_str );
         }
+        g_strfreev ( tab_str );
     }
     /* create a filename for the backup :
      * filename_yyyymmddTmmhhss.gsb */
@@ -784,14 +784,14 @@ static gint gsb_file_dialog_save ( void )
     time_t now = time ( NULL );
     gint result;
     GtkWidget *dialog;
-    gint difference = (gint) difftime ( now, etat.modification_fichier );
+    gint difference = (gint) difftime ( now, run.file_modification );
     gchar* message;
 	gchar* tmpstr1;
 	gchar* tmpstr2;
 
     /*     si le fichier n'est pas modifié on renvoie qu'on ne veut pas enregistrer */
 
-    if ( !etat.modification_fichier )
+    if ( ! gsb_file_get_modified ( ) )
 	return GTK_RESPONSE_NO;
 
     if ( conf.sauvegarde_auto &&
@@ -802,7 +802,7 @@ static gint gsb_file_dialog_save ( void )
     /*     si le fichier était déjà locké et que force enregistrement n'est pas mis, */
     /*     on prévient ici */
 
-    dialog = gtk_message_dialog_new ( GTK_WINDOW (window),
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( run.window ),
 				      GTK_DIALOG_DESTROY_WITH_PARENT,
 				      GTK_MESSAGE_WARNING,
 				      GTK_BUTTONS_NONE,
@@ -886,7 +886,7 @@ static gchar *gsb_file_dialog_ask_name ( void )
     gint result;
 
     dialog = gtk_file_chooser_dialog_new ( _("Name the accounts file"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
@@ -971,18 +971,17 @@ gboolean gsb_file_close ( void )
 		 nom_fichier_comptes )
 		gsb_file_util_modify_lock ( FALSE );
 
-	    gtk_widget_destroy (main_vbox);
-
 	    /* free all the variables */
  	    init_variables ();
+        gsb_gui_init_general_vbox ( );
         gsb_account_property_clear_config ( );
 
         gsb_main_set_grisbi_title ( -1 );
 
-	    menus_sensitifs ( FALSE );
+        /* unsensitive the necessaries menus */
+        gsb_menu_set_menus_with_file_sensitive ( FALSE );
 
-	    main_hpaned = NULL;
-	    table_etat = NULL;
+        table_etat = NULL;
 
 	    return ( TRUE );
 
@@ -1009,11 +1008,11 @@ void gsb_file_append_name_to_opened_list ( gchar * path_fichier )
     if ( !path_fichier )
         return;
 
-    if ( nb_max_derniers_fichiers_ouverts == 0 )
+    if ( conf.nb_max_derniers_fichiers_ouverts == 0 )
         return;
 
-    if ( nb_derniers_fichiers_ouverts < 0 )
-        nb_derniers_fichiers_ouverts = 0;
+    if ( conf.nb_derniers_fichiers_ouverts < 0 )
+        conf.nb_derniers_fichiers_ouverts = 0;
 
     if ( !g_path_is_absolute ( nom_fichier_comptes ) )
     {
@@ -1030,13 +1029,13 @@ void gsb_file_append_name_to_opened_list ( gchar * path_fichier )
         real_name = g_strdup ( path_fichier );
     }
 
-    /* on commence par vérifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts 
+    /* on commence par vérifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts
      * noms */
     position = 0;
 
-    if ( nb_derniers_fichiers_ouverts )
+    if ( conf.nb_derniers_fichiers_ouverts )
     {
-        for ( i = 0; i < nb_derniers_fichiers_ouverts; i++ )
+        for ( i = 0; i < conf.nb_derniers_fichiers_ouverts; i++ )
         {
             if ( !strcmp ( real_name, tab_noms_derniers_fichiers_ouverts[i] ) )
             {
@@ -1072,18 +1071,18 @@ void gsb_file_append_name_to_opened_list ( gchar * path_fichier )
 
         /* si on est déjà au max, c'est juste un décalage avec perte du dernier */
         /* on garde le ptit dernier dans le cas contraire */
-        dernier = tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1];
-        for ( i = nb_derniers_fichiers_ouverts - 1 ; i > 0 ; i-- )
+        dernier = tab_noms_derniers_fichiers_ouverts[conf.nb_derniers_fichiers_ouverts-1];
+        for ( i = conf.nb_derniers_fichiers_ouverts - 1 ; i > 0 ; i-- )
             tab_noms_derniers_fichiers_ouverts[i] = tab_noms_derniers_fichiers_ouverts[i-1];
     }
     else
         dernier = NULL;
 
-    if ( nb_derniers_fichiers_ouverts < nb_max_derniers_fichiers_ouverts )
+    if ( conf.nb_derniers_fichiers_ouverts < conf.nb_max_derniers_fichiers_ouverts )
     {
         tab_noms_derniers_fichiers_ouverts = g_realloc ( tab_noms_derniers_fichiers_ouverts,
-						    ( ++nb_derniers_fichiers_ouverts ) * sizeof ( gpointer ) );
-        tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1] = dernier;
+						    ( ++conf.nb_derniers_fichiers_ouverts ) * sizeof ( gpointer ) );
+        tab_noms_derniers_fichiers_ouverts[conf.nb_derniers_fichiers_ouverts-1] = dernier;
     }
 
     tab_noms_derniers_fichiers_ouverts[0] = my_strdup ( real_name );
@@ -1106,17 +1105,17 @@ void gsb_file_remove_name_from_opened_list ( gchar *filename )
 
     devel_debug ( filename );
     efface_derniers_fichiers_ouverts();
-    devel_debug_int ( nb_derniers_fichiers_ouverts );
+    devel_debug_int ( conf.nb_derniers_fichiers_ouverts );
 
-    for ( i = 0 ; i < nb_derniers_fichiers_ouverts; i++ )
+    for ( i = 0 ; i < conf.nb_derniers_fichiers_ouverts; i++ )
     {
         if ( strcmp (filename, tab_noms_derniers_fichiers_ouverts[i]) == 0 )
         {
-            for ( j = i; ( j + 1 ) < nb_derniers_fichiers_ouverts; j++ )
+            for ( j = i; ( j + 1 ) < conf.nb_derniers_fichiers_ouverts; j++ )
             {
                 tab_noms_derniers_fichiers_ouverts[j] = tab_noms_derniers_fichiers_ouverts[j+1];
             }
-            nb_derniers_fichiers_ouverts--;
+            conf.nb_derniers_fichiers_ouverts--;
         }
     }
     affiche_derniers_fichiers_ouverts();
@@ -1139,9 +1138,9 @@ void gsb_file_save_remove_old_file ( gchar *filename )
     gint resultat;
 	gchar *tmpstr;
 
-    dialog = gtk_dialog_new_with_buttons ( 
-                        _("Delete file copy from a previous version of grisbi"),
-                        GTK_WINDOW ( window ),
+    dialog = gtk_dialog_new_with_buttons (
+                        _("Delete file copy from a previous version of Grisbi"),
+                        GTK_WINDOW ( run.window ),
                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                         GTK_STOCK_NO, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_YES, GTK_RESPONSE_OK,
@@ -1155,13 +1154,13 @@ void gsb_file_save_remove_old_file ( gchar *filename )
     gtk_container_set_border_width ( GTK_CONTAINER( hbox ), 6 );
     gtk_box_pack_start ( GTK_BOX ( content_area ), hbox, FALSE, FALSE, 5 );
 
-    image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
+    image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
                         GTK_ICON_SIZE_DIALOG );
     gtk_box_pack_start ( GTK_BOX ( hbox ), image, FALSE, FALSE, 5 );
 
-    tmpstr = g_strdup_printf ( 
+    tmpstr = g_strdup_printf (
                         _("Caution, you are about to delete a file copy\n"
-                        "from a previous version of grisbi.\n"
+                        "from a previous version of Grisbi.\n"
                         "\n<b>Do you want to delete this file:\n%s ?</b>"),
                         filename );
 
@@ -1178,6 +1177,54 @@ void gsb_file_save_remove_old_file ( gchar *filename )
         g_unlink ( filename );
     gtk_widget_destroy ( GTK_WIDGET ( dialog ) );
 }
+
+
+/**
+ * set or unset the modified flag (run structure)
+ * and sensitive or not the menu to save the file
+ *
+ * \param modif TRUE to set the modified flag, FALSE to unset
+ *
+ * \return
+ */
+void gsb_file_set_modified ( gboolean modified )
+{
+/*     devel_debug_int (modified);  */
+
+    /* If no file is loaded, do not change menu items. */
+    if ( ! gsb_data_account_get_accounts_amount () )
+        return;
+
+    if ( modified )
+    {
+        if ( ! run.file_modification )
+        {
+            run.file_modification = time ( NULL );
+            gsb_gui_sensitive_menu_item ( "/menubar/FileMenu/Save", TRUE );
+        }
+    }
+    else
+    {
+        run.file_modification = 0;
+        gsb_gui_sensitive_menu_item ( "/menubar/FileMenu/Save", FALSE );
+    }
+}
+
+
+/**
+ * Tell if the current file has been modified or not
+ *
+ * \return TRUE if modified, FALSE otherwise
+ */
+gboolean gsb_file_get_modified ( void )
+{
+    if ( run.file_modification == 0 )
+        return FALSE;
+    else
+        return TRUE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
