@@ -1,5 +1,8 @@
 #ifndef _FICHIERS_GESTION_H
 #define _FICHIERS_GESTION_H (1)
+
+#include <gtk/gtk.h>
+
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
 
@@ -24,5 +27,7 @@ gboolean gsb_file_save ( void );
 gboolean gsb_file_save_as ( void );
 void gsb_file_set_backup_path ( const gchar *path );
 void gsb_file_update_last_path ( const gchar *last_path );
+void gsb_file_set_modified ( gboolean modified );
+gboolean gsb_file_get_modified ( void );
 /* END_DECLARATION */
 #endif
