@@ -31,6 +31,8 @@
 #endif
 
 #include "include.h"
+#include <errno.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_file_others.h"
@@ -38,6 +40,7 @@
 #include "gsb_data_budget.h"
 #include "gsb_data_category.h"
 #include "gsb_data_report.h"
+#include "gsb_file.h"
 #include "gsb_file_load.h"
 #include "gsb_file_save.h"
 #include "navigation.h"
@@ -78,7 +81,7 @@ static void gsb_file_others_start_element ( GMarkupParseContext *context,
 /*END_EXTERN*/
 
 
-/** 
+/**
  * save the category file
  * we don't check anything here, all must be done before, here we just write
  * the file
@@ -90,10 +93,11 @@ static void gsb_file_others_start_element ( GMarkupParseContext *context,
  * */
 gboolean gsb_file_others_save_category ( gchar *filename )
 {
+    gchar *file_content;
+    gchar *tmp_str;
     FILE *file;
     gulong iterator;
     gulong length_calculated;
-    gchar *file_content;
     gulong length_part;
 
     devel_debug (filename);
@@ -104,14 +108,22 @@ gboolean gsb_file_others_save_category ( gchar *filename )
      * with that i think we will allocate enough memory in one time but not too much */
 
     length_part = 500;
-    
+
     length_calculated = length_part * g_slist_length (gsb_data_category_get_categories_list());
+    if ( length_calculated == 0 )
+    {
+        tmp_str = g_strdup ( _("There is no category to record. Back.") );
+        dialogue_error ( tmp_str );
+        g_free ( tmp_str );
+
+        return ( TRUE );
+    }
 
     iterator = 0;
     file_content = g_malloc0 ( length_calculated );
 
     /* begin the file whit xml markup */
-    
+
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
@@ -144,22 +156,22 @@ gboolean gsb_file_others_save_category ( gchar *filename )
 		   iterator,
 		   file ))
     {
-        gchar *tmpstr = g_strdup_printf ( _("Cannot save file '%s': %s"),
-					   filename,
-					   g_strerror(errno) );
-	dialogue_error ( tmpstr );
-	g_free ( tmpstr );
-	g_free ( file_content);
-	return ( FALSE );
+        tmp_str = g_strdup_printf ( _("Cannot save file '%s': %s"),
+                        filename,
+                        g_strerror ( errno ) );
+        dialogue_error ( tmp_str );
+        g_free ( tmp_str );
+        g_free ( file_content );
+        return ( FALSE );
     }
-    
+
     fclose (file);
     g_free ( file_content);
 
     return ( TRUE );
 }
 
-/** 
+/**
  * save the budget file
  * we don't check anything here, all must be done before, here we just write
  * the file
@@ -171,10 +183,11 @@ gboolean gsb_file_others_save_category ( gchar *filename )
  * */
 gboolean gsb_file_others_save_budget ( gchar *filename )
 {
+    gchar *file_content;
+    gchar *tmp_str;
     FILE *file;
     gulong iterator;
     gulong length_calculated;
-    gchar *file_content;
     gulong length_part;
 
     devel_debug (filename);
@@ -185,14 +198,22 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
      * with that i think we will allocate enough memory in one time but not too much */
 
     length_part = 500;
-    
-    length_calculated = length_part * g_slist_length (gsb_data_budget_get_budgets_list());
+
+    length_calculated = length_part * g_slist_length ( gsb_data_budget_get_budgets_list () );
+    if ( length_calculated == 0 )
+    {
+        tmp_str = g_strdup ( _("There is no budgetary line to record. Back.") );
+        dialogue_error ( tmp_str );
+        g_free ( tmp_str );
+
+        return ( TRUE );
+    }
 
     iterator = 0;
     file_content = g_malloc0 ( length_calculated );
 
     /* begin the file whit xml markup */
-    
+
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
@@ -225,22 +246,22 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
 		   iterator,
 		   file ))
     {
-	gchar* tmpstr = g_strdup_printf ( _("Cannot save file '%s': %s"),
-					   filename,
-					   g_strerror(errno) );
-	dialogue_error ( tmpstr );
-	g_free ( tmpstr );
-	g_free ( file_content);
-	return ( FALSE );
+        tmp_str = g_strdup_printf ( _("Cannot save file '%s': %s"),
+                        filename,
+                        g_strerror ( errno ) );
+        dialogue_error ( tmp_str );
+        g_free ( tmp_str );
+        g_free ( file_content );
+        return ( FALSE );
     }
-    
+
     fclose ( file );
     g_free ( file_content);
 
     return ( TRUE );
 }
 
-/** 
+/**
  * save the report file
  * we don't check anything here, all must be done before, here we just write
  * the file
@@ -252,10 +273,11 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
  * */
 gboolean gsb_file_others_save_report ( gchar *filename )
 {
+    gchar *file_content;
+    gchar *tmp_str;
     FILE *file;
     gulong iterator;
     gulong length_calculated;
-    gchar *file_content;
     gulong length_part;
 
     devel_debug (filename);
@@ -266,14 +288,22 @@ gboolean gsb_file_others_save_report ( gchar *filename )
      * with that i think we will allocate enough memory in one time but not too much */
 
     length_part = 2500;
-    
+
     length_calculated = length_part * g_slist_length (gsb_data_report_get_report_list ());
+    if ( length_calculated == 0 )
+    {
+        tmp_str = g_strdup ( _("There is no report to record. Back.") );
+        dialogue_error ( tmp_str );
+        g_free ( tmp_str );
+
+        return ( TRUE );
+    }
 
     iterator = 0;
     file_content = g_malloc0 ( length_calculated );
 
     /* begin the file whit xml markup */
-    
+
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
@@ -308,15 +338,15 @@ gboolean gsb_file_others_save_report ( gchar *filename )
 		   iterator,
 		   file ))
     {
-	gchar* tmpstr = g_strdup_printf ( _("Cannot save file '%s': %s"),
-					   filename,
-					   g_strerror(errno) );
-	dialogue_error ( tmpstr);
-	g_free ( tmpstr );
-	g_free ( file_content);
-	return ( FALSE );
+        tmp_str = g_strdup_printf ( _("Cannot save file '%s': %s"),
+                        filename,
+                        g_strerror ( errno ) );
+        dialogue_error ( tmp_str);
+        g_free ( tmp_str );
+        g_free ( file_content );
+        return ( FALSE );
     }
-    
+
     fclose ( file );
     g_free ( file_content);
 
@@ -417,11 +447,12 @@ gboolean gsb_file_others_load ( gchar *filename,
 {
     gchar *file_content;
     GSList *import_list = NULL;
+    GError *error = NULL;
 
     devel_debug (filename);
 
     /* general check */
-    
+
     if ( !g_file_test ( filename,
 			G_FILE_TEST_EXISTS ))
     {
@@ -437,7 +468,7 @@ gboolean gsb_file_others_load ( gchar *filename,
     if ( !g_file_test ( filename,
 			G_FILE_TEST_IS_REGULAR ))
     {
-        gchar* tmpstr = g_strdup_printf ( 
+        gchar* tmpstr = g_strdup_printf (
                         _("%s doesn't seem to be a regular file,\nplease check it and try again."),
 					   filename );
 	dialogue_error ( tmpstr );
@@ -452,7 +483,7 @@ gboolean gsb_file_others_load ( gchar *filename,
 			       NULL,
 			       NULL ))
     {
-	GMarkupParser *markup_parser = g_malloc0 (sizeof (GMarkupParser));
+	GMarkupParser *markup_parser;
 	GMarkupParseContext *context;
 
 	/* check if it's a good file */
@@ -468,18 +499,26 @@ gboolean gsb_file_others_load ( gchar *filename,
 	 * and i'm too lazy to create an import for old files */
 	/* fill the GMarkupParser for a new xml structure */
 
-	markup_parser -> start_element = (void *) gsb_file_others_start_element;
-	markup_parser -> error = (void *) gsb_file_load_error;
+	markup_parser = g_malloc0 ( sizeof ( GMarkupParser ) );
+	markup_parser -> start_element = ( void * ) gsb_file_others_start_element;
+	markup_parser -> error = ( void * ) gsb_file_load_error;
 
-	context = g_markup_parse_context_new ( markup_parser,
-					       0,
-					       &import_list,
-					       NULL );
+    context = g_markup_parse_context_new ( markup_parser, 0, &import_list, NULL );
 
-	g_markup_parse_context_parse ( context,
-				       file_content,
-				       strlen (file_content),
-				       NULL );
+    if ( !g_markup_parse_context_parse ( context, file_content, strlen ( file_content ), &error ) )
+    {
+        gchar* tmpstr;
+
+        tmpstr = g_strdup_printf (_("Error parsing file '%s': %s"), filename, error->message );
+        dialogue_error ( tmpstr );
+
+        g_free ( tmpstr );
+        g_markup_parse_context_free ( context );
+        g_free ( markup_parser );
+        g_free ( file_content );
+
+        return FALSE;
+    }
 
 	/* now, import_list contains the list of categories/budget or report */
 	switch ( origin )
@@ -488,12 +527,12 @@ gboolean gsb_file_others_load ( gchar *filename,
 
 	    case 0:
 		/* comes for category */
-		remplit_arbre_categ ();
+		categories_fill_list ();
 		break;
 
 	    case 1:
 		/* comes for budget */
-		remplit_arbre_imputation ();
+		budgetary_lines_fill_list ();
 		break;
 
 	    case 2:
@@ -542,11 +581,11 @@ gboolean gsb_file_others_load ( gchar *filename,
 		    gsb_gui_navigation_add_report ( report_number );
 
 		    /* inform the user of that */
-		    dialogue_hint ( _("Some things in a report cannot be imported :\n"
+		    dialogue_hint ( _("Some things in a report cannot be imported:\n"
                         "The selected lists of financial years, accounts, transfer accounts, "
                         "categories, budgetaries, parties and kind of payments.\nSo that lists "
                         "have been erased while the import.\nThe currencies have been set too "
-                        "on the first currency of this grisbi file.\nYou should check and modify "
+                        "on the first currency of this Grisbi file.\nYou should check and modify "
                         "that in the property box of that account."),
 				        _("Importing a report"));
 		}
@@ -557,8 +596,7 @@ gboolean gsb_file_others_load ( gchar *filename,
 	g_free (markup_parser);
 	g_free (file_content);
 
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
     else
     {
@@ -588,14 +626,14 @@ gboolean gsb_file_others_check_file ( gchar *file_content,
 	 ||
 	 strlen (file_content) < 37 )
     {
-	dialogue_error ( _("This is not a grisbi file, loading canceled..."));
+	dialogue_error ( _("This is not a Grisbi file, loading canceled..."));
 	return FALSE;
     }
 
     file_content = gsb_string_uniform_new_line ( file_content, 37 );
     if ( !file_content )
     {
-        dialogue_error ( _("This is not a grisbi file, loading canceled..."));
+        dialogue_error ( _("This is not a Grisbi file, loading canceled..."));
         return FALSE;
     }
 
@@ -760,7 +798,7 @@ gboolean gsb_file_others_load_budget_from_category ( const gchar *filename )
     /* check here if it's not a regular file */
     if ( !g_file_test ( filename, G_FILE_TEST_IS_REGULAR ) )
     {
-        tmp_str = g_strdup_printf ( 
+        tmp_str = g_strdup_printf (
                         _("%s doesn't seem to be a regular file,\nplease check it and try again."),
 					   filename );
         dialogue_error ( tmp_str );
@@ -771,7 +809,7 @@ gboolean gsb_file_others_load_budget_from_category ( const gchar *filename )
     /* load the file */
     if ( g_file_get_contents ( filename, &file_content, NULL, NULL ) )
     {
-        GMarkupParser *markup_parser = g_malloc0 (sizeof (GMarkupParser));
+        GMarkupParser *markup_parser;
         GMarkupParseContext *context;
 
         /* check if it's a good file */
@@ -785,6 +823,7 @@ gboolean gsb_file_others_load_budget_from_category ( const gchar *filename )
          * there is very few people who will want to upgrade previous categories, budgets...
          * and i'm too lazy to create an import for old files */
         /* fill the GMarkupParser for a new xml structure */
+        markup_parser = g_malloc0 (sizeof (GMarkupParser));
         markup_parser -> start_element = (void *) gsb_file_others_start_budget_from_category;
         markup_parser -> error = (void *) gsb_file_load_error;
 
@@ -798,14 +837,13 @@ gboolean gsb_file_others_load_budget_from_category ( const gchar *filename )
                            NULL );
 
         /* on remplit l'arbre des imputation */
-        remplit_arbre_imputation ( );
+        budgetary_lines_fill_list ( );
 
         g_markup_parse_context_free ( context );
         g_free ( markup_parser );
         g_free ( file_content );
 
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
     else
     {
