@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_fyear_config.h"
@@ -41,6 +42,7 @@
 #include "gsb_data_account.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_transaction.h"
+#include "gsb_file.h"
 #include "gsb_fyear.h"
 #include "traitement_variables.h"
 #include "utils.h"
@@ -119,9 +121,9 @@ GtkWidget *gsb_fyear_config_create_page ( void )
     tree_model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
     gtk_container_add ( GTK_CONTAINER ( scrolled_window ),
 			tree_view);
-    g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)), 
+    g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)),
 		       "changed",
-		       G_CALLBACK (gsb_fyear_config_select), 
+		       G_CALLBACK (gsb_fyear_config_select),
 		       NULL );
 
 
@@ -192,6 +194,8 @@ GtkWidget *gsb_fyear_config_create_page ( void )
 
     /* Financial year name */
     label = gtk_label_new ( _("Name: ") );
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ),
 		       label, 0, 1, 0, 1,
 		       GTK_SHRINK | GTK_FILL, 0,
@@ -334,7 +338,7 @@ GtkWidget *gsb_fyear_config_create_list ()
     }
 
     /* Sort columns accordingly */
-    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model), 
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model),
 					  FYEAR_NAME_COLUMN, GTK_SORT_ASCENDING);
 
     return treeview;
@@ -375,7 +379,7 @@ void gsb_fyear_config_fill_list ( GtkTreeModel *model )
  * \param fyear_number
  * \param iter a pointer to an iter to fill it with the position of the new link, or NULL
  *
- * \return 
+ * \return
  * */
 void gsb_fyear_config_append_line ( GtkTreeModel *model,
 				    gint fyear_number,
@@ -493,7 +497,7 @@ gboolean gsb_fyear_config_select ( GtkTreeSelection *tree_selection,
 
 
 /**
- * called when something change for a fyear 
+ * called when something change for a fyear
  * update the list and the invalid
  *
  * \param entry the entry wich change
@@ -554,8 +558,7 @@ gboolean gsb_fyear_config_modify_fyear ( GtkWidget *entry,
 			  FYEAR_INVALID_COLUMN, invalid,
 			  FYEAR_NUMBER_COLUMN, fyear_number,
 			  -1 );
-     if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+     gsb_file_set_modified ( TRUE );
      return FALSE;
 }
 
@@ -622,7 +625,7 @@ gboolean gsb_fyear_config_add_fyear ( GtkWidget *tree_view )
     /* if bad things will append soon ... */
     if (!fyear_number)
 	return FALSE;
-    
+
     gsb_data_fyear_set_form_show ( fyear_number,
 				   TRUE );
     gsb_data_fyear_set_beginning_date ( fyear_number,
@@ -651,8 +654,7 @@ gboolean gsb_fyear_config_add_fyear ( GtkWidget *tree_view )
 
     /* Update various menus */
     gsb_fyear_update_fyear_list ();
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -710,7 +712,7 @@ gboolean gsb_fyear_config_remove_fyear ( GtkWidget *tree_view )
 		gint result;
 
 		result = question_yes_no_hint ( _("The selected financial year is used in the file"),
-						_("If you really remove it, all the associated transactions will be without financial year.\nAre you sure ?"),
+						_("If you really remove it, all the associated transactions will be without financial year.\nAre you sure?"),
 						GTK_RESPONSE_NO );
 		if (result)
 		{
@@ -743,8 +745,7 @@ gboolean gsb_fyear_config_remove_fyear ( GtkWidget *tree_view )
 
 	/* Update various menus */
 	gsb_fyear_update_fyear_list ();
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
     return FALSE;
 }
@@ -800,8 +801,7 @@ gboolean gsb_fyear_config_associate_transactions ( void )
 	dialogue (  tmpstr );
 	g_free ( tmpstr );
 	transaction_list_update_element (ELEMENT_EXERCICE);
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
     else
 	dialogue ( _("no transaction to associate"));
