@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_reconcile_config.h"
@@ -40,6 +41,7 @@
 #include "gsb_automem.h"
 #include "gsb_data_account.h"
 #include "gsb_data_reconcile.h"
+#include "gsb_file.h"
 #include "gsb_real.h"
 #include "gsb_transactions_list.h"
 #include "navigation.h"
@@ -47,6 +49,7 @@
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_dates.h"
+#include "utils_real.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -56,14 +59,13 @@ static gboolean gsb_reconcile_config_end_date_changed ( GtkWidget *checkbutton,
                         GdkEventButton *event,
                         gpointer data );
 static gboolean gsb_reconcile_config_find_alone_transactions ( void );
-static gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection, 
+static gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection,
 				       GtkWidget *table );
-static gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,    
+static gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,
 					    GtkWidget *tree_view );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 /* the tree view used to modify the reconciles */
@@ -95,7 +97,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
     GtkWidget *label;
     gint i;
     gfloat alignment[] = {
-	COLUMN_LEFT, COLUMN_CENTER, COLUMN_CENTER, 
+	COLUMN_LEFT, COLUMN_CENTER, COLUMN_CENTER,
 	COLUMN_RIGHT, COLUMN_RIGHT
     };
     gchar *titles[] = {
@@ -138,14 +140,14 @@ GtkWidget *gsb_reconcile_config_create ( void )
 
     /* create the model */
     reconcile_model = gtk_tree_store_new ( NUM_RECONCILIATION_COLUMNS,
-					   G_TYPE_STRING,    /* Name account or reconcile */
+					   G_TYPE_STRING,    /* Name account or reconciliation */
 					   G_TYPE_STRING,    /* init date  */
 					   G_TYPE_STRING,    /* final date  */
 					   G_TYPE_STRING,    /* init balance  */
 					   G_TYPE_STRING,    /* final balance  */
 					   G_TYPE_INT,       /* Account number */
 					   G_TYPE_INT,       /* Bold or regular text */
-					   G_TYPE_INT );     /* reconcile number */
+					   G_TYPE_INT );     /* reconciliation number */
     reconcile_treeview = gtk_tree_view_new_with_model ( GTK_TREE_MODEL (reconcile_model) );
     g_object_unref (G_OBJECT(reconcile_model));
     gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (reconcile_treeview), TRUE);
@@ -155,7 +157,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
 			reconcile_treeview );
 
     reconcile_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (reconcile_treeview));
-    g_signal_connect (reconcile_selection, "changed", 
+    g_signal_connect (reconcile_selection, "changed",
 		      G_CALLBACK (gsb_reconcile_config_select), table_selection);
 
     /* Name */
@@ -194,7 +196,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
     gtk_box_pack_start ( GTK_BOX (hbox), table_selection, FALSE, FALSE, 0 );
 
     /* set the name */
-	label = gtk_label_new ( _("Name: ") );
+	label = gtk_label_new ( _("Reconciliation reference: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 0, 1,
@@ -277,8 +279,8 @@ GtkWidget *gsb_reconcile_config_create ( void )
 	gtk_widget_set_sensitive ( table_selection, FALSE );
 
     /* set the button to find non-associated transactions */
-	button = gtk_button_new_with_label ( 
-                        _("Find all marked transactions not associated with a reconcile number"));
+	button = gtk_button_new_with_label (
+                        _("Find all marked transactions not associated with a reconciliation"));
 	gtk_button_set_relief ( GTK_BUTTON (button),
 			GTK_RELIEF_NONE );
 	g_signal_connect ( G_OBJECT (button), "clicked",
@@ -301,7 +303,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
  * fill the reconcile list,
  * sort each reconcile in its account
  *
- * \param 
+ * \param
  *
  * \return
  * */
@@ -354,8 +356,8 @@ void gsb_reconcile_config_fill ( void )
 
 		init_date = gsb_format_gdate (gsb_data_reconcile_get_init_date (reconcile_number));
 		final_date = gsb_format_gdate (gsb_data_reconcile_get_final_date (reconcile_number));
-		init_balance = gsb_real_get_string (gsb_data_reconcile_get_init_balance (reconcile_number));
-		final_balance = gsb_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
+		init_balance = utils_real_get_string (gsb_data_reconcile_get_init_balance (reconcile_number));
+		final_balance = utils_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
 
 		gtk_tree_store_append ( GTK_TREE_STORE (model),
 					&reconcile_iter,
@@ -394,7 +396,7 @@ void gsb_reconcile_config_fill ( void )
  *
  * \return FALSE
  */
-gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection, 
+gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection,
 				       GtkWidget *table )
 {
     GtkTreeIter iter;
@@ -406,7 +408,7 @@ gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection,
     {
 	gint reconcile_number;
 
-	gtk_tree_model_get (model, &iter, 
+	gtk_tree_model_get (model, &iter,
 			    RECONCILIATION_RECONCILE_COLUMN, &reconcile_number,
 			    -1 );
 
@@ -432,7 +434,7 @@ gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection,
 	    /* we make the table sensitive */
 	    gtk_widget_set_sensitive ( table, TRUE );
 	}
-	else 
+	else
 	    gtk_widget_set_sensitive ( table, FALSE );
     }
     else
@@ -448,7 +450,7 @@ gboolean gsb_reconcile_config_select ( GtkTreeSelection *selection,
  *
  * \return FALSE
  * */
-gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,    
+gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,
 					    GtkWidget *tree_view )
 {
     GtkTreeIter iter;
@@ -463,7 +465,7 @@ gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,
     {
 	gint reconcile_number;
 
-	gtk_tree_model_get (model, &iter, 
+	gtk_tree_model_get (model, &iter,
 			    RECONCILIATION_RECONCILE_COLUMN, &reconcile_number,
 			    -1 );
 
@@ -475,8 +477,8 @@ gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,
 
 		init_date = gsb_format_gdate (gsb_data_reconcile_get_init_date (reconcile_number));
 		final_date = gsb_format_gdate (gsb_data_reconcile_get_final_date (reconcile_number));
-		init_balance = gsb_real_get_string (gsb_data_reconcile_get_init_balance (reconcile_number));
-		final_balance = gsb_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
+		init_balance = utils_real_get_string (gsb_data_reconcile_get_init_balance (reconcile_number));
+		final_balance = utils_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
 
 		gtk_tree_store_set ( GTK_TREE_STORE (model),
 				     &iter,
@@ -498,8 +500,8 @@ gboolean gsb_reconcile_config_update_line ( GtkWidget *entry,
 }
 
 /**
- * callback called when the user click on 'Delete the reconcile'
- * this will delete the selected reconcile and will mark all the concerned
+ * callback called when the user click on 'Delete the reconciliation'
+ * this will delete the selected reconciliation and will mark all the concerned
  * transactions as P
  *
  * \param button
@@ -523,7 +525,7 @@ gboolean gsb_reconcile_config_delete ( GtkWidget *button,
 	gint reconcile_number;
 	gint account_number;
 
-	gtk_tree_model_get (model, &iter, 
+	gtk_tree_model_get (model, &iter,
 			    RECONCILIATION_RECONCILE_COLUMN, &reconcile_number,
 			    -1 );
 
@@ -556,8 +558,7 @@ gboolean gsb_reconcile_config_delete ( GtkWidget *button,
 		/* update the last statement for that account */
 		gsb_navigation_update_statement_label (account_number);
 	    }
-	    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+            gsb_file_set_modified ( TRUE );
 	}
     }
 
@@ -589,8 +590,7 @@ gboolean gsb_reconcile_config_end_date_changed ( GtkWidget *checkbutton,
 {
     etat.reconcile_end_date = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
