@@ -22,7 +22,7 @@
 
 /**
  * \file gsb_scheduler.c
- * contains several functions to work with the schedulers transactions 
+ * contains several functions to work with the schedulers transactions
  */
 
 
@@ -34,20 +34,21 @@
 
 /*START_INCLUDE*/
 #include "gsb_scheduler.h"
-#include "utils_dates.h"
+#include "accueil.h"
 #include "gsb_currency.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_payment.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
 #include "gsb_form_transaction.h"
-#include "accueil.h"
+#include "gsb_file.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_transactions_list.h"
 #include "main.h"
-#include "traitement_variables.h"
-#include "erreur.h"
 #include "structures.h"
+#include "traitement_variables.h"
+#include "utils_dates.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -58,8 +59,6 @@ static gboolean gsb_scheduler_get_category_for_transaction_from_transaction ( gi
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gint mise_a_jour_liste_echeances_auto_accueil;
-extern gint mise_a_jour_liste_echeances_manuelles_accueil;
 extern GSList *scheduled_transactions_taken;
 extern GSList *scheduled_transactions_to_take;
 /*END_EXTERN*/
@@ -67,17 +66,14 @@ extern GSList *scheduled_transactions_to_take;
 /** number of days before the scheduled to execute it */
 gint nb_days_before_scheduled;
 
-/** warn/execute scheduled at expiration (FALSE) or of the month (TRUE) */
-gboolean execute_scheduled_of_month;
-
 /**
  * set the next date in the scheduled transaction
  * if it's above the limit date, that transaction is deleted
  * if it's a split, the children are updated too
  * if the scheduled transaction is finished, it's removed from the list and from the scheduled transactions
- * 
+ *
  * \param scheduled_number the scheduled transaction we want to increase
- * 
+ *
  * \return FALSE if the scheduled transaction is finished, TRUE else
  * */
 gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
@@ -201,7 +197,7 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
 	    switch (gsb_data_scheduled_get_user_interval (scheduled_number))
 	    {
 		case PERIODICITY_DAYS:
-		    g_date_add_days ( return_date, 
+		    g_date_add_days ( return_date,
 				      gsb_data_scheduled_get_user_entry (scheduled_number));
 		    /* FIXME : there were a bug in gtk and we had to add 0 month to have the good date,
 		     * it seems fixed but we should wait the stable debian is upgraded to
@@ -210,7 +206,7 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
 		    break;
 
 		case PERIODICITY_WEEKS:
-		    g_date_add_days ( return_date, 
+		    g_date_add_days ( return_date,
 				      gsb_data_scheduled_get_user_entry (scheduled_number) * 7 );
 		    g_date_add_months ( return_date, 0 );
 		    break;
@@ -237,7 +233,7 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
 	g_date_free (return_date);
 	return_date = NULL;
     }
-    
+
     return ( return_date );
 }
 
@@ -247,7 +243,7 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
  * create a new transaction and fill it directly from a scheduled transaction
  * (don't pass throw the form)
  * if it's a child of split, append it automatickly to the mother
- * 
+ *
  * \param scheduled_number the transaction we use to fill the new transaction
  * \param transaction_mother the number of the mother if it's a split child, 0 else
  *
@@ -320,13 +316,12 @@ gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint schedule
 						    gsb_data_scheduled_get_sub_budgetary_number (scheduled_number));
 
     /* if the financial year is automatic, we set it here */
-
-    if ( gsb_data_scheduled_get_financial_year_number (scheduled_number) == -2 )
-	gsb_data_transaction_set_financial_year_number ( transaction_number,
-							 gsb_data_fyear_get_from_date ( gsb_data_transaction_get_date (transaction_number)));
+    if ( gsb_data_scheduled_get_financial_year_number ( scheduled_number ) == 0 )
+        gsb_data_transaction_set_financial_year_number ( transaction_number,
+    				    gsb_data_fyear_get_from_date ( gsb_data_transaction_get_date ( transaction_number ) ) );
     else
-	gsb_data_transaction_set_financial_year_number ( transaction_number,
-							 gsb_data_scheduled_get_financial_year_number (scheduled_number));
+        gsb_data_transaction_set_financial_year_number ( transaction_number,
+    				    gsb_data_scheduled_get_financial_year_number ( scheduled_number ) );
 
     /* get the category */
 
@@ -348,9 +343,9 @@ gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint schedule
  * used to catch a transaction from a scheduled transaction
  * take the category, check if it's a transfer or a split and
  * do the necessary (create contra-transaction)
- * don't execute the children if it's a split, need to call 
+ * don't execute the children if it's a split, need to call
  * gsb_scheduler_execute_children_of_scheduled_transaction later
- * 
+ *
  *
  * \param transaction_number
  * \param scheduled_number
@@ -412,7 +407,7 @@ gboolean gsb_scheduler_get_category_for_transaction_from_transaction ( gint tran
  * \param transaction_number the number of the transaction created from that scheduled (so, the future mother of the children)
  *
  * \return FALSE
- * 
+ *
  * */
 gboolean gsb_scheduler_execute_children_of_scheduled_transaction ( gint scheduled_number,
 								   gint transaction_number )
@@ -443,9 +438,9 @@ gboolean gsb_scheduler_execute_children_of_scheduled_transaction ( gint schedule
 /**
  * check the scheduled transactions if the are in time limit
  * and record the automatic transactions
- * 
+ *
  * \param
- * 
+ *
  * \return
  * */
 void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
@@ -472,10 +467,10 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 		      nb_days_before_scheduled );
     /* now date is in nb_days_before_scheduled, if we want the transactions of the month,
      * we change date to the end of its month */
-    if (execute_scheduled_of_month)
+    if ( conf.execute_scheduled_of_month)
     {
 	gint last_day;
-	
+
 	last_day = g_date_get_days_in_month ( g_date_get_month (date),
 					      g_date_get_year (date));
 	g_date_set_day (date, last_day);
@@ -519,7 +514,7 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 		/* set the scheduled transaction to the next date,
 		 * if it's not finished, we check them again if it need to be
 		 * executed more than one time (the easiest way is to check
-		 * all again, i don't think it will have thousand of scheduled transactions, 
+		 * all again, i don't think it will have thousand of scheduled transactions,
 		 * so no much waste of time...) */
 		if (gsb_scheduler_increase_scheduled (scheduled_number))
 		{
@@ -544,13 +539,12 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 
     if ( automatic_transactions_taken )
     {
-	mise_a_jour_liste_echeances_auto_accueil = 1;
-	if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+        run.mise_a_jour_liste_echeances_auto_accueil = TRUE;
+        gsb_file_set_modified ( TRUE );
     }
 
     if ( scheduled_transactions_to_take )
-	mise_a_jour_liste_echeances_manuelles_accueil = 1;
+	run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
 
     g_date_free ( date );
 }
