@@ -1,6 +1,8 @@
 #ifndef GSB_SCHEDULER_LIST_H
 #define GSB_SCHEDULER_LIST_H
 
+#include <gtk/gtk.h>
+
 enum
 {
     COL_NB_DATE = 0,
@@ -11,12 +13,13 @@ enum
     COL_NB_NOTES,
     COL_NB_AMOUNT,
 
-    SCHEDULER_COL_NB_BACKGROUND,		/*< color of the background */
+    SCHEDULER_COL_NB_BACKGROUND,		    /*< color of the background */
     SCHEDULER_COL_NB_SAVE_BACKGROUND,		/*< when selection, save of the normal color of background */
-    SCHEDULER_COL_NB_AMOUNT_COLOR, 		/*< color of the amount */
+    SCHEDULER_COL_NB_AMOUNT_COLOR, 		    /*< color of the amount */
     SCHEDULER_COL_NB_TRANSACTION_NUMBER,
-    SCHEDULER_COL_NB_FONT,			/*< PangoFontDescription if used */
+    SCHEDULER_COL_NB_FONT,			        /*< PangoFontDescription if used */
     SCHEDULER_COL_NB_VIRTUAL_TRANSACTION,	/*< to 1 if it's a calculated scheduled transaction (for longer view), so, cannot edit */
+    SCHEDULER_COL_NB_TEXT_COLOR,            /*< color of the text */
 
     SCHEDULER_COL_NB_TOTAL,
 };
@@ -55,10 +58,11 @@ enum periodicity_units {
 
 
 /* START_DECLARATION */
+void gsb_gui_update_scheduler_toolbar ( void );
 gboolean gsb_scheduler_list_append_new_scheduled ( gint scheduled_number,
                         GDate *end_date );
-gboolean gsb_scheduler_list_change_scheduler_view ( enum scheduler_periodicity periodicity,
-                        gpointer item );
+gboolean gsb_scheduler_list_clone_selected_scheduled ( GtkWidget *menu_item,
+                        gint *scheduled_number );
 GtkWidget *gsb_scheduler_list_create_list ( void );
 gboolean gsb_scheduler_list_delete_scheduled_transaction ( gint scheduled_number,
                         gboolean show_warning );
@@ -70,6 +74,7 @@ gboolean gsb_scheduler_list_fill_list ( GtkWidget *tree_view );
 gint gsb_scheduler_list_get_current_scheduled_number ( void );
 GDate *gsb_scheduler_list_get_end_date_scheduled_showed ( void );
 gint gsb_scheduler_list_get_last_scheduled_number ( void );
+GtkWidget *gsb_scheduler_list_get_toolbar ( void );
 GtkWidget *gsb_scheduler_list_get_tree_view ( void );
 void gsb_scheduler_list_init_variables ( void );
 gboolean gsb_scheduler_list_redraw ( void );
