@@ -34,6 +34,7 @@
 /*START_INCLUDE*/
 #include "gsb_status.h"
 #include "main.h"
+#include "structures.h"
 #include "utils.h"
 /*END_INCLUDE*/
 
@@ -41,7 +42,6 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 /** Status bar displayed in the bottom of Grisbi window.  */
@@ -100,10 +100,8 @@ void gsb_status_message ( gchar * message )
     gsb_status_clear ();
     message_id = gtk_statusbar_push ( GTK_STATUSBAR (main_statusbar), context_id, message );
 
-    /** Call gtk_main_iteration() to ensure status message is
-     * displayed.  This is done because we need to display it
-     * immediately without waiting to return to gtk_main().  */
-    while ( gtk_events_pending () ) gtk_main_iteration ( );
+    /* force status message to be displayed NOW */
+    update_gui ( );
 }
 
 
@@ -122,17 +120,15 @@ void gsb_status_clear (  )
 	message_id = -1;
     }
 
-    /** Call gtk_main_iteration() to ensure status message is
-     * displayed.  This is done because we need to display it
-     * immediately without waiting to return to gtk_main().  */
-    while ( gtk_events_pending () ) gtk_main_iteration ( );
+    /* force status message to be displayed NOW */
+    update_gui ( );
 }
 
 
 /**
  * Change current cursor to a animated watch (if animation supported
  * by environment).
- * 
+ *
  * \param force_update		Call a gtk iteration to ensure cursor
  *				is updated.  May cause trouble if
  *				called from some signal handlers.
@@ -141,50 +137,49 @@ void gsb_status_wait ( gboolean force_update )
 {
     GdkWindow * current_window;
 
-    gdk_window_set_cursor ( window -> window, 
-			    gdk_cursor_new_for_display ( gdk_display_get_default ( ), 
+    gdk_window_set_cursor ( run.window -> window,
+			    gdk_cursor_new_for_display ( gdk_display_get_default ( ),
 							 GDK_WATCH ) );
 
     current_window = gdk_display_get_window_at_pointer ( gdk_display_get_default ( ),
 							 NULL, NULL );
 
-    if ( current_window && GDK_IS_WINDOW ( current_window ) &&
-	 current_window != window -> window )
+    if ( current_window && GDK_IS_WINDOW ( current_window )
+     &&
+	 current_window != run.window -> window )
     {
 	GdkWindow * parent = gdk_window_get_toplevel ( current_window );
-	
+
 	if ( parent && parent != current_window )
 	{
 	    current_window = parent;
-	}	    
+	}
 
-	gdk_window_set_cursor ( current_window, 
-				gdk_cursor_new_for_display ( gdk_display_get_default ( ), 
+	gdk_window_set_cursor ( current_window,
+				gdk_cursor_new_for_display ( gdk_display_get_default ( ),
 							     GDK_WATCH ) );
 
 	tracked_window = current_window;
     }
 
     if ( force_update )
-    {
-	update_ecran ();
-    }
+	update_gui ( );
 }
 
 
 /**
  * Change current cursor to default cursor.
- * 
+ *
  * \param force_update		Call a gtk iteration to ensure cursor
  *				is updated.  May cause trouble if
  *				called from some signal handlers.
  */
 void gsb_status_stop_wait ( gboolean force_update )
 {
-    if ( ! window )
+    if ( ! run.window )
 	return;
 
-    gdk_window_set_cursor ( window -> window, NULL );
+    gdk_window_set_cursor ( run.window -> window, NULL );
 
     if ( tracked_window && gdk_window_is_visible ( tracked_window ) )
     {
@@ -193,12 +188,30 @@ void gsb_status_stop_wait ( gboolean force_update )
     }
 
     if ( force_update )
-    {
-	update_ecran ();
-    }
+	update_gui ( );
 }
 
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
+GtkWidget *gsb_status_get_status_bar ( void )
+{
+    return main_statusbar;
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
