@@ -1,7 +1,7 @@
 #ifndef _OPERATIONS_LISTE_H
 #define _OPERATIONS_LISTE_H (1)
 
-
+#include <gtk/gtk.h>
 
 /* the element number for each showable in the list */
 enum
@@ -38,6 +38,7 @@ enum
 
 
 /* START_DECLARATION */
+gboolean change_aspect_liste ( gint demande );
 gboolean clone_selected_transaction ( GtkWidget *menu_item,
                         gpointer null );
 GtkWidget *creation_fenetre_operations ( void );
@@ -45,9 +46,15 @@ gint find_element_col ( gint element_number );
 gint find_element_col_for_archive ( void );
 gint find_element_col_split ( gint element_number );
 gint find_element_line ( gint element_number );
+void gsb_gui_update_transaction_toolbar ( void );
 gchar *gsb_transactions_get_category_real_name ( gint transaction_number );
+gboolean gsb_transactions_list_add_transactions_from_archive ( gint archive_number,
+                        gint account_number,
+                        gboolean show_warning );
 gboolean gsb_transactions_list_append_new_transaction ( gint transaction_number,
                         gboolean update_tree_view );
+gboolean gsb_transactions_list_clone_template ( GtkWidget *menu_item,
+                        gpointer null );
 gboolean gsb_transactions_list_delete_transaction ( gint transaction_number,
                         gint show_warning );
 gboolean gsb_transactions_list_delete_transaction_from_tree_view ( gint transaction_number );
@@ -56,6 +63,8 @@ gboolean gsb_transactions_list_edit_transaction ( gint transaction_number );
 gboolean gsb_transactions_list_edit_transaction_by_pointer ( gint *transaction_number );
 gboolean gsb_transactions_list_fill_archive_store ( void );
 gfloat gsb_transactions_list_get_row_align ( void );
+GtkWidget *gsb_transactions_list_get_toolbar ( void );
+gchar *gsb_transaction_list_get_titre_colonne_liste_ope ( gint element );
 GtkWidget *gsb_transactions_list_get_tree_view (void);
 gchar *gsb_transactions_list_grep_cell_content ( gint transaction_number,
                         gint cell_content_number );
@@ -65,6 +74,7 @@ gboolean gsb_transactions_list_restore_archive ( gint archive_number,
 void gsb_transactions_list_selection_changed ( gint new_selected_transaction );
 gboolean gsb_transactions_list_set_largeur_col ( void );
 gboolean gsb_transactions_list_set_row_align ( gfloat row_align );
+void gsb_transaction_list_set_visible_archived_button ( gboolean visible );
 void gsb_transactions_list_set_visible_rows_number ( gint rows_number );
 void gsb_transactions_list_show_archives_lines ( gboolean show_l );
 void gsb_transactions_list_splitted_to_scheduled ( gint transaction_number,
@@ -84,5 +94,7 @@ void remove_transaction ();
 void schedule_selected_transaction ();
 gsb_real solde_debut_affichage ( gint account_number,
                         gint floating_point);
+void update_titres_tree_view ( void );
+
 /* END_DECLARATION */
 #endif
