@@ -32,7 +32,7 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_transactions_list_sort.h"
@@ -67,6 +67,12 @@ static gint gsb_transactions_list_sort_by_credit ( gint transaction_number_1,
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_date ( gint transaction_number_1,
                         gint transaction_number_2 );
+static gint gsb_transactions_list_sort_by_date_and_amount ( gint transaction_number_1,
+                        gint transaction_number_2 );
+static gint gsb_transactions_list_sort_by_date_and_no ( gint transaction_number_1,
+                        gint transaction_number_2 );
+static gint gsb_transactions_list_sort_by_date_and_party ( gint transaction_number_1,
+                        gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_debit ( gint transaction_number_1,
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_financial_year ( gint transaction_number_1,
@@ -84,18 +90,12 @@ static gint gsb_transactions_list_sort_by_party ( gint transaction_number_1,
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_reconcile_nb ( gint transaction_number_1,
                         gint transaction_number_2 );
-static gint gsb_transactions_list_sort_by_transaction_date_and_amount ( gint transaction_number_1,
-                        gint transaction_number_2 );
-static gint gsb_transactions_list_sort_by_transaction_date_and_no ( gint transaction_number_1,
-                        gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_type ( gint transaction_number_1,
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_voucher ( gint transaction_number_1,
                         gint transaction_number_2 );
-static gint gsb_transactions_list_sort_initial_by_primary_key_and_secondary_key ( gint transaction_number_1,
-                        gint transaction_number_2 );
 static gint gsb_transactions_list_sort_initial_by_secondary_key ( gint transaction_number_1,
                         gint transaction_number_2 );
 /*END_STATIC*/
@@ -179,7 +179,7 @@ gint gsb_transactions_list_sort (CustomRecord **a,
  * \param model
  * \param iter_1
  * \param iter_2
- * 
+ *
  * \return -1 if iter_1 is above iter_2
  * */
 gint gsb_transactions_list_sort_check_archive (  CustomRecord *record_1,
@@ -229,11 +229,11 @@ gint gsb_transactions_list_sort_check_archive (  CustomRecord *record_1,
  * check for the part wich cannot change : the white line must always be at
  * the end of the list
  * and into a transaction, the lines are not sorted in ascending or descending method
- * 
+ *
  * \param model
  * \param iter_1
  * \param iter_2
- * 
+ *
  * \return 0 if that test cannot say the return_value between the 2 lines,
  * or the return_value if it's possible here
  * */
@@ -261,15 +261,14 @@ gint gsb_transactions_list_sort_general_test ( CustomRecord *record_1,
 }
 
 
-
 /**
  * find the right function to sort the list and sort the 2 iters given
- * 
+ *
  * \param model
  * \param iter_1
  * \param iter_2
  * \param no_sort permit to find the right function
- * 
+ *
  * \return -1 if iter_1 is above iter_2
  * */
 gint gsb_transactions_list_sort_by_no_sort (  gint transaction_number_1,
@@ -368,12 +367,12 @@ gint gsb_transactions_list_sort_by_no_sort (  gint transaction_number_1,
  * used to compare the 2 dates first, and if they are the same
  * the 2 no of transactions to find the good return for sort
  * called at the end of each sort test, if they are equal
- * 
+ *
  * \param none but the local variables transaction_number_1 and transaction_number_2 MUST be set
- * 
+ *
  * \return -1 if transaction_number_1 is above transaction_number_2
  * */
-gint gsb_transactions_list_sort_by_transaction_date_and_no ( gint transaction_number_1,
+gint gsb_transactions_list_sort_by_date_and_no ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     gint return_value;
@@ -404,12 +403,12 @@ gint gsb_transactions_list_sort_by_transaction_date_and_no ( gint transaction_nu
 
 /**
  * compared by date and by amount
- * 
+ *
  * \param none but the local variables transaction_number_1 and transaction_number_2 MUST be set
- * 
+ *
  * \return -1 if amount_2 is above amount_number_1
  * */
-gint gsb_transactions_list_sort_by_transaction_date_and_amount ( gint transaction_number_1,
+gint gsb_transactions_list_sort_by_date_and_amount ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     gint return_value;
@@ -449,7 +448,7 @@ gint gsb_transactions_list_sort_by_transaction_date_and_amount ( gint transactio
  *
  * \return -1 if amount_2 is above amount_number_1
  * */
-gint gsb_transactions_list_sort_by_transaction_date_and_party ( gint transaction_number_1,
+gint gsb_transactions_list_sort_by_date_and_party ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     gint return_value;
@@ -512,42 +511,41 @@ gint gsb_transactions_list_sort_by_date ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     if ( conf.transactions_list_secondary_sorting == 1 )
-        return gsb_transactions_list_sort_by_transaction_date_and_amount (
+        return gsb_transactions_list_sort_by_date_and_amount (
                         transaction_number_1, transaction_number_2 );
     else if ( conf.transactions_list_secondary_sorting == 2 )
-        return gsb_transactions_list_sort_by_transaction_date_and_party (
+        return gsb_transactions_list_sort_by_date_and_party (
                         transaction_number_1, transaction_number_2 );
     else
-        return gsb_transactions_list_sort_by_transaction_date_and_no (
-                        transaction_number_1, transaction_number_2 );
+        return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 /**
  * used to compare 2 iters and sort the by value date or date if not exist
  * always put the white line below
- * 
+ *
  * \param model the GtkTreeModel
  * \param iter_1
  * \param iter_2
- * 
+ *
  * \return -1 if iter_1 is above iter_2
  * */
 gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
     gint return_value;
-    const GDate *value_date_1;
-    const GDate *value_date_2;
+    const GDate *value_date_1 = NULL;
+    const GDate *value_date_2 = NULL;
 
-    /* need to work a little more here because value date is not obligatory filled,
+   /* need to work a little more here because value date is not obligatory filled,
      * if we compare 2 transactions and 1 has no value date, set the value date before */
     value_date_1 = gsb_data_transaction_get_value_date ( transaction_number_1 );
-    if ( ! value_date_1 && !conf.transactions_list_primary_sorting )
+    if ( !value_date_1 && !conf.transactions_list_primary_sorting )
         value_date_1 = gsb_data_transaction_get_date ( transaction_number_1 );
 
     value_date_2 = gsb_data_transaction_get_value_date ( transaction_number_2 );
-    if ( ! value_date_2 && !conf.transactions_list_primary_sorting )
+    if ( !value_date_2 && !conf.transactions_list_primary_sorting )
         value_date_2 = gsb_data_transaction_get_date ( transaction_number_2 );
 
     if ( value_date_1 )
@@ -562,8 +560,7 @@ gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
         if (value_date_2)
             return_value = 1;
         else
-            return gsb_transactions_list_sort_by_date (
-                        transaction_number_1, transaction_number_2 );
+            return gsb_transactions_list_sort_by_date ( transaction_number_1, transaction_number_2 );
     }
 
     if ( return_value )
@@ -574,7 +571,7 @@ gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
 }
 
 
-/** used to compare 2 iters and sort the by party first, and 
+/** used to compare 2 iters and sort the by party first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -593,8 +590,7 @@ gint gsb_transactions_list_sort_by_party ( gint transaction_number_1,
     party_number_2 = gsb_data_transaction_get_party_number ( transaction_number_2 );
 
     if (  party_number_1 == party_number_2 )
-	    return_value = gsb_transactions_list_sort_by_transaction_date_and_no (
-                        transaction_number_1, transaction_number_2 );
+	    return_value = gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
     else
     {
         const gchar *temp_1;
@@ -617,12 +613,11 @@ gint gsb_transactions_list_sort_by_party ( gint transaction_number_1,
     if ( return_value )
         return return_value;
     else
-        return gsb_transactions_list_sort_by_transaction_date_and_no (
-                        transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
-/** used to compare 2 iters and sort the by budgetary first, and 
+/** used to compare 2 iters and sort the by budgetary first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -647,8 +642,7 @@ gint gsb_transactions_list_sort_by_budget ( gint transaction_number_1,
     if ( budgetary_number_1 == budgetary_number_2
 	 &&
 	 sub_budgetary_number_1 == sub_budgetary_number_2 )
-	    return_value = gsb_transactions_list_sort_by_transaction_date_and_no(
-                        transaction_number_1, transaction_number_2 );
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
     else
     {
         const gchar *temp_1;
@@ -675,20 +669,19 @@ gint gsb_transactions_list_sort_by_budget ( gint transaction_number_1,
     if ( return_value )
 	    return return_value;
     else
-	    return gsb_transactions_list_sort_by_transaction_date_and_no (
-                        transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 /**
- * used to compare 2 iters and sort the by credit amount first, and 
+ * used to compare 2 iters and sort the by credit amount first, and
  * by date and no transaction after
  * always put the white line below
- * 
+ *
  * \param model the GtkTreeModel
  * \param iter_1
  * \param iter_2
- * 
+ *
  * \return -1 if iter_1 is above iter_2
  * */
 gint gsb_transactions_list_sort_by_credit ( gint transaction_number_1,
@@ -701,14 +694,14 @@ gint gsb_transactions_list_sort_by_credit ( gint transaction_number_1,
 				  gsb_data_transaction_get_adjusted_amount ( transaction_number_2, -1));
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 
-/** used to compare 2 iters and sort the by debit amount first, and 
+/** used to compare 2 iters and sort the by debit amount first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -726,14 +719,14 @@ gint gsb_transactions_list_sort_by_debit ( gint transaction_number_1,
 				  gsb_data_transaction_get_adjusted_amount ( transaction_number_1, -1));
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 
-/** used to compare 2 iters and sort the by amount first, and 
+/** used to compare 2 iters and sort the by amount first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -751,14 +744,14 @@ gint gsb_transactions_list_sort_by_amount ( gint transaction_number_1,
 				  gsb_data_transaction_get_adjusted_amount ( transaction_number_1, -1));
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no (transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no (transaction_number_1, transaction_number_2);
 }
 
 
 
-/** used to compare 2 iters and sort the by type first, and 
+/** used to compare 2 iters and sort the by type first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -781,7 +774,7 @@ gint gsb_transactions_list_sort_by_type ( gint transaction_number_1,
 							  -1 ));
 
 	if ( !return_value )
-	    return_value = gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
     }
     else
     {
@@ -811,14 +804,14 @@ gint gsb_transactions_list_sort_by_type ( gint transaction_number_1,
 							  -1 ));
 
 	if ( !return_value )
-	    return_value = gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+		return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
     }
     return return_value;
 }
 
 
 
-/** used to compare 2 iters and sort the by reconcile number first, and 
+/** used to compare 2 iters and sort the by reconcile number first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -831,8 +824,8 @@ gint gsb_transactions_list_sort_by_reconcile_nb ( gint transaction_number_1,
 {
     gint return_value;
 
-    if ( gsb_data_transaction_get_reconcile_number ( transaction_number_1)== gsb_data_transaction_get_reconcile_number ( transaction_number_2))
-	return_value = gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+    if ( gsb_data_transaction_get_reconcile_number ( transaction_number_1) == gsb_data_transaction_get_reconcile_number ( transaction_number_2))
+		return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
     else
     {
 	const gchar *temp_1;
@@ -850,9 +843,9 @@ gint gsb_transactions_list_sort_by_reconcile_nb ( gint transaction_number_1,
     }
 
     if ( return_value )
-	return return_value;
+    	return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+		return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
@@ -871,7 +864,7 @@ gint gsb_transactions_list_sort_by_financial_year ( gint transaction_number_1,
     gint return_value;
 
     if ( gsb_data_transaction_get_financial_year_number ( transaction_number_1)== gsb_data_transaction_get_financial_year_number ( transaction_number_2))
-	return_value = gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+		return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
     else
     {
 	GDate *date_1;
@@ -898,15 +891,15 @@ gint gsb_transactions_list_sort_by_financial_year ( gint transaction_number_1,
     }
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+		return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 
 }
 
 
 
-/** used to compare 2 iters and sort the by category first, and 
+/** used to compare 2 iters and sort the by category first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -942,13 +935,13 @@ gint gsb_transactions_list_sort_by_category ( gint transaction_number_1,
     g_free (temp_2);
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
-/** used to compare 2 iters and sort the by mark first, and 
+/** used to compare 2 iters and sort the by mark first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -970,13 +963,12 @@ gint gsb_transactions_list_sort_by_mark ( gint transaction_number_1,
     if ( return_value )
 	    return return_value;
     else
-	return - gsb_transactions_list_sort_by_transaction_date_and_no (
-                        transaction_number_1, transaction_number_2 );
+		return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 
-/** used to compare 2 iters and sort the by voucher first, and 
+/** used to compare 2 iters and sort the by voucher first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -1002,13 +994,13 @@ gint gsb_transactions_list_sort_by_voucher ( gint transaction_number_1,
 						      -1 ));
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
-/** used to compare 2 iters and sort the by notes first, and 
+/** used to compare 2 iters and sort the by notes first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -1034,14 +1026,14 @@ gint gsb_transactions_list_sort_by_notes ( gint transaction_number_1,
 						      -1 ));
 
     if ( return_value )
-	return return_value;
+	    return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	    return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 
-/** used to compare 2 iters and sort the by bank first, and 
+/** used to compare 2 iters and sort the by bank first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -1069,12 +1061,12 @@ gint gsb_transactions_list_sort_by_bank ( gint transaction_number_1,
     if ( return_value )
 	return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
 
-/** used to compare 2 iters and sort the by cheque or no of transfer first, and 
+/** used to compare 2 iters and sort the by cheque or no of transfer first, and
  * by date and no transaction after
  * always put the white line below
  * \param model the GtkTreeModel
@@ -1102,7 +1094,7 @@ gint gsb_transactions_list_sort_by_chq ( gint transaction_number_1,
     if ( return_value )
 	return return_value;
     else
-	return gsb_transactions_list_sort_by_transaction_date_and_no(transaction_number_1, transaction_number_2);
+	return gsb_transactions_list_sort_by_date_and_no ( transaction_number_1, transaction_number_2 );
 }
 
 
@@ -1130,7 +1122,7 @@ gint gsb_transactions_list_sort_initial (CustomRecord **a,
         /* normally cannot happen, except come here at the opening
          * of grisbi, and must return 0 if we don't want a crash */
         return 0;
-    }   
+    }
 
     /* i don't know why but sometimes there is a comparison between the 2 same rows... */
     if (*a == *b)
@@ -1162,63 +1154,13 @@ gint gsb_transactions_list_sort_initial (CustomRecord **a,
         transaction_number_1 = gsb_data_transaction_get_transaction_number (record_1 -> transaction_pointer);
         transaction_number_2 = gsb_data_transaction_get_transaction_number (record_2 -> transaction_pointer);
 
-        return_value = gsb_transactions_list_sort_initial_by_primary_key_and_secondary_key (
-                        transaction_number_1, transaction_number_2 );
+        return_value = gsb_transactions_list_sort_by_value_date ( transaction_number_1, transaction_number_2 );
     }
 
     return return_value;
 }
 
 
-/**
- * used to compare 2 iters and sort the by primary key
- *
- * always put the white line below
- * \param model the GtkTreeModel
- * \param iter_1
- * \param iter_2
- * \return -1 if iter_1 is above iter_2
- * */
-gint gsb_transactions_list_sort_initial_by_primary_key_and_secondary_key ( gint transaction_number_1,
-                        gint transaction_number_2 )
-{
-    gint return_value;
-    const GDate *value_date_1;
-    const GDate *value_date_2;
-
-    /* need to work a little more here because value date is not obligatory filled,
-     * if we compare 2 transactions and 1 has no value date, set the value date before */
-    value_date_1 = gsb_data_transaction_get_value_date ( transaction_number_1 );
-    if ( !value_date_1 )
-        value_date_1 = gsb_data_transaction_get_date ( transaction_number_1 );
-
-    value_date_2 = gsb_data_transaction_get_value_date ( transaction_number_2 );
-    if ( !value_date_2 )
-        value_date_2 = gsb_data_transaction_get_date ( transaction_number_2 );
-
-    if ( value_date_1 )
-    {
-        if (value_date_2)
-            return_value = g_date_compare ( value_date_1, value_date_2);
-        else
-            return_value = -1;
-    }
-    else
-    {
-        if ( value_date_2 )
-            return_value = 1;
-        else
-            return_value = 0;
-    }
-
-    if ( return_value )
-        return return_value;
-    else
-        return gsb_transactions_list_sort_initial_by_secondary_key (
-                        transaction_number_1, transaction_number_2 );
-}
-
-
 /**
  * used to compare 2 iters and sort the by secondary key:
  * no or amount or payee_name
@@ -1237,6 +1179,9 @@ gint gsb_transactions_list_sort_initial_by_secondary_key ( gint transaction_numb
     else if ( conf.transactions_list_secondary_sorting == 2 )
         return gsb_transactions_list_sort_by_party (
                         transaction_number_1, transaction_number_2 );
+    else if ( conf.transactions_list_secondary_sorting == 3 )
+        return gsb_transactions_list_sort_by_date_and_no (
+                        transaction_number_1, transaction_number_2 );
     else
         return transaction_number_1 - transaction_number_2;
 }
