@@ -1,10 +1,14 @@
 #ifndef _HELP_H
 #define _HELP_H (1)
+
+#include <gtk/gtk.h>
+
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
 
 
 /* START_DECLARATION */
+gchar * extra_support ( void );
 void a_propos ( GtkWidget *bouton, gint data );
 /* END_DECLARATION */
 #endif
