@@ -1,6 +1,8 @@
 #ifndef _IMPORT_H
 #define _IMPORT_H (1)
 
+#include <gtk/gtk.h>
+
 /* START_INCLUDE_H */
 #include "gsb_real.h"
 #include "gsb_data_transaction.h"
@@ -70,7 +72,7 @@ struct struct_ope_importation
     gint action;		        /* IMPORT_TRANSACTION_GET_TRANSACTION, IMPORT_TRANSACTION_ASK_FOR_TRANSACTION, IMPORT_TRANSACTION_LEAVE_TRANSACTION*/
     gint ope_correspondante;    /* contient l'adr de l'opé qui correspond peut être à l'opé importée pour la présentation à l'utilisateur */
     GtkWidget *bouton;          /*  adr du bouton si cette opé est douteuse et vérifiée par l'utilisateur */
-    
+
     gchar *tiers;
     gchar *notes;
     gchar *cheque;
@@ -104,8 +106,6 @@ struct imported_file
 };
 
 
-typedef gboolean ( * import_function ) ( GtkWidget * assistant, struct imported_file * );
-
 struct import_format
 {
     gchar * name;
@@ -123,14 +123,14 @@ gint gsb_import_associations_list_append_assoc ( gint payee_number,
                         const gchar *search_str );
 gboolean gsb_import_by_rule ( gint rule );
 gchar *gsb_import_formats_get_list_formats_to_string ( void );
-G_MODULE_EXPORT void gsb_import_register_account ( struct struct_compte_importation * account );
-G_MODULE_EXPORT void gsb_import_register_account_error ( struct struct_compte_importation * account );
+void gsb_import_register_account ( struct struct_compte_importation * account );
+void gsb_import_register_account_error ( struct struct_compte_importation * account );
 GSList *import_selected_files ( GtkWidget * assistant );
 void importer_fichier ( void );
 GtkWidget *onglet_importation ( void );
-G_MODULE_EXPORT void register_import_format ( struct import_format *format );
+void register_import_format ( struct import_format *format );
 void register_import_formats ( void );
-G_MODULE_EXPORT gchar * unique_imported_name ( gchar * account_name );
+gchar * unique_imported_name ( gchar * account_name );
 /* END_DECLARATION */
 
 
