@@ -28,12 +28,12 @@
 #endif
 
 #include "include.h"
-
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "imputation_budgetaire.h"
 #include "dialog.h"
+#include "fenetre_principale.h"
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
 #include "gsb_data_budget.h"
@@ -45,6 +45,7 @@
 #include "gsb_transactions_list.h"
 #include "gtk_combofix.h"
 #include "main.h"
+#include "meta_budgetary.h"
 #include "metatree.h"
 #include "mouse.h"
 #include "transaction_list.h"
@@ -64,7 +65,6 @@ static gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
                         GdkEventButton *ev,
                         gpointer null );
 static void budgetary_line_list_popup_context_menu ( void );
-static GtkWidget *creation_barre_outils_ib ( void );
 static gboolean edit_budgetary_line ( GtkTreeView * view );
 static void exporter_ib ( void );
 static void importer_ib ( void );
@@ -72,33 +72,46 @@ static gboolean popup_budgetary_line_view_mode_menu ( GtkWidget * button );
 static void selectionne_sub_budgetary ( GtkTreeModel * model );
 /*END_STATIC*/
 
-
-GtkWidget *budgetary_line_tree = NULL;
-GtkTreeStore *budgetary_line_tree_model = NULL;
-gint no_devise_totaux_ib;
+static GtkWidget *budgetary_toolbar;
+static GtkWidget *budgetary_line_tree = NULL;
+static GtkTreeStore *budgetary_line_tree_model = NULL;
 
 /* variable for the management of the cancelled edition */
-gboolean sortie_edit_budgetary_line = FALSE;
+static gboolean sortie_edit_budgetary_line = FALSE;
 
 /* structure pour la sauvegarde de la position */
-struct metatree_hold_position *budgetary_hold_position;
+static struct metatree_hold_position *budgetary_hold_position;
 
 /*START_EXTERN*/
-extern MetatreeInterface * budgetary_interface;
-extern GdkColor couleur_selection;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
+/**
+ * réinitialisation des variables globales
+ *
+ * \param
+ *
+ * \return
+ * */
+void budgetary_lines_init_variables_list ( void )
+{
+    budgetary_line_tree_model = NULL;
+
+    budgetary_toolbar = NULL;
+    budgetary_line_tree = NULL;
+    etat.no_devise_totaux_ib = 1;
+
+    sortie_edit_budgetary_line = FALSE;
+}
 
 
-
-/* **************************************************************************************************** */
-/* Fonction onglet_imputations : */
-/* crée et renvoie le widget contenu dans l'onglet */
-/* **************************************************************************************************** */
-
-GtkWidget *onglet_imputations ( void )
+/**
+ * crée et renvoie le widget contenu dans l'onglet
+ *
+ *
+ *
+ */
+GtkWidget *budgetary_lines_create_list ( void )
 {
     GtkWidget *scroll_window;
     GtkWidget *vbox;
@@ -110,12 +123,11 @@ GtkWidget *onglet_imputations ( void )
 	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
     };
 
-
     /* We create the gtktreeview and model early so that they can be referenced. */
     budgetary_line_tree = gtk_tree_view_new();
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( budgetary_line_tree, GTK_STATE_SELECTED, &couleur_selection );
+    utils_set_tree_view_selection_and_text_color ( budgetary_line_tree );
 
     budgetary_line_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS,
 						     META_TREE_COLUMN_TYPES );
@@ -125,7 +137,9 @@ GtkWidget *onglet_imputations ( void )
     gtk_widget_show ( vbox );
 
     /* on y ajoute la barre d'outils */
-    gtk_box_pack_start ( GTK_BOX ( vbox ), creation_barre_outils_ib(), FALSE, FALSE, 0 );
+    budgetary_toolbar = gtk_handle_box_new ( );
+    gtk_widget_show ( budgetary_toolbar );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), budgetary_toolbar, FALSE, FALSE, 0 );
 
     /* création de l'arbre principal */
     scroll_window = gtk_scrolled_window_new ( NULL, NULL );
@@ -138,12 +152,12 @@ GtkWidget *onglet_imputations ( void )
 
     /* Create model */
     gtk_tree_sortable_set_sort_column_id ( GTK_TREE_SORTABLE(budgetary_line_tree_model),
-					   META_TREE_TEXT_COLUMN, GTK_SORT_ASCENDING );
+                        META_TREE_TEXT_COLUMN, GTK_SORT_ASCENDING );
     gtk_tree_sortable_set_sort_func ( GTK_TREE_SORTABLE(budgetary_line_tree_model),
-				      META_TREE_TEXT_COLUMN, metatree_sort_column,
-				      NULL, NULL );
+                        META_TREE_TEXT_COLUMN, metatree_sort_column,
+                        NULL, NULL );
     g_object_set_data ( G_OBJECT ( budgetary_line_tree_model), "metatree-interface",
-			budgetary_interface );
+                        budgetary_line_get_metatree_interface ( ) );
 
     /* Create container + TreeView */
     gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (budgetary_line_tree), TRUE);
@@ -166,6 +180,7 @@ GtkWidget *onglet_imputations ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Budgetary line"), cell,
 						       "text", META_TREE_TEXT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( budgetary_line_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -175,6 +190,7 @@ GtkWidget *onglet_imputations ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Account"), cell,
 						       "text", META_TREE_ACCOUNT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( budgetary_line_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -185,6 +201,7 @@ GtkWidget *onglet_imputations ( void )
 						       "text", META_TREE_BALANCE_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
 						       "xalign", META_TREE_XALIGN_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_column_set_alignment ( column, 1.0 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( budgetary_line_tree ),
@@ -194,6 +211,11 @@ GtkWidget *onglet_imputations ( void )
     gtk_widget_show ( budgetary_line_tree );
 
     /* Connect to signals */
+    g_signal_connect ( G_OBJECT ( budgetary_line_tree ),
+                        "row-collapsed",
+                        G_CALLBACK ( division_column_collapsed ),
+                        NULL );
+
     g_signal_connect ( G_OBJECT ( budgetary_line_tree ),
                         "row-expanded",
                         G_CALLBACK ( division_column_expanded ),
@@ -245,7 +267,7 @@ GtkWidget *onglet_imputations ( void )
  *
  * \return
  * */
-void remplit_arbre_imputation ( void )
+void budgetary_lines_fill_list ( void )
 {
     GSList *budget_list;
     GtkTreeIter iter_budgetary_line, iter_sub_budgetary_line;
@@ -261,7 +283,7 @@ void remplit_arbre_imputation ( void )
 
     /** Then, populate tree with budgetary lines. */
     budget_list = gsb_data_budget_get_budgets_list ();
-    
+
     /* add first the empty budget */
     budget_list = g_slist_prepend ( budget_list,
 				    gsb_data_budget_get_empty_budget ());
@@ -272,9 +294,11 @@ void remplit_arbre_imputation ( void )
 
 	budget_number = gsb_data_budget_get_no_budget (budget_list -> data);
 
-	gtk_tree_store_append (GTK_TREE_STORE (budgetary_line_tree_model), &iter_budgetary_line, NULL);
-	fill_division_row ( GTK_TREE_MODEL(budgetary_line_tree_model), budgetary_interface,
-			    &iter_budgetary_line, budget_number);
+	gtk_tree_store_append ( GTK_TREE_STORE ( budgetary_line_tree_model ), &iter_budgetary_line, NULL);
+	fill_division_row ( GTK_TREE_MODEL ( budgetary_line_tree_model ),
+                        budgetary_line_get_metatree_interface ( ),
+                        &iter_budgetary_line,
+                        budget_number );
 
 	/** Each budget has sub budgetary lines. */
 	if ( budget_number )
@@ -289,12 +313,13 @@ void remplit_arbre_imputation ( void )
 
 		sub_budget_number = gsb_data_budget_get_no_sub_budget (sub_budget_list -> data);
 
-		gtk_tree_store_append (GTK_TREE_STORE (budgetary_line_tree_model),
+		gtk_tree_store_append ( GTK_TREE_STORE (budgetary_line_tree_model),
 				       &iter_sub_budgetary_line, &iter_budgetary_line);
-		fill_sub_division_row ( GTK_TREE_MODEL(budgetary_line_tree_model), budgetary_interface,
-					&iter_sub_budgetary_line,
-					budget_number,
-					sub_budget_number);
+		fill_sub_division_row ( GTK_TREE_MODEL ( budgetary_line_tree_model ),
+                        budgetary_line_get_metatree_interface ( ),
+                        &iter_sub_budgetary_line,
+                        budget_number,
+                        sub_budget_number );
 
 		sub_budget_list = sub_budget_list -> next;
 	    }
@@ -303,14 +328,18 @@ void remplit_arbre_imputation ( void )
 	/* add the no-sub-budget only if budget exists */
 	if (budget_number)
 	{
-	    gtk_tree_store_append (GTK_TREE_STORE (budgetary_line_tree_model),
-				   &iter_sub_budgetary_line, &iter_budgetary_line);
-	    fill_sub_division_row ( GTK_TREE_MODEL(budgetary_line_tree_model), budgetary_interface,
-				    &iter_sub_budgetary_line, budget_number, 0 );
+	    gtk_tree_store_append ( GTK_TREE_STORE ( budgetary_line_tree_model ),
+                        &iter_sub_budgetary_line,
+                        &iter_budgetary_line );
+	    fill_sub_division_row ( GTK_TREE_MODEL(budgetary_line_tree_model),
+                        budgetary_line_get_metatree_interface ( ),
+                        &iter_sub_budgetary_line,
+                        budget_number,
+                        0 );
 	}
 	budget_list = budget_list -> next;
     }
-        /* replace le curseur sur la division, sub_division ou opération initiale */
+    /* replace le curseur sur la division, sub_division ou opération initiale */
     if ( budgetary_hold_position -> path )
     {
         if ( budgetary_hold_position -> expand )
@@ -322,12 +351,25 @@ void remplit_arbre_imputation ( void )
             gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( budgetary_line_tree ), ancestor );
             gtk_tree_path_free (ancestor );
         }
+        /* on colorise les lignes du tree_view */
+        utils_set_tree_view_background_color ( budgetary_line_tree, META_TREE_BACKGROUND_COLOR );
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( budgetary_line_tree ) );
         gtk_tree_selection_select_path ( selection, budgetary_hold_position -> path );
         gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( budgetary_line_tree ),
                         budgetary_hold_position -> path,
                         NULL, TRUE, 0.5, 0.5 );
     }
+    else
+    {
+        gchar *title;
+
+        /* on colorise les lignes du tree_view */
+        utils_set_tree_view_background_color ( budgetary_line_tree, META_TREE_BACKGROUND_COLOR );
+	    title = g_strdup(_("Budgetary lines"));
+        gsb_gui_headings_update_title ( title );
+        g_free ( title );
+        gsb_gui_headings_update_suffix ( "" );
+    }
 }
 
 
@@ -378,14 +420,14 @@ gboolean gsb_budget_update_combofix ( gboolean force )
  *
  *
  */
-void exporter_ib ( void )
+void budgetary_lines_exporter_list ( void )
 {
     GtkWidget *dialog;
     gint resultat;
     gchar *nom_ib;
 
     dialog = gtk_file_chooser_dialog_new ( _("Export the budgetary lines"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
@@ -401,7 +443,7 @@ void exporter_ib ( void )
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    nom_ib =file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
+	    nom_ib = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
 	    gsb_file_update_last_path (file_selection_get_last_directory (GTK_FILE_CHOOSER (dialog), TRUE));
 	    gtk_widget_destroy ( GTK_WIDGET ( dialog ));
 
@@ -425,7 +467,7 @@ void exporter_ib ( void )
 
 
 /* **************************************************************************************************** */
-void importer_ib ( void )
+void budgetary_lines_importer_list ( void )
 {
     GtkWidget *dialog;
     gint resultat;
@@ -434,7 +476,7 @@ void importer_ib ( void )
     GtkFileFilter * filter;
 
     dialog = gtk_file_chooser_dialog_new ( _("Import budgetary lines"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_OPEN,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
@@ -526,98 +568,116 @@ void importer_ib ( void )
  */
 GtkWidget *creation_barre_outils_ib ( void )
 {
-    GtkWidget * handlebox, * hbox2, * button;
+    GtkWidget *hbox, *button;
 
-    /* HandleBox */
-    handlebox = gtk_handle_box_new ();
-
-    /* Hbox2 */
-    hbox2 = gtk_hbox_new ( FALSE, 0 );
-    gtk_container_add ( GTK_CONTAINER(handlebox), hbox2 );
+    /* Hbox */
+    hbox = gtk_hbox_new ( FALSE, 0 );
 
     /* New budgetary line button */
-    button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
-					       _("New\nbudgetary line"), "new-ib.png",
-					       G_CALLBACK(appui_sur_ajout_imputation),
-					       budgetary_line_tree_model );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Create a new budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT (button), "type", GINT_TO_POINTER (1) );
+    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
+                                _("New\nbudgetary line"), "new-ib.png",
+                                G_CALLBACK ( appui_sur_ajout_imputation ),
+                                budgetary_line_tree_model );
+
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Create a new budgetary line") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (1) );
 
     /* New sub budgetary line button */
-    button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
-					       _("New sub\nbudgetary line"),
-					       "new-sub-ib.png",
-					       G_CALLBACK(appui_sur_ajout_imputation),
-					       budgetary_line_tree_model );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(budgetary_line_tree_model), button, "selection" );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(budgetary_line_tree_model), button, "sub-division" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Create a new sub-budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT (button), "type", GINT_TO_POINTER (2) );
+    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
+                                _("New sub\nbudgetary line"),
+                                "new-sub-ib.png",
+                                G_CALLBACK ( appui_sur_ajout_imputation ),
+                                budgetary_line_tree_model );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ), button, "selection" );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ), button, "sub-division" );
+
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Create a new sub-budgetary line") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (2) );
 
     /* Import button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_OPEN,
-					   _("Import"),
-					   G_CALLBACK(importer_ib),
-					   NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Import a Grisbi budgetary line file (.igsb)"
-                            " or create from a list of categories (.cgsb)" ) );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                GTK_STOCK_OPEN,
+                                _("Import"),
+                                G_CALLBACK ( budgetary_lines_importer_list ),
+                                NULL );
+
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                        _("Import a Grisbi budgetary line file (.igsb)"
+                        " or create from a list of categories (.cgsb)" ) );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* Export button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_SAVE,
-					   _("Export"),
-					   G_CALLBACK(exporter_ib),
-					   NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Export a Grisbi budgetary line file (.igsb)") );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                GTK_STOCK_SAVE,
+                                _("Export"),
+                                G_CALLBACK ( budgetary_lines_exporter_list ),
+                                NULL );
+
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+                        _("Export a Grisbi budgetary line file (.igsb)") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* Delete button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_DELETE, _("Delete"),
-					   G_CALLBACK(supprimer_division),
-					   budgetary_line_tree );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(budgetary_line_tree_model), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Delete selected budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                GTK_STOCK_DELETE, _("Delete"),
+                                G_CALLBACK ( supprimer_division ),
+                                budgetary_line_tree );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ), button, "selection" );
+
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Delete selected budgetary line") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* Properties button */
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_PROPERTIES, _("Properties"),
-					   G_CALLBACK(edit_budgetary_line),
-					   budgetary_line_tree );
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+                                GTK_STOCK_EDIT, _("Edit"),
+                                G_CALLBACK ( edit_budgetary_line ),
+                                budgetary_line_tree );
     metatree_register_widget_as_linked ( GTK_TREE_MODEL(budgetary_line_tree_model), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Edit selected budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Edit selected budgetary line") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
     /* View button */
-    button = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
-						GTK_STOCK_SELECT_COLOR,
-						_("View"),
-						G_CALLBACK(popup_budgetary_line_view_mode_menu),
-						NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
-				  _("Change display mode") );
-    gtk_box_pack_start ( GTK_BOX ( hbox2 ), button, FALSE, TRUE, 0 );
+    button = gsb_automem_stock_button_menu_new ( conf.display_toolbar,
+                                GTK_STOCK_SELECT_COLOR,
+                                _("View"),
+                                G_CALLBACK(popup_budgetary_line_view_mode_menu),
+                                NULL );
 
-    gtk_widget_show_all ( handlebox );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Change display mode") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL(budgetary_line_tree_model),
-					    FALSE, "selection" );
+    gtk_widget_show_all ( hbox );
 
-    return ( handlebox );
+    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL ( budgetary_line_tree_model ), FALSE, "selection" );
+
+    return ( hbox );
 }
 
 
+/**
+ *
+ *
+ *
+ */
+void budgetary_lines_update_toolbar_list ( void )
+{
+    GList *list = NULL;
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( budgetary_toolbar ) );
+
+    if ( list )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( budgetary_toolbar ),
+                               GTK_WIDGET ( list -> data ) );
+        g_list_free ( list );
+    }
+
+    gtk_container_add ( GTK_CONTAINER ( budgetary_toolbar ), creation_barre_outils_ib () );
+}
+
 
 /**
  * Popup a menu that allow changing the view mode of the category
@@ -700,7 +760,7 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
 							     _("No budget defined") ));
 
     dialog = gtk_dialog_new_with_buttons ( title ,
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_DIALOG_MODAL,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
 					   GTK_STOCK_APPLY, GTK_RESPONSE_OK,
@@ -825,22 +885,24 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
     if ( sub_budget_number > 0 )
     {
 	div_iter = get_iter_from_div ( model, budget_number, sub_budget_number );
-	fill_sub_division_row ( model, budgetary_interface,
-				div_iter,
-				budget_number,
-				sub_budget_number);
+	fill_sub_division_row ( model,
+                        budgetary_line_get_metatree_interface ( ),
+                        div_iter,
+                        budget_number,
+                        sub_budget_number );
     }
     else
     {
 	div_iter = get_iter_from_div ( model, budget_number, 0 );
-	fill_division_row ( model, budgetary_interface,
-			    div_iter,
-			    budget_number );
+	fill_division_row ( model,
+                        budgetary_line_get_metatree_interface ( ),
+                        div_iter,
+                        budget_number );
     }
-    gtk_tree_iter_free (div_iter);
+    gtk_tree_iter_free ( div_iter );
 
     /* update the transactions list */
-    transaction_list_update_element (ELEMENT_BUDGET);
+    transaction_list_update_element ( ELEMENT_BUDGET );
 
     return TRUE;
 }
@@ -886,7 +948,7 @@ void selectionne_sub_budgetary ( GtkTreeModel * model )
     gint budget_number = -1, sub_budget_number = -1;
     gint i = 0,j = 0;
 
-    selection = gtk_tree_view_get_selection ( 
+    selection = gtk_tree_view_get_selection (
                         GTK_TREE_VIEW (budgetary_line_tree) );
     if ( selection && gtk_tree_selection_get_selected (
                         selection, &model, &parent ) )
@@ -904,7 +966,7 @@ void selectionne_sub_budgetary ( GtkTreeModel * model )
         return;
 
     name =  my_strdup (_("New sub-budget"));
-    sub_budget_number = gsb_data_budget_get_sub_budget_number_by_name ( 
+    sub_budget_number = gsb_data_budget_get_sub_budget_number_by_name (
                         budget_number, name, FALSE );
     j = gtk_tree_model_iter_n_children ( model, &parent );
     for (i = 0; i < j; i++ )
@@ -1050,13 +1112,28 @@ void budgetary_line_list_popup_context_menu ( void )
 
     type_division = metatree_get_row_type_from_tree_view ( budgetary_line_tree );
 
-    if ( type_division == META_TREE_TRANSACTION
-     ||
-     type_division == META_TREE_INVALID )
+    if ( type_division == META_TREE_INVALID )
         return;
 
     menu = gtk_menu_new ();
 
+    if ( type_division == META_TREE_TRANSACTION )
+    {
+        title = g_strdup ( _("Transfers the identical transactions in another sub-budgetary line") );
+
+        menu_item = gtk_image_menu_item_new_with_label ( title );
+        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
+                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
+                        GTK_ICON_SIZE_MENU ) );
+        g_signal_connect_swapped ( G_OBJECT ( menu_item ),
+                        "activate",
+                        G_CALLBACK ( metatree_transfer_identical_transactions ),
+                        budgetary_line_tree );
+        gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+
+        g_free ( title );
+    }
+
     if ( type_division == META_TREE_DIV || type_division == META_TREE_SUB_DIV )
     {
 
@@ -1068,7 +1145,7 @@ void budgetary_line_list_popup_context_menu ( void )
 
         menu_item = gtk_image_menu_item_new_with_label ( title );
         gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                            gtk_image_new_from_stock ( GTK_STOCK_PROPERTIES,
+                            gtk_image_new_from_stock ( GTK_STOCK_EDIT,
                             GTK_ICON_SIZE_MENU ) );
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                             "activate",
@@ -1111,6 +1188,69 @@ void budgetary_line_list_popup_context_menu ( void )
 }
 
 
+/**
+ *
+ *
+ *
+ */
+GtkTreeStore *budgetary_lines_get_tree_store ( void )
+{
+    return budgetary_line_tree_model;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+GtkWidget *budgetary_lines_get_tree_view ( void )
+{
+    return budgetary_line_tree;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void budgetary_lines_new_budgetary_line ( void )
+{
+    metatree_new_division ( GTK_TREE_MODEL ( budgetary_line_tree_model ) );
+
+    sortie_edit_budgetary_line = FALSE;
+    edit_budgetary_line ( GTK_TREE_VIEW ( budgetary_line_tree ) );
+    if ( sortie_edit_budgetary_line )
+    {
+        supprimer_division ( GTK_TREE_VIEW ( budgetary_line_tree ) );
+        sortie_edit_budgetary_line = FALSE;
+    }
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void budgetary_lines_delete_budgetary_line ( void )
+{
+    supprimer_division ( GTK_TREE_VIEW ( budgetary_line_tree ) );
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void budgetary_lines_edit_budgetary_line ( void )
+{
+    edit_budgetary_line ( GTK_TREE_VIEW ( budgetary_line_tree ) );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
