@@ -28,11 +28,10 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "menu.h"
-#include "barre_outils.h"
 #include "custom_list.h"
 #include "export.h"
 #include "fenetre_principale.h"
@@ -43,6 +42,7 @@
 #include "gsb_assistant_archive.h"
 #include "gsb_assistant_archive_export.h"
 #include "gsb_data_account.h"
+#include "gsb_data_mix.h"
 #include "gsb_debug.h"
 #include "gsb_file.h"
 #include "gsb_form.h"
@@ -69,30 +69,23 @@ static gboolean help_manual ( void );
 static gboolean help_quick_start ( void );
 static gboolean help_translation ( void );
 static gboolean help_website ( void );
-static void menu_add_widget (GtkUIManager *p_uiManager,
-                        GtkWidget *p_widget,
-                        GtkContainer *p_box) ;
 static gboolean gsb_menu_reinit_largeur_col_menu ( void );
 /*END_STATIC*/
 
 
 
 /*START_EXTERN*/
-extern GtkTreeModel * navigation_model;
-extern gsize nb_derniers_fichiers_ouverts;
-extern gint nb_max_derniers_fichiers_ouverts;
 extern gchar **tab_noms_derniers_fichiers_ouverts;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
-gboolean block_menu_cb = FALSE;
-GtkUIManager *ui_manager;
+static gboolean block_menu_cb = FALSE;
+static GtkUIManager *ui_manager;
 static gint merge_id = -1;
 static gint recent_files_merge_id = -1;
 static gint move_to_account_merge_id = -1;
 
-static gchar *ui_manager_buffer = 
+static const gchar *ui_manager_buffer =
 "<ui>"
 "  <menubar>"
 "    <menu name='FileMenu' action='FileMenuAction' >"
@@ -119,10 +112,12 @@ static gchar *ui_manager_buffer =
 "      <menuitem name='Quit' action='QuitAction'/>"
 "    </menu>"
 "    <menu name='EditMenu' action='EditMenuAction' >"
+"      <menuitem name='EditTransaction' action='EditTransactionAction'/>"
+"      <separator/>"
 "      <menuitem name='NewTransaction' action='NewTransactionAction'/>"
 "      <menuitem name='RemoveTransaction' action='RemoveTransactionAction'/>"
+"      <menuitem name='TemplateTransaction' action='TemplateTransactionAction'/>"
 "      <menuitem name='CloneTransaction' action='CloneTransactionAction'/>"
-"      <menuitem name='EditTransaction' action='EditTransactionAction'/>"
 "      <separator/>"
 "      <menuitem name='ConvertToScheduled' action='ConvertToScheduledAction'/>"
 "      <menu name='MoveToAnotherAccount' action='MoveToAnotherAccountAction'>"
@@ -151,7 +146,7 @@ static gchar *ui_manager_buffer =
 "    <menu name='Help' action='HelpMenuAction' >"
 "      <menuitem name='Manual' action='ManualAction'/>"
 "      <menuitem name='QuickStart' action='QuickStartAction'/>"
-"      <menuitem name='Translation' action='TranslationAction'/>"
+/*"      <menuitem name='Translation' action='TranslationAction'/>"*/
 "      <menuitem name='About' action='AboutAction'/>"
 "      <separator/>"
 "      <menuitem name='GrisbiWebsite' action='GrisbiWebsiteAction'/>"
@@ -163,15 +158,6 @@ static gchar *ui_manager_buffer =
 "</ui>";
 
 
-static void menu_add_widget (GtkUIManager * p_uiManager, GtkWidget * p_widget, 
-                        GtkContainer * p_box) 
-{ 
-    gtk_box_pack_start (GTK_BOX (p_box), p_widget, FALSE, FALSE, 0);
-    gtk_widget_show (p_widget); 
-    return; 
-}
-
-
 GtkWidget *init_menus ( GtkWidget *vbox )
 {
     GtkWidget *menubar;
@@ -223,18 +209,20 @@ GtkWidget *init_menus ( GtkWidget *vbox )
          G_CALLBACK ( gsb_file_close ) },
 	#endif
         {"QuitAction", GTK_STOCK_QUIT, _("_Quit"), NULL, NULL,
-         G_CALLBACK ( gsb_grisbi_close ) },
+         G_CALLBACK ( gsb_main_grisbi_close ) },
 
         /* Editmenu */
         {"EditMenuAction", NULL, _("_Edit"), NULL, NULL, NULL },
-        {"NewTransactionAction", GTK_STOCK_NEW, _("_New transaction"), "", NULL,
-         G_CALLBACK ( new_transaction ) },
+        {"EditTransactionAction", GTK_STOCK_EDIT, _("_Edit transaction"), "", NULL,
+         G_CALLBACK ( gsb_data_mix_edit_current_transaction ) },
+        {"NewTransactionAction", GTK_STOCK_NEW, _("_New transaction"), "<Control>T", NULL,
+         G_CALLBACK ( gsb_data_mix_new_transaction_by_menu ) },
         {"RemoveTransactionAction", GTK_STOCK_DELETE, _("_Remove transaction"), "", NULL,
-         G_CALLBACK ( remove_transaction ) },
+         G_CALLBACK ( gsb_data_mix_delete_current_transaction ) },
+        {"TemplateTransactionAction", GTK_STOCK_COPY, _("Use selected transaction as a template"), "", NULL,
+         G_CALLBACK ( gsb_transactions_list_clone_template ) },
         {"CloneTransactionAction", GTK_STOCK_COPY, _("_Clone transaction"), "", NULL,
-         G_CALLBACK ( clone_selected_transaction ) },
-        {"EditTransactionAction", GTK_STOCK_PROPERTIES, _("_Edit transaction"), "", NULL,
-         G_CALLBACK ( gsb_transactions_list_edit_current_transaction ) },
+         G_CALLBACK ( gsb_data_mix_clone_current_transaction ) },
         {"ConvertToScheduledAction", GTK_STOCK_CONVERT, _("Convert to _scheduled transaction"), NULL, NULL,
          G_CALLBACK ( schedule_selected_transaction ) },
         {"MoveToAnotherAccountAction", NULL, _("_Move transaction to another account"), NULL, NULL, NULL },
@@ -261,8 +249,8 @@ GtkWidget *init_menus ( GtkWidget *vbox )
 	#endif
         {"QuickStartAction", NULL, _("_Quick start"), NULL, NULL,
          G_CALLBACK ( help_quick_start ) },
-        {"TranslationAction", NULL, _("_Translation"), NULL, NULL,
-         G_CALLBACK ( help_translation ) },
+        /* {"TranslationAction", NULL, _("_Translation"), NULL, NULL,
+         G_CALLBACK ( help_translation ) }, */
         {"AboutAction", GTK_STOCK_ABOUT, _("_About Grisbi..."), NULL, NULL,
          G_CALLBACK ( a_propos ) },
         {"GrisbiWebsiteAction", NULL, _("_Grisbi website"), NULL, NULL,
@@ -291,7 +279,7 @@ GtkWidget *init_menus ( GtkWidget *vbox )
         {"DebugModeAction", NULL, _("Debug mode"), NULL, NULL,
          G_CALLBACK ( gsb_debug_start_log ), etat.debug_mode },
         {"ShowTransactionFormAction", NULL, _("Show transaction _form"), NULL, NULL,
-         G_CALLBACK ( gsb_gui_toggle_show_form ), etat.formulaire_toujours_affiche },
+         G_CALLBACK ( gsb_gui_toggle_show_form ), conf.formulaire_toujours_affiche },
 #ifdef GTKOSXAPPLICATION
         {"ShowReconciledAction", NULL, _("Show _reconciled"), "<Meta>R", NULL,
          G_CALLBACK ( gsb_gui_toggle_show_reconciled ), 0 },
@@ -304,7 +292,7 @@ GtkWidget *init_menus ( GtkWidget *vbox )
          G_CALLBACK ( gsb_gui_toggle_show_archived ), 0 },
 #endif
         {"ShowClosedAction", NULL, _("Show _closed accounts"), NULL, NULL,
-         G_CALLBACK ( gsb_gui_toggle_show_closed_accounts ), etat.show_closed_accounts } 
+         G_CALLBACK ( gsb_gui_toggle_show_closed_accounts ), conf.show_closed_accounts }
     };
 
     ui_manager = gtk_ui_manager_new ();
@@ -314,37 +302,35 @@ GtkWidget *init_menus ( GtkWidget *vbox )
     gtk_action_group_add_actions (actions,
                         entries,
                         G_N_ELEMENTS ( entries ),
-                        (gpointer) window );
+                        (gpointer) run.window );
 
     gtk_action_group_add_radio_actions ( actions,
-                        radio_entries, 
-                        G_N_ELEMENTS ( radio_entries ), 
+                        radio_entries,
+                        G_N_ELEMENTS ( radio_entries ),
                         -1,
-                        G_CALLBACK ( gsb_gui_toggle_line_view_mode ), 
+                        G_CALLBACK ( gsb_gui_toggle_line_view_mode ),
                         NULL );
 
     gtk_action_group_add_toggle_actions ( actions,
-                        toggle_entries, 
-                        G_N_ELEMENTS ( toggle_entries ), 
+                        toggle_entries,
+                        G_N_ELEMENTS ( toggle_entries ),
                         NULL );
 
     gtk_ui_manager_insert_action_group ( ui_manager, actions, 0 );
+    g_object_unref ( G_OBJECT ( actions ) );
+
     merge_id = gtk_ui_manager_add_ui_from_string ( ui_manager,
-                        ui_manager_buffer,
-                        strlen ( ui_manager_buffer ),
-                        NULL );
+                        ui_manager_buffer, -1, NULL );
 
 #ifndef GTKOSXAPPLICATION
-    gtk_window_add_accel_group ( GTK_WINDOW ( window ),
+    gtk_window_add_accel_group ( GTK_WINDOW ( run.window ),
                         gtk_ui_manager_get_accel_group ( ui_manager ) );
 #endif /* GTKOSXAPPLICATION */
 
     menubar = gtk_ui_manager_get_widget ( ui_manager, "/menubar" );
     gtk_box_pack_start ( GTK_BOX ( vbox ),  menubar, FALSE, TRUE, 0 );
 
-    gsb_gui_sensitive_menu_item ( "EditMenu", "NewTransaction", NULL, FALSE );
-    gsb_menu_transaction_operations_set_sensitive ( FALSE );
-
+    /* return */
     return menubar;
 }
 
@@ -368,42 +354,43 @@ gboolean affiche_derniers_fichiers_ouverts ( void )
 
     efface_derniers_fichiers_ouverts ();
 
-    if ( nb_derniers_fichiers_ouverts > nb_max_derniers_fichiers_ouverts )
+    if ( conf.nb_derniers_fichiers_ouverts > conf.nb_max_derniers_fichiers_ouverts )
     {
-        nb_derniers_fichiers_ouverts = nb_max_derniers_fichiers_ouverts;
+        conf.nb_derniers_fichiers_ouverts = conf.nb_max_derniers_fichiers_ouverts;
     }
 
-    if ( ! nb_derniers_fichiers_ouverts || ! nb_max_derniers_fichiers_ouverts )
+    if ( ! conf.nb_derniers_fichiers_ouverts || ! conf.nb_max_derniers_fichiers_ouverts )
     {
         return FALSE;
     }
 
     action_group = gtk_action_group_new ( "Group2" );
 
-    for ( i = 0 ; i < nb_derniers_fichiers_ouverts ; i++ )
+    for ( i = 0 ; i < conf.nb_derniers_fichiers_ouverts ; i++ )
     {
         gchar *tmp_name;
         GtkAction *action;
 
         tmp_name = g_strdup_printf ( "LastFile%d", i );
 
-        action = gtk_action_new ( tmp_name, 
-                        tab_noms_derniers_fichiers_ouverts[i], 
+        action = gtk_action_new ( tmp_name,
+                        tab_noms_derniers_fichiers_ouverts[i],
                         "",
                         "" );
         g_free ( tmp_name );
         g_signal_connect ( action,
                         "activate",
-                        G_CALLBACK ( gsb_file_open_direct_menu ), 
+                        G_CALLBACK ( gsb_file_open_direct_menu ),
                         GINT_TO_POINTER ( i ) );
         gtk_action_group_add_action ( action_group, action );
     }
 
     gtk_ui_manager_insert_action_group ( ui_manager, action_group, 1 );
+    g_object_unref ( G_OBJECT ( action_group ) );
 
     recent_files_merge_id = gtk_ui_manager_new_merge_id ( ui_manager );
 
-    for ( i=0 ; i<nb_derniers_fichiers_ouverts ; i++ )
+    for ( i=0 ; i < conf.nb_derniers_fichiers_ouverts ; i++ )
     {
         gchar *tmp_name;
         gchar *tmp_label;
@@ -412,7 +399,7 @@ gboolean affiche_derniers_fichiers_ouverts ( void )
         tmp_label = g_strdup_printf ( "_%d LastFile%d", i, i );
 
         gtk_ui_manager_add_ui ( ui_manager,
-                    recent_files_merge_id, 
+                    recent_files_merge_id,
                     "/menubar/FileMenu/RecentFiles/",
                     tmp_label,
                     tmp_name,
@@ -425,7 +412,7 @@ gboolean affiche_derniers_fichiers_ouverts ( void )
 
     /* add a separator */
     gtk_ui_manager_add_ui ( ui_manager,
-                    merge_id, 
+                    merge_id,
                     "/menubar/FileMenu/Open/",
                     NULL,
                     NULL,
@@ -453,7 +440,7 @@ gboolean help_manual ( void )
     gchar *lang = _("en");
     gchar *string;
 
-    string = g_strconcat ( HELP_PATH, "/", lang, "/manual.html", NULL );
+    string = g_build_filename ( HELP_PATH, lang, "manual.html", NULL );
 
     if (g_file_test ( string,
 		      G_FILE_TEST_EXISTS ))
@@ -464,7 +451,7 @@ gboolean help_manual ( void )
     else
     {
 	g_free (string);
-	string = g_strconcat ( HELP_PATH, "/", lang, "/grisbi-manuel.html", NULL );
+	string = g_build_filename ( HELP_PATH, lang, "grisbi-manuel.html", NULL );
 	lance_navigateur_web (string);
 	g_free (string);
     }
@@ -484,8 +471,7 @@ gboolean help_quick_start ( void )
 {
     gchar *lang = _("en");
 
-    gchar* tmpstr = g_strconcat ( HELP_PATH, "/", lang, "/quickstart.html", 
-					 NULL );
+    gchar* tmpstr = g_build_filename ( HELP_PATH, lang, "quickstart.html", NULL );
     lance_navigateur_web ( tmpstr );
     g_free ( tmpstr );
 
@@ -504,8 +490,7 @@ gboolean help_translation ( void )
 {
     gchar *lang = _("en");
 
-    gchar* tmpstr = g_strconcat ( HELP_PATH, "/", lang, "/translation.html", 
-					 NULL );
+    gchar* tmpstr = g_build_filename ( HELP_PATH, lang, "translation.html", NULL );
     lance_navigateur_web ( tmpstr );
     g_free ( tmpstr );
 
@@ -542,45 +527,22 @@ gboolean help_bugreport ( void )
 
 
 
-/**
- * Concatenate menu entry names to produce a valid menu path, like
- * /menubar/FileMenu/Save
- *
- * \param menu		Name of the root menu.
- * \param submenu	Name of the sub-menu.
- * \param subsubmenu	Name of the sub-sub-menu.
- *
- * \return A newly-created string representing the menu path.
- */
-gchar *menu_name ( gchar *menu, gchar *submenu, gchar *subsubmenu )
-{
-  if ( subsubmenu )
-    return g_strconcat ( "/menubar/", menu, "/", submenu, "/", subsubmenu, NULL );
-  else if ( submenu )
-    return g_strconcat ( "/menubar/", menu, "/", submenu, NULL );
-  else
-    return g_strconcat ( "/menubar/", menu, NULL );
-}
-
-
-
 /**
  * Set sensitiveness of a menu item according to a string
  * representation of its position in the menu.
  * menu.
  *
- * \param root_menu_name	Name of the menu.
- * \param submenu_name		Name of the sub menu.
- * \param subsubmenu_name	Name of the sub sub menu.
+ * \param item_name		Path of the menu item.
+ * \param state			Whether widget should be 'sensitive' or not.
  *
  * \return TRUE on success.
  */
-gboolean gsb_gui_sensitive_menu_item_from_string ( gchar *item_name, gboolean state )
+gboolean gsb_gui_sensitive_menu_item ( gchar *item_name, gboolean state )
 {
     GtkWidget * widget;
 
     widget = gtk_ui_manager_get_widget ( ui_manager, item_name );
-    
+
     if ( widget && GTK_IS_WIDGET(widget) )
     {
 	gtk_widget_set_sensitive ( widget, state );
@@ -592,33 +554,6 @@ gboolean gsb_gui_sensitive_menu_item_from_string ( gchar *item_name, gboolean st
 
 
 /**
- * Set sensitiveness of a menu item according to its position in the
- * menu.
- *
- * \param root_menu_name	Name of the menu.
- * \param submenu_name		Name of the sub menu.
- * \param subsubmenu_name	Name of the sub sub menu.
- *
- * \return TRUE on success.
- */
-gboolean gsb_gui_sensitive_menu_item ( gchar *root_menu_name,
-                        gchar *submenu_name,
-                        gchar *subsubmenu_name,
-                        gboolean state )
-{
-    gchar* tmpstr;
-    gboolean result;
-
-    tmpstr = menu_name ( root_menu_name, submenu_name, subsubmenu_name );
-    result = gsb_gui_sensitive_menu_item_from_string ( tmpstr, state );
-
-    g_free ( tmpstr );
-
-    return result;
-}
-
-
-/** 
  * Callback called when an item of the "View/Show ... lines" menu is
  * triggered.
  */
@@ -658,7 +593,8 @@ gboolean gsb_gui_toggle_show_form ( void )
     devel_debug (NULL);
 
     /* FIXME benj: ugly but I cannot find a way to block this ... */
-    if ( block_menu_cb ) return FALSE;
+    if ( block_menu_cb )
+        return FALSE;
 
     gsb_form_switch_expander ( );
 
@@ -680,7 +616,7 @@ gboolean gsb_gui_toggle_show_reconciled ( void )
 	    return FALSE;
 
     current_account = gsb_gui_navigation_get_current_account ( );
-    if ( current_account == -1 || etat.equilibrage == 1 )
+    if ( current_account == -1 || run.equilibrage == 1 )
         return FALSE;
 
     if ( gsb_data_account_get_r ( current_account ) )
@@ -724,13 +660,12 @@ gboolean gsb_gui_toggle_show_archived ( void )
  */
 gboolean gsb_gui_toggle_show_closed_accounts ( void )
 {
-    etat.show_closed_accounts = ! etat.show_closed_accounts;
+    conf.show_closed_accounts = !conf.show_closed_accounts;
 
-    create_account_list ( navigation_model );
+    gsb_gui_navigation_create_account_list ( gsb_gui_navigation_get_model ( ) );
     gsb_gui_navigation_update_home_page ( );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -754,55 +689,50 @@ gboolean gsb_menu_update_view_menu ( gint account_number )
     block_menu_cb = TRUE;
 
     /* update the showing of reconciled transactions */
-    tmpstr = menu_name ( "ViewMenu", "ShowReconciled", NULL );
+    tmpstr = "/menubar/ViewMenu/ShowReconciled";
     gtk_toggle_action_set_active ( GTK_TOGGLE_ACTION (
-                        gtk_ui_manager_get_action ( ui_manager, tmpstr) ), 
+                        gtk_ui_manager_get_action ( ui_manager, tmpstr) ),
 				        gsb_data_account_get_r ( account_number ) );
-    g_free ( tmpstr );
 
-    tmpstr = menu_name ( "ViewMenu", "ShowTransactionForm", NULL );
+    tmpstr = "/menubar/ViewMenu/ShowTransactionForm";
     gtk_toggle_action_set_active ( GTK_TOGGLE_ACTION (
-                        gtk_ui_manager_get_action ( ui_manager, tmpstr) ), 
+                        gtk_ui_manager_get_action ( ui_manager, tmpstr) ),
 				        gsb_form_is_visible ( ) );
-    g_free ( tmpstr );
 
     /* update the showing of archived transactions */
-    tmpstr = menu_name ( "ViewMenu", "ShowArchived", NULL );
+    tmpstr = "/menubar/ViewMenu/ShowArchived";
     gtk_toggle_action_set_active ( GTK_TOGGLE_ACTION (
-                        gtk_ui_manager_get_action ( ui_manager, tmpstr) ), 
+                        gtk_ui_manager_get_action ( ui_manager, tmpstr) ),
 				        gsb_data_account_get_l ( account_number ) );
-    g_free ( tmpstr );
 
     /* update the number of line showed */
     switch ( gsb_data_account_get_nb_rows (account_number))
     {
 	default:
 	case 1 :
-	    item_name = menu_name ( "ViewMenu", "ShowOneLine", NULL );
+	    item_name = "/menubar/ViewMenu/ShowOneLine";
 	    break;
 	case 2 :
-	    item_name = menu_name ( "ViewMenu", "ShowTwoLines", NULL );
+	    item_name = "/menubar/ViewMenu/ShowTwoLines";
 	    break;
 	case 3 :
-	    item_name = menu_name ( "ViewMenu", "ShowThreeLines", NULL );
+	    item_name = "/menubar/ViewMenu/ShowThreeLines";
 	    break;
 	case 4 :
-	    item_name = menu_name ( "ViewMenu", "ShowFourLines", NULL );
+	    item_name = "/menubar/ViewMenu/ShowFourLines";
 	    break;
     }
 
     gtk_toggle_action_set_active ( GTK_TOGGLE_ACTION (
                         gtk_ui_manager_get_action ( ui_manager, item_name ) ),
 				        TRUE );
-    g_free ( item_name );
-
     block_menu_cb = FALSE;
 
     return FALSE;
 }
 
 
-/** 
+/**
  * Update the clickable list of closed accounts and target
  * accounts to move a transaction, in menu.
  *
@@ -814,8 +744,8 @@ gboolean gsb_menu_update_accounts_in_menus ( void )
     GSList *list_tmp;
     GtkActionGroup * action_group;
 
-    if ( move_to_account_merge_id != -1 ) 
-	gtk_ui_manager_remove_ui ( ui_manager, move_to_account_merge_id );
+    if ( move_to_account_merge_id != -1 )
+        gtk_ui_manager_remove_ui ( ui_manager, move_to_account_merge_id );
 
     move_to_account_merge_id = gtk_ui_manager_new_merge_id ( ui_manager );
     action_group = gtk_action_group_new ( "Group3" );
@@ -825,42 +755,49 @@ gboolean gsb_menu_update_accounts_in_menus ( void )
 
     while ( list_tmp )
     {
-	gint i;
+        gint i;
 
-	i = gsb_data_account_get_no_account ( list_tmp -> data );
+        i = gsb_data_account_get_no_account ( list_tmp -> data );
 
-	if ( !gsb_data_account_get_closed_account ( i ))
-	{
-	    gchar * tmp_name = g_strdup_printf ( "MoveToAccount%d", i );
-	    gchar * account_name = gsb_data_account_get_name(i);
-	    GtkAction * action;
+        if ( !gsb_data_account_get_closed_account ( i ) )
+        {
+            gchar *tmp_name;
+            gchar *account_name;
+            GtkAction *action;
 
-	    if ( ! account_name )
-	    {
-		account_name = _("Unnamed account");
-	    }
-	    action = gtk_action_new ( tmp_name, account_name, "", "" );
+            tmp_name = g_strdup_printf ( "MoveToAccount%d", i );
+            account_name = gsb_data_account_get_name ( i );
+            if ( !account_name )
+                account_name = _("Unnamed account");
 
-	    if ( gsb_gui_navigation_get_current_account () == i )
-		gtk_action_set_sensitive ( action, FALSE );
+            action = gtk_action_new ( tmp_name, account_name, "", "" );
 
-	    gtk_action_group_add_action ( action_group, action );
+            if ( gsb_gui_navigation_get_current_account () == i )
+                gtk_action_set_sensitive ( action, FALSE );
 
-	    g_signal_connect ( action, "activate", 
-			       G_CALLBACK(move_selected_operation_to_account_nb), 
-			       GINT_TO_POINTER(i) );
-	    gtk_ui_manager_add_ui ( ui_manager, recent_files_merge_id, 
-				    "/menubar/EditMenu/MoveToAnotherAccount/",
-				    tmp_name, tmp_name,
-				    GTK_UI_MANAGER_MENUITEM, FALSE );
-	    g_free ( tmp_name );
-	}
+            gtk_action_group_add_action ( action_group, action );
+            g_signal_connect ( action,
+                        "activate",
+                        G_CALLBACK ( move_selected_operation_to_account_nb ),
+                        GINT_TO_POINTER ( i ) );
 
-	list_tmp = list_tmp -> next;
+            gtk_ui_manager_add_ui ( ui_manager,
+                        move_to_account_merge_id,
+                        "/menubar/EditMenu/MoveToAnotherAccount/",
+                        tmp_name,
+                        tmp_name,
+                        GTK_UI_MANAGER_MENUITEM,
+                        FALSE );
+            g_object_unref ( G_OBJECT ( action ) );
+            g_free ( tmp_name );
+        }
+
+        list_tmp = list_tmp -> next;
     }
 
     gtk_ui_manager_insert_action_group ( ui_manager, action_group, 2 );
     gtk_ui_manager_ensure_update ( ui_manager );
+    g_object_unref ( G_OBJECT ( action_group ) );
 
     return FALSE;
 }
@@ -872,18 +809,39 @@ gboolean gsb_menu_update_accounts_in_menus ( void )
 
  * \param sensitive	Sensitiveness (FALSE for unsensitive, TRUE for
  *			sensitive).
- * 
+ *
  * \return		FALSE
  */
-gboolean gsb_menu_transaction_operations_set_sensitive ( gboolean sensitive )
+gboolean gsb_menu_set_menus_select_transaction_sensitive ( gboolean sensitive )
 {
     devel_debug ( sensitive ? "item sensitive" : "item unsensitive" );
 
-    gsb_gui_sensitive_menu_item ( "EditMenu", "RemoveTransaction", NULL, sensitive );
-    gsb_gui_sensitive_menu_item ( "EditMenu", "CloneTransaction", NULL, sensitive );
-    gsb_gui_sensitive_menu_item ( "EditMenu", "EditTransaction", NULL, sensitive );
-    gsb_gui_sensitive_menu_item ( "EditMenu", "ConvertToScheduled", NULL, sensitive );
-    gsb_gui_sensitive_menu_item ( "EditMenu", "MoveToAnotherAccount", NULL, sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/EditTransaction", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/RemoveTransaction", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/TemplateTransaction", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/CloneTransaction", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/ConvertToScheduled", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/MoveToAnotherAccount", sensitive );
+
+    return FALSE;
+}
+
+
+/**
+ * Set sensitiveness of all menu items that work on the selected scheduled.
+
+ * \param sensitive	Sensitiveness (FALSE for unsensitive, TRUE for
+ *			sensitive).
+ *
+ * \return		FALSE
+ */
+gboolean gsb_menu_set_menus_select_scheduled_sensitive ( gboolean sensitive )
+{
+    devel_debug ( sensitive ? "item sensitive" : "item unsensitive" );
+
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/EditTransaction", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/RemoveTransaction", sensitive );
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/CloneTransaction", sensitive );
 
     return FALSE;
 }
@@ -901,6 +859,22 @@ GtkUIManager *gsb_menu_get_ui_manager ( void )
 }
 
 
+/**
+ *
+ *
+ *
+ *
+ **/
+void gsb_menu_free_ui_manager ( void )
+{
+    if ( ! ui_manager )
+        return;
+
+    g_object_unref ( G_OBJECT ( ui_manager ) );
+    ui_manager = NULL;
+}
+
+
 /**
  *
  *
@@ -930,6 +904,116 @@ gboolean gsb_menu_reinit_largeur_col_menu ( void )
 }
 
 
+/**
+ *
+ *
+ *
+ */
+gboolean gsb_menu_set_block_menu_cb ( gboolean etat )
+{
+
+    block_menu_cb = etat;
+
+    return FALSE;
+}
+
+
+/**
+ * Initialise la barre de menus en fonction de la présence ou non d'un fichier de comptes
+ *
+ * \param sensitif
+ *
+ * \return
+ * */
+void gsb_menu_set_menus_with_file_sensitive ( gboolean sensitive )
+{
+    gchar * items[] = {
+        "/menubar/FileMenu/Save",
+        "/menubar/FileMenu/SaveAs",
+        "/menubar/FileMenu/DebugFile",
+        "/menubar/FileMenu/Obfuscate",
+        "/menubar/FileMenu/DebugMode",
+        "/menubar/FileMenu/ExportFile",
+        "/menubar/FileMenu/CreateArchive",
+        "/menubar/FileMenu/ExportArchive",
+        "/menubar/FileMenu/Close",
+        "/menubar/EditMenu/NewTransaction",
+        "/menubar/EditMenu/RemoveTransaction",
+        "/menubar/EditMenu/TemplateTransaction",
+        "/menubar/EditMenu/CloneTransaction",
+        "/menubar/EditMenu/EditTransaction",
+        "/menubar/EditMenu/ConvertToScheduled",
+        "/menubar/EditMenu/MoveToAnotherAccount",
+        "/menubar/EditMenu/Preferences",
+        "/menubar/EditMenu/RemoveAccount",
+        "/menubar/EditMenu/NewAccount",
+        "/menubar/ViewMenu/ShowTransactionForm",
+        "/menubar/ViewMenu/ShowReconciled",
+        "/menubar/ViewMenu/ShowArchived",
+        "/menubar/ViewMenu/ShowClosed",
+        "/menubar/ViewMenu/ShowOneLine",
+        "/menubar/ViewMenu/ShowTwoLines",
+        "/menubar/ViewMenu/ShowThreeLines",
+        "/menubar/ViewMenu/ShowFourLines",
+        "/menubar/ViewMenu/InitwidthCol",
+        NULL
+    };
+    gchar ** tmp = items;
+
+    devel_debug_int (sensitive);
+
+    while ( *tmp )
+    {
+        gsb_gui_sensitive_menu_item ( *tmp, sensitive );
+        tmp++;
+    }
+
+    /* As this function may only be called when a new account is
+     * created and the like, it is unlikely that we want to sensitive
+     * transaction-related menus. */
+    gsb_gui_sensitive_menu_item ( "/menubar/EditMenu/NewTransaction", FALSE );
+    gsb_menu_set_menus_select_transaction_sensitive ( FALSE );
+}
+
+/**
+ * Initialise la barre de menus si un compte est sélectionné
+ *
+ * \param sensitif
+ *
+ * \return
+ * */
+void gsb_menu_set_menus_view_account_sensitive ( gboolean sensitive )
+{
+    gchar * items[] = {
+        "/menubar/ViewMenu/ShowTransactionForm",
+        "/menubar/ViewMenu/ShowReconciled",
+        "/menubar/ViewMenu/ShowArchived",
+        "/menubar/ViewMenu/ShowOneLine",
+        "/menubar/ViewMenu/ShowTwoLines",
+        "/menubar/ViewMenu/ShowThreeLines",
+        "/menubar/ViewMenu/ShowFourLines",
+        "/menubar/ViewMenu/InitwidthCol",
+        NULL
+    };
+    gchar **tmp = items;
+
+    devel_debug_int (sensitive);
+
+    while ( *tmp )
+    {
+        gsb_gui_sensitive_menu_item ( *tmp, sensitive );
+        tmp++;
+    }
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
