@@ -25,7 +25,8 @@
 #endif
 
 #include "include.h"
-#include "metatree.h"
+#include <glib/gi18n.h>
+
 
 /*START_INCLUDE*/
 #include "meta_budgetary.h"
@@ -33,27 +34,26 @@
 #include "gsb_data_budget.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
-#include "utils_str.h"
 #include "gsb_real.h"
+#include "structures.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 
 /*START_STATIC*/
 static gint budgetary_line_add_div ();
 static gint budgetary_line_add_sub_div ( int div_id );
-static gboolean budgetary_line_add_transaction_to_div ( gint transaction_number, 
+static gboolean budgetary_line_add_transaction_to_div ( gint transaction_number,
 						 int div_id );
-static gchar * budgetary_line_div_name ( gint div );
+static gchar *budgetary_line_div_name ( gint div );
 static gint budgetary_line_get_without_div_pointer ( );
 static gsb_real budgetary_line_sub_div_balance ( gint div, gint sub_div );
-static gchar * budgetary_line_sub_div_name ( gint div, gint sub_div );
+static gchar *budgetary_line_sub_div_name ( gint div, gint sub_div );
 static gint budgetary_line_sub_div_nb_transactions ( gint div, gint sub_div );
 static gint budgetary_lint_get_number_by_name ( const gchar *name, gboolean create );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gint no_devise_totaux_ib;
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -102,7 +102,7 @@ static MetatreeInterface _budgetary_interface = {
     budgetary_hold_position_set_expand,
 };
 
-MetatreeInterface * budgetary_interface = &_budgetary_interface;
+static MetatreeInterface *budgetary_interface = &_budgetary_interface;
 
 
 /**
@@ -111,7 +111,7 @@ MetatreeInterface * budgetary_interface = &_budgetary_interface;
  */
 gint budgetary_line_tree_currency ( )
 {
-    return no_devise_totaux_ib;
+    return etat.no_devise_totaux_ib;
 }
 
 
@@ -222,7 +222,7 @@ gint budgetary_line_add_div ()
     {
 	g_free (name);
 	i++;
-	name = g_strdup_printf ( _("New budget #%d"), i ); 
+	name = g_strdup_printf ( _("New budget #%d"), i );
     }
 
     new_budget_number = gsb_data_budget_get_number_by_name ( name, TRUE, 0 );
@@ -252,7 +252,7 @@ gint budgetary_line_add_sub_div ( int div_id )
     {
 	g_free (name);
 	i++;
-	name = g_strdup_printf ( _("New sub-budget #%d"), i ); 
+	name = g_strdup_printf ( _("New sub-budget #%d"), i );
     }
 
     new_sub_budget_number = gsb_data_budget_get_sub_budget_number_by_name ( div_id, name, TRUE );
@@ -264,10 +264,11 @@ gint budgetary_line_add_sub_div ( int div_id )
 
 
 /**
+ *
  *
  *
  */
-gboolean budgetary_line_add_transaction_to_div ( gint transaction_number, 
+gboolean budgetary_line_add_transaction_to_div ( gint transaction_number,
 						 int div_id )
 {
     gsb_data_budget_add_transaction_to_budget ( transaction_number,
@@ -276,3 +277,17 @@ gboolean budgetary_line_add_transaction_to_div ( gint transaction_number,
 }
 
 
+/**
+ *
+ *
+ *
+ */
+MetatreeInterface *budgetary_line_get_metatree_interface ( void )
+{
+    return budgetary_interface;
+}
+
+
+/* Local Variables: */
+/* c-basic-offset: 4 */
+/* End: */
