@@ -25,7 +25,7 @@
 #endif
 
 #include "include.h"
-#include "metatree.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "meta_categories.h"
@@ -34,15 +34,16 @@
 #include "gsb_data_category.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
-#include "utils_str.h"
 #include "gsb_real.h"
+#include "structures.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 
 /*START_STATIC*/
 static gint category_add_div ();
 static gint category_add_sub_div ( int div_id );
-static gboolean category_add_transaction_to_div ( gint transaction_number, 
+static gboolean category_add_transaction_to_div ( gint transaction_number,
 					   int div_id );
 static gchar *category_div_name ( gint div );
 static gint category_get_div_pointer_from_name ( const gchar * name, gboolean create );
@@ -56,8 +57,6 @@ static gint category_transaction_div_id ( gint transaction_number );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gint no_devise_totaux_categ;
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 static MetatreeInterface _category_interface = {
@@ -101,11 +100,11 @@ static MetatreeInterface _category_interface = {
     gsb_data_category_add_transaction_to_category,
     gsb_data_category_remove_transaction_from_category,
     gsb_data_category_remove_transaction_from_category,
-    category_hold_position_set_path,
-    category_hold_position_set_expand,
+    categories_hold_position_set_path,
+    categories_hold_position_set_expand,
 };
 
-MetatreeInterface * category_interface = &_category_interface;
+static MetatreeInterface *category_interface = &_category_interface;
 
 
 
@@ -116,7 +115,7 @@ MetatreeInterface * category_interface = &_category_interface;
  */
 gint category_tree_currency ( )
 {
-    return no_devise_totaux_categ;
+    return etat.no_devise_totaux_categ;
 }
 
 
@@ -234,7 +233,7 @@ gint category_transaction_div_id ( gint transaction_number )
     if (transaction_number)
     {
 	if ( gsb_data_transaction_get_contra_transaction_number (transaction_number) > 0
-	     || 
+	     ||
 	     gsb_data_transaction_get_split_of_transaction (transaction_number))
 	    return -1;
 	else
@@ -261,7 +260,7 @@ gboolean category_scheduled_set_div_id ( gint scheduled_number,
 							     0 );
     }
     /* TODO dOm : add the return instruction.
-     * Is not better for this function to return void ? */ 
+     * Is not better for this function to return void ? */
     return TRUE;
 }
 
@@ -283,7 +282,7 @@ gint category_add_div ( void )
     {
 	g_free (name);
 	i++;
-	name = g_strdup_printf ( _("New category #%d"), i ); 
+	name = g_strdup_printf ( _("New category #%d"), i );
     }
 
     new_category_number = gsb_data_category_get_number_by_name ( name, TRUE, 0 );
@@ -313,7 +312,7 @@ gint category_add_sub_div ( int div_id )
     {
 	g_free (name);
 	i++;
-	name = g_strdup_printf ( _("New sub-category #%d"), i ); 
+	name = g_strdup_printf ( _("New sub-category #%d"), i );
     }
 
     new_sub_category_number = gsb_data_category_get_sub_category_number_by_name ( div_id, name, TRUE );
@@ -330,7 +329,7 @@ gint category_add_sub_div ( int div_id )
  *
  *
  */
-gboolean category_add_transaction_to_div ( gint transaction_number, 
+gboolean category_add_transaction_to_div ( gint transaction_number,
 					   int div_id )
 {
     gsb_data_category_add_transaction_to_category ( transaction_number,
@@ -339,6 +338,20 @@ gboolean category_add_transaction_to_div ( gint transaction_number,
 }
 
 
+/**
+ *
+ *
+ *
+ */
+MetatreeInterface *category_get_metatree_interface ( void )
+{
+    return category_interface;
+}
+
+
+/* Local Variables: */
+/* c-basic-offset: 4 */
+/* End: */
 
 
 
