@@ -2,6 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2009 Benjamin Drieu (bdrieu@april.org)                       */
+/*            2008-2012 Pierre Biava (grisbi@pierre.biava.name)               */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -30,7 +31,7 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "parametres.h"
@@ -49,9 +50,12 @@
 #include "gsb_currency_config.h"
 #include "gsb_currency_link_config.h"
 #include "gsb_data_account.h"
+#include "gsb_data_partial_balance.h"
+#include "gsb_dirs.h"
 #include "gsb_file.h"
 #include "gsb_form_config.h"
 #include "gsb_fyear_config.h"
+#include "gsb_locale.h"
 #include "gsb_payment_method_config.h"
 #include "gsb_real.h"
 #include "gsb_reconcile_config.h"
@@ -69,12 +73,16 @@
 #include "utils.h"
 #include "utils_dates.h"
 #include "utils_files.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static GtkWidget *create_preferences_tree ( );
+static gboolean gsb_config_metatree_sort_transactions_changed ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gint *pointeur );
 static gboolean gsb_config_onglet_metatree_action_changed ( GtkWidget *checkbutton,
                         GdkEventButton *event,
                         gint *pointeur );
@@ -118,27 +126,298 @@ static gint width_spin_button = 50;
 
 /*START_EXTERN*/
 extern GtkWidget *account_page;
-extern GtkWidget *arbre_categ;
-extern GtkWidget *budgetary_line_tree;
 extern struct conditional_message delete_msg[];
-extern gboolean execute_scheduled_of_month;
 extern struct conditional_message messages[];
-extern gint mise_a_jour_liste_comptes_accueil;
 extern gchar *nom_fichier_comptes;
 extern gint nb_days_before_scheduled;
-extern gint nb_max_derniers_fichiers_ouverts;
-extern GtkWidget *payee_tree;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
+/**
+ * force le recalcul des soldes et la mise à jour de la page d'accueil
+ *
+ * \param   none
+ *
+ * \return  FALSE
+ * */
+static gboolean gsb_config_scheduler_switch_balances_with_scheduled ( void )
+{
+    GSList *list_tmp;
+
+    devel_debug ( NULL );
+
+    list_tmp = gsb_data_account_get_list_accounts ();
+
+    while ( list_tmp )
+    {
+        gint account_number;
+
+        account_number = gsb_data_account_get_no_account ( list_tmp -> data );
+        gsb_data_account_set_balances_are_dirty ( account_number );
+
+        /* MAJ HOME_PAGE */
+        gsb_gui_navigation_update_home_page ( );
+
+        list_tmp = list_tmp -> next;
+    }
+    return FALSE;
+}
+
+
+/**
+ * callback function for conf.group_partial_balance_under_account variable
+ *
+ * \param button        object clicked
+ * \param user_data
+ *
+ * \return              FALSE
+ * */
+static gboolean gsb_config_partial_balance_group_under_accounts_clicked ( GtkToggleButton *button,
+                        gpointer user_data )
+{
+    gsb_gui_navigation_update_home_page ();
+
+    return FALSE;
+}
+
+
+/**
+ * page de configuration pour la page d'accueil
+ *
+ * \param       none
+ *
+ * \ return     the widget for preferences
+ * */
+static GtkWidget *onglet_accueil ( void )
+{
+    GtkWidget *vbox_pref, *vbox, *paddingbox, *button;
+    GtkWidget *hbox, *vbox2, *sw, *treeview;
+    GtkListStore *list_store;
+    GtkTreeViewColumn *column;
+    GtkCellRenderer *cell;
+    GtkTreeSelection *selection;
+    GtkTreeDragDestIface * dst_iface;
+    GtkTreeDragSourceIface * src_iface;
+    static GtkTargetEntry row_targets[] = {
+    { "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
+    };
+
+    vbox_pref = new_vbox_with_title_and_icon ( _("Configuration of the main page"),
+                        "title.png" );
+
+    vbox = gtk_vbox_new ( FALSE, 12 );
+    gtk_box_pack_start ( GTK_BOX ( vbox_pref ), vbox, TRUE, TRUE, 0 );
+    gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 12 );
+
+    /* pour les francophones ;-) */
+    if ( g_strstr_len ( ( g_ascii_strup ( gdk_set_locale ( ), -1 ) ), -1, "FR" ) )
+    {
+        paddingbox = new_paddingbox_with_title (vbox, FALSE, "Pluriel de final" );
+
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ),
+                        gsb_automem_radiobutton_new ( "Soldes finals",
+                        "Soldes finaux",
+                        &conf.pluriel_final,
+                        G_CALLBACK (gsb_gui_navigation_update_home_page), NULL ),
+                        FALSE, FALSE, 0 );
+    }
+
+    /* Take into account the planned operations in the calculation of balances */
+    paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Calculation of balances") );
+
+    hbox = gtk_hbox_new ( FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
+
+    button = gsb_automem_checkbutton_new (
+                        _("Take into account the scheduled operations "
+                          "in the calculation of balances"),
+                        &conf.balances_with_scheduled,
+                        G_CALLBACK ( gsb_config_scheduler_switch_balances_with_scheduled ),
+                        NULL );
+
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
+
+    /* Data partial balance settings */
+    paddingbox = new_paddingbox_with_title (vbox, FALSE,
+                        _("Balances partials of the list of accounts") );
+
+    hbox = gtk_hbox_new ( FALSE, 5 );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, TRUE, TRUE, 5);
+
+    sw = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
+                        GTK_SHADOW_ETCHED_IN);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+                        GTK_POLICY_AUTOMATIC,
+                        GTK_POLICY_ALWAYS);
+    gtk_box_pack_start ( GTK_BOX (hbox), sw, TRUE,TRUE, 0 );
+
+    /* Create Add/Edit/Remove buttons */
+    vbox2 = gtk_vbox_new ( FALSE, 5 );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), vbox2, FALSE, FALSE, 0 );
+
+    /* Button "Add" */
+    button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+    g_signal_connect ( G_OBJECT ( button ),
+                        "clicked",
+                        G_CALLBACK  ( gsb_partial_balance_add ),
+                        vbox_pref );
+    gtk_box_pack_start ( GTK_BOX ( vbox2 ), button, FALSE, FALSE, 5 );
+    g_object_set_data ( G_OBJECT (vbox_pref), "add_button", button );
+
+    /* Button "Edit" */
+    button = gtk_button_new_from_stock (GTK_STOCK_EDIT);
+    g_signal_connect ( G_OBJECT ( button ),
+                        "clicked",
+                        G_CALLBACK  ( gsb_partial_balance_edit ),
+                        vbox_pref );
+    gtk_box_pack_start ( GTK_BOX ( vbox2 ), button, FALSE, FALSE, 5 );
+    gtk_widget_set_sensitive ( button, FALSE );
+    g_object_set_data ( G_OBJECT (vbox_pref), "edit_button", button );
+
+    /* Button "Remove" */
+    button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+    g_signal_connect ( G_OBJECT ( button ),
+                        "clicked",
+                        G_CALLBACK ( gsb_partial_balance_delete ),
+                        vbox_pref );
+    gtk_box_pack_start ( GTK_BOX ( vbox2 ), button, FALSE, FALSE, 5 );
+    gtk_widget_set_sensitive ( button, FALSE );
+    g_object_set_data ( G_OBJECT (vbox_pref), "remove_button", button );
+
+    /* create the model */
+    list_store = gsb_partial_balance_create_model ( );
+
+    /* populate the model if necessary */
+    if ( g_slist_length ( gsb_data_partial_balance_get_list ( ) ) > 0 )
+        gsb_partial_balance_fill_model ( list_store );
+
+    /* create the treeview */
+    treeview = gtk_tree_view_new_with_model (
+                        GTK_TREE_MODEL (list_store) );
+    g_object_unref ( list_store );
+
+    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
+    gtk_widget_set_size_request ( treeview, -1, 150 );
+
+    /* check the keys on the list */
+    g_signal_connect ( G_OBJECT ( treeview ),
+                        "key_press_event",
+                        G_CALLBACK ( gsb_partial_balance_key_press ),
+                        NULL );
+
+    /* check the buttons on the list */
+    g_signal_connect ( G_OBJECT ( treeview ),
+                        "button_press_event",
+                        G_CALLBACK ( gsb_partial_balance_button_press ),
+                        NULL );
+
+    /* Enable drag & drop */
+    gtk_tree_view_enable_model_drag_source ( GTK_TREE_VIEW (treeview),
+                        GDK_BUTTON1_MASK, row_targets, 1,
+                        GDK_ACTION_MOVE );
+    gtk_tree_view_enable_model_drag_dest ( GTK_TREE_VIEW (treeview), row_targets,
+                        1, GDK_ACTION_MOVE );
+    gtk_tree_view_set_reorderable ( GTK_TREE_VIEW (treeview), TRUE );
+
+    selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW (treeview) );
+    gtk_tree_selection_set_select_function ( selection,
+                        (GtkTreeSelectionFunc) gsb_partial_balance_select_func,
+                        vbox_pref, NULL );
+    gtk_container_add (GTK_CONTAINER (sw), treeview);
+    gtk_container_set_resize_mode (GTK_CONTAINER (sw), GTK_RESIZE_PARENT);
+    g_object_set_data ( G_OBJECT (vbox_pref), "treeview", treeview );
+
+    /* Nom du solde partiel */
+    cell = gtk_cell_renderer_text_new ( );
+    column = gtk_tree_view_column_new_with_attributes ( _("Name"),
+                        cell, "text", 0, NULL);
+    gtk_tree_view_column_set_expand ( column, TRUE );
+    gtk_tree_view_column_set_alignment ( column, 0.5 );
+    gtk_tree_view_column_set_sort_column_id (column, 0);
+    gtk_tree_view_append_column ( GTK_TREE_VIEW (treeview), column);
+
+    /* Liste des comptes */
+    cell = gtk_cell_renderer_text_new ( );
+    column = gtk_tree_view_column_new_with_attributes ( _("Accounts list"),
+                        cell, "text", 1, NULL);
+    gtk_tree_view_column_set_expand ( column, TRUE );
+    gtk_tree_view_column_set_alignment ( column, 0.5 );
+    gtk_tree_view_column_set_sort_column_id (column, 1);
+    gtk_tree_view_append_column ( GTK_TREE_VIEW (treeview), column);
+
+    /* Colorize */
+    cell = gtk_cell_renderer_toggle_new ( );
+    g_signal_connect ( cell,
+                        "toggled",
+                        G_CALLBACK ( gsb_partial_balance_colorise_toggled ),
+                        treeview );
+    gtk_cell_renderer_toggle_set_radio ( GTK_CELL_RENDERER_TOGGLE(cell), FALSE );
+    g_object_set (cell, "xalign", 0.5, NULL);
+
+    column = gtk_tree_view_column_new_with_attributes ( _("Colorize"),
+                        cell,
+                        "active", 5,
+                        NULL);
+    gtk_tree_view_append_column ( GTK_TREE_VIEW(treeview), column);
+
+    /* Type de compte */
+    cell = gtk_cell_renderer_text_new ( );
+    column = gtk_tree_view_column_new_with_attributes ( _("Account kind"),
+                        cell, "text", 2, NULL);
+    gtk_tree_view_column_set_expand ( column, TRUE );
+    gtk_tree_view_column_set_alignment ( column, 0.5 );
+    gtk_tree_view_column_set_sort_column_id (column, 2);
+    gtk_tree_view_append_column ( GTK_TREE_VIEW (treeview), column);
+
+    /* Devise */
+    cell = gtk_cell_renderer_text_new ( );
+    column = gtk_tree_view_column_new_with_attributes ( _("Currency"),
+                        cell, "text", 3, NULL);
+    gtk_tree_view_column_set_expand ( column, TRUE );
+    gtk_tree_view_column_set_alignment ( column, 0.5 );
+    gtk_tree_view_column_set_sort_column_id (column, 3);
+    gtk_tree_view_append_column ( GTK_TREE_VIEW (treeview), column);
+
+    dst_iface = GTK_TREE_DRAG_DEST_GET_IFACE ( list_store );
+    if ( dst_iface )
+        dst_iface -> drag_data_received = &gsb_data_partial_balance_drag_data_received;
+
+    src_iface = GTK_TREE_DRAG_SOURCE_GET_IFACE ( list_store );
+    if ( src_iface )
+    {
+        gtk_selection_add_target ( treeview,
+                      GDK_SELECTION_PRIMARY,
+                      GDK_SELECTION_TYPE_ATOM,
+                      1 );
+        src_iface -> drag_data_get = &gsb_data_partial_balance_drag_data_get;
+    }
+
+    /* mettre les soldes partiels sous les comptes si possibles */
+    hbox = gtk_hbox_new ( FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
+
+    button = gsb_automem_checkbutton_new (
+                        _("Place the partial balance  under its accounts if it's possible"),
+                        &conf.group_partial_balance_under_accounts,
+                        G_CALLBACK ( gsb_config_partial_balance_group_under_accounts_clicked ),
+                        NULL );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
+
+    gtk_widget_show_all ( vbox_pref );
+
+    return ( vbox_pref );
+}
+
+
+
 /**
  * Creates a simple TreeView and a TreeModel to handle preference
  * tabs.  Sets preference_tree_model to the newly created TreeModel.
  *
  * \return a GtkScrolledWindow
  */
-GtkWidget * create_preferences_tree ( )
+GtkWidget *create_preferences_tree ( )
 {
     GtkWidget *sw;
     GtkTreeViewColumn *column;
@@ -179,7 +458,7 @@ GtkWidget * create_preferences_tree ( )
 
     /* Handle select */
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
-    g_signal_connect (selection, 
+    g_signal_connect (selection,
                         "changed",
                         (GCallback) selectionne_liste_preference,
                         preference_tree_model);
@@ -193,7 +472,7 @@ GtkWidget * create_preferences_tree ( )
     gtk_container_add (GTK_CONTAINER (sw), tree_view);
 
     /* expand all rows after the treeview widget has been realized */
-    g_signal_connect ( tree_view, 
+    g_signal_connect ( tree_view,
                         "realize",
                         (GCallback) gtk_tree_view_expand_all,
                         NULL );
@@ -262,7 +541,7 @@ gboolean preferences ( gint page )
 
     /* Create dialog */
     fenetre_preferences = gtk_dialog_new_with_buttons (_("Grisbi preferences"),
-                        GTK_WINDOW ( window ),
+                        GTK_WINDOW ( run.window ),
                         GTK_DIALOG_MODAL,
                         GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                         NULL );
@@ -332,7 +611,7 @@ gboolean preferences ( gint page )
                         1, IMPORT_ASSOCIATION_PAGE,
                         2, 400,
                         -1);
-    gtk_notebook_append_page (preference_frame, 
+    gtk_notebook_append_page (preference_frame,
                         gsb_import_associations_gere_tiers (), NULL);
 
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
@@ -419,7 +698,7 @@ gboolean preferences ( gint page )
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
     gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
                         &iter2,
-                        0, _("Toolbars"),
+                        0, _("Elements of interface"),
                         1, TOOLBARS_PAGE,
                         2, 400,
                         -1);
@@ -444,6 +723,16 @@ gboolean preferences ( gint page )
     gtk_notebook_append_page (preference_frame,
                         GTK_WIDGET(onglet_affichage_operations()), NULL);
 
+    gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
+    gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
+                        &iter2,
+                        0, _("Transactions list cells"),
+                        1, TRANSACTIONS_CELLULES_PAGE,
+                        2, 400,
+                        -1);
+    gtk_notebook_append_page (preference_frame,
+                        GTK_WIDGET ( onglet_affichage_liste ( ) ), NULL );
+
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
     gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
                         &iter2,
@@ -656,12 +945,12 @@ GtkWidget *onglet_messages_and_warnings ( void )
 
     /* Display or not tips */
     tip_checkbox = gsb_automem_checkbutton_new ( _("Display tip of the day"),
-                        &(etat.show_tip),
+                        &(conf.show_tip),
                         NULL, NULL );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), tip_checkbox, FALSE, FALSE, 0 );
 
     /* Warnings */
-    paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE, 
+    paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE,
                         _("Display following warnings messages") );
 
     model = GTK_TREE_MODEL(gtk_tree_store_new ( 3, G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT ) );
@@ -695,8 +984,6 @@ GtkWidget *onglet_messages_and_warnings ( void )
                         g_path_get_basename ( nom_fichier_comptes ) );
         else if ( g_utf8_collate ( messages[i].name, "development-version" ) == 0 )
             tmpstr = g_strdup_printf ( _(messages[i] . hint), VERSION );
-        else if ( g_utf8_collate ( messages[i].name, "gtk_obsolete" ) == 0 )
-            tmpstr = g_strdup_printf ( _(messages[i] . hint), get_gtk_run_version ( ) );
         else
             tmpstr = g_strdup ( _(messages[i] . hint) );
 
@@ -739,7 +1026,7 @@ GtkWidget *onglet_delete_messages ( void )
     vbox_pref = new_vbox_with_title_and_icon ( _("Messages before deleting"), "delete.png" );
 
     /* Delete messages */
-    paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE, 
+    paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE,
                         _("Display following messages") );
 
     model = GTK_TREE_MODEL(gtk_tree_store_new ( 3, G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT ) );
@@ -895,7 +1182,7 @@ GtkWidget *onglet_fichier ( void )
     label = gtk_label_new ( _("Memorise last opened files: ") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
-    button = gsb_automem_spin_button_new ( &(nb_max_derniers_fichiers_ouverts),
+    button = gsb_automem_spin_button_new ( &conf.nb_max_derniers_fichiers_ouverts,
                         G_CALLBACK ( affiche_derniers_fichiers_ouverts ), NULL );
     gtk_widget_set_size_request ( button, width_spin_button, -1 );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
@@ -950,7 +1237,7 @@ GtkWidget *onglet_fichier ( void )
     /* on passe par une fonction intermédiaire pour pallier à un bug
      * du gtk_file_chooser_button_new qui donne le répertoire home
      * lorsque l'on annule le choix du nouveau répertoire */
-    dialog = utils_files_create_file_chooser ( window,
+    dialog = utils_files_create_file_chooser ( run.window,
                         _("Select/Create backup directory") );
 
     button = gtk_file_chooser_button_new_with_dialog ( dialog );
@@ -959,7 +1246,7 @@ GtkWidget *onglet_fichier ( void )
                         gsb_file_get_backup_path ());
     else
         gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER (button),
-                        my_get_XDG_grisbi_data_dir () );
+                        gsb_dirs_get_user_data_dir () );
     g_signal_connect ( G_OBJECT (button),
                         "selection-changed",
                         G_CALLBACK ( gsb_config_backup_dir_chosen ),
@@ -1027,8 +1314,7 @@ gboolean gsb_config_backup_dir_chosen ( GtkWidget *button,
     if ( path && strlen ( path ) > 0 )
         g_free ( path );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -1050,7 +1336,7 @@ GtkWidget *onglet_programmes (void)
 
     paddingbox = new_paddingbox_with_title (vbox_pref, FALSE, _("Web"));
 
-    table = gtk_table_new ( 0, 2, FALSE );
+    table = gtk_table_new ( 0, 1, FALSE );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 0 );
     gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
     gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
@@ -1063,8 +1349,8 @@ GtkWidget *onglet_programmes (void)
     entry = gsb_automem_entry_new ( &conf.browser_command, NULL, NULL );
     gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
 
-    text = make_blue ( g_strconcat ( 
-                        _("You may use %s to expand the URL I.e:\n'firefox -remote %s'"),
+    text = make_blue ( g_strconcat (
+                        _("You may use %s to expand the URL - I.e: 'firefox %s' "),
                         NULL ) );
     label = gtk_label_new ( text );
     gtk_label_set_use_markup ( GTK_LABEL(label), TRUE );
@@ -1074,31 +1360,6 @@ GtkWidget *onglet_programmes (void)
     g_free ( text );
 
 
-    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE,
-                        _("LaTeX support (old print system)") );
-
-    table = gtk_table_new ( 0, 2, FALSE );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 0 );
-    gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
-    gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
-
-    label = gtk_label_new ( _("LaTeX command: ") );
-    gtk_size_group_add_widget ( size_group, label );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 0, 1,
-                        GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0 );
-    entry = gsb_automem_entry_new ( &conf.latex_command, NULL, NULL );
-    gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
-
-    label = gtk_label_new ( _("dvips command: ") );
-    gtk_size_group_add_widget ( size_group, label );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 1, 2,
-                        GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0 );
-    entry = gsb_automem_entry_new ( &conf.dvips_command, NULL, NULL );
-    gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 1, 2, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
-
-
     gtk_size_group_set_mode ( size_group, GTK_SIZE_GROUP_HORIZONTAL );
     gtk_widget_show_all ( vbox_pref );
 
@@ -1133,7 +1394,7 @@ static GtkWidget *gsb_config_scheduler_page ( void )
                         _("Scheduler warnings at Grisbi's opening"),
                         _("Warn/Execute the scheduled transactions arriving at expiration date"),
                         _("Warn/Execute the scheduled transactions of the month"),
-                        &execute_scheduled_of_month,
+                        &conf.execute_scheduled_of_month,
                         NULL, NULL );
 
     hbox = gtk_hbox_new ( FALSE, 0);
@@ -1162,8 +1423,9 @@ static GtkWidget *gsb_config_scheduler_page ( void )
 GtkWidget *onglet_metatree ( void )
 {
     GtkWidget *vbox_pref, *paddingbox, *total_currencies;
+    GtkWidget *check_button;
 
-    vbox_pref = new_vbox_with_title_and_icon ( 
+    vbox_pref = new_vbox_with_title_and_icon (
                         _("Payees, categories and budgetaries"),
                         "organization.png" );
 
@@ -1171,6 +1433,15 @@ GtkWidget *onglet_metatree ( void )
     total_currencies = gsb_currency_config_create_totals_page ( );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), total_currencies, FALSE, FALSE, 0 );
 
+    /* calcul des totaux */
+    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE, _("Calculation of totals") );
+    check_button = gsb_automem_checkbutton_new (
+                        _("Add transactions archived in the totals"),
+                        &etat.add_archive_in_total_balance,
+                        G_CALLBACK ( gsb_config_metatree_re_sort_divisions ),
+                        NULL);
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), check_button, FALSE, FALSE, 0 );
+
     /* tri des opérations */
     gsb_automem_radiobutton3_new_with_title ( vbox_pref,
                         _("Sort option for transactions"),
@@ -1183,13 +1454,13 @@ GtkWidget *onglet_metatree ( void )
                         GTK_ORIENTATION_VERTICAL );
 
     gsb_automem_radiobutton3_new_with_title ( vbox_pref,
-						_("Choice of the action for double click of the mouse: "),
+                        _("Action associated with a double click on a subdivision: "),
                         _("Expand the line"),
                         _("Edit the line"),
                         _("Manage the line"),
-					    &conf.metatree_action_2button_press,
-					    G_CALLBACK ( gsb_config_onglet_metatree_action_changed ),
-					    &conf.metatree_action_2button_press,
+                        &conf.metatree_action_2button_press,
+                        G_CALLBACK ( gsb_config_onglet_metatree_action_changed ),
+                        &conf.metatree_action_2button_press,
                         GTK_ORIENTATION_VERTICAL );
 
     return vbox_pref;
@@ -1197,21 +1468,19 @@ GtkWidget *onglet_metatree ( void )
 
 
 /**
+ * Cette fonction est appellée suite au changement de l'ordre de tri des opérations
+ * dans les divisions.
  *
+ * \param
+ * \param
+ * \param
  *
- *
- *
+ * \return FALSE
  * */
 gboolean gsb_config_metatree_sort_transactions_changed ( GtkWidget *checkbutton,
                         GdkEventButton *event,
                         gint *pointeur )
 {
-    GtkTreeSelection *selection;
-    GtkTreeModel *model;
-    GtkTreeIter iter;
-    GtkTreePath *path = NULL;
-    gint page_number;
-
     if ( pointeur )
     {
         gint value = 0;
@@ -1220,49 +1489,82 @@ gboolean gsb_config_metatree_sort_transactions_changed ( GtkWidget *checkbutton,
         *pointeur = value;
     }
 
+    gsb_config_metatree_re_sort_divisions ( checkbutton, event, pointeur );
+
+    /* return */
+    return FALSE;
+}
+
+
+/**
+ * Cette fonction retrie la division affichée après un changement
+ *
+ * \param
+ * \param
+ * \param
+ *
+ * \return TRUE if OK else FALSE
+ * */
+gboolean gsb_config_metatree_re_sort_divisions ( GtkWidget *checkbutton,
+                        GdkEventButton *event,
+                        gpointer data )
+{
+    GtkWidget *division_tree;
+    GtkTreeSelection *selection;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    GtkTreePath *path = NULL;
+    gint page_number;
+
     page_number = gsb_gui_navigation_get_current_page ( );
 
     switch ( page_number )
     {
-	case GSB_PAYEES_PAGE:
-        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( payee_tree ) );
-        if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
-            path = gtk_tree_model_get_path ( model, &iter );
-		payee_fill_tree ();
-        gtk_tree_path_up ( path );
-        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), path );
-        gtk_tree_path_free ( path );
-	    break;
+        case GSB_PAYEES_PAGE:
+            division_tree = payees_get_tree_view ( );
 
-	case GSB_CATEGORIES_PAGE:
-        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( arbre_categ ) );
-        if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
-            path = gtk_tree_model_get_path ( model, &iter );
-        remplit_arbre_categ ();
-        gtk_tree_path_up ( path );
-        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), path );
-        gtk_tree_path_free ( path );
-	    break;
+            selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( division_tree ) );
+            if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
+                path = gtk_tree_model_get_path ( model, &iter );
+            payees_fill_list ();
+            break;
 
-	case GSB_BUDGETARY_LINES_PAGE:
-        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( budgetary_line_tree ) );
-        if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
-            path = gtk_tree_model_get_path ( model, &iter );
-		remplit_arbre_imputation ();
-        gtk_tree_path_up ( path );
-        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), path );
-        gtk_tree_path_free ( path );
-	    break;
+        case GSB_CATEGORIES_PAGE:
+            division_tree = categories_get_tree_view ( );
 
-	default:
-	    notice_debug ("B0rk page selected");
-	    break;
+            selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( division_tree ) );
+            if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
+                path = gtk_tree_model_get_path ( model, &iter );
+            categories_fill_list ();
+            break;
+
+        case GSB_BUDGETARY_LINES_PAGE:
+            division_tree = budgetary_lines_get_tree_view ( );
+
+            selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( division_tree ) );
+            if ( gtk_tree_selection_get_selected ( selection, &model, &iter ) )
+                path = gtk_tree_model_get_path ( model, &iter );
+            budgetary_lines_fill_list ();
+            break;
+
+        default:
+            notice_debug ("Not page selected");
+
+            return FALSE;
+            break;
     }
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    if ( path )
+    {
+        gtk_tree_path_up ( path );
+        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( division_tree ), path );
+        gtk_tree_path_free ( path );
+    }
 
-    return FALSE;
+    gsb_file_set_modified ( TRUE );
+
+    /* return */
+    return TRUE;
 }
 
 
@@ -1274,16 +1576,12 @@ gboolean gsb_config_metatree_sort_transactions_changed ( GtkWidget *checkbutton,
  * */
 GtkWidget *onglet_localisation ( void )
 {
-    GtkWidget *vbox_pref, *paddingbox;
-
+    GtkWidget *vbox_pref;
 
     vbox_pref = new_vbox_with_title_and_icon ( _("Localization"), "locale.png" );
 
-/*    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE, _("Choose Language") ); */
-
-    paddingbox = gsb_config_date_format_chosen ( vbox_pref, GTK_ORIENTATION_VERTICAL );
-
-    paddingbox = gsb_config_number_format_chosen ( vbox_pref, GTK_ORIENTATION_VERTICAL );
+    gsb_config_date_format_chosen ( vbox_pref, GTK_ORIENTATION_VERTICAL );
+    gsb_config_number_format_chosen ( vbox_pref, GTK_ORIENTATION_VERTICAL );
 
     return vbox_pref;
 }
@@ -1298,10 +1596,10 @@ GtkWidget *onglet_localisation ( void )
 GtkWidget *gsb_config_date_format_chosen ( GtkWidget *parent, gint sens )
 {
     GtkWidget *hbox, *paddingbox;
-    GtkWidget *button_1, *button_2;
+    GtkWidget *button_1, *button_2, *button_3;
     gchar *format_date;
 
-    button_1 =gtk_radio_button_new_with_label ( NULL, "dd/mm/yyyy" );
+    button_1 = gtk_radio_button_new_with_label ( NULL, "dd/mm/yyyy" );
     format_date = g_strdup ( "%d/%m/%Y" );
     g_object_set_data_full ( G_OBJECT ( button_1 ),
                         "pointer",
@@ -1317,11 +1615,21 @@ GtkWidget *gsb_config_date_format_chosen ( GtkWidget *parent, gint sens )
                         format_date,
                         g_free );
 
+    button_3 = gtk_radio_button_new_with_label ( gtk_radio_button_get_group (
+                        GTK_RADIO_BUTTON ( button_1 ) ),
+                        "dd.mm.yyyy" );
+    format_date = g_strdup ( "%d.%m.%Y" );
+    g_object_set_data_full ( G_OBJECT ( button_3 ),
+                        "pointer",
+                        format_date,
+                        g_free );
+
     if ( sens == GTK_ORIENTATION_VERTICAL )
     {
         paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Choose the date format") );
         gtk_box_pack_start ( GTK_BOX ( paddingbox ), button_1, FALSE, FALSE, 0 );
         gtk_box_pack_start ( GTK_BOX ( paddingbox ), button_2, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), button_3, FALSE, FALSE, 0 );
     }
     else
     {
@@ -1330,12 +1638,19 @@ GtkWidget *gsb_config_date_format_chosen ( GtkWidget *parent, gint sens )
         gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
         gtk_box_pack_start ( GTK_BOX ( hbox ), button_1, FALSE, FALSE, 0 );
         gtk_box_pack_start ( GTK_BOX ( hbox ), button_2, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( hbox ), button_3, FALSE, FALSE, 0 );
     }
 
     format_date = gsb_date_get_format_date ( );
-    if ( format_date && strcmp ( format_date, "%m/%d/%Y" ) == 0 )
-        gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button_2 ), TRUE );
-    g_free ( format_date );
+    if ( format_date )
+    {
+        if ( strcmp ( format_date, "%m/%d/%Y" ) == 0 )
+            gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button_2 ), TRUE );
+        else if ( strcmp ( format_date, "%d.%m.%Y" ) == 0 )
+            gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button_3 ), TRUE );
+
+        g_free ( format_date );
+    }
 
     g_signal_connect ( G_OBJECT ( button_1 ),
                         "button-release-event",
@@ -1346,6 +1661,10 @@ GtkWidget *gsb_config_date_format_chosen ( GtkWidget *parent, gint sens )
                         G_CALLBACK ( gsb_localisation_format_date_toggle ),
                         GINT_TO_POINTER ( sens ) );
 
+    g_signal_connect ( G_OBJECT ( button_3 ),
+                        "button-release-event",
+                        G_CALLBACK ( gsb_localisation_format_date_toggle ),
+                        GINT_TO_POINTER ( sens ) );
     return paddingbox;
 }
 
@@ -1434,14 +1753,14 @@ GtkWidget *gsb_config_number_format_chosen ( GtkWidget *parent, gint sens )
         gtk_box_pack_start ( GTK_BOX ( hbox ), thou_hbox, FALSE, FALSE, 0 );
     }
 
-    mon_decimal_point = gsb_real_get_decimal_point ( );
+    mon_decimal_point = gsb_locale_get_mon_decimal_point ( );
     if ( strcmp ( mon_decimal_point, "," ) == 0 )
         gtk_combo_box_set_active ( GTK_COMBO_BOX ( dec_sep ), 1 );
     else
         gtk_combo_box_set_active ( GTK_COMBO_BOX ( dec_sep ), 0 );
     g_free ( mon_decimal_point );
 
-    mon_thousands_sep = gsb_real_get_thousands_sep ( );
+    mon_thousands_sep = gsb_locale_get_mon_thousands_sep ( );
     if ( mon_thousands_sep == NULL )
         gtk_combo_box_set_active ( GTK_COMBO_BOX ( thou_sep ), 3 );
     else if ( strcmp ( mon_thousands_sep, "." ) == 0 )
@@ -1488,27 +1807,27 @@ void gsb_localisation_decimal_point_changed ( GtkComboBox *widget, gpointer user
 
     if ( g_strcmp0 ( text, "," ) == 0 )
     {
-        gsb_real_set_decimal_point ( "," );
+        gsb_locale_set_mon_decimal_point ( "," );
 
         if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "," ) == 0 )
         {
-            gsb_real_set_thousands_sep ( " " );
+            gsb_locale_set_mon_thousands_sep ( " " );
             gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 0 );
         }
     }
     else
     {
-        gsb_real_set_decimal_point ( "." );
+        gsb_locale_set_mon_decimal_point ( "." );
         if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "." ) == 0 )
         {
-            gsb_real_set_thousands_sep ( "," );
+            gsb_locale_set_mon_thousands_sep ( "," );
             gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 2 );
         }
     }
 
     /* reset capital */
     entry = bet_finance_get_capital_entry ( );
-    str_capital = gsb_real_get_string_with_currency ( gsb_real_double_to_real (
+    str_capital = utils_real_get_string_with_currency ( gsb_real_double_to_real (
                     etat.bet_capital ),
                     etat.bet_currency,
                     FALSE );
@@ -1538,37 +1857,37 @@ void gsb_localisation_thousands_sep_changed ( GtkComboBox *widget, gpointer user
 
     text = gtk_combo_box_get_active_text ( widget );
     combo_box = g_object_get_data ( G_OBJECT ( widget ), "separator" );
-    
+
     if ( g_strcmp0 ( text, "' '" ) == 0 )
     {
-        gsb_real_set_thousands_sep ( " " );
+        gsb_locale_set_mon_thousands_sep ( " " );
     }
     else if ( g_strcmp0 ( text, "." ) == 0 )
     {
 
-        gsb_real_set_thousands_sep ( "." );
+        gsb_locale_set_mon_thousands_sep ( "." );
         if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "." ) == 0 )
         {
-            gsb_real_set_decimal_point ( "," );
+            gsb_locale_set_mon_decimal_point ( "," );
             gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 1 );
         }
     }
     else if ( g_strcmp0 ( text, "," ) == 0 )
     {
 
-        gsb_real_set_thousands_sep ( "," );
+        gsb_locale_set_mon_thousands_sep ( "," );
         if ( g_strcmp0 ( gtk_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) ), "," ) == 0 )
         {
-            gsb_real_set_decimal_point ( "." );
+            gsb_locale_set_mon_decimal_point ( "." );
             gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo_box ), 0 );
         }
     }
     else
-        gsb_real_set_thousands_sep ( NULL );
+        gsb_locale_set_mon_thousands_sep ( NULL );
 
     /* reset capital */
     entry = bet_finance_get_capital_entry ( );
-    str_capital = gsb_real_get_string_with_currency ( gsb_real_double_to_real (
+    str_capital = utils_real_get_string_with_currency ( gsb_real_double_to_real (
                     etat.bet_capital ),
                     etat.bet_currency,
                     FALSE );
@@ -1599,7 +1918,7 @@ void gsb_localisation_update_affichage ( gint type_maj )
     if ( current_page == GSB_HOME_PAGE )
         mise_a_jour_accueil ( TRUE );
     else
-        mise_a_jour_liste_comptes_accueil = TRUE;
+        run.mise_a_jour_liste_comptes_accueil = TRUE;
 
     /* update sheduled liste */
     gsb_scheduler_list_fill_list ( gsb_scheduler_list_get_tree_view ( ) );
@@ -1632,6 +1951,8 @@ void gsb_localisation_update_affichage ( gint type_maj )
         kind = gsb_data_account_get_kind ( account_number );
         switch ( kind )
         {
+            case GSB_TYPE_BALANCE:
+                break;
             case GSB_TYPE_BANK:
             case GSB_TYPE_CASH:
                 if ( account_current_page == 1 || account_current_page == 2 )
@@ -1651,11 +1972,11 @@ void gsb_localisation_update_affichage ( gint type_maj )
 
     /* update payees, categories and budgetary lines */
     if ( current_page == GSB_PAYEES_PAGE )
-        payee_fill_tree ( );
+        payees_fill_list ( );
     else if ( current_page == GSB_CATEGORIES_PAGE )
-        remplit_arbre_categ ( );
+        categories_fill_list ( );
     else if ( current_page == GSB_BUDGETARY_LINES_PAGE )
-        remplit_arbre_imputation ( );
+        budgetary_lines_fill_list ( );
 
     /* update simulator page */
     if ( current_page == GSB_SIMULATOR_PAGE )
@@ -1678,8 +1999,7 @@ gboolean gsb_config_onglet_metatree_action_changed ( GtkWidget *checkbutton,
 
         value = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
         *pointeur = value;
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     return FALSE;
