@@ -25,14 +25,15 @@
 
 #include "include.h"
 
+#include <glib/gi18n.h>
 #include <libxml/parser.h>
+#include <glib/gstdio.h>
 
 /*START_INCLUDE*/
 #include "gnucash.h"
 #include "dialog.h"
 #include "gsb_data_transaction.h"
 #include "gsb_real.h"
-#include "import.h"
 #include "utils_str.h"
 #include "utils_files.h"
 #include "erreur.h"
@@ -46,8 +47,8 @@ static gchar * child_content ( xmlNodePtr node, gchar * child_name );
 static struct struct_compte_importation * find_imported_account_by_name ( gchar * name );
 static struct struct_compte_importation * find_imported_account_by_uid ( gchar * guid );
 static struct gnucash_category * find_imported_categ_by_uid ( gchar * guid );
-static struct gnucash_split * find_split ( GSList * split_list, gsb_real amount, 
-				    struct struct_compte_importation * account, 
+static struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
+				    struct struct_compte_importation * account,
 				    struct gnucash_category * categ );
 static xmlNodePtr get_child ( xmlNodePtr node, gchar * child_name );
 static gchar * get_currency ( xmlNodePtr currency_node );
@@ -57,51 +58,17 @@ static struct struct_ope_importation * new_transaction_from_split ( struct gnuca
 							     gchar * tiers, GDate * date );
 static gboolean node_strcmp ( xmlNodePtr node, gchar * name );
 static xmlDocPtr parse_gnucash_file ( gchar * filename );
-static gboolean recuperation_donnees_gnucash ( GtkWidget * assistant,
-					struct imported_file * imported );
 static void recuperation_donnees_gnucash_book ( xmlNodePtr book_node );
 static void recuperation_donnees_gnucash_categorie ( xmlNodePtr categ_node );
 static void recuperation_donnees_gnucash_compte ( xmlNodePtr compte_node );
 static void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node );
-static void update_split ( struct gnucash_split * split, gsb_real amount, 
+static void update_split ( struct gnucash_split * split, gsb_real amount,
 		    gchar * account, gchar * categ );
 /*END_STATIC*/
 
-
-static struct import_format gnucash_format = {
-    "Gnucash", 
-    "Gnucash",	
-    "gnc",
-    (import_function) recuperation_donnees_gnucash,
-};
-
 GSList * gnucash_accounts = NULL;
 
 
-#ifndef ENABLE_STATIC
-/** Module name. */
-G_MODULE_EXPORT const gchar plugin_name[] = "gnucash";
-#endif
-
-
-
-/** Initialization function. */
-G_MODULE_EXPORT extern void gnucash_plugin_register ( void )
-{
-    devel_debug ("Initializating gnucash plugin");
-
-    register_import_format ( &gnucash_format );
-}
-
-
-
-/** Main function of module. */
-G_MODULE_EXPORT extern gpointer gnucash_plugin_run ( void )
-{
-    return NULL;
-}
-
-
 
 /*****************************************************************/
 
@@ -179,15 +146,15 @@ gboolean recuperation_donnees_gnucash ( GtkWidget * assistant,
  * Main role of this function is to iterate over XML nodes of the file
  * and determine which account nodes are category nodes and which are
  * real accounts, as in Gnucash, accounts and categories are mixed.
- * 
+ *
  * \param book_node	Pointer to current XML node.
  */
 void recuperation_donnees_gnucash_book ( xmlNodePtr book_node )
 {
     xmlNodePtr child_node;
-    
+
     child_node = book_node -> children;
-    
+
     while ( child_node )
     {
 	/* Books are subdivisions of gnucash files */
@@ -209,12 +176,12 @@ void recuperation_donnees_gnucash_book ( xmlNodePtr book_node )
 		recuperation_donnees_gnucash_categorie ( child_node );
 	    }
 	}
-	
+
 	if ( node_strcmp(child_node, "transaction") )
         {
 	    recuperation_donnees_gnucash_transaction ( child_node );
 	}
-	
+
 	child_node = child_node -> next;
     }
 }
@@ -239,19 +206,19 @@ void recuperation_donnees_gnucash_compte ( xmlNodePtr compte_node )
     /* Gnucash import */
     compte -> origine = my_strdup ( "Gnucash" );
 
-    if ( !strcmp(type, "BANK") || !strcmp(type, "CREDIT") ) 
+    if ( !strcmp(type, "BANK") || !strcmp(type, "CREDIT") )
     {
 	compte -> type_de_compte = 0; /* Bank */
     }
-    else if ( !strcmp(type, "CASH") || !strcmp(type, "CURRENCY") ) 
+    else if ( !strcmp(type, "CASH") || !strcmp(type, "CURRENCY") )
     {
 	compte -> type_de_compte = 1; /* Currency */
     }
-    else if ( !strcmp(type, "ASSET") || !strcmp(type, "STOCK") || !strcmp(type, "MUTUAL") ) 
+    else if ( !strcmp(type, "ASSET") || !strcmp(type, "STOCK") || !strcmp(type, "MUTUAL") )
     {
 	compte -> type_de_compte = 0; /* Asset */
     }
-    else if ( !strcmp(type, "LIABILITY") ) 
+    else if ( !strcmp(type, "LIABILITY") )
     {
 	compte -> type_de_compte = 0; /* Liability */
     }
@@ -266,7 +233,7 @@ void recuperation_donnees_gnucash_compte ( xmlNodePtr compte_node )
     compte -> nom_de_compte = unique_imported_name ( compte -> nom_de_compte );
 
     gsb_import_register_account ( compte );
-    
+
     gnucash_accounts = g_slist_append ( gnucash_accounts, compte );
 }
 
@@ -312,7 +279,7 @@ void recuperation_donnees_gnucash_categorie ( xmlNodePtr categ_node )
     {
 	categ -> type = GNUCASH_CATEGORY_INCOME;
     }
-    else 
+    else
     {
 	categ -> type = GNUCASH_CATEGORY_EXPENSE;
     }
@@ -330,7 +297,7 @@ void recuperation_donnees_gnucash_categorie ( xmlNodePtr categ_node )
 void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
 {
   struct struct_ope_importation * transaction;
-  struct struct_compte_importation * account = NULL; 
+  struct struct_compte_importation * account = NULL;
   struct gnucash_split * split;
   gchar * date_string, *space, *tiers;
   GDate * date;
@@ -344,7 +311,7 @@ void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
 
   while ( split_node )
     {
-      struct struct_compte_importation * split_account = NULL; 
+      struct struct_compte_importation * split_account = NULL;
       struct gnucash_category * categ = NULL;
       struct gnucash_split * split;
       enum operation_etat_rapprochement p_r = OPERATION_NORMALE;
@@ -362,12 +329,12 @@ void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
 	{
 	  gchar * account_name = NULL, * categ_name = NULL;
 
-	  split_account = find_imported_account_by_uid ( child_content ( split_node, 
+	  split_account = find_imported_account_by_uid ( child_content ( split_node,
 									"account" ) );
 	  categ = find_imported_categ_by_uid ( child_content ( split_node, "account" ) );
 	  amount = gnucash_value ( child_content(split_node, "value") );
 
-	  if ( categ ) 
+	  if ( categ )
 	    categ_name = categ -> name;
 	  if ( split_account )
 	    {
@@ -434,15 +401,15 @@ void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
       while ( split_list )
 	{
 	  struct gnucash_split * split = split_list -> data;
-	  struct struct_compte_importation * account = NULL; 
-	  
+	  struct struct_compte_importation * account = NULL;
+
 	  transaction = new_transaction_from_split ( split, tiers, date );
 	  transaction -> ope_de_ventilation = 1;
 
 	  account = find_imported_account_by_name ( split -> account );
 	  if ( account )
 	    account -> operations_importees = g_slist_append ( account -> operations_importees, transaction );
-      
+
 	  split_list = split_list -> next;
 	}
     }
@@ -490,7 +457,7 @@ struct struct_compte_importation * find_imported_account_by_uid ( gchar * guid )
 	}
 
       liste_tmp = liste_tmp -> next;
-    }  
+    }
 
   return NULL;
 }
@@ -523,7 +490,7 @@ struct struct_compte_importation * find_imported_account_by_name ( gchar * name
 	}
 
       liste_tmp = liste_tmp -> next;
-    }  
+    }
 
   return NULL;
 }
@@ -554,7 +521,7 @@ struct gnucash_category * find_imported_categ_by_uid ( gchar * guid )
 	}
 
       liste_tmp = liste_tmp -> next;
-    }  
+    }
 
   return NULL;
 }
@@ -577,7 +544,7 @@ gsb_real gnucash_value ( gchar * value )
   gdouble number, mantisse;
 
   tab_value = g_strsplit ( value, "/", 2 );
-  
+
   number = utils_str_atoi ( tab_value[0] );
   mantisse = utils_str_atoi ( tab_value[1] );
 
@@ -636,34 +603,38 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
    * handle it gracefully.
    */
   while ( fgets ( buffer, 1024, filein ) )
-    {
-      gchar * tag;
-      tag = g_strrstr ( buffer, "<gnc-v2>" );
-      
-      if ( tag )
+  {
+    gchar * tag;
+    tag = g_strrstr ( buffer, "<gnc-v2>" );
+
+    if ( tag )
 	{
-	  gchar * ns[14] = { "gnc", "cd", "book", "act", "trn", "split", "cmdty", 
-			     "ts", "slots", "slot", "price", "sx", "fs", NULL };
-	  gchar ** iter;
+        gchar *ns[14] = { "gnc", "cd", "book", "act", "trn", "split", "cmdty",
+                        "ts", "slots", "slot", "price", "sx", "fs", NULL };
+        gchar **iter;
 
-	  tag += 7;
-	  *tag = 0;
-	  tag++;
+        tag += 7;
+        *tag = 0;
+        tag++;
 
-	  fputs ( buffer, tempfile );
-	  for ( iter = ns ; *iter != NULL ; iter++ )
-	    {
-	      fputs ( g_strdup_printf ( "  xmlns:%s=\"http://www.gnucash.org/lxr/gnucash/source/src/doc/xml/%s-v1.dtd#%s\"\n", 
-					*iter, *iter, *iter ),
-		      tempfile );
+	    fputs ( buffer, tempfile );
+	    for ( iter = ns ; *iter != NULL ; iter++ )
+        {
+            gchar *header;
+
+            header = g_strdup_printf (
+                        "  xmlns:%s=\"http://www.gnucash.org/lxr/gnucash/source/src/doc/xml/%s-v1.dtd#%s\"\n",
+                        *iter, *iter, *iter );
+            fputs ( header, tempfile );
+            g_free ( header );
 	    }
-	  fputs ( ">\n", tempfile );
+        fputs ( ">\n", tempfile );
 	}
-      else
+    else
 	{
 	  fputs ( buffer, tempfile );
 	}
-    }
+  }
   fclose ( filein );
   fclose ( tempfile );
 
@@ -671,7 +642,7 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
 
   /** Once parsed, the temporary file is removed as it is useless.  */
   g_unlink ( tempname );
-  
+
   return doc;
 }
 
@@ -688,12 +659,12 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
  *
  * \return		A gnucash_split upon success.  NULL otherwise.
  */
-struct gnucash_split * find_split ( GSList * split_list, gsb_real amount, 
-				    struct struct_compte_importation * account, 
+struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
+				    struct struct_compte_importation * account,
 				    struct gnucash_category * categ )
 {
   GSList * tmp;
-  
+
   tmp = split_list;
   while ( tmp )
     {
@@ -709,7 +680,7 @@ struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
 
       tmp = tmp -> next;
     }
-  
+
   return NULL;
 }
 
@@ -721,13 +692,13 @@ struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
  * account, this means it is the second split of the pair and first
  * split was an account split, so this is transfer split and we set
  * split's contra_account to 'account'.
- * 
+ *
  * \param split		Split to update.
  * \param amount	Amount to set if account is not NULL.
  * \param account	Account to set if not NULL.
  * \param categ		Category to set if not NULL.
  */
-void update_split ( struct gnucash_split * split, gsb_real amount, 
+void update_split ( struct gnucash_split * split, gsb_real amount,
 		    gchar * account, gchar * categ )
 {
   if ( categ )
@@ -769,11 +740,11 @@ struct gnucash_split * new_split ( gsb_real amount, gchar * account, gchar * cat
   split -> amount = amount;
   if ( account )
     split -> account = my_strdup ( account );
-  else 
+  else
     split -> account = NULL;
   if ( categ )
     split -> category = my_strdup ( categ );
-  else 
+  else
     split -> category = NULL;
 
   return split;
@@ -784,7 +755,7 @@ struct gnucash_split * new_split ( gsb_real amount, gchar * account, gchar * cat
 /**
  * Allocate and return a struct_ope_importation created from a
  * gnucash_split and some arguments.
- * 
+ *
  * \param split		Split to use as a base.
  * \param tiers		Transaction payee name.
  * \param date		Transaction date.
@@ -809,7 +780,7 @@ struct struct_ope_importation * new_transaction_from_split ( struct gnucash_spli
       /** If split contains a contra account, then this is a transfer. */
       struct struct_compte_importation * contra_account;
       struct struct_ope_importation * contra_transaction;
-	  
+
       contra_transaction = calloc ( 1, sizeof ( struct struct_ope_importation ));
       contra_transaction -> montant = gsb_real_opposite (split -> amount);
       contra_transaction -> notes = split -> notes;
@@ -872,7 +843,7 @@ gchar * child_content ( xmlNodePtr node, gchar * child_name )
 
   if ( child_node )
     return (gchar *) xmlNodeGetContent ( child_node );
-  
+
   return NULL;
 }
 
