@@ -26,7 +26,10 @@
 #endif
 
 #include "include.h"
-
+#include <stdlib.h>
+#include <ctype.h>
+#include <errno.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "qif.h"
@@ -41,6 +44,7 @@
 #include "gsb_data_transaction.h"
 #include "gsb_file_util.h"
 #include "gsb_real.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "import.h"
 #include "erreur.h"
@@ -63,8 +67,8 @@ extern GSList *liste_comptes_importes;
 extern GSList *liste_comptes_importes_error;
 /*END_EXTERN*/
 
-gchar *last_header = NULL;
-gboolean mismatch_dates = TRUE;
+static gchar *last_header = NULL;
+static gboolean mismatch_dates = TRUE;
 
 enum
 {
@@ -211,7 +215,7 @@ gboolean recuperation_donnees_qif ( GtkWidget *assistant, struct imported_file *
 
                     if ( account_type == 6 )
                     {
-                        /* on considère le imported_account d'investissement comme un imported_account 
+                        /* on considère le imported_account d'investissement comme un imported_account
                          * bancaire mais met un warning car pas implémenté, aucune idée si ça passe ou pas... */
                         gchar *msg;
 
@@ -677,7 +681,7 @@ gboolean gsb_qif_export_archive ( const gchar *filename,
 	}
 	tmp_list = tmp_list -> next;
     }
-    
+
     /* if there is more than 1 file created, we show what files we did */
     if (g_slist_length (name_list) > 1)
     {
@@ -794,7 +798,7 @@ gboolean qif_export ( const gchar *filename,
 			  g_date_get_year (gsb_data_transaction_get_date (transaction_number_tmp)));
 
 		/* met le solde initial */
-		tmpstr = gsb_real_get_string (gsb_data_account_get_init_balance (account_nb, -1));
+		tmpstr = utils_real_get_string (gsb_data_account_get_init_balance (account_nb, -1));
 		fprintf ( fichier_qif,
 			  "T%s\n",
 			  tmpstr);
@@ -849,7 +853,7 @@ gboolean qif_export ( const gchar *filename,
 
 
 		/* met le montant, transforme la devise si necessaire */
-		tmpstr = gsb_real_get_string (gsb_data_transaction_get_adjusted_amount ( transaction_number_tmp, floating_point));
+		tmpstr = utils_real_get_string (gsb_data_transaction_get_adjusted_amount ( transaction_number_tmp, floating_point));
 		fprintf ( fichier_qif,
 			  "T%s\n",
 			  tmpstr);
@@ -944,7 +948,7 @@ gboolean qif_export ( const gchar *filename,
 
 			    /* set the amount of the split child */
 
-			    tmpstr = gsb_real_get_string (gsb_data_transaction_get_adjusted_amount (transaction_number_tmp_2, floating_point));
+			    tmpstr = utils_real_get_string (gsb_data_transaction_get_adjusted_amount (transaction_number_tmp_2, floating_point));
 			    fprintf ( fichier_qif,
 				      "$%s\n",
 				      tmpstr);
@@ -992,7 +996,7 @@ gboolean qif_export ( const gchar *filename,
 	/* there is no transaction in the account, so do the opening of the account, bug no date */
 	/* met le solde initial */
 
-	gchar* tmpstr = gsb_real_get_string (gsb_data_account_get_init_balance (account_nb, -1));
+	gchar* tmpstr = utils_real_get_string (gsb_data_account_get_init_balance (account_nb, -1));
 	fprintf ( fichier_qif,
 		  "T%s\n",
 		  tmpstr);
@@ -1128,14 +1132,14 @@ gint gsb_qif_recupere_operations_from_account ( FILE *qif_file,
                 gchar *new_str;
 
                 new_str = utils_str_localise_decimal_point_from_string ( string + 1 );
-                imported_transaction -> montant = gsb_real_get_from_string ( new_str );
+                imported_transaction -> montant = utils_real_get_from_string ( new_str );
 
                 g_free ( new_str );
             }
 
             /* récupération du chèque */
             if ( string[0] == 'N' )
-                imported_transaction -> cheque = my_strdup ( string + 1 ); 
+                imported_transaction -> cheque = my_strdup ( string + 1 );
 
             /* récupération du tiers */
             if ( string[0] == 'P' )
@@ -1151,7 +1155,7 @@ gint gsb_qif_recupere_operations_from_account ( FILE *qif_file,
                 /* begin a splitted transaction, if we were on a transaction, we save it */
                 if ( returned_value != EOF && imported_transaction && imported_transaction -> date_tmp )
                 {
-                    
+
                     if ( imported_splitted == NULL )
                     imported_account -> operations_importees = g_slist_append (
                                         imported_account -> operations_importees, imported_transaction );
@@ -1206,7 +1210,7 @@ gint gsb_qif_recupere_operations_from_account ( FILE *qif_file,
                 gchar *new_str;
 
                 new_str = utils_str_localise_decimal_point_from_string ( string + 1 );
-                imported_splitted -> montant = gsb_real_get_from_string ( new_str );
+                imported_splitted -> montant = utils_real_get_from_string ( new_str );
 
                 g_free ( new_str );
             }
@@ -1231,7 +1235,7 @@ gint gsb_qif_recupere_operations_from_account ( FILE *qif_file,
         else
         {
             if ( imported_transaction -> date_tmp == NULL
-             || 
+             ||
              strlen ( g_strstrip ( imported_transaction -> date_tmp ) ) == 0 )
             {
                 /* l'opération n'a pas de date, c'est pas normal. pour éviter de la perdre, on va lui */
@@ -1245,11 +1249,11 @@ gint gsb_qif_recupere_operations_from_account ( FILE *qif_file,
                 else
                     imported_transaction -> tiers = my_strdup ( _(" [Transaction imported without date]") );
             }
-            
+
             imported_account -> operations_importees = g_slist_append (
                                         imported_account -> operations_importees, imported_transaction );
         }
-    } 
+    }
 
     if ( string[0] == '!' )
     {
@@ -1328,14 +1332,14 @@ gint gsb_qif_recupere_categories ( FILE *qif_file, const gchar *coding_system )
                 if (tab_str[1])
                 {
                     tab_str[1] = g_strstrip ( tab_str[1] );
-            
+
                     gsb_data_category_get_sub_category_number_by_name (
                                 category_number,
                                 tab_str[1],
                                 TRUE );
                 }
             }
-            
+
             g_strfreev(tab_str);
         }
     }
