@@ -1,6 +1,9 @@
 #ifndef _STRUCTURES_H
 #define _STRUCTURES_H (1)
 
+#include <glib.h>
+#include <gtk/gtk.h>
+
 /* fichier d'en tête structures.h */
 /* contient presque toutes les structures du prog */
 
@@ -16,52 +19,9 @@
 #define VERSION_FICHIER_ETAT "0.6.0"
 #define VERSION_FICHIER_CATEG "0.6.0"
 #define VERSION_FICHIER_IB "0.6.0"
-#define VERSION_GTK_MAJOR 2
-#define VERSION_GTK_MINOR 16
-#define VERSION_GTK_MICRO 0
 
 #define CSV_MAX_TOP_LINES 10	/** How many lines to show in CSV preview.  */
-
-/* definition des variables PIXMAPS_DIR PLUGINS_DIR */
-#define GRISBI_PIXMAPS_DIR (utils_get_pixmaps_dir ( ) )
-#define GRISBI_PLUGINS_DIR (utils_get_plugins_dir ( ) ) 
-
-
-/* structures pour la gestion de l'impression */
-enum filetype
-{
-  POSTSCRIPT_FILE = 0,
-  LATEX_FILE,
-  NUM_FILETYPES,
-}; 
-
-
-struct paper_config 
-{
-  gchar *name;
-  gfloat width;
-  gfloat height;
-};
-
-
-enum orientation
-{
-  LANDSCAPE = 0,
-  PORTRAIT,
-  NUM_ORIENTATION,
-}; 
-
-
-struct print_config
-{
-  gboolean printer;
-  gchar * printer_name;
-  gchar * printer_filename;
-  enum filetype filetype;
-  struct paper_config paper_config;
-  enum orientation orientation;
-};
-
+#define GSB_EPSILON 0.0000005   /* Sert à comparer des doubles */
 
 /** structure etat
  * variables contenant juste 0 ou 1
@@ -72,40 +32,31 @@ struct print_config
  * */
 struct gsb_etat_t
 {
-    time_t modification_fichier;
     gint is_archive;                /** TRUE if the file is an archive, FALSE else */
 
-    /* Rapprochement */
-    gint reconcile_end_date;        /* Date initiale + 1 mois par défaut */
-    gint equilibrage;
-    gint reconcile_account_number;  /* Save the last reconciliation try: account */
-    gchar *reconcile_final_balance; /* final balance amount */
-    GDate *reconcile_new_date;      /* new date */
-
     gboolean debug_mode;            /* TRUE in debug mode, FALSE for normale mode */
 
     /* files and backup part */
     gint crypt_file;                /* TRUE if we want to crypt the file */
     gint fichier_deja_ouvert;       /* à un si lors de l'ouverture, le fichier semblait déjà ouvert */
 
+    /* devises pour les catégories, imputations budgétaires et les tiers */
+    gint no_devise_totaux_categ;
+    gint no_devise_totaux_ib;
+    gint no_devise_totaux_tiers;
+
+    /* reconciliation */
+    gint reconcile_end_date;        /* Date initiale + 1 mois par défaut */
+
     /* formulaire */
-    gint formulaire_toujours_affiche;
-    gint affichage_exercice_automatique;    /* automatic fyear :0 to set according to the date, 2 according to value date */
     gint affiche_nb_ecritures_listes;
-    gint largeur_auto_colonnes;
     gint retient_affichage_par_compte;      /* à 1 si les caractéristiques de l'affichage (R, non R ...) diffèrent par compte */
-    gint en_train_de_sauvegarder;
-    gint en_train_de_charger;
 
     /* Fonts & logo */
     gint utilise_logo;
-    gboolean is_pixmaps_dir;        /* TRUE if path_icon == GRISBI_PIXMAPS_DIR */
+    gboolean is_pixmaps_dir;        /* TRUE if path_icon == gsb_dirs_get_pixmaps_dir ( ) */
     gchar *name_logo;
-    
-    gint display_toolbar;           /** Display mode of toolbar. */
-    gboolean show_toolbar;          /** Show toolbar or not.  */
-    gboolean show_headings_bar;     /** Show headings bar or not. */
-    gboolean show_closed_accounts;
+
     gboolean automatic_separator;   /* TRUE if do automatic separator */
 
     /* Various display message stuff    */
@@ -118,6 +69,7 @@ struct gsb_etat_t
 
     /* import files */
     gint get_extract_number_for_check;      /* TRUE if Extracting a number and save it in the field No Cheque/Virement */
+    gint get_copy_payee_in_note;            /* TRUE si recopie le tiers dans les notes FALSE par défaut */
     gint get_fusion_import_transactions;    /* TRUE if merge transactions imported with transactions found*/
     gint get_categorie_for_payee;           /* TRUE to automatically retrieve the category of the payee if it exists */
     gint get_fyear_by_value_date;           /* TRUE to get the fyear by value date, FALSE by date */
@@ -136,10 +88,7 @@ struct gsb_etat_t
     gint combofix_enter_select_completion;  /* TRUE if enter close the popup and keep what is in the entry (else, select the current item in the list) */
     gint combofix_force_payee;              /* TRUE if no new item can be appended in the payee combofix */
     gint combofix_force_category;           /* TRUE if no new item can be appended in the category and budget combofix */
-    
-    /* Print stuff */
-    struct print_config print_config;
-    
+
     /* width panned */
     gint largeur_colonne_echeancier;
     gint largeur_colonne_comptes_comptes;
@@ -147,10 +96,9 @@ struct gsb_etat_t
 
     /* variables sur l'échéancier */
     gint affichage_commentaire_echeancier;      /* à 1 si le commentaire est affiché */
-
-    /* Tips */
-    gint last_tip; 
-    gint show_tip; 
+    gint affichage_echeances;                   /* affichage de la période affichée dans la vue échéancier */
+    gint affichage_echeances_perso_nb_libre;    /* nombre de périodicité des échéances personnalisées */
+    gint affichage_echeances_perso_j_m_a;       /* type de périodicité des échéances personnalisées */
 
     /* variables pour les metatree */
     gint metatree_sort_transactions;        /* 1 = sorting by increasing date 2 = Sort by date descending */
@@ -167,6 +115,10 @@ struct gsb_etat_t
     gint bet_index_duree;
     gdouble bet_frais;
     gint bet_type_taux;
+
+    /* largeur des colonnes */
+    gchar *transaction_column_width;
+    gchar *scheduler_column_width;
 };
 
 /* declared in parametres.c */
@@ -186,29 +138,35 @@ struct gsb_conf_t
     gint main_width;                                /* main_window width */
     gint main_height;                               /* main_window height */
     gint full_screen;                               /* 1 to full screen, 0 else */
-    gint largeur_colonne_comptes_operation;
+    gint maximize_screen;                           /* 1 to maximize screen, 0 else */
+    gint panel_width;                               /* panel width */
     gint prefs_width;                               /* preferences width */
 
     /* general part */
     gint r_modifiable;                              /* Changes in reconciled transactions */
-    gint entree;                                    /* si etat.entree = 1, la touche entrée finit l'opération */ 
+    gint entree;                                    /* si etat.entree = 1, la touche entrée finit l'opération */
     gint alerte_mini;
     gint utilise_fonte_listes;                      /* TRUE to use a custom font for the lists */
     gchar *font_string;                             /* contain the description of the font, or NULL */
     gchar *browser_command;
-    gchar *latex_command;
-    gchar *dvips_command;
     gint pluriel_final;                             /* 0 = finals 1 = finaux */
 
     gint display_grisbi_title;                      /* selection du titre principal de grisbi */
+    gboolean active_scrolling_left_pane;            /* active mouse scrolling in the left_pane. */
+
+    gint display_toolbar;                           /* Display mode of toolbar. */
+    gboolean show_headings_bar;                     /* Show headings bar or not. */
+    gboolean show_closed_accounts;
 
     /* files part */
     gint sauvegarde_demarrage;                      /* utilisé pour enregistrer le fichier s'il s'est bien ouvert */
     gint sauvegarde_auto;                           /* utilisé pour enregistrer le fichier automatiquementà la fermeture */
     gint dernier_fichier_auto;
-    gint compress_file;                             /* TRUE if we want to compress the grisbi file */
+    gint compress_file;                             /* TRUE if we want to compress the Grisbi file */
     gint alerte_permission;                         /* à un si le message d'alerte s'affiche */
     gint force_enregistrement;                      /* à un si on force l'enregistrement */
+    gint nb_max_derniers_fichiers_ouverts;          /* contient le nb max que peut contenir nb_derniers_fichiers_ouverts */
+    gsize nb_derniers_fichiers_ouverts;             /* contient le nb de derniers fichiers ouverts */
 
     /* backup part */
     gint make_backup;                               /* TRUE for create a backup when save file */
@@ -221,14 +179,21 @@ struct gsb_conf_t
     gint automatic_completion_payee;                /* 1 pour autoriser la completion automatique des opérations */
     gboolean limit_completion_to_current_account;   /* Limit payee completion to current account or do a full search. */
     gboolean automatic_recover_splits;              /* 1 pour recréer automatiquement les sous opérations */
+    gboolean automatic_erase_credit_debit;          /* 1 pour effacer les champs crédit et débit */
+    gboolean formulaire_toujours_affiche;           /* TRUE formulaire toujours affiché */
+    gint affichage_exercice_automatique;            /* automatic fyear :0 to set according to the date, 1 according to value date */
 
 #if IS_DEVELOPMENT_VERSION == 1
     /* config file */
     gint stable_config_file_model;                  /* TRUE for use the stable config file as model */
 #endif
 
+    /* variables pour l'échéancier */
+    gboolean execute_scheduled_of_month;            /* warn/execute scheduled at expiration (FALSE) or of the month (TRUE) */
+
     /* variables pour le calcul des soldes */
     gboolean balances_with_scheduled;               /* TRUE = the balance incorporates the scheduled operations */
+    gboolean group_partial_balance_under_accounts;  /* TRUE = in home page group the partial balance with accounts */
 
     /* variables for the list of transactions */
     gint show_transaction_selected_in_form;         /* TRUE will show the selected transaction in the form */
@@ -243,6 +208,9 @@ struct gsb_conf_t
     gint check_for_archival;                        /* TRUE if we want to check the number of non archived transactions at the opening */
     gint max_non_archived_transactions_for_check;   /* the max number of transaction before grisbi warm at the opening */
 
+    /* Tips */
+    gint last_tip;
+    gint show_tip;
 };
 
 /* declared in gsb_file_config.c */
@@ -256,13 +224,32 @@ extern struct gsb_conf_t conf;
 
 struct gsb_run_t
 {
+    /* main window of grisbi */
+    GtkWidget *window;
+
     /* initialisation variables */
     gboolean new_crypted_file;      /* 0 à l'exécution de init_variables () 1 si new crypted file*/
 
-    /* largeur des colonnes */
-    gchar *transaction_column_width;
-    gchar *scheduler_column_width;
+    /* file stuff */
+    time_t file_modification;
+    gboolean is_saving;
+    gboolean is_loading;
 
+    /* reconciliation */
+    gint equilibrage;
+    gint reconcile_account_number;  /* Save the last reconciliation try: account */
+    gchar *reconcile_final_balance; /* final balance amount */
+    GDate *reconcile_new_date;      /* new date */
+
+    /* home page - accueil */
+    /* ces 5 variables sont mises à 1 lorsqu'il est nécessaire de rafraichir cette */
+    /* partie la prochaine fois qu'on va sur l'accueil */
+
+    gboolean mise_a_jour_liste_comptes_accueil;
+    gboolean mise_a_jour_liste_echeances_manuelles_accueil;
+    gboolean mise_a_jour_liste_echeances_auto_accueil;
+    gboolean mise_a_jour_soldes_minimaux;
+    gboolean mise_a_jour_fin_comptes_passifs;
 };
 
 /* declared in main.c */
@@ -311,7 +298,7 @@ enum bet_array_origin_data
 
 
 /* définition du type de mise à jour en fonction des données du module budgétaire */
-enum bet_type_maj 
+enum bet_type_maj
 {
     BET_MAJ_FALSE = 0,
     BET_MAJ_ESTIMATE,
@@ -321,5 +308,16 @@ enum bet_type_maj
 };
 
 
+/* définition du type d'onglets du module budgétaire affiché */
+typedef enum _bet_type_onglets bet_type_onglets;
+enum _bet_type_onglets
+{
+    BET_ONGLETS_SANS = 0,
+    BET_ONGLETS_PREV,
+    BET_ONGLETS_HIST,
+    BET_ONGLETS_ASSET,
+    BET_ONGLETS_CAP,
+};
+
 
 #endif
