@@ -33,6 +33,7 @@
 #endif
 
 #include "include.h"
+#include <stdlib.h>
 
 /* START_INCLUDE */
 #include "gsb_real_cunit.h"
@@ -41,10 +42,8 @@
 
 /* START_STATIC */
 static void gsb_real_cunit__gsb_real_add ( void );
-static void gsb_real_cunit__gsb_real_get_from_string ( void );
 static void gsb_real_cunit__gsb_real_mul();
 static void gsb_real_cunit__gsb_real_normalize();
-static void gsb_real_cunit__gsb_real_get_string_with_currency ( void );
 static void gsb_real_cunit__gsb_real_raw_format_string ( void );
 static void gsb_real_cunit__gsb_real_raw_get_from_string();
 static void gsb_real_cunit__gsb_real_raw_get_from_string__locale();
@@ -73,70 +72,6 @@ int gsb_real_cunit_clean_suite ( void )
     return 0;
 }
 
-void gsb_real_cunit__gsb_real_get_from_string ( void )
-{
-    char *lc_monetary_orig;
-    char *result = setlocale(LC_MONETARY, NULL);
-    if (result != NULL)
-    {
-        lc_monetary_orig = (char *)malloc((strlen(result) + 1) * sizeof(char));
-        strcpy(lc_monetary_orig, result);
-
-        /* C test */
-        result = setlocale(LC_MONETARY, "C");
-        if (result != NULL)
-        {
-            gsb_real val = gsb_real_get_from_string("123.45");
-            CU_ASSERT_EQUAL(12345, val.mantissa);
-            CU_ASSERT_EQUAL(2, val.exponent);
-
-            val = gsb_real_get_from_string("21000000");
-            CU_ASSERT_EQUAL(21000000, val.mantissa);
-            CU_ASSERT_EQUAL(0, val.exponent);
-        }
-
-        /* French test */
-        result = setlocale(LC_MONETARY, "fr_FR.UTF-8");
-        if (result == NULL)
-            result = setlocale(LC_MONETARY, "fr_FR@euro");
-        if (result == NULL)
-            result = setlocale(LC_MONETARY, "fr_FR");
-        if (result != NULL)
-        {
-            gsb_real val = gsb_real_get_from_string("123,45");
-            CU_ASSERT_EQUAL(12345, val.mantissa);
-            CU_ASSERT_EQUAL(2, val.exponent);
-
-            val = gsb_real_get_from_string("21000000");
-            CU_ASSERT_EQUAL(21000000, val.mantissa);
-            CU_ASSERT_EQUAL(0, val.exponent);
-        }
-
-        /* English test */
-        result = setlocale(LC_MONETARY, "en_US.UTF-8");
-        if (result == NULL)
-            result = setlocale(LC_MONETARY, "en_GB.UTF-8");
-        if (result == NULL)
-            result = setlocale(LC_MONETARY, "en_US");
-        if (result == NULL)
-            result = setlocale(LC_MONETARY, "en_GB");
-        if (result != NULL)
-        {
-            gsb_real val = gsb_real_get_from_string("123.45");
-            CU_ASSERT_EQUAL(12345, val.mantissa);
-            CU_ASSERT_EQUAL(2, val.exponent);
-
-            val = gsb_real_get_from_string("21 000 000");
-            CU_ASSERT_EQUAL(21000000, val.mantissa);
-            CU_ASSERT_EQUAL(0, val.exponent);
-        }
-
-        /* Restore current locale and free memory */
-        setlocale(LC_MONETARY, lc_monetary_orig);
-        free(lc_monetary_orig) ;
-    }
-}
-
 void gsb_real_cunit__gsb_real_raw_get_from_string()
 {
     gsb_real val;
@@ -244,17 +179,17 @@ void gsb_real_cunit__gsb_real_raw_get_from_string()
 
 /*     // too large positive number ==> error  */
     val = gsb_real_raw_get_from_string ( " 2 147 483 648 ", NULL, NULL );
-    CU_ASSERT_EQUAL ( 2147483648, val.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(2147483648), val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
 /*     // too large positive number ==> error  */
     val = gsb_real_raw_get_from_string ( " 2 147 483 649 ", NULL, NULL );
-    CU_ASSERT_EQUAL ( 2147483649, val.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(2147483649), val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
 /*     // very large positive number ==> error  */
     val = gsb_real_raw_get_from_string ( " 112 147 483 649 ", NULL, NULL );
-    CU_ASSERT_EQUAL ( 112147483649, val.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(112147483649), val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
 /*     // 0 with positive sign  */
@@ -327,19 +262,19 @@ void gsb_real_cunit__gsb_real_raw_get_from_string()
     CU_ASSERT_EQUAL ( -2147483647, val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
-/*     // too large negative number ==> error  */
+    /*  G_MININT - 1 */
     val = gsb_real_raw_get_from_string ( " -2 147 483 648 ", NULL, NULL );
-    CU_ASSERT_EQUAL ( -2147483648, val.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(-2147483648), val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
-/*     // too large negative number ==> error  */
+    /* G_MININT - 2 */
     val = gsb_real_raw_get_from_string ( " -2 147 483 649 ", NULL, NULL );
-    CU_ASSERT_EQUAL ( -2147483649, val.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(-2147483649), val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
-/*     // too large negative number ==> error  */
+    /* large negative number */
     val = gsb_real_raw_get_from_string ( " -112 147 483 649 ", NULL, NULL );
-    CU_ASSERT_EQUAL ( -112147483649, val.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(-112147483649), val.mantissa );
     CU_ASSERT_EQUAL ( 0, val.exponent );
 
 /*     // error number as string ==> error  */
@@ -379,7 +314,7 @@ void gsb_real_cunit__gsb_real_raw_format_string ( void )
     conv.mon_thousands_sep = "< >";
     conv.mon_decimal_point = "<.>";
     gchar *currency_symbol = "<€>";
-        
+
     n.mantissa = 1;
     n.exponent = 2;
     s = gsb_real_raw_format_string(n, &conv, currency_symbol);
@@ -422,19 +357,19 @@ void gsb_real_cunit__gsb_real_raw_format_string ( void )
     CU_ASSERT_STRING_EQUAL("<+>21< >474< >836<.>47<€>", s);
     g_free(s);
 
-    n.mantissa = -2147483649;
+    n.mantissa = G_GINT64_CONSTANT(-2147483649);
     n.exponent = 0;
     s = gsb_real_raw_format_string(n, &conv, currency_symbol);
     CU_ASSERT_STRING_EQUAL("<->2< >147< >483< >649<.>0<€>", s);
     g_free(s);
 
-    n.mantissa = -2147483649;
+    n.mantissa = G_GINT64_CONSTANT(-2147483649);
     n.exponent = 1;
     s = gsb_real_raw_format_string(n, &conv, currency_symbol);
     CU_ASSERT_STRING_EQUAL("<->214< >748< >364<.>9<€>", s);
     g_free(s);
 
-    n.mantissa = -2147483649;
+    n.mantissa = G_GINT64_CONSTANT(-2147483649);
     n.exponent = 2;
     s = gsb_real_raw_format_string(n, &conv, currency_symbol);
     CU_ASSERT_STRING_EQUAL("<->21< >474< >836<.>49<€>", s);
@@ -462,37 +397,6 @@ void gsb_real_cunit__gsb_real_raw_format_string ( void )
 }
 
 
-void gsb_real_cunit__gsb_real_get_string_with_currency ( void )
-{
-    gchar *s;
-    gsb_real n;
-    gint currency_number = 1;
-
-    n.mantissa = 0;
-    n.exponent = 0;
-    s = gsb_real_get_string_with_currency ( n, currency_number, FALSE );
-    CU_ASSERT_STRING_EQUAL("0", s);
-    g_free(s);
-
-    n.mantissa = 31415;
-    n.exponent = 100;
-    s = gsb_real_get_string_with_currency ( n, currency_number, FALSE );
-    CU_ASSERT_STRING_EQUAL(ERROR_REAL_STRING, s);
-    g_free(s);
-
-    n.mantissa = 31415;
-    n.exponent = -1;
-    s = gsb_real_get_string_with_currency ( n, currency_number, FALSE );
-    CU_ASSERT_STRING_EQUAL(ERROR_REAL_STRING, s);
-    g_free(s);
-
-    n.mantissa = 0x7fffffffffffffff + 1;
-    n.exponent = 2;
-    s = gsb_real_get_string_with_currency ( n, currency_number, FALSE );
-    CU_ASSERT_STRING_EQUAL(ERROR_REAL_STRING, s);
-}
-
-
 void gsb_real_cunit__gsb_real_normalize()
 {
     gsb_real a;
@@ -545,7 +449,7 @@ void gsb_real_cunit__gsb_real_add ( void )
     gsb_real r = gsb_real_add(a, b);
     CU_ASSERT_EQUAL(41415, r.mantissa);
     CU_ASSERT_EQUAL(4, r.exponent);
-    
+
     a.mantissa = 0x7FFFFFFE;
     a.exponent = 0;
     b.mantissa = 1;
@@ -553,7 +457,7 @@ void gsb_real_cunit__gsb_real_add ( void )
     r = gsb_real_add(a, b);
     CU_ASSERT_EQUAL(0x7FFFFFFF, r.mantissa);
     CU_ASSERT_EQUAL(0, r.exponent);
-    
+
     a.mantissa = 0x7FFFFFFF;
     a.exponent = 0;
     b.mantissa = 2;
@@ -561,7 +465,7 @@ void gsb_real_cunit__gsb_real_add ( void )
     r = gsb_real_add(a, b);
     CU_ASSERT_EQUAL(0x80000001, r.mantissa);
     CU_ASSERT_EQUAL(0, r.exponent);
-    
+
     a.mantissa = 0x80000001;
     a.exponent = 0;
     b.mantissa = -2;
@@ -594,7 +498,7 @@ void gsb_real_cunit__gsb_real_sub()
     gsb_real r = gsb_real_sub ( a, b );
     CU_ASSERT_EQUAL ( -41415, r.mantissa );
     CU_ASSERT_EQUAL ( 4, r.exponent );
-    
+
     a.mantissa = 0x7FFFFFFE;
     a.exponent = 0;
     b.mantissa = -1;
@@ -602,7 +506,7 @@ void gsb_real_cunit__gsb_real_sub()
     r = gsb_real_sub ( a, b );
     CU_ASSERT_EQUAL ( 0x7FFFFFFF, r.mantissa );
     CU_ASSERT_EQUAL ( 0, r.exponent );
-    
+
     a.mantissa = 0x7FFFFFFF;
     a.exponent = 0;
     b.mantissa = -2;
@@ -610,7 +514,7 @@ void gsb_real_cunit__gsb_real_sub()
     r = gsb_real_sub ( a, b );
     CU_ASSERT_EQUAL ( 0x80000001, r.mantissa );
     CU_ASSERT_EQUAL ( 0, r.exponent );
-    
+
     a.mantissa = 0x80000001;
     a.exponent = 0;
     b.mantissa = 2;
@@ -628,15 +532,15 @@ void gsb_real_cunit__gsb_real_mul()
     gsb_real r = gsb_real_mul ( a, b );
     CU_ASSERT_EQUAL ( 37698, r.mantissa );
     CU_ASSERT_EQUAL ( 4, r.exponent );
-    
+
     a.mantissa = 0x7FFFFFFF;
     a.exponent = 0;
     b.mantissa = 2;
     b.exponent = 0;
     r = gsb_real_mul ( a, b );
-    CU_ASSERT_EQUAL ( 4294967294, r.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(4294967294), r.mantissa );
     CU_ASSERT_EQUAL ( 0, r.exponent );
-    
+
     a.mantissa = 0x7FFFFFFF;
     a.exponent = 0;
     b.mantissa = 9;
@@ -644,7 +548,7 @@ void gsb_real_cunit__gsb_real_mul()
     r = gsb_real_mul ( a, b );
     CU_ASSERT_EQUAL ( 19327352823, r.mantissa );
     CU_ASSERT_EQUAL ( 1, r.exponent );
-    
+
     a.mantissa = G_MININT64;
     a.exponent = 0;
     b.mantissa = 2;
@@ -666,7 +570,7 @@ void gsb_real_cunit__gsb_real_mul()
     b.mantissa = 100000;
     b.exponent = 0;
     r = gsb_real_mul ( a, b );
-    CU_ASSERT_EQUAL ( 2200000000, r.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(2200000000), r.mantissa );
     CU_ASSERT_EQUAL ( 0, r.exponent );
 
     a.mantissa = -22000;
@@ -674,7 +578,7 @@ void gsb_real_cunit__gsb_real_mul()
     b.mantissa = 100000;
     b.exponent = 0;
     r = gsb_real_mul ( a, b );
-    CU_ASSERT_EQUAL ( -2200000000, r.mantissa );
+    CU_ASSERT_EQUAL ( G_GINT64_CONSTANT(-2200000000), r.mantissa );
     CU_ASSERT_EQUAL ( 0, r.exponent );
 }
 
@@ -704,8 +608,7 @@ CU_pSuite gsb_real_cunit_create_suite ( void )
     if(NULL == pSuite)
         return NULL;
 
-    if ( ( NULL == CU_add_test( pSuite, "of gsb_real_get_from_string()",     gsb_real_cunit__gsb_real_get_from_string ) )
-      || ( NULL == CU_add_test( pSuite, "of gsb_real_raw_get_from_string()", gsb_real_cunit__gsb_real_raw_get_from_string ) )
+    if ( ( NULL == CU_add_test( pSuite, "of gsb_real_raw_get_from_string()", gsb_real_cunit__gsb_real_raw_get_from_string ) )
       || ( NULL == CU_add_test( pSuite, "of gsb_real_raw_get_from_string() with locale", gsb_real_cunit__gsb_real_raw_get_from_string__locale ) )
       || ( NULL == CU_add_test( pSuite, "of gsb_real_raw_format_string()",   gsb_real_cunit__gsb_real_raw_format_string ) )
       || ( NULL == CU_add_test( pSuite, "of gsb_real_gsb_real_normalize()",  gsb_real_cunit__gsb_real_normalize ) )
@@ -713,7 +616,6 @@ CU_pSuite gsb_real_cunit_create_suite ( void )
       || ( NULL == CU_add_test( pSuite, "of gsb_real_sub()",                 gsb_real_cunit__gsb_real_sub ) )
       || ( NULL == CU_add_test( pSuite, "of gsb_real_mul()",                 gsb_real_cunit__gsb_real_mul ) )
       || ( NULL == CU_add_test( pSuite, "of gsb_real_adjust_exponent()",     gsb_real_cunit__gsb_real_adjust_exponent ) )
-      || ( NULL == CU_add_test( pSuite, "of gsb_real_get_string_with_currency()", gsb_real_cunit__gsb_real_get_string_with_currency ) )
        )
         return NULL;
 
