@@ -33,11 +33,13 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
+
 #include "dialog.h"
 
 /*START_INCLUDE*/
 #include "tiers_onglet.h"
-#include "metatree.h"
+#include "fenetre_principale.h"
 #include "gsb_assistant.h"
 #include "gsb_automem.h"
 #include "gsb_data_form.h"
@@ -45,24 +47,26 @@
 #include "gsb_data_payee.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
-#include "utils_editables.h"
+#include "gsb_file.h"
 #include "gsb_form_widget.h"
-#include "import.h"
 #include "gsb_status.h"
-#include "utils_str.h"
+#include "gsb_transactions_list.h"
 #include "gtk_combofix.h"
+#include "import.h"
+#include "meta_payee.h"
+#include "metatree.h"
+#include "structures.h"
 #include "traitement_variables.h"
+#include "transaction_list.h"
 #include "utils.h"
 #include "utils_buttons.h"
-#include "transaction_list.h"
-#include "gsb_transactions_list.h"
-#include "structures.h"
+#include "utils_editables.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static void appui_sur_ajout_payee ( GtkTreeModel * model );
-static void appui_sur_manage_tiers ( void );
 static GtkWidget *creation_barre_outils_tiers ( void );
 static gboolean edit_payee ( GtkTreeView * view );
 static void gsb_assistant_payees_clicked ( GtkButton *button, GtkWidget *assistant );
@@ -93,32 +97,31 @@ static gboolean payee_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePa
 static gboolean payee_list_button_press ( GtkWidget *tree_view,
                         GdkEventButton *ev,
                         gpointer null );
-static gboolean payee_remove_unused ( GtkWidget *button,
-                        gpointer null );
+/* static gboolean payee_remove_unused ( GtkWidget *button,
+ *                         gpointer null );
+ */
 static void payee_tree_update_transactions ( GtkTreeModel * model,
                         MetatreeInterface * iface, GtkTreeIter * iter,
                         gint division, gchar * old_payee );
 static gboolean popup_payee_view_mode_menu ( GtkWidget * button );
 /*END_STATIC*/
 
-gint no_devise_totaux_tiers;
 
-GtkWidget *payee_tree = NULL;
-GtkTreeStore *payee_tree_model = NULL;
+static GtkWidget *payee_toolbar;
+static GtkWidget *payee_tree = NULL;
+static GtkTreeStore *payee_tree_model = NULL;
+
+/* variable for display payees without transactions */
+static gboolean display_unused_payees;
 
 /* variable for the management of the cancelled edition */
-gboolean sortie_edit_payee = FALSE;
+static gboolean sortie_edit_payee = FALSE;
 
 /* structure pour la sauvegarde de la position */
-struct metatree_hold_position *payee_hold_position;
-
-struct conditional_message *overwrite_payee;
+static struct metatree_hold_position *payee_hold_position;
 
 /*START_EXTERN*/
-extern GdkColor couleur_selection;
 extern GSList *liste_associations_tiers;
-extern MetatreeInterface * payee_interface;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 enum payees_assistant_page
@@ -137,30 +140,33 @@ enum {
 };
 
 /**
- * update the payee combofix in the form with the current list of payee
+ * réinitialisation des variables globales
  *
  * \param
  *
- * \return FALSE
+ * \return
  * */
-gboolean gsb_payee_update_combofix ( void )
+void payees_init_variables_list ( void )
 {
-    if ( gsb_data_form_check_for_value ( TRANSACTION_FORM_PARTY ))
-    gtk_combofix_set_list ( GTK_COMBOFIX ( gsb_form_widget_get_widget 
-                        (TRANSACTION_FORM_PARTY)),
-                        gsb_data_payee_get_name_and_report_list ());
+    payee_tree_model = NULL;
 
-    return FALSE;
+    payee_toolbar = NULL;
+    payee_tree = NULL;
+    etat.no_devise_totaux_tiers = 1;
+
+    display_unused_payees = FALSE;
+    sortie_edit_payee = FALSE;
 }
 
 
-
-/* **************************************************************************************************** */
-/* Fonction onglet_tiers : */
-/* crée et renvoie le widget contenu dans l'onglet */
-/* **************************************************************************************************** */
-
-GtkWidget *onglet_tiers ( void )
+/*
+ * Crée la liste des Tiers
+ *
+ * \param
+ *
+ * \return	A newly-allocated widget.
+* */
+GtkWidget *payees_create_list ( void )
 {
     GtkWidget *onglet, *scroll_window;
     GtkTreeViewColumn *column;
@@ -179,16 +185,14 @@ GtkWidget *onglet_tiers ( void )
     payee_tree = gtk_tree_view_new();
 
     /* set the color of selected row */
-    gtk_widget_modify_base ( payee_tree, GTK_STATE_SELECTED, &couleur_selection );
+    utils_set_tree_view_selection_and_text_color ( payee_tree );
 
     payee_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
 
     /* on y ajoute la barre d'outils */
-    gtk_box_pack_start ( GTK_BOX ( onglet ),
-                        creation_barre_outils_tiers ( ),
-                        FALSE,
-                        FALSE,
-                        0 );
+    payee_toolbar = gtk_handle_box_new ();
+    gtk_widget_show ( payee_toolbar );
+    gtk_box_pack_start ( GTK_BOX ( onglet ), payee_toolbar, FALSE, FALSE, 0 );
 
     /* création de l'arbre principal */
     scroll_window = gtk_scrolled_window_new ( NULL, NULL );
@@ -206,7 +210,7 @@ GtkWidget *onglet_tiers ( void )
                         META_TREE_TEXT_COLUMN, metatree_sort_column,
                         NULL, NULL );
     g_object_set_data ( G_OBJECT ( payee_tree_model), "metatree-interface",
-                        payee_interface );
+                        payee_get_metatree_interface ( ) );
 
     /* Create container + TreeView */
     gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (payee_tree), TRUE);
@@ -228,6 +232,7 @@ GtkWidget *onglet_tiers ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Payees"), cell,
 						       "text", META_TREE_TEXT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( payee_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -237,6 +242,7 @@ GtkWidget *onglet_tiers ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Account"), cell,
 						       "text", META_TREE_ACCOUNT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( payee_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -247,6 +253,7 @@ GtkWidget *onglet_tiers ( void )
 						       "text", META_TREE_BALANCE_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
 						       "xalign", META_TREE_XALIGN_COLUMN,
+                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( payee_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -255,6 +262,11 @@ GtkWidget *onglet_tiers ( void )
     gtk_widget_show ( payee_tree );
 
     /* Connect to signals */
+    g_signal_connect ( G_OBJECT ( payee_tree ),
+                        "row-collapsed",
+                        G_CALLBACK ( division_column_collapsed ),
+                        NULL );
+
     g_signal_connect ( G_OBJECT ( payee_tree ),
                         "row-expanded",
                         G_CALLBACK ( division_column_expanded ),
@@ -287,20 +299,14 @@ GtkWidget *onglet_tiers ( void )
 	src_iface -> drag_data_get = &payee_drag_data_get;
     }
 
-    g_signal_connect ( gtk_tree_view_get_selection ( GTK_TREE_VIEW(payee_tree)),
-		       "changed", G_CALLBACK(metatree_selection_changed),
-		       payee_tree_model );
+    g_signal_connect ( gtk_tree_view_get_selection ( GTK_TREE_VIEW ( payee_tree ) ),
+                        "changed",
+                        G_CALLBACK ( metatree_selection_changed ),
+                        payee_tree_model );
 
     /* création de la structure de sauvegarde de la position */
     payee_hold_position = g_malloc0 ( sizeof ( struct metatree_hold_position ) );
 
-    /* création de la structure pour le remplacement des notes */
-    overwrite_payee = g_malloc0 ( sizeof (struct conditional_message ) );
-    overwrite_payee -> name = g_strdup ( "crush-existing-note" );
-    overwrite_payee -> hint = g_strdup ( _("Warning you will crush the existing note.") );
-    overwrite_payee -> hidden = FALSE;
-    overwrite_payee -> default_answer = FALSE;
-
     return ( onglet );
 }
 
@@ -315,76 +321,95 @@ GtkWidget *onglet_tiers ( void )
  */
 GtkWidget *creation_barre_outils_tiers ( void )
 {
-    GtkWidget *hbox, *handlebox, *button;
-
-    /* HandleBox */
-    handlebox = gtk_handle_box_new ();
+    GtkWidget *hbox, *button;
 
     /* Hbox */
     hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_container_add ( GTK_CONTAINER(handlebox), hbox );
 
     /* Add various icons */
-    button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
+    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
 					       _("New payee"), "new-payee.png",
-					       G_CALLBACK(appui_sur_ajout_payee),
+					       G_CALLBACK ( appui_sur_ajout_payee ),
 					       payee_tree_model );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
 				  _("Create a new payee"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
 					   GTK_STOCK_DELETE, _("Delete"),
-					   G_CALLBACK(supprimer_division),
+					   G_CALLBACK ( supprimer_division ),
 					   payee_tree );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL (payee_tree_model), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( payee_tree_model ), button, "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
 				  _("Delete selected payee"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
-					   GTK_STOCK_PROPERTIES, _("Properties"),
-					   G_CALLBACK(edit_payee),
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
+					   GTK_STOCK_EDIT, _("Edit"),
+					   G_CALLBACK ( edit_payee ),
 					   payee_tree );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL (payee_tree_model), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( payee_tree_model ), button, "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
 				  _("Edit selected payee"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    button = gsb_automem_stock_button_menu_new ( etat.display_toolbar,
+    button = gsb_automem_stock_button_menu_new ( conf.display_toolbar,
 						GTK_STOCK_SELECT_COLOR,
 						_("View"),
-						G_CALLBACK(popup_payee_view_mode_menu),
+						G_CALLBACK ( popup_payee_view_mode_menu ),
 						NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
 				  _("Change view mode"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-	button = gsb_automem_imagefile_button_new ( etat.display_toolbar,
+	button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
 						_("Manage payees"), "payeesmg.png",
-						G_CALLBACK( appui_sur_manage_tiers ),
+						G_CALLBACK ( payees_manage_payees ),
 						NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
 				  _("Manage the payees"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    button = gsb_automem_stock_button_new ( etat.display_toolbar,
+    button = gsb_automem_stock_button_new ( conf.display_toolbar,
 					   GTK_STOCK_DELETE, _("Remove unused payees"),
-					   G_CALLBACK(payee_remove_unused),
+					   G_CALLBACK ( payees_remove_unused_payees ),
 					   NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET (button),
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
 				  _("Remove orphan payees"));
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
 
-    gtk_widget_show_all ( handlebox );
+    gtk_widget_show_all ( hbox );
 
-    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL(payee_tree_model),
+    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL ( payee_tree_model ),
 					    FALSE, "selection" );
 
-    return ( handlebox );
+    return ( hbox );
 }
 
 
+
+/**
+ *
+ *
+ *
+ */
+void payees_update_toolbar_list ( void )
+{
+    GList * list = NULL;
+
+    list = gtk_container_get_children ( GTK_CONTAINER ( payee_toolbar ) );
+
+    if ( list )
+    {
+	gtk_container_remove ( GTK_CONTAINER ( payee_toolbar ),
+			       GTK_WIDGET ( list -> data ) );
+	g_list_free ( list );
+    }
+    gtk_container_add ( GTK_CONTAINER ( payee_toolbar ), creation_barre_outils_tiers () );
+}
+
+
+
 /**
  * called by button delete unused payees
  * show a message to be sure and remove all the payees without transactions
@@ -394,8 +419,7 @@ GtkWidget *creation_barre_outils_tiers ( void )
  *
  * \return FALSE
  * */
-gboolean payee_remove_unused ( GtkWidget *button,
-                        gpointer null )
+void payees_remove_unused_payees ( void )
 {
     gint result;
 
@@ -413,10 +437,9 @@ gboolean payee_remove_unused ( GtkWidget *button,
         nb_removed = gsb_data_payee_remove_unused ();
         if ( nb_removed > 0 )
         {
-            payee_fill_tree ();
+            payees_fill_list ();
             tmpstr = g_strdup_printf ( _("Removed %d payees."), nb_removed);
-            if ( etat.modification_fichier == 0 )
-                modification_fichier ( TRUE );
+            gsb_file_set_modified ( TRUE );
         }
         else
         {
@@ -425,7 +448,23 @@ gboolean payee_remove_unused ( GtkWidget *button,
         dialogue (tmpstr);
         g_free (tmpstr);
     }
-    return FALSE;
+}
+
+
+/**
+ * Fonction de callback d'affichage des tiers inutilisés
+ *
+ * \param
+ * \param
+ *
+ * \return
+ */
+static void payee_menu_display_unused_payees_activate ( GtkWidget *item,
+                        gpointer data )
+{
+    display_unused_payees = gtk_check_menu_item_get_active ( GTK_CHECK_MENU_ITEM ( item ) );
+
+    payees_fill_list ();
 }
 
 
@@ -440,6 +479,7 @@ gboolean payee_remove_unused ( GtkWidget *button,
 gboolean popup_payee_view_mode_menu ( GtkWidget * button )
 {
     GtkWidget *menu, *menu_item;
+    gint nb_unused;
 
     menu = gtk_menu_new ();
 
@@ -456,6 +496,33 @@ gboolean popup_payee_view_mode_menu ( GtkWidget * button )
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", payee_tree );
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
 
+    /* Separator */
+    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), gtk_separator_menu_item_new() );
+
+    /* menu pour afficher les tiers inutilisés */
+    if ( ( nb_unused = gsb_data_payee_get_unused_payees () ) == 0 )
+    {
+        menu_item = gtk_check_menu_item_new_with_label ( _("Display unused payees") );
+        gtk_widget_set_sensitive ( menu_item, FALSE );
+    }
+    else
+    {
+        gchar *tmp_str;
+        gchar *tmp_str_1;
+
+        tmp_str = g_strdup_printf (" (%d)", nb_unused );
+        tmp_str_1 = g_strconcat ( _("Display unused payees"), tmp_str, NULL );
+        menu_item = gtk_check_menu_item_new_with_label ( tmp_str_1 );
+        g_free ( tmp_str );
+        g_free ( tmp_str_1 );
+    }
+    gtk_check_menu_item_set_active ( GTK_CHECK_MENU_ITEM ( menu_item ), display_unused_payees );
+    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+    g_signal_connect ( G_OBJECT ( menu_item ),
+                        "activate",
+                        G_CALLBACK ( payee_menu_display_unused_payees_activate ),
+                        NULL );
+
     gtk_widget_show_all ( menu );
 
     gtk_menu_popup ( GTK_MENU(menu), NULL, button, set_popup_position, button, 1,
@@ -473,8 +540,10 @@ gboolean popup_payee_view_mode_menu ( GtkWidget * button )
  *
  * \return
  * */
-void payee_fill_tree ( void )
+void payees_fill_list ( void )
 {
+    void *empty_payee;
+    gint payee_number;
     GSList *payee_list_tmp;
     GtkTreeIter iter_payee;
     GtkTreeSelection *selection;
@@ -483,6 +552,12 @@ void payee_fill_tree ( void )
 
     gsb_status_wait ( FALSE );
 
+    /* on bloque la fonction pendant la mise à jour du model */
+    selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( payee_tree ) );
+    g_signal_handlers_block_by_func ( G_OBJECT ( selection ),
+                        G_CALLBACK ( metatree_selection_changed ),
+                        payee_tree_model );
+
     /* Dettach the model so that insertion will be much faster */
     g_object_ref ( G_OBJECT(payee_tree_model) );
     gtk_tree_view_set_model ( GTK_TREE_VIEW (payee_tree), NULL );
@@ -493,33 +568,45 @@ void payee_fill_tree ( void )
     /* Compute payee balances. */
     gsb_data_payee_update_counters ();
 
-    /** Then, populate tree with payee. */
-    payee_list_tmp = gsb_data_payee_get_payees_list ();
+    /* add the virtually unused payee to the top of the list */
+    empty_payee = gsb_data_payee_get_empty_payee ( );
+    payee_number = gsb_data_payee_get_no_payee ( empty_payee );
+    gtk_tree_store_append (GTK_TREE_STORE (payee_tree_model), &iter_payee, NULL);
+    fill_division_row ( GTK_TREE_MODEL(payee_tree_model),
+                payee_get_metatree_interface ( ),
+                &iter_payee, payee_number );
 
-    payee_list_tmp = g_slist_prepend ( payee_list_tmp, gsb_data_payee_get_empty_payee ());
+    /** Then, populate tree with payee. */
+    payee_list_tmp = g_slist_copy ( gsb_data_payee_get_payees_list () );
+
+    payee_list_tmp = g_slist_sort ( payee_list_tmp, (GCompareFunc) gsb_data_payee_compare_payees_by_name);
 
     while ( payee_list_tmp )
     {
-        gint payee_number;
+        payee_number = gsb_data_payee_get_no_payee ( payee_list_tmp->data);
 
-        payee_number = gsb_data_payee_get_no_payee (payee_list_tmp -> data);
-
-        /* no display the payee without transactions (archived) */
-        if ( payee_number == 0
-         ||
-         gsb_data_payee_get_nb_transactions ( payee_number ) )
+        if ( display_unused_payees || gsb_data_payee_get_nb_transactions ( payee_number ) )
         {
-            gtk_tree_store_append (GTK_TREE_STORE (payee_tree_model), &iter_payee, NULL);
-            fill_division_row ( GTK_TREE_MODEL(payee_tree_model), payee_interface,
-                        &iter_payee, payee_number );
+            gtk_tree_store_append ( GTK_TREE_STORE ( payee_tree_model ), &iter_payee, NULL );
+            fill_division_row ( GTK_TREE_MODEL ( payee_tree_model ),
+                        payee_get_metatree_interface (),
+                        &iter_payee,
+                        payee_number );
         }
         payee_list_tmp = payee_list_tmp -> next;
     }
 
+    g_slist_free ( payee_list_tmp );
+
     /* Reattach the model */
     gtk_tree_view_set_model (GTK_TREE_VIEW (payee_tree),
 			     GTK_TREE_MODEL (payee_tree_model));
 
+    /* on débloque la fonction de callback */
+    g_signal_handlers_unblock_by_func ( G_OBJECT ( selection ),
+                        G_CALLBACK ( metatree_selection_changed ),
+                        payee_tree_model );
+
     /* replace le curseur sur la division, sub_division ou opération initiale */
     if ( payee_hold_position -> path )
     {
@@ -532,12 +619,27 @@ void payee_fill_tree ( void )
             gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( payee_tree ), ancestor );
             gtk_tree_path_free (ancestor );
         }
-        selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( payee_tree ) );
+
+        /* on colorise les lignes du tree_view */
+        utils_set_tree_view_background_color ( payee_tree, META_TREE_BACKGROUND_COLOR );
         gtk_tree_selection_select_path ( selection, payee_hold_position -> path );
         gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( payee_tree ),
                         payee_hold_position -> path,
                         NULL, TRUE, 0.5, 0.5 );
     }
+    else
+    {
+        gchar *title;
+
+        /* on colorise les lignes du tree_view */
+        utils_set_tree_view_background_color ( payee_tree, META_TREE_BACKGROUND_COLOR );
+        /* on fixe le titre et le suffixe de la barre d'information */
+	    title = g_strdup(_("Payees"));
+        gsb_gui_headings_update_title ( title );
+        g_free ( title );
+        gsb_gui_headings_update_suffix ( "" );
+    }
+
     g_object_unref ( G_OBJECT ( payee_tree_model ) );
 
     gsb_status_stop_wait ( FALSE );
@@ -568,18 +670,6 @@ gboolean payee_drag_data_get ( GtkTreeDragSource * drag_source, GtkTreePath * pa
 }
 
 
-
-gint classement_alphabetique_tree ( GtkWidget *tree,
-                        GtkCListRow *ligne_1,
-                        GtkCListRow *ligne_2 )
-{
-    return g_utf8_collate ( ligne_1->cell->u.text, ligne_2->cell->u.text );
-}
-
-
-
-
-
 /**
  *
  *
@@ -597,6 +687,7 @@ gboolean edit_payee ( GtkTreeView * view )
     gchar * title;
     gchar * old_payee;
     GtkTreeIter *div_iter;
+    MetatreeInterface *payee_interface;
 
     devel_debug (NULL);
 
@@ -616,7 +707,7 @@ gboolean edit_payee ( GtkTreeView * view )
     title = g_strdup_printf ( _("Properties for %s"), old_payee );
 
     dialog = gtk_dialog_new_with_buttons ( title,
-                        GTK_WINDOW ( window ),
+                        GTK_WINDOW ( run.window ),
                         GTK_DIALOG_MODAL,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
                         GTK_STOCK_APPLY, GTK_RESPONSE_OK,
@@ -688,8 +779,8 @@ gboolean edit_payee ( GtkTreeView * view )
         {
             gsb_data_payee_set_name ( payee_number,
                         gtk_entry_get_text ( GTK_ENTRY (entry_name)));
-	    break;
-	}
+            break;
+        }
         else
         {
             gchar *message;
@@ -709,6 +800,7 @@ gboolean edit_payee ( GtkTreeView * view )
 
     gtk_widget_destroy ( dialog );
 
+    payee_interface = payee_get_metatree_interface ( );
     div_iter = get_iter_from_div ( model, payee_number, 0 );
     fill_division_row ( model, payee_interface,
                         div_iter, payee_number );
@@ -729,8 +821,7 @@ gboolean edit_payee ( GtkTreeView * view )
 
     /* update the transactions list */
     transaction_list_update_element (ELEMENT_PARTY);
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -784,7 +875,7 @@ void appui_sur_ajout_payee ( GtkTreeModel * model )
  *
  * \param path
  */
-gboolean payee_hold_position_set_path ( GtkTreePath *path )
+gboolean payees_hold_position_set_path ( GtkTreePath *path )
 {
     payee_hold_position -> path = gtk_tree_path_copy ( path );
 
@@ -795,7 +886,7 @@ gboolean payee_hold_position_set_path ( GtkTreePath *path )
  *
  * \param expand
  */
-gboolean payee_hold_position_set_expand ( gboolean expand )
+gboolean payees_hold_position_set_expand ( gboolean expand )
 {
     payee_hold_position -> expand = expand;
 
@@ -812,7 +903,7 @@ gboolean payee_hold_position_set_expand ( gboolean expand )
  *
  *
  */
-void appui_sur_manage_tiers ( void )
+void payees_manage_payees ( void )
 {
     GtkWidget *assistant;
     GtkResponseType return_value;
@@ -939,14 +1030,14 @@ void appui_sur_manage_tiers ( void )
             }
             /* on efface les tiers inutilisés */
             nb_removed = gsb_data_payee_remove_unused ();
-            payee_fill_tree ();
+            payees_fill_list ();
             if ( nb_removed == 1 )
             {
                 tmpstr = g_strdup_printf ( _("One payee was replaced with a new one."));
             }
             else
             {
-                tmpstr = g_strdup_printf ( _("%d payees were replaced with a new one."), 
+                tmpstr = g_strdup_printf ( _("%d payees were replaced with a new one."),
                             nb_removed);
             }
             dialogue (tmpstr);
@@ -957,11 +1048,10 @@ void appui_sur_manage_tiers ( void )
             gsb_data_payee_set_name ( new_payee_number,
                         gtk_entry_get_text ( g_object_get_data (
                         G_OBJECT (assistant), "new_payee") ) );
-            payee_fill_tree ();
+            payees_fill_list ();
         }
 
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
 
         /* On sélectionne le nouveau tiers */
         iter = get_iter_from_div ( GTK_TREE_MODEL ( payee_tree_model ), new_payee_number, 0 );
@@ -976,6 +1066,7 @@ void appui_sur_manage_tiers ( void )
         gsb_status_stop_wait ( TRUE );
     }
 
+    g_slist_free ( g_object_get_data ( G_OBJECT (assistant), "sup_payees" ) );
     gtk_widget_destroy (assistant);
 }
 
@@ -1278,20 +1369,25 @@ static gboolean gsb_assistant_payees_enter_page_3 ( GtkWidget *assistant )
 
     str_cherche = gtk_combofix_get_text ( g_object_get_data (
                         G_OBJECT (assistant), "payee") );
-    str = g_strdup_printf ( _("Payee sought : %s"), str_cherche );
+
+    str = g_strdup_printf ( _("Payee sought: %s"), str_cherche );
     payee_search_label = g_object_get_data (
                         G_OBJECT (assistant), "payee_search_label" );
     gtk_label_set_text ( GTK_LABEL (payee_search_label), str );
+    g_free ( str );
+
     new_tiers = gtk_entry_get_text( g_object_get_data (
                         G_OBJECT (assistant), "new_payee") );
-    new_tiers = g_strdup_printf ( _("New payee : %s"), new_tiers );
+    str = g_strdup_printf ( _("New payee: %s"), new_tiers );
     new_payee_label = g_object_get_data (
                         G_OBJECT (assistant), "new_payee_label" );
-    gtk_label_set_text ( GTK_LABEL (new_payee_label), new_tiers );
+    gtk_label_set_text ( GTK_LABEL (new_payee_label), str );
+    g_free ( str );
 
     payee_list_tmp = gsb_data_payee_get_payees_list ();
-    list_store = gtk_list_store_new ( N_COLUMNS, G_TYPE_BOOLEAN,
-                        G_TYPE_UINT, G_TYPE_STRING );
+    treeview = g_object_get_data ( G_OBJECT (assistant), "treeview" );
+    list_store = GTK_LIST_STORE ( gtk_tree_view_get_model ( treeview ) );
+    gtk_list_store_clear ( list_store );
 
     while ( payee_list_tmp )
     {
@@ -1320,16 +1416,17 @@ static gboolean gsb_assistant_payees_enter_page_3 ( GtkWidget *assistant )
 
     if ( i > 0 )
     {
-        treeview = g_object_get_data ( G_OBJECT (assistant), "treeview" );
-        if ( treeview )
-            gtk_tree_view_set_model (GTK_TREE_VIEW (treeview),
-                            GTK_TREE_MODEL (list_store));
         label = g_object_get_data ( G_OBJECT (assistant), "nbre_tiers_total" );
-        gtk_label_set_text ( GTK_LABEL (label ),
-                        g_strdup_printf ("%d", i ) );
+        str = g_strdup_printf ("%d", i );
+        gtk_label_set_text ( GTK_LABEL (label), str );
+        g_free ( str );
+
         label = g_object_get_data ( G_OBJECT (assistant), "nbre_tiers_select" );
-        gtk_label_set_text ( GTK_LABEL (label ),
-                        g_strdup_printf ("%d", i ) );
+        str = g_strdup_printf ("%d", i );
+        gtk_label_set_text ( GTK_LABEL (label), str );
+        g_free ( str );
+
+        g_slist_free ( g_object_get_data ( G_OBJECT (assistant), "sup_payees" ) );
         g_object_set_data ( G_OBJECT (assistant), "sup_payees", sup_payees );
     }
     return FALSE;
@@ -1342,26 +1439,27 @@ static gboolean gsb_assistant_payees_enter_page_3 ( GtkWidget *assistant )
  */
 static gboolean gsb_assistant_payees_enter_page_finish ( GtkWidget *assistant )
 {
-    GtkTreeView *treeview;
     GtkLabel *label;
     GtkComboFix *combo;
     GtkEntry *entry;
     GSList *sup_payees;
     gchar *tmpstr;
     const gchar *str_cherche;
+    gchar *str_replace_wildcard;
 
     devel_debug ("Enter page finish");
-    treeview = g_object_get_data ( G_OBJECT (assistant), "treeview" );
     sup_payees = g_object_get_data ( G_OBJECT (assistant), "sup_payees" );
     combo = g_object_get_data ( G_OBJECT (assistant), "payee");
     str_cherche = gtk_combofix_get_text ( combo );
     entry = g_object_get_data ( G_OBJECT (assistant), "new_payee");
+    str_replace_wildcard = gsb_string_remplace_joker ( str_cherche, "..." );
+
     if ( g_slist_length (sup_payees) == 1 )
     {
     tmpstr = g_strdup_printf (
                         _("You are about to replace one payee which name contain %s by %s\n\n"
                         "Are you sure?"),
-                        gsb_string_remplace_joker ( str_cherche, "..." ),
+                        str_replace_wildcard,
                         gtk_entry_get_text ( entry) );
     }
     else
@@ -1370,12 +1468,13 @@ static gboolean gsb_assistant_payees_enter_page_finish ( GtkWidget *assistant )
                         _("You are about to replace %d payees whose names contain %s by %s\n\n"
                         "Are you sure?"),
                         g_slist_length (sup_payees),
-                        gsb_string_remplace_joker ( str_cherche, "..." ),
+                        str_replace_wildcard,
                         gtk_entry_get_text ( entry) );
     }
     label = g_object_get_data ( G_OBJECT (assistant), "finish_label" );
     gtk_label_set_markup ( label, tmpstr );
 
+    g_free ( str_replace_wildcard );
     g_free ( tmpstr);
 
     return FALSE;
@@ -1486,8 +1585,6 @@ void gsb_assistant_payees_toggled ( GtkCellRendererToggle *cell,
 
     /* do something with the value */
     sup_payees = g_object_get_data ( G_OBJECT (assistant), "sup_payees" );
-    if (!sup_payees)
-        return;
     if ( g_slist_find (sup_payees, GINT_TO_POINTER (payee_number)) && fixed )
         sup_payees = g_slist_delete_link ( sup_payees,
                         g_slist_find ( sup_payees,
@@ -1620,6 +1717,8 @@ void gsb_assistant_payees_modifie_operations ( GSList *sup_payees,
     gint payee_number;
     gchar *nombre;
     gboolean question = TRUE;
+    struct conditional_message overwrite_payee;
+
 
     payee_number = gsb_data_mix_get_party_number ( transaction_number, is_transaction );
     if ( g_slist_find ( sup_payees, GINT_TO_POINTER ( payee_number ) ) )
@@ -1632,17 +1731,25 @@ void gsb_assistant_payees_modifie_operations ( GSList *sup_payees,
                         transaction_number, is_transaction ) );
             if ( tmpstr && strlen ( tmpstr ) )
             {
-                overwrite_payee -> message = g_strdup_printf (
+
+                overwrite_payee.name = g_strdup ( "crush-existing-note" );
+                overwrite_payee.hint = g_strdup ( _("Warning you will crush the existing note.") );
+                overwrite_payee.hidden = FALSE;
+                overwrite_payee.default_answer = FALSE;
+                overwrite_payee.message = g_strdup_printf (
                     _("Do you want overwrite the existing note.\n\n"
                     "If you answer YES, the existing note will be replaced by %s."),
                     gsb_data_payee_get_name ( payee_number, TRUE ) );
 
                 if ( question_conditional_yes_no_with_struct (
-                 overwrite_payee ) == FALSE )
+                 &overwrite_payee ) == FALSE )
                     question = FALSE;
+                g_free ( overwrite_payee.name );
+                g_free ( overwrite_payee.hint );
+                g_free ( overwrite_payee.message );
                 g_free ( tmpstr );
             }
-            else 
+            else
                 question = TRUE;
             if ( question && my_strcmp ( (gchar *) gsb_data_payee_get_name (
                 payee_number, TRUE ),
@@ -1716,6 +1823,69 @@ gboolean payee_list_button_press ( GtkWidget *tree_view,
 }
 
 
+/**
+ *
+ *
+ *
+ */
+GtkTreeStore *payees_get_tree_store ( void )
+{
+    return payee_tree_model;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+GtkWidget *payees_get_tree_view ( void )
+{
+    return payee_tree;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void payees_new_payee ( void )
+{
+    metatree_new_division ( GTK_TREE_MODEL ( payee_tree_model ) );
+
+    sortie_edit_payee = FALSE;
+    edit_payee ( GTK_TREE_VIEW ( payee_tree ) );
+    if ( sortie_edit_payee )
+    {
+        supprimer_division ( GTK_TREE_VIEW ( payee_tree ) );
+        sortie_edit_payee = FALSE;
+    }
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void payees_delete_payee ( void )
+{
+    supprimer_division ( GTK_TREE_VIEW ( payee_tree ) );
+}
+
+
+/**
+ *
+ *
+ *
+ */
+void payees_edit_payee ( void )
+{
+    edit_payee ( GTK_TREE_VIEW ( payee_tree ) );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
