@@ -26,7 +26,7 @@
  * \file transaction_list.c
  * this contains the general functions to work with the CustomList
  * as append/remove some transactions, filter, colorize the list...
- * 
+ *
  * Grisbi shouldn't work directly on the CustomList except by those files
  */
 
@@ -35,12 +35,14 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "transaction_list.h"
 #include "affichage_liste.h"
 #include "custom_list.h"
 #include "dialog.h"
+#include "gsb_color.h"
 #include "gsb_data_account.h"
 #include "gsb_data_archive.h"
 #include "gsb_data_archive_store.h"
@@ -55,6 +57,7 @@
 #include "transaction_list_sort.h"
 #include "transaction_model.h"
 #include "utils_dates.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -67,18 +70,11 @@ static gboolean transaction_list_update_white_child ( CustomRecord *white_record
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GdkColor archive_background_color;
-extern GdkColor couleur_fond[2];
-extern GdkColor couleur_jour;
 extern gint display_one_line;
 extern gint display_three_lines;
 extern gint display_two_lines;
-extern gsb_real null_real;
 extern GSList *orphan_child_transactions;
-extern GdkColor split_background;
 extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
-extern GdkColor text_color[2];
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -101,6 +97,7 @@ gboolean transaction_list_create (void)
 
     custom_list = custom_list_new ();
     transaction_model_set_model (custom_list);
+    g_object_unref ( custom_list );
 
     return (custom_list != NULL);
 }
@@ -157,14 +154,14 @@ void transaction_list_append_transaction ( gint transaction_number )
 	white_record = g_malloc0 (sizeof (CustomRecord));
 	white_record -> transaction_pointer = gsb_data_transaction_get_pointer_of_transaction (white_line_number);
 	white_record -> what_is_line = IS_TRANSACTION;
-	white_record -> row_bg = &split_background;
+	white_record -> row_bg = gsb_color_get_couleur ( "split_background" );
 
 	/* as we append just now the white line, there are no child split, so the total is 0 */
-	amount_string = gsb_real_get_string_with_currency (null_real,
+	amount_string = utils_real_get_string_with_currency (null_real,
 							   gsb_data_transaction_get_currency_number (transaction_number), TRUE);
-	variance_string = gsb_real_get_string_with_currency (gsb_data_transaction_get_amount (transaction_number),
+	variance_string = utils_real_get_string_with_currency (gsb_data_transaction_get_amount (transaction_number),
 							     gsb_data_transaction_get_currency_number (transaction_number), TRUE);
-	white_record -> visible_col[2] = g_strdup_printf ( _("Total : %s (variance : %s)"),
+	white_record -> visible_col[2] = g_strdup_printf ( _("Total: %s (variance : %s)"),
 							   amount_string,
 							   variance_string );
 	g_free (amount_string);
@@ -244,7 +241,7 @@ void transaction_list_append_transaction ( gint transaction_number )
             newrecord[i] -> has_expander = TRUE;
             white_record -> mother_row = newrecord[i];
             /* set the color of the mother */
-            mother_text_color = &text_color[1];
+            mother_text_color = gsb_color_get_couleur_with_indice ( "text_color", 1 );
             newrecord[i] -> text_color = mother_text_color;
 	    }
 
@@ -292,7 +289,7 @@ void transaction_list_append_transaction ( gint transaction_number )
  *
  * \return
  * */
-void transaction_list_append_archive (gint archive_store_number)
+void transaction_list_append_archive ( gint archive_store_number )
 {
     gint archive_number;
     gulong newsize;
@@ -323,7 +320,7 @@ void transaction_list_append_archive (gint archive_store_number)
     /* create and fill the record */
     newrecord = g_malloc0 (sizeof (CustomRecord));
 
-    archive_number = gsb_data_archive_store_get_archive_number (archive_store_number);
+    archive_number = gsb_data_archive_store_get_archive_number ( archive_store_number );
 
     if ( find_element_col ( ELEMENT_DATE ) == 0 )
         element_date = find_element_col_for_archive ( );
@@ -343,7 +340,8 @@ void transaction_list_append_archive (gint archive_store_number)
     else
         amount_col = find_element_col (ELEMENT_CREDIT);
 
-    newrecord -> visible_col[amount_col] = gsb_real_get_string_with_currency (
+    if ( amount_col > 0 )
+        newrecord -> visible_col[amount_col] = utils_real_get_string_with_currency (
                         gsb_data_archive_store_get_balance (archive_store_number),
                         gsb_data_account_get_currency (
                         gsb_data_archive_store_get_account_number ( archive_store_number ) ),
@@ -351,7 +349,7 @@ void transaction_list_append_archive (gint archive_store_number)
     newrecord -> transaction_pointer = gsb_data_archive_store_get_structure (
                         archive_store_number);
     newrecord -> what_is_line = IS_ARCHIVE;
-    newrecord -> row_bg = &archive_background_color;
+    newrecord -> row_bg = gsb_color_get_couleur ( "archive_background_color" );
 
     /* save the newrecord pointer */
     custom_list->rows[pos] = newrecord;
@@ -408,14 +406,14 @@ gboolean transaction_list_remove_transaction ( gint transaction_number )
                         record -> children_rows[0] -> transaction_pointer ) );
 
     /* now we can delete the rows */
-    for (i=0 ; i<CUSTOM_MODEL_N_VISIBLES_COLUMN ; i++)
+    for (i=0 ; i<CUSTOM_MODEL_VISIBLE_COLUMNS ; i++)
 	if (record -> visible_col[i])
 	    g_free (record -> visible_col[i]);
 
     if (record -> mother_row)
     {
 	/* we are deleting a child, update the mother
-	 * the child can never be the last one of the mother because there is 
+	 * the child can never be the last one of the mother because there is
      * always a white line at the end */
 	gint new_number_of_children;
 	CustomRecord **new_children_rows;
@@ -548,10 +546,10 @@ gboolean transaction_list_remove_archive ( gint archive_number )
         /* we are on a good archive store, delete it */
 
         /* delete the rows */
-        for ( j=0 ; j<CUSTOM_MODEL_N_VISIBLES_COLUMN ; j++ )
+        for ( j=0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++ )
             if (record -> visible_col[j])
                 g_free (record -> visible_col[j]);
-        
+
         /* remove the row. I decrement "i" because the next line of model is shifted
          * and has  "i" for index. Otherwise we do not test. */
         custom_list -> num_rows--;
@@ -715,7 +713,7 @@ void transaction_list_filter ( gint account_number )
 	    case IS_TRANSACTION:
 		/* the row is shown, if it's the last row chowed of the transaction
 		 * we have to move the children to that row if they exist */
-		if ( record -> number_of_children && 
+		if ( record -> number_of_children &&
 		     record -> line_in_transaction == ( transaction_list_get_last_line (
 											gsb_data_account_get_nb_rows (account_number) ) ) )
 		{
@@ -740,7 +738,7 @@ void transaction_list_filter ( gint account_number )
 		if (previous_shown && (record -> filtered_pos == last_pos_filtered_list))
 		{
 		    /* the row itself didn't change but perhaps it got or losed some children
-		     * in that case, the children were moved before, so we just have to 
+		     * in that case, the children were moved before, so we just have to
 		     * tell to the tree view that children changed */
 		    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list),
 							  path, &iter);
@@ -810,7 +808,7 @@ void transaction_list_filter ( gint account_number )
  *
  * to update all the tree view, use gsb_transactions_list_update_tree_view instead
  *
- * \param 
+ * \param
  *
  * \return
  * */
@@ -856,7 +854,8 @@ void transaction_list_colorize (void)
             {
                 /* set the color of the mother */
                 for (j=0 ; j<TRANSACTION_LIST_ROWS_NB ; j++)
-                    record -> transaction_records[j] -> text_color = &text_color[0];
+                    record -> transaction_records[j] -> text_color =
+                                                            gsb_color_get_couleur_with_indice ( "text_color", 0 );
             }
 
         }
@@ -868,7 +867,7 @@ void transaction_list_colorize (void)
 	    }
 
 	    /* set the color of the row */
-	    record -> row_bg = &couleur_fond[current_color];
+	    record -> row_bg = gsb_color_get_couleur_with_indice ( "couleur_fond", current_color );
 	}
     }
 }
@@ -913,7 +912,7 @@ void transaction_list_set_balances ( void )
 
     if ( account_number == -1
 	 ||
-	 line_balance == -1 
+	 line_balance == -1
 	 ||
 	 !display_mode_check_line ( line_balance, nb_rows ) )
 	return;
@@ -961,7 +960,7 @@ void transaction_list_set_balances ( void )
 
         /* calculate the new balance */
         current_total = gsb_real_add ( current_total, amount );
-        record -> visible_col[column_balance] = gsb_real_get_string_with_currency ( current_total,
+        record -> visible_col[column_balance] = utils_real_get_string_with_currency ( current_total,
                                                  currency_number , TRUE);
         if (current_total.mantissa >= 0)
             record -> amount_color = NULL;
@@ -1005,6 +1004,7 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
     gint nb_rows;
     gint line_p;
     gboolean marked_transaction;
+    gboolean mother_is_visible = TRUE;
     CustomList *custom_list;
     CustomRecord *white_record = NULL;
     CustomRecord **children_rows = NULL;
@@ -1021,11 +1021,12 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
     /* we can update a transaction wich is not visible, so need to find the iter into
      * all the transactions */
     if (!transaction_model_get_transaction_iter (&iter, transaction_number, 0))
-	return FALSE;
+        return FALSE;
 
     record = iter.user_data;
     if (!record)
-	return FALSE;
+        return FALSE;
+
     /* printf ("transaction_number = %d record -> filtered_pos = %d record -> line_in_transaction = %d\n",
         transaction_number,
         record -> filtered_pos,
@@ -1037,33 +1038,33 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
 	&&
 	!record -> number_of_children )
     {
-	/* there is no children, we add a white line */
-	gint white_line_number;
-	gchar *amount_string;
-	gchar *variance_string;
+        /* there is no children, we add a white line */
+        gint white_line_number;
+        gchar *amount_string;
+        gchar *variance_string;
 
-	white_line_number = gsb_data_transaction_new_white_line (transaction_number);
-	children_rows = g_malloc0 (sizeof (CustomRecord*));
+        white_line_number = gsb_data_transaction_new_white_line (transaction_number);
+        children_rows = g_malloc0 (sizeof (CustomRecord*));
 
-	/* create and fill the white line record */
-	white_record = g_malloc0 (sizeof (CustomRecord));
-	white_record -> transaction_pointer = gsb_data_transaction_get_pointer_of_transaction (
-                        white_line_number);
-	white_record -> what_is_line = IS_TRANSACTION;
-	white_record -> row_bg = &split_background;
+        /* create and fill the white line record */
+        white_record = g_malloc0 (sizeof (CustomRecord));
+        white_record -> transaction_pointer = gsb_data_transaction_get_pointer_of_transaction (
+                            white_line_number);
+        white_record -> what_is_line = IS_TRANSACTION;
+        white_record -> row_bg = gsb_color_get_couleur ( "split_background" );
 
-	/* as we append just now the white line, there are no child split, so the total is 0 */
-	amount_string = gsb_real_get_string_with_currency (null_real,
-							   gsb_data_transaction_get_currency_number (transaction_number), TRUE);
-	variance_string = gsb_real_get_string_with_currency (gsb_data_transaction_get_amount (transaction_number),
-							     gsb_data_transaction_get_currency_number (transaction_number), TRUE);
-	white_record -> visible_col[2] = g_strdup_printf ( _("Total : %s (variance : %s)"),
-							   amount_string,
-							   variance_string );
-	g_free (amount_string);
-	g_free (variance_string);
+        /* as we append just now the white line, there are no child split, so the total is 0 */
+        amount_string = utils_real_get_string_with_currency (null_real,
+                                   gsb_data_transaction_get_currency_number (transaction_number), TRUE);
+        variance_string = utils_real_get_string_with_currency (gsb_data_transaction_get_amount (transaction_number),
+                                     gsb_data_transaction_get_currency_number (transaction_number), TRUE);
+        white_record -> visible_col[2] = g_strdup_printf ( _("Total: %s (variance : %s)"),
+                                   amount_string,
+                                   variance_string );
+        g_free (amount_string);
+        g_free (variance_string);
 
-	children_rows[0] = white_record;
+        children_rows[0] = white_record;
     }
 
     /* get the P position if the transaction is marked */
@@ -1071,19 +1072,27 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
     line_p = find_element_line (ELEMENT_MARK);
 
     /* if we update a child, only 1 line */
-    if (record -> mother_row)
-	nb_rows = 1;
+    if ( record -> mother_row )
+    {
+        nb_rows = 1;
+        /* positione une variable qui indique que l'opération fille qui est l'objet d'une mise à jour
+         * est une contre opération d'un transfert et donc que sa mère n'est pas visible.
+         * Ça empêche la mise à jour du tree_view.
+         */
+        if ( record -> mother_row -> filtered_pos == -1 )
+            mother_is_visible = FALSE;
+    }
     else
-	nb_rows = TRANSACTION_LIST_ROWS_NB;
+        nb_rows = TRANSACTION_LIST_ROWS_NB;
 
     /* now we can save the new rows */
     for (i=0 ; i<nb_rows ; i++)
     {
-	CustomRecord *tmp_record;
+        CustomRecord *tmp_record;
 
-	/* get the good line in the record */
-	if (!record -> mother_row)
-	    record = record -> transaction_records[i];
+        /* get the good line in the record */
+        if (!record -> mother_row)
+            record = record -> transaction_records[i];
 
         if ( !record )
             return FALSE;
@@ -1091,7 +1100,7 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
         /* the tmp record will contain the new gchars of columns */
         tmp_record = transaction_list_create_record (transaction_number, i);
 
-        for (j=0 ; j<CUSTOM_MODEL_N_VISIBLES_COLUMN ; j++)
+        for (j=0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++)
         {
             if (record -> visible_col[j])
                 g_free (record -> visible_col[j]);
@@ -1112,9 +1121,9 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
             record -> checkbox_active = marked_transaction;
 
         /* inform the tree view we changed the row, only if visible */
-        if (record -> filtered_pos != -1)
+        if ( record -> filtered_pos != -1 && mother_is_visible )
         {
-            GtkTreePath *path = gtk_tree_path_new();
+            GtkTreePath *path = gtk_tree_path_new ();
 
             /* if there is some children and we are the last row, set the expander */
             if ( white_record
@@ -1127,9 +1136,10 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
 
             /* set the path */
             if (record -> mother_row)
-            /* it's a child, need to get the path of the mother */
-            gtk_tree_path_append_index (path, record -> mother_row -> filtered_pos);
-            gtk_tree_path_append_index(path, record->filtered_pos);
+                /* it's a child, need to get the path of the mother if visible */
+                gtk_tree_path_append_index (path, record -> mother_row -> filtered_pos);
+
+            gtk_tree_path_append_index (path, record->filtered_pos);
 
             /* set the iter */
             iter.user_data = record;
@@ -1146,7 +1156,7 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
     }
 
     /* if the modification is on a child or a mother, update the white line */
-    if (record -> mother_row || record -> number_of_children)
+    if ( ( record -> mother_row && mother_is_visible ) || record -> number_of_children)
     {
         /* we need now to recalculate the amount of split and update the white line */
         CustomRecord *mother_record;
@@ -1167,7 +1177,7 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
         record -> checkbox_active = marked_transaction;
 
     /* inform the tree view we changed the row, only if visible */
-    if (record -> filtered_pos != -1)
+    if ( record -> filtered_pos != -1 && mother_is_visible )
     {
         GtkTreePath *path = gtk_tree_path_new();
 
@@ -1176,14 +1186,14 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
          &&
          i == ( transaction_list_get_last_line ( custom_list -> nb_rows_by_transaction ) ) )
         {
-        record -> has_expander = TRUE;
-        white_record -> mother_row = record;
+            record -> has_expander = TRUE;
+            white_record -> mother_row = record;
         }
 
         /* set the path */
         if (record -> mother_row)
-        /* it's a child, need to get the path of the mother */
-        gtk_tree_path_append_index (path, record -> mother_row -> filtered_pos);
+            /* it's a child, need to get the path of the mother */
+            gtk_tree_path_append_index (path, record -> mother_row -> filtered_pos);
         gtk_tree_path_append_index(path, record->filtered_pos);
 
         /* set the iter */
@@ -1194,21 +1204,12 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
 
         /* if there is a child (white line), set the expander */
         if (record -> has_expander)
-        gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list),
-                              path, &iter);
+            gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list), path, &iter);
+
         gtk_tree_path_free(path);
     }
 
-    if (nb_rows == 1)
-    {
-        CustomRecord *white_record;
-
-        /* we need now to recalculate the amount of split and update the white line */
-        white_record = record -> mother_row -> children_rows[record -> 
-                            mother_row -> number_of_children -1];
-        transaction_list_update_white_child (white_record);
-    }
-
+    /* return */
     return TRUE;
 }
 
@@ -1233,7 +1234,7 @@ gboolean transaction_list_update_element ( gint element_number )
     /* for now, this is the same position for all accounts, so no problem */
 
     /* get the position of the element */
-    column_element = find_element_col (element_number);        /*  0 to CUSTOM_MODEL_N_VISIBLES_COLUMN */
+    column_element = find_element_col (element_number);        /*  0 to CUSTOM_MODEL_VISIBLE_COLUMNS */
     line_element = find_element_line (element_number);        /*  0 to TRANSACTION_LIST_ROWS_NB */
 
     if ( column_element == -1
@@ -1249,7 +1250,7 @@ gboolean transaction_list_update_element ( gint element_number )
  * update the column of all the record with the value
  * this is used to update some non seen fixed columns, as font for example
  * to update some visible columns, use instead transaction_list_update_element
- * 
+ *
  * the columns are defined in custom_list.h
  *
  * \param column    the column of the value we want to update
@@ -1515,7 +1516,7 @@ gboolean transaction_list_show_toggle_mark ( gboolean show )
  * Sets the value of one or more cells in the row referenced by iter.
  * The variable argument list should contain integer column numbers, each column number followed by the value to be set.
  * The list is terminated by a -1
- * 
+ *
  * \param iter        iter of the row
 
  * \param column    number of column
@@ -1598,7 +1599,7 @@ void transaction_list_set ( GtkTreeIter *iter, ... )
 	    case CUSTOM_MODEL_VISIBLE:
 		/* this value should not be changed here, check later if i'm right,
 		 * for now just show a message */
-		devel_debug (_("Try to change a visible line by transaction_list_set. It shouldn't append ! Check that."));
+		devel_debug (_("Try to change a visible line by transaction_list_set. It shouldn't append! Check that."));
 		/*         record -> line_visible = va_arg (var_args, gboolean); */
 		break;
 	    case CUSTOM_MODEL_CHECKBOX_VISIBLE:
@@ -1780,7 +1781,7 @@ static void transaction_list_append_child ( gint transaction_number )
      * we go on the first mother */
     mother_record = mother_record -> transaction_records[0];
 
-    /* set by default the mother row of the child. avoids a crash when creating 
+    /* set by default the mother row of the child. avoids a crash when creating
      * an archive directly on the home page */
     newrecord -> mother_row = mother_record;
 
@@ -1822,7 +1823,7 @@ static void transaction_list_append_child ( gint transaction_number )
     white_record -> filtered_pos = pos;
 
     /* set the color */
-    newrecord -> row_bg = &split_background;
+    newrecord -> row_bg = gsb_color_get_couleur ( "split_background" );
 
     /* we can now save the new number of children and the new children rows into their mothers */
     for (i=0 ; i < TRANSACTION_LIST_ROWS_NB ; i++)
@@ -1903,7 +1904,7 @@ static CustomRecord *transaction_list_create_record ( gint transaction_number,
     newrecord = g_malloc0 (sizeof (CustomRecord));
 
     /* fill the row with the visibles columns */
-    for ( column = 0 ; column < CUSTOM_MODEL_N_VISIBLES_COLUMN ; column++ )
+    for ( column = 0 ; column < CUSTOM_MODEL_VISIBLE_COLUMNS ; column++ )
 	newrecord -> visible_col[column] = gsb_transactions_list_grep_cell_content ( transaction_number,
 										     tab_affichage_ope[line_in_transaction][column]);
 
@@ -1914,7 +1915,7 @@ static CustomRecord *transaction_list_create_record ( gint transaction_number,
     newrecord -> line_in_transaction = line_in_transaction;
     newrecord -> checkbox_visible_reconcile = line_in_transaction == 0 ? 1 : 0;
     newrecord -> checkbox_active = gsb_data_transaction_get_marked_transaction (transaction_number) != 0;
-    newrecord -> text_color = &text_color[0];
+    newrecord -> text_color = gsb_color_get_couleur_with_indice ( "text_color", 0 );
 
     return newrecord;
 }
@@ -1959,23 +1960,23 @@ static gboolean transaction_list_update_white_child ( CustomRecord *white_record
     variance = gsb_real_sub ( gsb_data_transaction_get_amount (transaction_number),
 			      total_split);
     /* update the white line */
-    amount_string = gsb_real_get_string_with_currency (total_split,
+    amount_string = utils_real_get_string_with_currency (total_split,
 						       gsb_data_transaction_get_currency_number (transaction_number), TRUE);
-    variance_string = gsb_real_get_string_with_currency (variance,
+    variance_string = utils_real_get_string_with_currency (variance,
 							 gsb_data_transaction_get_currency_number (transaction_number), TRUE);
 
     /* show the variance and sub-total only if different of the transaction */
     if (variance.mantissa)
     {
-	white_record -> visible_col[2] = g_strdup_printf ( _("Total : %s (variance : %s)"),
+	white_record -> visible_col[2] = g_strdup_printf ( _("Total: %s (variance : %s)"),
 							   amount_string,
 							   variance_string );
-	mother_text_color = &text_color[1];
+	mother_text_color = gsb_color_get_couleur_with_indice ( "text_color", 1 );
     }
     else
     {
 	white_record -> visible_col[2] = NULL;
-	mother_text_color = &text_color[0];
+	mother_text_color = gsb_color_get_couleur_with_indice ( "text_color", 0 );
     }
 
     /* set the color of the mother */
@@ -2065,7 +2066,7 @@ gint transaction_list_get_last_line ( gint nb_rows )
 /**
  * colorise avec un fond gris la ligne qui correspond à la date du jour
  *
- * \param 
+ * \param
  *
  * \return
  * */
@@ -2110,7 +2111,7 @@ void transaction_list_set_color_jour ( gint account_number )
                     /* colorize the record */
                     for (j=0 ; j < custom_list -> nb_rows_by_transaction ; j++)
                     {
-                        record -> row_bg = &couleur_jour;
+                        record -> row_bg = gsb_color_get_couleur ( "couleur_jour" );
                         i--;
                         if ( i >= 0 )
                             record = custom_list -> visibles_rows[i];
@@ -2122,7 +2123,7 @@ void transaction_list_set_color_jour ( gint account_number )
             }
         }
     }
-    g_date_free ( date_jour ); 
+    g_date_free ( date_jour );
 }
 
 
@@ -2146,7 +2147,7 @@ gboolean transaction_list_get_variance ( gint transaction_number )
     g_return_val_if_fail ( custom_list != NULL, FALSE );
 
     /* if the selection didn't change, do nothing */
-    if ( gsb_data_transaction_get_transaction_number (custom_list -> selected_row) == 
+    if ( gsb_data_transaction_get_transaction_number (custom_list -> selected_row) ==
         transaction_number )
         white_record = custom_list -> selected_row;
 
@@ -2160,6 +2161,8 @@ gboolean transaction_list_get_variance ( gint transaction_number )
     }
 
     mother_record = white_record -> mother_row;
+    if ( !mother_record )
+        return FALSE;
 
     for (i=0 ; i < mother_record -> number_of_children -1 ; i++)
     {
@@ -2183,6 +2186,79 @@ gboolean transaction_list_get_variance ( gint transaction_number )
     else
         return FALSE;
 }
+
+
+/**
+ * remove an archive line from the tree model
+ * it should be a good thing to update the tree_view after that
+ *
+ * \param archive_number    the archive to remove
+ * \param account_number    the account
+ *
+ * \return TRUE : archive removed, FALSE : problem, nothing done
+ * */
+gboolean transaction_list_remove_archive_line ( gint archive_number,
+                        gint account_number )
+{
+    gint i;
+    CustomList *custom_list;
+    gboolean return_val = FALSE;
+
+    custom_list = transaction_model_get_model ();
+
+    if ( custom_list == NULL )
+        return FALSE;
+
+    for ( i = 0 ; i < custom_list -> num_rows ; i++ )
+    {
+        CustomRecord *record;
+        gulong newsize;
+        gint j;
+        gint archive_store_number;
+
+        record = custom_list -> rows[i];
+        archive_store_number = gsb_data_archive_store_get_number ( record -> transaction_pointer );
+        if ( record -> what_is_line != IS_ARCHIVE
+         ||
+         gsb_data_archive_store_get_archive_number ( archive_store_number ) != archive_number
+         ||
+         gsb_data_archive_store_get_account_number ( archive_store_number ) != account_number )
+        {
+            continue;
+        }
+
+        /* we are on a good archive store, delete it */
+
+        /* delete the row */
+        for ( j=0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++ )
+            if (record -> visible_col[j])
+                g_free (record -> visible_col[j]);
+
+        /* remove the row. I decrement "i" because the next line of model is shifted
+         * and has  "i" for index. Otherwise we do not test. */
+        custom_list -> num_rows--;
+        i--;
+
+        for (j=record -> pos ; j < custom_list -> num_rows ; j++)
+        {
+            custom_list -> rows[j] = custom_list -> rows[j+1];
+            custom_list -> rows[j] -> pos = j;
+        }
+
+        /* resize the array */
+        newsize = custom_list->num_rows * sizeof(CustomRecord*);
+        custom_list->rows = g_realloc(custom_list->rows, newsize);
+        custom_list->visibles_rows = g_realloc(custom_list->visibles_rows, newsize);
+
+        /* free the record */
+        g_free (record);
+        return_val = TRUE;
+    }
+
+    return return_val;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
