@@ -1,6 +1,7 @@
 #ifndef _TRANSACTION_LIST_H
 #define _TRANSACTION_LIST_H (1)
 
+#include <gtk/gtk.h>
 
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
@@ -16,6 +17,8 @@ gint transaction_list_get_n_children ( gint transaction_number );
 gboolean transaction_list_get_variance ( gint transaction_number );
 gboolean transaction_list_redraw ( void );
 gboolean transaction_list_remove_archive ( gint archive_number );
+gboolean transaction_list_remove_archive_line ( gint archive_number,
+                        gint account_number );
 gboolean transaction_list_remove_transaction ( gint transaction_number );
 void transaction_list_set ( GtkTreeIter *iter, ... );
 void transaction_list_set_balances ( void );
