@@ -3,7 +3,7 @@
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2003-2004 Alain Portal (aportal@univ-montp2.fr)                   */
 /*          2003-2004 Francois Terrot (francois.terrot@grisbi.org)            */
-/*          2008-2010 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          2008-2012 Pierre Biava (grisbi@pierre.biava.name)                 */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -27,16 +27,17 @@
 #endif
 
 #include "include.h"
-
+#include <stdlib.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
-#include "utils.h"
-#include "dialog.h"
+ #include "dialog.h"
+#include "gsb_color.h"
 #include "gsb_data_account.h"
 #include "gsb_file_config.h"
 #include "structures.h"
-#include "utils_str.h"
 #include "erreur.h"
+#include "gsb_dirs.h"
 /*END_INCLUDE*/
 
 #ifdef GTKOSXAPPLICATION
@@ -48,7 +49,6 @@
 
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -184,7 +184,7 @@ gboolean lance_navigateur_web ( const gchar *url )
     {
         use_default_browser = !strcmp ( conf.browser_command,ETAT_WWW_BROWSER );
     }
-    
+
 #else /* _WIN32 */
     if ( !( conf.browser_command && strlen ( conf.browser_command ) ) )
     {
@@ -222,7 +222,7 @@ gboolean lance_navigateur_web ( const gchar *url )
             chaine = tmp_str;
         }
         else
-            chaine = g_strconcat ( conf.browser_command, " ", url, "&", NULL ); 
+            chaine = g_strconcat ( conf.browser_command, " ", url, "&", NULL );
 
         if ( system ( chaine ) == -1 )
         {
@@ -256,12 +256,12 @@ gboolean lance_navigateur_web ( const gchar *url )
  * \param fill Give all available space to padding box or not
  * \param title Title to display on top of the paddingbox
  */
-GtkWidget *new_paddingbox_with_title (GtkWidget * parent, gboolean fill, const gchar *title)
+GtkWidget *new_paddingbox_with_title (GtkWidget *parent, gboolean fill, const gchar *title)
 {
     GtkWidget *vbox, *hbox, *paddingbox, *label;
 	gchar* tmp_str;
 
-    vbox = gtk_vbox_new ( FALSE, 0 );
+    vbox = gtk_vbox_new ( FALSE, 6 );
     if ( GTK_IS_BOX(parent) )
     {
 	gtk_box_pack_start ( GTK_BOX ( parent ), vbox,
@@ -309,17 +309,17 @@ GtkWidget *new_paddingbox_with_title (GtkWidget * parent, gboolean fill, const g
 /**
  * Function that makes a nice title with an optional icon.  It is
  * mainly used to automate preference tabs with titles.
- * 
+ *
  * \param title Title that will be displayed in window
  * \param filename (relative or absolute) to an image in a file format
  * recognized by gtk_image_new_from_file().  Use NULL if you don't
  * want an image to be displayed
- * 
+ *
  * \returns A pointer to a vbox widget that will contain all created
  * widgets and user defined widgets
  */
-GtkWidget *new_vbox_with_title_and_icon ( gchar * title,
-                        gchar * image_filename)
+GtkWidget *new_vbox_with_title_and_icon ( gchar *title,
+                        gchar *image_filename)
 {
     GtkWidget *vbox_pref, *hbox, *label, *image, *eb;
     GtkStyle * style;
@@ -344,7 +344,7 @@ GtkWidget *new_vbox_with_title_and_icon ( gchar * title,
     /* Icon */
     if ( image_filename )
     {
-	gchar* tmpstr = g_build_filename ( GRISBI_PIXMAPS_DIR,
+	gchar* tmpstr = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ),
 					  image_filename, NULL);
 	image = gtk_image_new_from_file (tmpstr);
 	g_free(tmpstr);
@@ -372,11 +372,11 @@ GtkWidget *new_vbox_with_title_and_icon ( gchar * title,
 /**
  * Function that makes a nice title with an optional icon.  It is
  * mainly used to automate preference tabs with titles.
- * 
+ *
  * \param title Title that will be displayed in window
  * \param image.  Use NULL if you don't want an image to be displayed
- * 
- * 
+ *
+ *
  * \returns A pointer to a vbox widget that will contain all created
  * widgets and user defined widgets
  */
@@ -441,21 +441,19 @@ gboolean assert_account_loaded ()
 
 
 
-
-
-/******************************************************************************/
-/* cette fonction rafraichit l'écran pendant les traitements d'information */
-/******************************************************************************/
-void update_ecran ( void )
+/**
+ * Function to explicitly update window "outside gtk_main ( )"
+ * For example during computations
+ *
+ * \return
+ */
+void update_gui ( void )
 {
-    devel_debug (NULL);
-
-    while ( g_main_iteration (FALSE));
+    while ( g_main_context_iteration ( NULL, FALSE ) );
 }
-/******************************************************************************/
 
 
-void register_button_as_linked ( GtkWidget * widget, GtkWidget * linked )
+void register_button_as_linked ( GtkWidget *widget, GtkWidget *linked )
 {
     GSList * links;
 
@@ -472,7 +470,7 @@ void register_button_as_linked ( GtkWidget * widget, GtkWidget * linked )
  *
  *
  */
-gboolean radio_set_active_linked_widgets ( GtkWidget * widget )
+gboolean radio_set_active_linked_widgets ( GtkWidget *widget )
 {
     GSList * links;
 
@@ -480,7 +478,7 @@ gboolean radio_set_active_linked_widgets ( GtkWidget * widget )
 
     while ( links )
     {
-	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON(links -> data), 
+	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON(links -> data),
 				       gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( widget ) ) );
 	links = links -> next;
     }
@@ -488,50 +486,23 @@ gboolean radio_set_active_linked_widgets ( GtkWidget * widget )
     return FALSE;
 }
 
+
 /**
- *  Cette fonction renvoie une string de la version de GTK
+ * Get the string of the running GTK version.
+ * Must be freed when no longer used
+ *
+ * \return string
  */
 gchar *get_gtk_run_version ( void )
 {
-	gchar *version = NULL;
+    gchar *version = NULL;
 
-   	version = g_strconcat( utils_str_itoa ( (guint) gtk_major_version ), ".",
-                        utils_str_itoa ( (guint) gtk_minor_version ), ".", 
-                        utils_str_itoa ( (guint) gtk_micro_version ),
-                        NULL);
-	return version;
-}
+    version = g_strdup_printf ( "%d.%d.%d",
+                                gtk_major_version,
+                                gtk_minor_version,
+                                gtk_micro_version );
 
-
-/**
- *
- *
- *
- *
- * */
-gchar *utils_get_pixmaps_dir ( void )
-{
-#ifdef GTKOSXAPPLICATION
-    return grisbi_osx_get_pixmaps_dir ( );
-#else
-    return PIXMAPS_DIR;
-#endif
-}
-
-
-/**
- *
- *
- *
- *
- * */
-gchar *utils_get_plugins_dir ( void )
-{
-#ifdef GTKOSXAPPLICATION
-    return grisbi_osx_get_plugins_dir ( );
-#else
-    return PLUGINS_DIR;
-#endif
+    return version;
 }
 
 
@@ -562,6 +533,227 @@ void lance_mailer ( const gchar *uri )
     g_free ( chaine );
 }
 
+
+/**
+ * positionne les couleurs pour les tree_view
+ *
+ *\param tree_view
+ *
+ * */
+void utils_set_tree_view_selection_and_text_color ( GtkWidget *tree_view )
+{
+    gtk_widget_modify_base ( tree_view, GTK_STATE_SELECTED, gsb_color_get_couleur ( "couleur_selection" ) );
+    gtk_widget_modify_base ( tree_view, GTK_STATE_ACTIVE, gsb_color_get_couleur ( "couleur_selection" ) );
+
+    gtk_widget_modify_text ( tree_view, GTK_STATE_SELECTED, gsb_color_get_couleur_with_indice ( "text_color", 0 ) );
+    gtk_widget_modify_text ( tree_view, GTK_STATE_ACTIVE, gsb_color_get_couleur_with_indice ( "text_color", 0 ) );
+}
+
+
+/**
+ * set the background colors of the list
+ *
+ * \param tree_view
+ * \param n° de colonne
+ *
+ * \return FALSE
+ * */
+gboolean utils_set_tree_view_background_color ( GtkWidget *tree_view, gint color_column )
+{
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+
+    if ( !tree_view )
+        return FALSE;
+
+    model = gtk_tree_view_get_model ( GTK_TREE_VIEW ( tree_view ) );
+
+    if ( gtk_tree_model_get_iter_first ( GTK_TREE_MODEL ( model ), &iter ) )
+    {
+        gint current_color = 0;
+        GtkTreeIter fils_iter;
+        GtkTreePath *path;
+
+        do
+        {
+            gtk_tree_store_set ( GTK_TREE_STORE ( model ),
+                        &iter,
+                        color_column, gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
+                        -1 );
+
+            current_color = !current_color;
+            path = gtk_tree_model_get_path ( model, &iter );
+
+            if ( gtk_tree_model_iter_children ( GTK_TREE_MODEL ( model ), &fils_iter, &iter )
+             &&
+             gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path ) )
+            {
+                GtkTreeIter third_iter;
+
+                do
+                {
+                    gtk_tree_store_set ( GTK_TREE_STORE ( model ),
+                                &fils_iter,
+                                color_column, gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
+                                -1 );
+
+                    current_color = !current_color;
+                    gtk_tree_path_free ( path );
+                    path = gtk_tree_model_get_path ( model, &fils_iter );
+
+                    if ( gtk_tree_model_iter_children ( GTK_TREE_MODEL ( model ), &third_iter, &fils_iter )
+                     &&
+                     gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path ) )
+                    {
+                        do
+                        {
+                            gtk_tree_store_set ( GTK_TREE_STORE ( model ),
+                                        &third_iter,
+                                        color_column, gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
+                                        -1 );
+
+                            current_color = !current_color;
+                        }
+                        while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &third_iter ) );
+                    }
+                }
+                while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &fils_iter ) );
+            }
+
+            gtk_tree_path_free ( path );
+        }
+        while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &iter ) );
+    }
+
+    return FALSE;
+}
+
+
+/**
+ * crée un une image avec 2 états
+ *
+ * \param etat  0 = Warning 1 = OK
+ *
+ * \return      widget initialisé
+ * */
+GtkWidget *utils_get_image_with_etat ( GtkMessageType msg,
+                        gint initial,
+                        const gchar *tooltip_0,
+                        const gchar *tooltip_1 )
+{
+    GtkWidget *hbox;
+    GtkWidget *icon_0;
+    GtkWidget *icon_1;
+    GValue value = {0,};
+
+    g_value_init ( &value, G_TYPE_BOOLEAN );
+    g_value_set_boolean ( &value, TRUE );
+
+    hbox = gtk_hbox_new ( FALSE, 5 );
+    g_object_set_data ( G_OBJECT ( hbox ), "initial", GINT_TO_POINTER ( initial ) );
+
+    if ( msg == GTK_MESSAGE_WARNING )
+        icon_0 = gtk_image_new_from_stock ( GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_MENU );
+    else
+        icon_0 = gtk_image_new_from_stock ( GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_MENU );
+
+    g_object_set_property ( G_OBJECT ( icon_0 ), "no-show-all", &value );
+    if ( tooltip_0 )
+        gtk_widget_set_tooltip_text ( icon_0, tooltip_0 );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), icon_0, FALSE, FALSE, 0 );
+    g_object_set_data ( G_OBJECT ( hbox ), "icon_0", icon_0 );
+
+    icon_1 = gtk_image_new_from_stock ( GTK_STOCK_APPLY, GTK_ICON_SIZE_MENU );
+    g_object_set_property ( G_OBJECT ( icon_1 ), "no-show-all", &value );
+
+    if ( tooltip_1 )
+        gtk_widget_set_tooltip_text ( icon_1, tooltip_1 );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), icon_1, FALSE, FALSE, 0 );
+    g_object_set_data ( G_OBJECT ( hbox ), "icon_1", icon_1 );
+
+    if ( initial )
+        gtk_widget_show ( icon_1 );
+    else
+        gtk_widget_show ( icon_0 );
+
+    gtk_widget_show ( hbox );
+
+    /* return */
+    return hbox;
+}
+
+
+/**
+ * change l'icone du widget en fonction de etat
+ *
+ * \param etat  0 = Warning 1 = OK
+ *
+ * \return      TRUE if OK FALSE si rien à faire
+ * */
+gboolean utils_set_image_with_etat ( GtkWidget *widget,
+                        gint etat )
+{
+    GtkWidget *icon_0;
+    GtkWidget *icon_1;
+    GtkWidget *hbox;
+    gint initial;
+
+    hbox = g_object_get_data ( G_OBJECT ( widget ), "icon" );
+
+    initial = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( hbox ), "initial" ) );
+    if ( initial == etat )
+        return FALSE;
+
+    /* on met la nouvelle valeur pour initial */
+    g_object_set_data ( G_OBJECT ( hbox ), "initial", GINT_TO_POINTER ( etat ) );
+
+    icon_0 = g_object_get_data ( G_OBJECT ( hbox ), "icon_0" );
+    icon_1 = g_object_get_data ( G_OBJECT ( hbox ), "icon_1" );
+
+    if ( etat )
+    {
+        gtk_widget_hide ( icon_0 );
+        gtk_widget_show ( icon_1 );
+    }
+    else
+    {
+        gtk_widget_show ( icon_0 );
+        gtk_widget_hide ( icon_1 );
+    }
+
+    /* return */
+    return TRUE;
+}
+
+
+/**
+ * Deleting children of container
+ *
+ * \param widget    container with children
+ *
+ * \return          none
+ * */
+void utils_container_remove_children ( GtkWidget *widget )
+{
+    GList *children;
+
+    children = gtk_container_get_children ( GTK_CONTAINER ( widget ) );
+
+    if ( children && children -> data )
+    {
+        gtk_container_remove ( GTK_CONTAINER ( widget ), GTK_WIDGET ( children -> data ) );
+        g_list_free ( children );
+    }
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
