@@ -32,6 +32,7 @@
 #include "gsb_automem.h"
 #include "structures.h"
 #include "utils.h"
+#include "gsb_dirs.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -39,7 +40,6 @@
 
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -58,7 +58,7 @@ GtkWidget * new_stock_image_label ( GsbButtonStyle style, const gchar * stock_id
     }
     else if (style == GSB_BUTTON_BOTH_HORIZ )
     {
-        image = gtk_image_new_from_stock ( stock_id, 
+        image = gtk_image_new_from_stock ( stock_id,
                         GTK_ICON_SIZE_SMALL_TOOLBAR );
         gtk_box_pack_start ( GTK_BOX(hbox), image, TRUE, TRUE, 0 );
     }
@@ -92,7 +92,10 @@ GtkWidget * new_stock_image_label ( GsbButtonStyle style, const gchar * stock_id
 
 GtkWidget * new_image_label ( GsbButtonStyle style, const gchar * image_name, const gchar * name )
 {
-    GtkWidget * vbox, *hbox, * label, * image;
+    GtkWidget *vbox;
+    GtkWidget *hbox;
+    GtkWidget *label = NULL;
+    GtkWidget *image;
 
     vbox = gtk_vbox_new ( FALSE, 0 );
     hbox = gtk_hbox_new ( FALSE, 0 );
@@ -100,13 +103,13 @@ GtkWidget * new_image_label ( GsbButtonStyle style, const gchar * image_name, co
     /* Define image */
     if ( style == GSB_BUTTON_ICON || style == GSB_BUTTON_BOTH )
     {
-	image = gtk_image_new_from_file (g_build_filename ( GRISBI_PIXMAPS_DIR,
+	image = gtk_image_new_from_file (g_build_filename ( gsb_dirs_get_pixmaps_dir ( ),
 							   image_name, NULL));
 	gtk_box_pack_start ( GTK_BOX(vbox), image, TRUE, TRUE, 0 );
     }
     else if (style == GSB_BUTTON_BOTH_HORIZ )
     {
-        image = gtk_image_new_from_file (g_build_filename ( GRISBI_PIXMAPS_DIR,
+        image = gtk_image_new_from_file (g_build_filename ( gsb_dirs_get_pixmaps_dir ( ),
 							   image_name, NULL));
         gtk_box_pack_start ( GTK_BOX(hbox), image, TRUE, TRUE, 0 );
     }
@@ -135,6 +138,9 @@ GtkWidget * new_image_label ( GsbButtonStyle style, const gchar * image_name, co
     }
     gtk_widget_show_all ( vbox );
 
+    /* permettra de changer le label du bouton */
+    g_object_set_data ( G_OBJECT ( vbox ), "label", label );
+
     return vbox;
 }
 
