@@ -28,16 +28,18 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "utils_files.h"
 #include "dialog.h"
-#include "utils_file_selection.h"
 #include "go-charmap-sel.h"
+#include "gsb_dirs.h"
 #include "gsb_file.h"
-#include "utils_str.h"
 #include "gsb_file_config.h"
+#include "structures.h"
+#include "utils_file_selection.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -57,7 +59,6 @@ static void utils_files_go_charmap_sel_changed ( GtkWidget *go_charmap_sel,
 
 /*START_EXTERN*/
 extern gchar *charmap_imported;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -186,7 +187,7 @@ void browse_file ( GtkButton *button, gpointer data )
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_selector),
 					 gsb_file_get_last_path ());
     gtk_window_set_transient_for ( GTK_WINDOW ( file_selector ),
-				   GTK_WINDOW ( window ));
+				   GTK_WINDOW ( run.window ));
     gtk_window_set_modal ( GTK_WINDOW ( file_selector ), TRUE );
 
     switch ( gtk_dialog_run ( GTK_DIALOG (file_selector)))
@@ -202,75 +203,6 @@ void browse_file ( GtkButton *button, gpointer data )
     }
 }
 
-/**
- * return the absolute path of where the configuration file should be located
- * on Un*x based system return $HOME
- * on Windows based systems return APPDATA\Grisbi
- * 
- * \return the absolute path of the configuration file directory
- */
-gchar* my_get_grisbirc_dir(void)
-{
-#ifndef _WIN32
-    return (gchar *) g_get_home_dir ();
-#else
-    return win32_get_grisbirc_folder_path();
-#endif
-}
-
-
-/**
- * return the absolute path of where the configuration file should be located
- * On UNIX platforms this is determined using the mechanisms described 
- * in the  XDG Base Directory Specification
- * on Windows based systems return APPDATA\Grisbi
- * 
- * \return the absolute path of the configuration file directory
- */
-gchar* my_get_XDG_grisbirc_dir(void)
-{
-#ifndef _WIN32
-    return (gchar *) C_PATH_CONFIG;
-#else
-    return win32_get_grisbirc_folder_path();
-#endif
-}
-
-
-/**
- * return the absolute path of where the data files should be located
- * On UNIX platforms this is determined using the mechanisms described 
- * in the  XDG Base Directory Specification
- * on Windows based systems return APPDATA\Grisbi
- * 
- * \return the absolute path of the home directory
- */
-gchar* my_get_XDG_grisbi_data_dir ( void )
-{
-#ifndef _WIN32
-    return (gchar *) C_PATH_DATA_FILES;
-#else
-    return g_get_home_dir ();
-#endif
-}
-
-/**
- * return the absolute path of the default accounts files location
- * on Un*x based system return $HOME
- * on Windows based systems return "My Documents"
- * 
- * \return the absolute path of the configuration file directory
- */
-gchar* my_get_gsb_file_default_dir ( void )
-{
-#ifndef _WIN32
-    return (gchar *) g_get_home_dir();
-#else
-    return win32_get_my_documents_folder_path();
-#endif
-}
-
-
 
 /* get the line af the file,
  * convert it in UTF8 and fill string with that line
@@ -293,7 +225,7 @@ gint get_utf8_line_from_file ( FILE *fichier,
 
     if ( !fichier )
 	return 0;
-	    
+
     /* allocate 30 characters, and increase it 30 by 30 */
     pointeur_char = (gchar*)g_realloc(pointeur_char,30*sizeof(gchar));
 
@@ -336,7 +268,7 @@ gint get_utf8_line_from_file ( FILE *fichier,
 	}
     }
 
-    tmp_string = g_convert ( pointeur_char, -1, "UTF-8", 
+    tmp_string = g_convert ( pointeur_char, -1, "UTF-8",
 			     coding_system, NULL, NULL,
 			     NULL );
     if (!tmp_string)
@@ -345,10 +277,10 @@ gint get_utf8_line_from_file ( FILE *fichier,
         tmp_string = latin2utf8 (pointeur_char);
         if ( tmp_string == NULL )
         {
-            dialogue_special ( GTK_MESSAGE_ERROR, make_hint (
-                            _("Convert to utf8 failed."),
+            dialogue_error_hint (
                             _("If the result is not correct, try again by selecting the "
-                            "correct character set in the window for selecting files.") ) );
+                            "correct character set in the window for selecting files."),
+                            _("Convert to utf8 failed.") );
             return 0;
         }
     }
@@ -362,34 +294,9 @@ gint get_utf8_line_from_file ( FILE *fichier,
 }
 
 
-/**
- * Make a GtkEntry that will contain a file name, a GtkButton that
- * will pop up a file selector, pack them in a GtkHbox and return it.
- *
- * \return A newly created GtkHbox.
- */
-GtkWidget * my_file_chooser ()
-{
-    GtkWidget * hbox, *entry, *button;
-
-    hbox = gtk_hbox_new ( FALSE, 6 );
-
-    entry = gtk_entry_new ( );
-    gtk_box_pack_start ( GTK_BOX(hbox), entry, TRUE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT(hbox), "entry", entry );
-
-    button = gtk_button_new_with_label ( _("Browse") );
-    gtk_box_pack_start ( GTK_BOX(hbox), button, FALSE, FALSE, 0 );
-
-    g_signal_connect ( G_OBJECT(button), "clicked",
-		       (GCallback) browse_file, entry );
-
-    return hbox;
-}
-
 /**
  * \brief utf8 version of fopen (see fopen for more detail about mode)
- * 
+ *
  * convert utf8 file path into the locale OS charset before calling fopen
  *
  * \param utf8filename file to open path coded using utf8 charset
@@ -397,7 +304,7 @@ GtkWidget * my_file_chooser ()
  *
  * \return file descriptor returned by fopen
  */
-G_MODULE_EXPORT FILE* utf8_fopen (const gchar *utf8filename, gchar *mode )
+FILE* utf8_fopen (const gchar *utf8filename, gchar *mode )
 {
 #ifdef _MSC_VER
     return fopen ( g_locale_from_utf8 ( utf8filename, -1, NULL, NULL, NULL ), mode );
@@ -409,7 +316,7 @@ G_MODULE_EXPORT FILE* utf8_fopen (const gchar *utf8filename, gchar *mode )
 
 /**
  * \brief utf8 version of remove (see remove for more detail about mode)
- * 
+ *
  * convert utf8 file path into the locale OS charset before calling remove
  *
  * \param utf8filename file to remove path coded using utf8 charset
@@ -425,7 +332,7 @@ gint utf8_remove ( const gchar *utf8filename )
 #endif
 }
 
-/** 
+/**
  * Sanitize a safe filename.  All chars that are not normally allowed
  * are replaced by underscores.
  *
@@ -437,7 +344,7 @@ gchar *safe_file_name ( gchar *filename )
 }
 
 
-/** 
+/**
  * \brief pallie à un bug du gtk_file_chooser_button_new
  *
  * \param widget parent et titre de la femnêtre
@@ -448,7 +355,7 @@ GtkWidget *utils_files_create_file_chooser ( GtkWidget *parent, gchar *titre )
 {
     GtkWidget *chooser;
     GtkWidget *bouton_cancel, *bouton_OK;
-    
+
     chooser = gtk_file_chooser_dialog_new ( titre,
                         GTK_WINDOW (parent),
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
@@ -474,8 +381,8 @@ GtkWidget *utils_files_create_file_chooser ( GtkWidget *parent, gchar *titre )
 }
 
 
-/** 
- * \brief permet de pallier au bug de l'annulation du 
+/**
+ * \brief permet de pallier au bug de l'annulation du
  * gtk_file_chooser_button_new
  *
  * \param bouton appellant et chooser
@@ -492,11 +399,11 @@ void utils_files_file_chooser_cancel ( GtkWidget *bouton, GtkWidget *chooser)
 }
 
 
-/** 
+/**
  * \brief create the config and the data directories
  * using the mechanisms described in the XDG Base Directory Specification
  *
- * \param 
+ * \param
  *
  * \return TRUE if ok
  */
@@ -507,8 +414,8 @@ gboolean utils_files_create_XDG_dir ( void )
 #else
     int mode = S_IRUSR | S_IWUSR | S_IXUSR;
 #endif /*_MSC_VER */
-    if ( g_mkdir_with_parents ( C_PATH_CONFIG, mode ) == 0 &&
-         g_mkdir_with_parents ( C_PATH_DATA_FILES, mode ) == 0 )
+    if ( g_mkdir_with_parents ( gsb_dirs_get_user_config_dir (), mode ) == 0 &&
+         g_mkdir_with_parents ( gsb_dirs_get_user_data_dir (), mode ) == 0 )
         return TRUE;
     else
         return FALSE;
@@ -517,7 +424,7 @@ gboolean utils_files_create_XDG_dir ( void )
 
 /**
  * Test if converting a string to UTF8 is correct with different character sets
- * 
+ *
  * \param contents
  * \param coding_system
  *
@@ -536,7 +443,7 @@ GSList *utils_files_check_UTF8_validity ( const gchar *contents,
     gchar *ptr;
 
     ptr = (gchar *) contents;
-    
+
     while ( strlen ( ptr ) > 0 )
     {
         gchar *ptr_tmp;
@@ -634,7 +541,7 @@ gchar *utils_files_create_sel_charset ( GtkWidget *assistant,
 
     label = gtk_label_new ( NULL );
     tmpstr = g_strdup_printf ( _("You are here because your file"
-                        " can't be imported directly into grisbi.\n%s"),
+                        " can't be imported directly into Grisbi.\n%s"),
                         filename );
     gtk_label_set_markup ( GTK_LABEL ( label ),
                         make_pango_attribut ( "weight=\"bold\"",tmpstr ) );
@@ -687,7 +594,7 @@ gchar *utils_files_create_sel_charset ( GtkWidget *assistant,
 
     /* select an other encoding */
     label = gtk_label_new ( _("If no proposals above are correct you can choose a "
-                        "different charset") );
+                        "different charset.") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), label, TRUE, TRUE, 0 );
@@ -715,7 +622,7 @@ gchar *utils_files_create_sel_charset ( GtkWidget *assistant,
     {
         GSList *tmp_list;
         struct struc_check_encoding *result;
-            
+
         tmp_list = list;
         result = tmp_list -> data;
         g_object_set_data_full ( G_OBJECT ( dialog ), "charset_str",
@@ -724,9 +631,9 @@ gchar *utils_files_create_sel_charset ( GtkWidget *assistant,
         while ( tmp_list )
         {
             struct struc_check_encoding *result;
-            
+
             result = tmp_list -> data;
-            
+
             gtk_list_store_append ( GTK_LIST_STORE ( model ), &iter );
             gtk_list_store_set ( GTK_LIST_STORE ( model ), &iter,
                         IMPORT_CHARMAP_ENCODING, result -> charset,
@@ -824,7 +731,7 @@ void utils_files_go_charmap_sel_changed ( GtkWidget *go_charmap_sel,
         gtk_label_set_text ( GTK_LABEL ( label ), _("Select a charset") );
         return;
     }
-    
+
     contents = g_object_get_data ( G_OBJECT ( dialog ), "charset_str" );
     string = g_convert ( contents, -1, "UTF-8", encoding, NULL, NULL, NULL );
     if ( string )
@@ -838,7 +745,7 @@ void utils_files_go_charmap_sel_changed ( GtkWidget *go_charmap_sel,
     {
         gtk_label_set_text ( GTK_LABEL ( label ), "");
         gtk_label_set_markup ( GTK_LABEL ( label ),
-                        make_red ( _("The conversion failed try another set of characters") ) );
+                        make_red ( _("The conversion failed, try another set of characters") ) );
         gtk_dialog_set_response_sensitive   ( GTK_DIALOG ( dialog ), GTK_RESPONSE_OK, FALSE );
     }
 }
@@ -857,7 +764,7 @@ gchar *utils_files_get_ofx_charset ( gchar *contents )
     gint i = 0;
 
     ptr = (gchar *) contents;
-    
+
     while ( strlen ( ptr ) > 0 )
     {
         gchar *ptr_tmp;
