@@ -28,11 +28,17 @@
 
 #include "include.h"
 #include <stdlib.h>
+#include <string.h>
+#include <ctype.h>
+#include <glib/gstdio.h>
 
 /*START_INCLUDE*/
 #include "utils_str.h"
 #include "gsb_data_report.h"
 #include "gsb_data_currency.h"
+#include "gsb_locale.h"
+#include "gsb_real.h"
+#include "utils_real.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -41,23 +47,18 @@ static gchar * gsb_string_truncate_n ( gchar * string, int n, gboolean hard_trun
 /*END_STATIC*/
 
 
-/*START_EXTERN*/
-extern gsb_real error_real;
-/*END_EXTERN*/
-
-
 /**
  * @brief convert an integer into a gchar based string
- * 
- * 
+ *
+ *
  * @param integer   integer to convert
- * 
+ *
  * @return  a newly allocated string
- * 
+ *
  * @caveats You have to unallocate the returned string when you no more use it to save memory
  *
  * @todo: check usage of this function which a cause of memory leak
- * 
+ *
  * */
 gchar *utils_str_itoa ( gint integer )
 {
@@ -67,14 +68,14 @@ gchar *utils_str_itoa ( gint integer )
     gint num;
 
     chaine = g_malloc0 ( 11*sizeof (gchar) );
-    
+
     num = abs(integer);
 
     /* Construct the result in the reverse order from right to left, then reverse it. */
     do
     {
 	result_div = div ( num, 10 );
-	chaine[i] = result_div.rem + '0'; 
+	chaine[i] = result_div.rem + '0';
 	i++;
     }
     while ( ( num = result_div.quot ));
@@ -85,7 +86,7 @@ gchar *utils_str_itoa ( gint integer )
     {
         chaine[i++] = '-';
     }
-    
+
     chaine[i] = 0;
 
     g_strreverse ( chaine );
@@ -166,7 +167,7 @@ gchar *utils_str_reduce_exponant_from_string ( const gchar *amount_string,
 
 
 /**
- * locates the decimal dot 
+ * locates the decimal dot
  *
  *
  *
@@ -179,8 +180,8 @@ gchar *utils_str_localise_decimal_point_from_string ( const gchar *string )
     gchar *mon_separateur;
     gchar **tab;
 
-    mon_decimal_point = gsb_real_get_decimal_point ( );
-    mon_separateur = gsb_real_get_thousands_sep ( );
+    mon_decimal_point = gsb_locale_get_mon_decimal_point ( );
+    mon_separateur = gsb_locale_get_mon_thousands_sep ( );
 
     if ( ( ptr_1 = g_strstr_len ( string, -1, "," ) )
      &&
@@ -225,16 +226,16 @@ gchar *utils_str_localise_decimal_point_from_string ( const gchar *string )
 
 /**
  * @brief Secured version of atoi
- * 
+ *
  * Encapsulated call of atoi which may crash when it is call with a NULL pointer.
- * 
+ *
  * @param chaine   pointer to the buffer containing the string to convert
- * 
+ *
  * @return  the converted string as interger
  * @retval  0 when the pointer is NULL or the string empty.
- * 
+ *
  * */
-G_MODULE_EXPORT gint utils_str_atoi ( const gchar *chaine )
+gint utils_str_atoi ( const gchar *chaine )
 {
     if ((chaine )&&(*chaine))
     {
@@ -253,7 +254,7 @@ G_MODULE_EXPORT gint utils_str_atoi ( const gchar *chaine )
  *
  *
  * */
-G_MODULE_EXPORT gchar * latin2utf8 ( const gchar * inchar)
+gchar * latin2utf8 ( const gchar * inchar)
 {
     return g_locale_from_utf8 ( inchar, -1, NULL, NULL, NULL );
 }
@@ -315,7 +316,7 @@ gint my_strcmp ( gchar *string_1, gchar *string_2 )
 	{
 	    gint retour;
  	    gchar *new_1, *new_2;
-	    
+
 	    new_1 = g_utf8_collate_key ( string_1, -1 );
 	    new_2 = g_utf8_collate_key ( string_2, -1 );
 	    retour = strcmp ( new_1, new_2 );
@@ -340,7 +341,8 @@ gint my_strcmp ( gchar *string_1, gchar *string_2 )
  *
  * \return -1 string_1 before string_2 (or string_2 NULL) ; 0 if same or NULL everyone ; +1 if string_1 after string_2 (or string_1 NULL)
  * */
-gint my_strcasecmp ( const gchar *string_1, const gchar *string_2 )
+gint my_strcasecmp ( const gchar *string_1,
+                        const gchar *string_2 )
 {
     if (!string_1 && string_2)
 	    return 1;
@@ -355,13 +357,11 @@ gint my_strcasecmp ( const gchar *string_1, const gchar *string_2 )
         {
             gint retour;
             gchar *new_1, *new_2;
-            
-            new_1 = g_utf8_collate_key ( g_utf8_casefold ( string_1,-1 ),
-                         -1 );
-            new_2 = g_utf8_collate_key ( g_utf8_casefold (  string_2,-1 ),
-                         -1 );
-            retour = strcmp ( new_1,
-                      new_2 );
+
+            new_1 = g_utf8_casefold ( string_1, -1 );
+            new_2 = g_utf8_casefold (  string_2, -1 );
+            retour = g_utf8_collate ( new_1, new_2);
+
             g_free ( new_1 );
             g_free ( new_2 );
             return ( retour );
@@ -397,7 +397,7 @@ gint my_strncasecmp ( gchar *string_1,
         {
             gint retour;
             gchar *new_1, *new_2;
-            
+
             new_1 = g_utf8_casefold ( string_1,longueur );
             new_2 = g_utf8_casefold (  string_2,longueur );
             retour = g_utf8_collate ( new_1, new_2);
@@ -416,17 +416,17 @@ gint my_strncasecmp ( gchar *string_1,
 
 /**
  * Protect the my_strdup function if the string is NULL
- * 
+ *
  * If the length of string is 0 (ie ""), return NULL.  That is just
  * nonsense, but it has been done that way and disabling it would
  * certainly cause side effects. [benj]
  *
  * \param string the string to be dupped
  *
- * \return a newly allocated string (which is a copy of that string) 
- * or NULL if the parameter is NULL or an empty string. 
+ * \return a newly allocated string (which is a copy of that string)
+ * or NULL if the parameter is NULL or an empty string.
  * */
-G_MODULE_EXPORT gchar *my_strdup ( const gchar *string )
+gchar *my_strdup ( const gchar *string )
 {
     if ( string && strlen (string) )
 	return g_strdup (string);
@@ -565,7 +565,7 @@ GSList *gsb_string_get_string_list_from_string ( const gchar *string,
 
 /**
  * return a gslist of struct_categ_budget_sel
- * from a string as no_categ/no_sub_categ/no_sub_categ/no_sub_categ-no_categ/no_sub_categ... 
+ * from a string as no_categ/no_sub_categ/no_sub_categ/no_sub_categ-no_categ/no_sub_categ...
  * (or idem with budget)
  *
  * \param string	the string we want to change to a list
@@ -654,7 +654,7 @@ gchar * gsb_string_truncate_n ( gchar * string, int n, gboolean hard_trunc )
 
     if ( strlen(string) < n )
 	return my_strdup ( string );
-    
+
     tmp = string + n;
     if ( ! hard_trunc && ! ( tmp = strchr ( tmp, ' ' ) ) )
     {
@@ -662,7 +662,7 @@ gchar * gsb_string_truncate_n ( gchar * string, int n, gboolean hard_trunc )
 	   UTF-8 accent ... the end is probably near btw. */
 	return my_strdup ( string );
     }
-    else 
+    else
     {
 	while ( ! isascii(*tmp) && *tmp )
 	    tmp++;
@@ -707,7 +707,7 @@ gchar * gsb_string_remplace_string ( gchar *str, gchar *old_str, gchar *new_str
 
 
 /**
- * recherche des mots séparés par des jokers "%*" dans une chaine 
+ * recherche des mots séparés par des jokers "%*" dans une chaine
  *
  * \param haystack
  * \param needle
@@ -721,7 +721,7 @@ gboolean gsb_string_is_trouve ( const gchar *payee_name, const gchar *needle )
     gint i;
     gboolean is_prefix = FALSE, is_suffix = FALSE;
 
-    if ( g_strstr_len ( needle, -1, "%" ) == NULL && 
+    if ( g_strstr_len ( needle, -1, "%" ) == NULL &&
                         g_strstr_len ( needle, -1, "*" ) == NULL )
     {
         if ( my_strcasecmp ( payee_name, needle ) == 0 )
@@ -793,9 +793,13 @@ gboolean gsb_string_is_trouve ( const gchar *payee_name, const gchar *needle )
 gchar * gsb_string_remplace_joker ( const gchar *chaine, gchar *new_str )
 {
     gchar **tab_str;
+    gchar *result;
 
     tab_str = g_strsplit_set ( chaine, "%*", 0 );
-    return g_strjoinv ( new_str, tab_str );
+    result = g_strjoinv ( new_str, tab_str );
+    g_strfreev ( tab_str );
+
+    return result;
 }
 
 
@@ -809,15 +813,19 @@ gchar * gsb_string_remplace_joker ( const gchar *chaine, gchar *new_str )
 gchar *gsb_string_supprime_joker ( const gchar *chaine )
 {
     gchar **tab_str;
+    gchar *result;
 
     tab_str = g_strsplit_set ( chaine, "%*", 0 );
-    return g_strjoinv ( "", tab_str );
+    result = g_strjoinv ( "", tab_str );
+    g_strfreev ( tab_str );
+
+    return result;
 }
 
 
 /*
  * extrait un nombre d'une chaine
- * 
+ *
  * \param chaine
  *
  * \return guint
@@ -858,7 +866,8 @@ gchar *gsb_string_extract_int ( const gchar *chaine )
  */
 gchar *gsb_string_uniform_new_line ( const gchar *chaine, gint nbre_char )
 {
-    gchar **tab_str;
+    gchar **tab_str = NULL;
+    gchar *result = NULL;
 
     if ( chaine == NULL )
         return NULL;
@@ -866,19 +875,20 @@ gchar *gsb_string_uniform_new_line ( const gchar *chaine, gint nbre_char )
     if ( g_strstr_len ( chaine, nbre_char, "\r\n" ) )
     {
         tab_str = g_strsplit_set ( chaine, "\r", 0 );
-        return g_strjoinv ( "", tab_str );
+        result = g_strjoinv ( "", tab_str );
     }
-    else if ( g_strstr_len ( chaine, nbre_char, "\r" ) 
-     && 
+    else if ( g_strstr_len ( chaine, nbre_char, "\r" )
+     &&
      !g_strstr_len ( chaine, nbre_char, "\n" ) )
     {
         tab_str = g_strsplit_set ( chaine, "\r", 0 );
-        return g_strjoinv ( "\n", tab_str );
+        result = g_strjoinv ( "\n", tab_str );
     }
     else if ( g_strstr_len ( chaine, nbre_char, "\n" ) )
-        return g_strdup ( chaine );
-    else
-        return NULL;
+        result = g_strdup ( chaine );
+
+    g_strfreev ( tab_str );
+    return result;
 }
 
 
@@ -948,7 +958,7 @@ gdouble utils_str_strtod ( const gchar *str_number, gchar **endptr )
     if ( str_number == NULL )
         return 0.0;
 
-    real = gsb_real_get_from_string ( str_number );
+    real = utils_real_get_from_string ( str_number );
 
     number = gsb_real_real_to_double ( real );
 
@@ -999,7 +1009,7 @@ gchar *utils_str_incremente_number_from_str ( const gchar *str_number, gint incr
         }
         if ( i > 0 )
             prefix = g_strndup ( str_number, i );
-    
+
         number = utils_str_atoi ( str_number );
     }
 
@@ -1017,54 +1027,6 @@ gchar *utils_str_incremente_number_from_str ( const gchar *str_number, gint incr
 }
 
 
-/**
- * Return the real in a formatted string with an optional currency
- * symbol, according to the locale regarding decimal separator,
- * thousands separator and positive or negative sign.
- *
- * \param number		Number to format.
- * \param currency_number 	the currency we want to adapt the number, 0 for no adaptation
- * \param show_symbol 		TRUE to add the currency symbol in the string
- *
- * \return		A newly allocated string of the number (this
- *			function will never return NULL)
- */
-gchar *gsb_real_get_string_with_currency ( gsb_real number,
-                        gint currency_number,
-                        gboolean show_symbol )
-{
-    struct lconv *conv = localeconv ();
-    gint floating_point;
-
-    const gchar *currency_symbol = (currency_number && show_symbol)
-                                   ? gsb_data_currency_get_code_or_isocode (currency_number)
-                                   : NULL;
-
-    /* First of all if number = 0 I return 0 with the symbol of the currency if necessary */
-    if (number.mantissa == 0)
-    {
-        if (currency_symbol && conv -> p_cs_precedes)
-            return g_strdup_printf ( "%s %s", currency_symbol, "0" );
-        else if (currency_symbol && ! conv -> p_cs_precedes)
-            return g_strdup_printf ( "%s %s", "0", currency_symbol );
-        else
-            return g_strdup ("0");
-    }
-    else if ( (number.exponent < 0)
-    || (number.exponent > EXPONENT_MAX )
-    || (number.mantissa == error_real.mantissa) )
-        return g_strdup ( ERROR_REAL_STRING );
-
-    /* first we need to adapt the exponent to the currency */
-    /* if the exponent of the real is not the same of the currency, need to adapt it */
-    floating_point = gsb_data_currency_get_floating_point ( currency_number );
-    if ( currency_number && number.exponent != floating_point )
-        number = gsb_real_adjust_exponent ( number, floating_point );
-
-    return gsb_real_raw_format_string ( number, conv, currency_symbol );
-}
-
-
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
